(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('react'), require('react-native'), require('react-native/Libraries/Image/resolveAssetSource')) :
  typeof define === 'function' && define.amd ? define(['exports', 'react', 'react-native', 'react-native/Libraries/Image/resolveAssetSource'], factory) :
  (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global["bootstrap-rn"] = {}, global.React, global.ReactNative, global.require$$12));
})(this, (function (exports, React, _reactNative, require$$12) { 'use strict';

  function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

  var React__default = /*#__PURE__*/_interopDefaultLegacy(React);
  var _reactNative__default = /*#__PURE__*/_interopDefaultLegacy(_reactNative);
  var require$$12__default = /*#__PURE__*/_interopDefaultLegacy(require$$12);

  const isRTL = () => {
    // To support previous RN versions. Newer versions use below getConstants()
    if (_reactNative.I18nManager.isRTL !== undefined) {
      return _reactNative.I18nManager.isRTL;
    } // @ts-ignore - RN web only


    if (_reactNative.I18nManager.getConstants) {
      // @ts-ignore - RN web only
      return _reactNative.I18nManager.getConstants().isRTL;
    }
  };

  const measureOffset = ref => new Promise(resolve => {
    if (ref.current) {
      ref.current.measureInWindow((x, y, width, height) => {
        resolve({
          top: y,
          left: x,
          width,
          height
        });
      });
    }
  });

  function useOverlayPosition(props) {
    let {
      targetRef,
      overlayRef,
      placement = 'bottom',
      offset = 0,
      crossOffset = 0,
      isOpen = true,
      shouldFlip = true,
      shouldOverlapWithTrigger = false
    } = props;
    let [position, setPosition] = React__default["default"].useState({
      position: {},
      arrowOffsetLeft: undefined,
      arrowOffsetTop: undefined,
      maxHeight: undefined,
      placement: undefined
    }); // Layout measurement happens asynchronously in RN. This causes initial flickr. Using opacity and setting it to 1 post calculation prevents that.

    let [rendered, setRendered] = React__default["default"].useState(false);

    let updatePosition = async () => {
      const [overlayOffset, triggerOffset] = await Promise.all([measureOffset(overlayRef), measureOffset(targetRef)]); // Sometimes measure returns height/width 0. Best solution would be to use onLayout callback, but that might diverege from React Aria's useOverlayPosition API. Decide later, this works for now

      if (!overlayOffset.width || !overlayOffset.height || !triggerOffset.width || !triggerOffset.height) {
        requestAnimationFrame(updatePosition);
        return;
      }

      const {
        height: windowHeight,
        width: windowWidth
      } = _reactNative.Dimensions.get('window');
      const positions = calculatePosition({
        placement: translateRTL(placement),
        targetNode: triggerOffset,
        overlayNode: overlayOffset,
        scrollNode: overlayOffset,
        padding: 0,
        shouldFlip,
        boundaryElement: {
          top: 0,
          left: 0,
          width: windowWidth,
          height: windowHeight
        },
        offset,
        crossOffset,
        shouldOverlapWithTrigger
      });
      setPosition(positions);
      setRendered(true);
    };

    React__default["default"].useEffect(() => {
      return () => {
        setRendered(false);
      };
    }, []);
    React__default["default"].useLayoutEffect(() => {
      updatePosition();
    }, [placement, isOpen, offset, shouldFlip, crossOffset, shouldOverlapWithTrigger]);
    const returnProps = {
      rendered,
      overlayProps: {
        style: { ...position.position
        }
      },
      placement: position.placement,
      arrowProps: {
        style: {
          left: position.arrowOffsetLeft,
          top: position.arrowOffsetTop
        }
      },
      updatePosition
    };

    if (position.maxHeight !== undefined) {
      //@ts-ignore
      returnProps.overlayProps.style.maxHeight = position.maxHeight;
    }

    return returnProps;
  }

  function translateRTL(position) {
    if (isRTL()) {
      return position.replace('start', 'right').replace('end', 'left');
    }

    return position.replace('start', 'left').replace('end', 'right');
  }

  const calculatePosition = opts => {
    let {
      placement,
      targetNode,
      overlayNode,
      scrollNode,
      padding,
      shouldFlip,
      boundaryElement,
      offset,
      crossOffset,
      shouldOverlapWithTrigger
    } = opts;
    let childOffset = targetNode;
    let isContainerPositioned = false;
    let overlaySize = overlayNode;
    let margins = {
      top: 0,
      bottom: 0,
      left: 0,
      right: 0
    };
    let scrollSize = scrollNode;
    let boundaryDimensions = boundaryElement;
    let containerOffsetWithBoundary = overlayNode;
    return calculatePositionInternal(placement, childOffset, overlaySize, scrollSize, margins, padding, shouldFlip, boundaryDimensions, containerOffsetWithBoundary, offset, crossOffset, isContainerPositioned, shouldOverlapWithTrigger);
  };

  function calculatePositionInternal(placementInput, childOffset, overlaySize, scrollSize, margins, padding, flip, boundaryDimensions, containerOffsetWithBoundary, offset, crossOffset, isContainerPositioned, shouldOverlapWithTrigger) {
    let placementInfo = parsePlacement(placementInput);
    let {
      size,
      crossAxis,
      crossSize,
      placement,
      crossPlacement
    } = placementInfo;
    let position = computePosition(childOffset, boundaryDimensions, overlaySize, placementInfo, offset, crossOffset);
    let normalizedOffset = offset;
    let space = getAvailableSpace(boundaryDimensions, containerOffsetWithBoundary, childOffset, margins, padding + offset, placementInfo);

    if (flip && scrollSize[size] > space) {
      let flippedPlacementInfo = parsePlacement(`${FLIPPED_DIRECTION[placement]} ${crossPlacement}`);
      let flippedPosition = computePosition(childOffset, boundaryDimensions, overlaySize, flippedPlacementInfo, offset, crossOffset);
      let flippedSpace = getAvailableSpace(boundaryDimensions, containerOffsetWithBoundary, childOffset, margins, padding + offset, flippedPlacementInfo); // If the available space for the flipped position is greater than the original available space, flip.

      if (flippedSpace > space) {
        placementInfo = flippedPlacementInfo;
        position = flippedPosition;
        normalizedOffset = offset;
      }
    }

    let delta = getDelta(crossAxis, position[crossAxis], overlaySize[crossSize], boundaryDimensions, padding);
    position[crossAxis] += delta;
    let maxHeight = getMaxHeight(position, boundaryDimensions, containerOffsetWithBoundary, childOffset);
    overlaySize.height = Math.min(overlaySize.height, maxHeight);
    position = computePosition(childOffset, boundaryDimensions, overlaySize, placementInfo, normalizedOffset, crossOffset);
    delta = getDelta(crossAxis, position[crossAxis], overlaySize[crossSize], boundaryDimensions, padding);
    position[crossAxis] += delta;
    let arrowPosition = {};
    arrowPosition[crossAxis] = childOffset[crossAxis] - position[crossAxis] + childOffset[crossSize] / 2;

    if (shouldOverlapWithTrigger) {
      position[FLIPPED_DIRECTION[placementInfo.placement]] = position[FLIPPED_DIRECTION[placementInfo.placement]] - childOffset[size];
    }

    return {
      position,
      maxHeight,
      arrowOffsetLeft: arrowPosition.left,
      arrowOffsetTop: arrowPosition.top,
      placement: placementInfo.placement
    };
  }

  function getDelta(axis, offset, size, containerDimensions, padding) {
    //@ts-ignore
    let containerScroll = containerDimensions[axis]; //@ts-ignore

    let containerHeight = containerDimensions[AXIS_SIZE[axis]];
    let startEdgeOffset = offset - padding - containerScroll;
    let endEdgeOffset = offset + padding - containerScroll + size;

    if (startEdgeOffset < 0) {
      return -startEdgeOffset;
    } else if (endEdgeOffset > containerHeight) {
      return Math.max(containerHeight - endEdgeOffset, -startEdgeOffset);
    } else {
      return 0;
    }
  }

  function getMaxHeight(position, boundaryDimensions, _containerOffsetWithBoundary, childOffset, _margins, _padding) {
    return position.top != null ? // We want the distance between the top of the overlay to the bottom of the boundary
    Math.max(0, boundaryDimensions.height - // this is the bottom of the boundary
    position.top // this is the top of the overlay
    ) : // We want the distance between the top of the trigger to the top of the boundary
    Math.max(0, childOffset.top - // this is the top of the trigger
    0 // this is the top of the boundary
    );
  }

  function computePosition(childOffset, boundaryDimensions, overlaySize, placementInfo, offset, crossOffset, _containerOffsetWithBoundary, _isContainerPositioned) {
    let {
      placement,
      crossPlacement,
      axis,
      crossAxis,
      size,
      crossSize
    } = placementInfo;
    let position = {}; //@ts-ignore

    position[crossAxis] = childOffset[crossAxis];

    if (crossPlacement === 'center') {
      position[crossAxis] += (childOffset[crossSize] - overlaySize[crossSize]) / 2;
    } else if (crossPlacement !== crossAxis) {
      position[crossAxis] += childOffset[crossSize] - overlaySize[crossSize];
    }

    position[crossAxis] += crossOffset; // this is button center position - the overlay size + half of the button to align bottom of overlay with button center

    let minViablePosition = childOffset[crossAxis] + childOffset[crossSize] / 2 - overlaySize[crossSize]; // this is button position of center, aligns top of overlay with button center

    let maxViablePosition = childOffset[crossAxis] + childOffset[crossSize] / 2; // clamp it into the range of the min/max positions

    position[crossAxis] = Math.min(Math.max(minViablePosition, position[crossAxis]), maxViablePosition); // Floor these so the position isn't placed on a partial pixel, only whole pixels. Shouldn't matter if it was floored or ceiled, so chose one.

    if (placement === axis) {
      // If the container is positioned (non-static), then we use the container's actual
      // height, as `bottom` will be relative to this height.  But if the container is static,
      // then it can only be the `document.body`, and `bottom` will be relative to _its_
      // container, which should be as large as boundaryDimensions.
      const containerHeight = boundaryDimensions[size];
      position[FLIPPED_DIRECTION[axis]] = Math.floor(containerHeight - childOffset[axis] + offset);
    } else {
      position[axis] = Math.floor(childOffset[axis] + childOffset[size] + offset);
    }

    return position;
  }

  function getAvailableSpace(boundaryDimensions, _containerOffsetWithBoundary, childOffset, _margins, padding, placementInfo) {
    let {
      placement,
      axis,
      size
    } = placementInfo;

    if (placement === axis) {
      return Math.max(0, childOffset[axis] - padding);
    }

    return Math.max(0, boundaryDimensions[size] - childOffset[axis] - childOffset[size] - padding);
  }

  const AXIS = {
    top: 'top',
    bottom: 'top',
    left: 'left',
    right: 'left'
  };
  const FLIPPED_DIRECTION = {
    top: 'bottom',
    bottom: 'top',
    left: 'right',
    right: 'left'
  };
  const CROSS_AXIS = {
    top: 'left',
    left: 'top'
  };
  const AXIS_SIZE = {
    top: 'height',
    left: 'width'
  };
  const PARSED_PLACEMENT_CACHE = {};

  function parsePlacement(input) {
    if (PARSED_PLACEMENT_CACHE[input]) {
      return PARSED_PLACEMENT_CACHE[input];
    }

    let [placement, crossPlacement] = input.split(' ');
    let axis = AXIS[placement] || 'right';
    let crossAxis = CROSS_AXIS[axis];

    if (!AXIS[crossPlacement]) {
      crossPlacement = 'center';
    }

    let size = AXIS_SIZE[axis];
    let crossSize = AXIS_SIZE[crossAxis];
    PARSED_PLACEMENT_CACHE[input] = {
      placement,
      crossPlacement,
      axis,
      crossAxis,
      size,
      crossSize
    };
    return PARSED_PLACEMENT_CACHE[input];
  }

  function _extends$2() { _extends$2 = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends$2.apply(this, arguments); }
  const PortalContext = /*#__PURE__*/React__default["default"].createContext(null);
  let globalOverlayCounter = 0;
  function PortalProvider(props) {
    const [items, setItems] = React__default["default"].useState([]);

    const setOverlayItem = item => {
      const overlayId = ++globalOverlayCounter;
      setItems(prev => prev.concat([{
        id: overlayId,
        node: item
      }]));
      return overlayId;
    };

    const updateOverlayItem = (id, node) => {
      setItems(prev => prev.map(item => {
        if (item.id === id) {
          return {
            id,
            node
          };
        }

        return item;
      }));
    };

    const removeOverlayItem = id => {
      setItems(prev => {
        const newItems = prev.filter(item => item.id !== id);
        return newItems;
      });
    };

    return /*#__PURE__*/React__default["default"].createElement(PortalContext.Provider, {
      value: {
        items,
        setOverlayItem,
        removeOverlayItem,
        updateOverlayItem
      }
    }, props.children, items.map(item => {
      return /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, {
        key: item.id
      }, item.node);
    }));
  }

  function OverlayView(props) {
    return /*#__PURE__*/React__default["default"].createElement(_reactNative.View, _extends$2({
      pointerEvents: "box-none",
      style: _reactNative.StyleSheet.absoluteFill,
      collapsable: false
    }, props));
  }

  const OverlayProvider = PortalProvider;
  function OverlayContainer(props) {
    const context = usePortalProvider();
    const overlayId = React__default["default"].useRef(undefined);
    let contents = /*#__PURE__*/React__default["default"].createElement(OverlayView, props);
    React.useEffect(() => {
      // Mount
      if (overlayId.current === undefined) {
        overlayId.current = context === null || context === void 0 ? void 0 : context.setOverlayItem(contents);
      } // Update
      else {
          if (overlayId.current) {
            context === null || context === void 0 ? void 0 : context.updateOverlayItem(overlayId.current, contents);
          }
        }
    }, // To re-render the child
    [props]); // Unmount

    React.useEffect(() => {
      return () => {
        if (overlayId.current) {
          context === null || context === void 0 ? void 0 : context.removeOverlayItem(overlayId.current);
        }
      };
    }, []);
    return null;
  }

  function usePortalProvider() {
    const context = React__default["default"].useContext(PortalContext);
    return context;
  }

  function ownKeys$2(object, enumerableOnly) {
    var keys = Object.keys(object);

    if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);
      enumerableOnly && (symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      })), keys.push.apply(keys, symbols);
    }

    return keys;
  }

  function _objectSpread2(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = null != arguments[i] ? arguments[i] : {};
      i % 2 ? ownKeys$2(Object(source), !0).forEach(function (key) {
        _defineProperty(target, key, source[key]);
      }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys$2(Object(source)).forEach(function (key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }

    return target;
  }

  function _typeof(obj) {
    "@babel/helpers - typeof";

    return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) {
      return typeof obj;
    } : function (obj) {
      return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
    }, _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];
      descriptor.enumerable = descriptor.enumerable || false;
      descriptor.configurable = true;
      if ("value" in descriptor) descriptor.writable = true;
      Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);
    if (staticProps) _defineProperties(Constructor, staticProps);
    Object.defineProperty(Constructor, "prototype", {
      writable: false
    });
    return Constructor;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, {
        value: value,
        enumerable: true,
        configurable: true,
        writable: true
      });
    } else {
      obj[key] = value;
    }

    return obj;
  }

  function _extends$1() {
    _extends$1 = Object.assign || function (target) {
      for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i];

        for (var key in source) {
          if (Object.prototype.hasOwnProperty.call(source, key)) {
            target[key] = source[key];
          }
        }
      }

      return target;
    };

    return _extends$1.apply(this, arguments);
  }

  function _setPrototypeOf$1(o, p) {
    _setPrototypeOf$1 = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;
      return o;
    };

    return _setPrototypeOf$1(o, p);
  }

  function _isNativeReflectConstruct$1() {
    if (typeof Reflect === "undefined" || !Reflect.construct) return false;
    if (Reflect.construct.sham) return false;
    if (typeof Proxy === "function") return true;

    try {
      Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {}));
      return true;
    } catch (e) {
      return false;
    }
  }

  function _construct$1(Parent, args, Class) {
    if (_isNativeReflectConstruct$1()) {
      _construct$1 = Reflect.construct;
    } else {
      _construct$1 = function _construct(Parent, args, Class) {
        var a = [null];
        a.push.apply(a, args);
        var Constructor = Function.bind.apply(Parent, a);
        var instance = new Constructor();
        if (Class) _setPrototypeOf$1(instance, Class.prototype);
        return instance;
      };
    }

    return _construct$1.apply(null, arguments);
  }

  function _objectWithoutPropertiesLoose(source, excluded) {
    if (source == null) return {};
    var target = {};
    var sourceKeys = Object.keys(source);
    var key, i;

    for (i = 0; i < sourceKeys.length; i++) {
      key = sourceKeys[i];
      if (excluded.indexOf(key) >= 0) continue;
      target[key] = source[key];
    }

    return target;
  }

  function _objectWithoutProperties(source, excluded) {
    if (source == null) return {};

    var target = _objectWithoutPropertiesLoose(source, excluded);

    var key, i;

    if (Object.getOwnPropertySymbols) {
      var sourceSymbolKeys = Object.getOwnPropertySymbols(source);

      for (i = 0; i < sourceSymbolKeys.length; i++) {
        key = sourceSymbolKeys[i];
        if (excluded.indexOf(key) >= 0) continue;
        if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;
        target[key] = source[key];
      }
    }

    return target;
  }

  function _taggedTemplateLiteral(strings, raw) {
    if (!raw) {
      raw = strings.slice(0);
    }

    return Object.freeze(Object.defineProperties(strings, {
      raw: {
        value: Object.freeze(raw)
      }
    }));
  }

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest();
  }

  function _toConsumableArray(arr) {
    return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread();
  }

  function _arrayWithoutHoles(arr) {
    if (Array.isArray(arr)) return _arrayLikeToArray(arr);
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  function _iterableToArray(iter) {
    if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter);
  }

  function _iterableToArrayLimit(arr, i) {
    var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"];

    if (_i == null) return;
    var _arr = [];
    var _n = true;
    var _d = false;

    var _s, _e;

    try {
      for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);

        if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;
      _e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }

    return _arr;
  }

  function _unsupportedIterableToArray(o, minLen) {
    if (!o) return;
    if (typeof o === "string") return _arrayLikeToArray(o, minLen);
    var n = Object.prototype.toString.call(o).slice(8, -1);
    if (n === "Object" && o.constructor) n = o.constructor.name;
    if (n === "Map" || n === "Set") return Array.from(o);
    if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
  }

  function _arrayLikeToArray(arr, len) {
    if (len == null || len > arr.length) len = arr.length;

    for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];

    return arr2;
  }

  function _nonIterableSpread() {
    throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
  }

  var checkFunction = function checkFunction(char, silent) {
    if (typeof char !== 'function') {
      return true;
    }

    if (silent) {
      return false;
    }

    throw new Error("CSS syntax error: Unexpected function.");
  };

  var InputStream = /*#__PURE__*/function () {
    function InputStream(fragments) {
      for (var _len = arguments.length, tags = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
        tags[_key - 1] = arguments[_key];
      }

      _classCallCheck(this, InputStream);

      this.dictionary = fragments.reduce(function (result, current, i) {
        var value = current.split('');
        var tag = tags[i - 1];

        if (!tag) {
          return [].concat(_toConsumableArray(result), _toConsumableArray(value));
        }

        if (typeof tag !== 'string') {
          return [].concat(_toConsumableArray(result), [tag], _toConsumableArray(value));
        }

        return [].concat(_toConsumableArray(result), _toConsumableArray(tag.split('')), _toConsumableArray(value));
      });
      this.cursor = 0;
    }

    _createClass(InputStream, [{
      key: "peek",
      value: function peek() {
        var offset = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
        return this.dictionary[this.cursor + offset];
      }
    }, {
      key: "read",
      value: function read(marker) {
        var char = this.peek();

        if (marker && marker !== char) {
          throw new Error("CSS syntax error: Expected \"".concat(marker, "\", but found \"").concat(char, "\""));
        }

        if (this.remainingChars() === 0) {
          throw new Error("CSS syntax error: Unexpected end of string.");
        }

        this.cursor += 1;
        return char;
      }
    }, {
      key: "charsWhile",
      value: function charsWhile(check) {
        var silent = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
        var value = '';

        while (checkFunction(this.peek(), silent) && check(this.peek())) {
          value += this.read();
        }

        return value;
      }
    }, {
      key: "remainingChars",
      value: function remainingChars() {
        return this.dictionary.length - this.cursor;
      }
    }]);

    return InputStream;
  }();

  function isIdent(char) {
    return /[a-z0-9_-]/i.test(char);
  }

  function isWhitespace$1(char) {
    return /\s/.test(char);
  }

  var breaksDeclaration = function breaksDeclaration(char) {
    return typeof char !== 'function' && char !== '$' && char !== ';' && char !== '}' && char !== '';
  };

  var declaration = {
    locate: function locate(input) {
      return /[a-z_]/i.test(input.peek());
    },
    read: function read(input) {
      // Parse name.
      var name = input.charsWhile(isIdent); // Parse whitespaces, separator

      input.charsWhile(isWhitespace$1);
      input.read(':');
      input.charsWhile(isWhitespace$1, true); // Parse value.

      var value = [];

      do {
        // Add function to resolve variable.
        if (input.peek() === '$') {
          (function () {
            input.read('$');
            var variableName = input.charsWhile(isIdent);
            value.push(function (variables) {
              if (variables[variableName] === undefined) {
                throw new Error("Variable $".concat(variableName, " is not defined."));
              }

              return variables[variableName];
            });
          })();
        } // Add function.


        if (typeof input.peek() === 'function') {
          value.push(input.read());
        }

        var part = input.charsWhile(breaksDeclaration, true);

        if (part.length > 0) {
          value.push(part);
        }
      } while (input.peek() === '$' || typeof input.peek() === 'function');

      if (input.peek() === ';') {
        input.read(';');
      }

      return {
        type: 'declaration',
        name: name,
        value: value
      };
    }
  };

  var variable = {
    locate: function locate(input) {
      return input.peek() === '$';
    },
    read: function read(input) {
      input.read('$');

      if (!declaration.locate(input)) {
        throw new Error("CSS syntax error: Unexpected char after $.");
      }

      var _declaration$read = declaration.read(input),
          name = _declaration$read.name,
          value = _declaration$read.value;

      return {
        type: 'variable',
        name: name,
        value: value
      };
    }
  };

  var consumeArgumentSeperator = function consumeArgumentSeperator(input) {
    if (input.peek() !== ',') {
      return false;
    }

    input.read(',');
    return true;
  };

  var directive = {
    locate: function locate(input) {
      return input.peek() === '@';
    },
    read: function read(input, parseBlock) {
      input.read('@');
      var directiveName = input.charsWhile(isIdent);

      if (directiveName !== 'include') {
        throw new Error('Only @include directive is supported.');
      }

      input.charsWhile(isWhitespace$1);
      var name = input.charsWhile(isIdent);

      if (name.length === 0) {
        throw new Error('No name.');
      }

      input.charsWhile(isWhitespace$1);
      input.read('(');
      var args = [];

      do {
        input.charsWhile(isWhitespace$1);
        args.push(input.charsWhile(isIdent));
        input.charsWhile(isWhitespace$1);
      } while (consumeArgumentSeperator(input));

      input.read(')');
      input.charsWhile(isWhitespace$1);
      input.read('{');
      var children = [];

      while (input.peek() !== '}') {
        var block = parseBlock(input);

        if (block) {
          children.push(block);
        }
      }

      input.read('}');
      return {
        type: 'block',
        scopes: [{
          type: 'mixin',
          name: name,
          args: args
        }],
        children: children
      };
    }
  };

  var SELECTOR_TYPES = ['hover', 'focus', 'active'];
  var selector$1 = {
    locate: function locate(input) {
      return input.peek() === '&' && input.peek(1) === ':';
    },
    read: function read(input, parseBlock) {
      input.read('&');
      input.read(':');
      var name = input.charsWhile(isIdent);

      if (!SELECTOR_TYPES.includes(name)) {
        throw new Error("CSS syntax error: Unexpected selector name \"".concat(name, "\"."));
      }

      input.charsWhile(isWhitespace$1);
      input.read('{');
      var children = [];

      while (input.peek() !== '}') {
        var block = parseBlock(input);

        if (block) {
          children.push(block);
        }
      }

      input.read('}');
      return {
        type: 'block',
        scopes: [{
          type: 'selector',
          name: name
        }],
        children: children
      };
    }
  };

  var consumeAsterisk = function consumeAsterisk(input) {
    input.read('*');

    if (input.peek() === '/') {
      input.read('/');
      return false;
    }

    return true;
  };

  var comment = {
    locate: function locate(input) {
      return input.peek() === '/' && (input.peek(1) === '*' || input.peek(1) === '/');
    },
    read: function read(input) {
      input.read('/'); // Read until new line for inline comments

      if (input.peek() === '/') {
        input.read('/');
        input.charsWhile(function (char) {
          return char !== '\n';
        });
        return null;
      }

      input.read('*'); // Read until comment ending

      do {
        input.charsWhile(function (char) {
          return char !== '*';
        });
      } while (consumeAsterisk(input));

      return null;
    }
  };

  function parseBlock(input) {
    if (isWhitespace$1(input.peek())) {
      input.charsWhile(isWhitespace$1);
      return null;
    }

    if (variable.locate(input)) {
      return variable.read(input);
    }

    if (declaration.locate(input)) {
      return declaration.read(input);
    }

    if (selector$1.locate(input)) {
      return selector$1.read(input, parseBlock);
    }

    if (directive.locate(input)) {
      return directive.read(input, parseBlock);
    }

    if (comment.locate(input)) {
      return comment.read(input);
    }

    throw new Error("CSS syntax error: Unknown error at \"".concat(input.peek(), "\""));
  }

  function parse$5() {
    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    var input = _construct$1(InputStream, args);

    var children = [];

    while (input.remainingChars() > 0) {
      var block = parseBlock(input);

      if (block) {
        children.push(block);
      }
    }

    return {
      type: 'root',
      children: children
    };
  }

  var commonjsGlobal = typeof globalThis !== 'undefined' ? globalThis : typeof window !== 'undefined' ? window : typeof global !== 'undefined' ? global : typeof self !== 'undefined' ? self : {};

  function createCommonjsModule(fn) {
    var module = { exports: {} };
  	return fn(module, module.exports), module.exports;
  }

  var openParentheses = "(".charCodeAt(0);
  var closeParentheses = ")".charCodeAt(0);
  var singleQuote = "'".charCodeAt(0);
  var doubleQuote = '"'.charCodeAt(0);
  var backslash = "\\".charCodeAt(0);
  var slash = "/".charCodeAt(0);
  var comma$1 = ",".charCodeAt(0);
  var colon$1 = ":".charCodeAt(0);
  var star$1 = "*".charCodeAt(0);
  var uLower = "u".charCodeAt(0);
  var uUpper = "U".charCodeAt(0);
  var plus$2 = "+".charCodeAt(0);
  var isUnicodeRange = /^[a-f0-9?-]+$/i;

  var parse$4 = function(input) {
    var tokens = [];
    var value = input;

    var next,
      quote,
      prev,
      token,
      escape,
      escapePos,
      whitespacePos,
      parenthesesOpenPos;
    var pos = 0;
    var code = value.charCodeAt(pos);
    var max = value.length;
    var stack = [{ nodes: tokens }];
    var balanced = 0;
    var parent;

    var name = "";
    var before = "";
    var after = "";

    while (pos < max) {
      // Whitespaces
      if (code <= 32) {
        next = pos;
        do {
          next += 1;
          code = value.charCodeAt(next);
        } while (code <= 32);
        token = value.slice(pos, next);

        prev = tokens[tokens.length - 1];
        if (code === closeParentheses && balanced) {
          after = token;
        } else if (prev && prev.type === "div") {
          prev.after = token;
          prev.sourceEndIndex += token.length;
        } else if (
          code === comma$1 ||
          code === colon$1 ||
          (code === slash &&
            value.charCodeAt(next + 1) !== star$1 &&
            (!parent ||
              (parent && parent.type === "function" && parent.value !== "calc")))
        ) {
          before = token;
        } else {
          tokens.push({
            type: "space",
            sourceIndex: pos,
            sourceEndIndex: next,
            value: token
          });
        }

        pos = next;

        // Quotes
      } else if (code === singleQuote || code === doubleQuote) {
        next = pos;
        quote = code === singleQuote ? "'" : '"';
        token = {
          type: "string",
          sourceIndex: pos,
          quote: quote
        };
        do {
          escape = false;
          next = value.indexOf(quote, next + 1);
          if (~next) {
            escapePos = next;
            while (value.charCodeAt(escapePos - 1) === backslash) {
              escapePos -= 1;
              escape = !escape;
            }
          } else {
            value += quote;
            next = value.length - 1;
            token.unclosed = true;
          }
        } while (escape);
        token.value = value.slice(pos + 1, next);
        token.sourceEndIndex = token.unclosed ? next : next + 1;
        tokens.push(token);
        pos = next + 1;
        code = value.charCodeAt(pos);

        // Comments
      } else if (code === slash && value.charCodeAt(pos + 1) === star$1) {
        next = value.indexOf("*/", pos);

        token = {
          type: "comment",
          sourceIndex: pos,
          sourceEndIndex: next + 2
        };

        if (next === -1) {
          token.unclosed = true;
          next = value.length;
          token.sourceEndIndex = next;
        }

        token.value = value.slice(pos + 2, next);
        tokens.push(token);

        pos = next + 2;
        code = value.charCodeAt(pos);

        // Operation within calc
      } else if (
        (code === slash || code === star$1) &&
        parent &&
        parent.type === "function" &&
        parent.value === "calc"
      ) {
        token = value[pos];
        tokens.push({
          type: "word",
          sourceIndex: pos - before.length,
          sourceEndIndex: pos + token.length,
          value: token
        });
        pos += 1;
        code = value.charCodeAt(pos);

        // Dividers
      } else if (code === slash || code === comma$1 || code === colon$1) {
        token = value[pos];

        tokens.push({
          type: "div",
          sourceIndex: pos - before.length,
          sourceEndIndex: pos + token.length,
          value: token,
          before: before,
          after: ""
        });
        before = "";

        pos += 1;
        code = value.charCodeAt(pos);

        // Open parentheses
      } else if (openParentheses === code) {
        // Whitespaces after open parentheses
        next = pos;
        do {
          next += 1;
          code = value.charCodeAt(next);
        } while (code <= 32);
        parenthesesOpenPos = pos;
        token = {
          type: "function",
          sourceIndex: pos - name.length,
          value: name,
          before: value.slice(parenthesesOpenPos + 1, next)
        };
        pos = next;

        if (name === "url" && code !== singleQuote && code !== doubleQuote) {
          next -= 1;
          do {
            escape = false;
            next = value.indexOf(")", next + 1);
            if (~next) {
              escapePos = next;
              while (value.charCodeAt(escapePos - 1) === backslash) {
                escapePos -= 1;
                escape = !escape;
              }
            } else {
              value += ")";
              next = value.length - 1;
              token.unclosed = true;
            }
          } while (escape);
          // Whitespaces before closed
          whitespacePos = next;
          do {
            whitespacePos -= 1;
            code = value.charCodeAt(whitespacePos);
          } while (code <= 32);
          if (parenthesesOpenPos < whitespacePos) {
            if (pos !== whitespacePos + 1) {
              token.nodes = [
                {
                  type: "word",
                  sourceIndex: pos,
                  sourceEndIndex: whitespacePos + 1,
                  value: value.slice(pos, whitespacePos + 1)
                }
              ];
            } else {
              token.nodes = [];
            }
            if (token.unclosed && whitespacePos + 1 !== next) {
              token.after = "";
              token.nodes.push({
                type: "space",
                sourceIndex: whitespacePos + 1,
                sourceEndIndex: next,
                value: value.slice(whitespacePos + 1, next)
              });
            } else {
              token.after = value.slice(whitespacePos + 1, next);
              token.sourceEndIndex = next;
            }
          } else {
            token.after = "";
            token.nodes = [];
          }
          pos = next + 1;
          token.sourceEndIndex = token.unclosed ? next : pos;
          code = value.charCodeAt(pos);
          tokens.push(token);
        } else {
          balanced += 1;
          token.after = "";
          token.sourceEndIndex = pos + 1;
          tokens.push(token);
          stack.push(token);
          tokens = token.nodes = [];
          parent = token;
        }
        name = "";

        // Close parentheses
      } else if (closeParentheses === code && balanced) {
        pos += 1;
        code = value.charCodeAt(pos);

        parent.after = after;
        parent.sourceEndIndex += after.length;
        after = "";
        balanced -= 1;
        stack[stack.length - 1].sourceEndIndex = pos;
        stack.pop();
        parent = stack[balanced];
        tokens = parent.nodes;

        // Words
      } else {
        next = pos;
        do {
          if (code === backslash) {
            next += 1;
          }
          next += 1;
          code = value.charCodeAt(next);
        } while (
          next < max &&
          !(
            code <= 32 ||
            code === singleQuote ||
            code === doubleQuote ||
            code === comma$1 ||
            code === colon$1 ||
            code === slash ||
            code === openParentheses ||
            (code === star$1 &&
              parent &&
              parent.type === "function" &&
              parent.value === "calc") ||
            (code === slash &&
              parent.type === "function" &&
              parent.value === "calc") ||
            (code === closeParentheses && balanced)
          )
        );
        token = value.slice(pos, next);

        if (openParentheses === code) {
          name = token;
        } else if (
          (uLower === token.charCodeAt(0) || uUpper === token.charCodeAt(0)) &&
          plus$2 === token.charCodeAt(1) &&
          isUnicodeRange.test(token.slice(2))
        ) {
          tokens.push({
            type: "unicode-range",
            sourceIndex: pos,
            sourceEndIndex: next,
            value: token
          });
        } else {
          tokens.push({
            type: "word",
            sourceIndex: pos,
            sourceEndIndex: next,
            value: token
          });
        }

        pos = next;
      }
    }

    for (pos = stack.length - 1; pos; pos -= 1) {
      stack[pos].unclosed = true;
      stack[pos].sourceEndIndex = value.length;
    }

    return stack[0].nodes;
  };

  var walk$2 = function walk(nodes, cb, bubble) {
    var i, max, node, result;

    for (i = 0, max = nodes.length; i < max; i += 1) {
      node = nodes[i];
      if (!bubble) {
        result = cb(node, i, nodes);
      }

      if (
        result !== false &&
        node.type === "function" &&
        Array.isArray(node.nodes)
      ) {
        walk(node.nodes, cb, bubble);
      }

      if (bubble) {
        cb(node, i, nodes);
      }
    }
  };

  function stringifyNode(node, custom) {
    var type = node.type;
    var value = node.value;
    var buf;
    var customResult;

    if (custom && (customResult = custom(node)) !== undefined) {
      return customResult;
    } else if (type === "word" || type === "space") {
      return value;
    } else if (type === "string") {
      buf = node.quote || "";
      return buf + value + (node.unclosed ? "" : buf);
    } else if (type === "comment") {
      return "/*" + value + (node.unclosed ? "" : "*/");
    } else if (type === "div") {
      return (node.before || "") + value + (node.after || "");
    } else if (Array.isArray(node.nodes)) {
      buf = stringify$2(node.nodes, custom);
      if (type !== "function") {
        return buf;
      }
      return (
        value +
        "(" +
        (node.before || "") +
        buf +
        (node.after || "") +
        (node.unclosed ? "" : ")")
      );
    }
    return value;
  }

  function stringify$2(nodes, custom) {
    var result, i;

    if (Array.isArray(nodes)) {
      result = "";
      for (i = nodes.length - 1; ~i; i -= 1) {
        result = stringifyNode(nodes[i], custom) + result;
      }
      return result;
    }
    return stringifyNode(nodes, custom);
  }

  var stringify_1$1 = stringify$2;

  var minus$1 = "-".charCodeAt(0);
  var plus$1 = "+".charCodeAt(0);
  var dot$1 = ".".charCodeAt(0);
  var exp = "e".charCodeAt(0);
  var EXP = "E".charCodeAt(0);

  // Check if three code points would start a number
  // https://www.w3.org/TR/css-syntax-3/#starts-with-a-number
  function likeNumber(value) {
    var code = value.charCodeAt(0);
    var nextCode;

    if (code === plus$1 || code === minus$1) {
      nextCode = value.charCodeAt(1);

      if (nextCode >= 48 && nextCode <= 57) {
        return true;
      }

      var nextNextCode = value.charCodeAt(2);

      if (nextCode === dot$1 && nextNextCode >= 48 && nextNextCode <= 57) {
        return true;
      }

      return false;
    }

    if (code === dot$1) {
      nextCode = value.charCodeAt(1);

      if (nextCode >= 48 && nextCode <= 57) {
        return true;
      }

      return false;
    }

    if (code >= 48 && code <= 57) {
      return true;
    }

    return false;
  }

  // Consume a number
  // https://www.w3.org/TR/css-syntax-3/#consume-number
  var unit = function(value) {
    var pos = 0;
    var length = value.length;
    var code;
    var nextCode;
    var nextNextCode;

    if (length === 0 || !likeNumber(value)) {
      return false;
    }

    code = value.charCodeAt(pos);

    if (code === plus$1 || code === minus$1) {
      pos++;
    }

    while (pos < length) {
      code = value.charCodeAt(pos);

      if (code < 48 || code > 57) {
        break;
      }

      pos += 1;
    }

    code = value.charCodeAt(pos);
    nextCode = value.charCodeAt(pos + 1);

    if (code === dot$1 && nextCode >= 48 && nextCode <= 57) {
      pos += 2;

      while (pos < length) {
        code = value.charCodeAt(pos);

        if (code < 48 || code > 57) {
          break;
        }

        pos += 1;
      }
    }

    code = value.charCodeAt(pos);
    nextCode = value.charCodeAt(pos + 1);
    nextNextCode = value.charCodeAt(pos + 2);

    if (
      (code === exp || code === EXP) &&
      ((nextCode >= 48 && nextCode <= 57) ||
        ((nextCode === plus$1 || nextCode === minus$1) &&
          nextNextCode >= 48 &&
          nextNextCode <= 57))
    ) {
      pos += nextCode === plus$1 || nextCode === minus$1 ? 3 : 2;

      while (pos < length) {
        code = value.charCodeAt(pos);

        if (code < 48 || code > 57) {
          break;
        }

        pos += 1;
      }
    }

    return {
      number: value.slice(0, pos),
      unit: value.slice(pos)
    };
  };

  function ValueParser(value) {
    if (this instanceof ValueParser) {
      this.nodes = parse$4(value);
      return this;
    }
    return new ValueParser(value);
  }

  ValueParser.prototype.toString = function() {
    return Array.isArray(this.nodes) ? stringify_1$1(this.nodes) : "";
  };

  ValueParser.prototype.walk = function(cb, bubble) {
    walk$2(this.nodes, cb, bubble);
    return this;
  };

  ValueParser.unit = unit;

  ValueParser.walk = walk$2;

  ValueParser.stringify = stringify_1$1;

  var lib$4 = ValueParser;

  var camelize = function(obj) {
      if (typeof obj === 'string') return camelCase(obj);
      return walk$1(obj);
  };

  function walk$1 (obj) {
      if (!obj || typeof obj !== 'object') return obj;
      if (isDate(obj) || isRegex(obj)) return obj;
      if (isArray(obj)) return map$1(obj, walk$1);
      return reduce(objectKeys(obj), function (acc, key) {
          var camel = camelCase(key);
          acc[camel] = walk$1(obj[key]);
          return acc;
      }, {});
  }

  function camelCase(str) {
      return str.replace(/[_.-](\w|$)/g, function (_,x) {
          return x.toUpperCase();
      });
  }

  var isArray = Array.isArray || function (obj) {
      return Object.prototype.toString.call(obj) === '[object Array]';
  };

  var isDate = function (obj) {
      return Object.prototype.toString.call(obj) === '[object Date]';
  };

  var isRegex = function (obj) {
      return Object.prototype.toString.call(obj) === '[object RegExp]';
  };

  var has$5 = Object.prototype.hasOwnProperty;
  var objectKeys = Object.keys || function (obj) {
      var keys = [];
      for (var key in obj) {
          if (has$5.call(obj, key)) keys.push(key);
      }
      return keys;
  };

  function map$1 (xs, f) {
      if (xs.map) return xs.map(f);
      var res = [];
      for (var i = 0; i < xs.length; i++) {
          res.push(f(xs[i], i));
      }
      return res;
  }

  function reduce (xs, f, acc) {
      if (xs.reduce) return xs.reduce(f, acc);
      for (var i = 0; i < xs.length; i++) {
          acc = f(acc, xs[i], i);
      }
      return acc;
  }

  var black = "#000000";
  var silver = "#c0c0c0";
  var gray = "#808080";
  var white = "#ffffff";
  var maroon = "#800000";
  var red = "#ff0000";
  var purple = "#800080";
  var fuchsia = "#ff00ff";
  var green = "#008000";
  var lime = "#00ff00";
  var olive = "#808000";
  var yellow = "#ffff00";
  var navy = "#000080";
  var blue = "#0000ff";
  var teal = "#008080";
  var aqua = "#00ffff";
  var orange = "#ffa500";
  var aliceblue = "#f0f8ff";
  var antiquewhite = "#faebd7";
  var aquamarine = "#7fffd4";
  var azure = "#f0ffff";
  var beige = "#f5f5dc";
  var bisque = "#ffe4c4";
  var blanchedalmond = "#ffebcd";
  var blueviolet = "#8a2be2";
  var brown = "#a52a2a";
  var burlywood = "#deb887";
  var cadetblue = "#5f9ea0";
  var chartreuse = "#7fff00";
  var chocolate = "#d2691e";
  var coral = "#ff7f50";
  var cornflowerblue = "#6495ed";
  var cornsilk = "#fff8dc";
  var crimson = "#dc143c";
  var darkblue = "#00008b";
  var darkcyan = "#008b8b";
  var darkgoldenrod = "#b8860b";
  var darkgray = "#a9a9a9";
  var darkgreen = "#006400";
  var darkgrey = "#a9a9a9";
  var darkkhaki = "#bdb76b";
  var darkmagenta = "#8b008b";
  var darkolivegreen = "#556b2f";
  var darkorange = "#ff8c00";
  var darkorchid = "#9932cc";
  var darkred = "#8b0000";
  var darksalmon = "#e9967a";
  var darkseagreen = "#8fbc8f";
  var darkslateblue = "#483d8b";
  var darkslategray = "#2f4f4f";
  var darkslategrey = "#2f4f4f";
  var darkturquoise = "#00ced1";
  var darkviolet = "#9400d3";
  var deeppink = "#ff1493";
  var deepskyblue = "#00bfff";
  var dimgray = "#696969";
  var dimgrey = "#696969";
  var dodgerblue = "#1e90ff";
  var firebrick = "#b22222";
  var floralwhite = "#fffaf0";
  var forestgreen = "#228b22";
  var gainsboro = "#dcdcdc";
  var ghostwhite = "#f8f8ff";
  var gold = "#ffd700";
  var goldenrod = "#daa520";
  var greenyellow = "#adff2f";
  var grey = "#808080";
  var honeydew = "#f0fff0";
  var hotpink = "#ff69b4";
  var indianred = "#cd5c5c";
  var indigo = "#4b0082";
  var ivory = "#fffff0";
  var khaki = "#f0e68c";
  var lavender = "#e6e6fa";
  var lavenderblush = "#fff0f5";
  var lawngreen = "#7cfc00";
  var lemonchiffon = "#fffacd";
  var lightblue = "#add8e6";
  var lightcoral = "#f08080";
  var lightcyan = "#e0ffff";
  var lightgoldenrodyellow = "#fafad2";
  var lightgray = "#d3d3d3";
  var lightgreen = "#90ee90";
  var lightgrey = "#d3d3d3";
  var lightpink = "#ffb6c1";
  var lightsalmon = "#ffa07a";
  var lightseagreen = "#20b2aa";
  var lightskyblue = "#87cefa";
  var lightslategray = "#778899";
  var lightslategrey = "#778899";
  var lightsteelblue = "#b0c4de";
  var lightyellow = "#ffffe0";
  var limegreen = "#32cd32";
  var linen = "#faf0e6";
  var mediumaquamarine = "#66cdaa";
  var mediumblue = "#0000cd";
  var mediumorchid = "#ba55d3";
  var mediumpurple = "#9370db";
  var mediumseagreen = "#3cb371";
  var mediumslateblue = "#7b68ee";
  var mediumspringgreen = "#00fa9a";
  var mediumturquoise = "#48d1cc";
  var mediumvioletred = "#c71585";
  var midnightblue = "#191970";
  var mintcream = "#f5fffa";
  var mistyrose = "#ffe4e1";
  var moccasin = "#ffe4b5";
  var navajowhite = "#ffdead";
  var oldlace = "#fdf5e6";
  var olivedrab = "#6b8e23";
  var orangered = "#ff4500";
  var orchid = "#da70d6";
  var palegoldenrod = "#eee8aa";
  var palegreen = "#98fb98";
  var paleturquoise = "#afeeee";
  var palevioletred = "#db7093";
  var papayawhip = "#ffefd5";
  var peachpuff = "#ffdab9";
  var peru = "#cd853f";
  var pink = "#ffc0cb";
  var plum = "#dda0dd";
  var powderblue = "#b0e0e6";
  var rosybrown = "#bc8f8f";
  var royalblue = "#4169e1";
  var saddlebrown = "#8b4513";
  var salmon = "#fa8072";
  var sandybrown = "#f4a460";
  var seagreen = "#2e8b57";
  var seashell = "#fff5ee";
  var sienna = "#a0522d";
  var skyblue = "#87ceeb";
  var slateblue = "#6a5acd";
  var slategray = "#708090";
  var slategrey = "#708090";
  var snow = "#fffafa";
  var springgreen = "#00ff7f";
  var steelblue = "#4682b4";
  var tan = "#d2b48c";
  var thistle = "#d8bfd8";
  var tomato = "#ff6347";
  var turquoise = "#40e0d0";
  var violet = "#ee82ee";
  var wheat = "#f5deb3";
  var whitesmoke = "#f5f5f5";
  var yellowgreen = "#9acd32";
  var rebeccapurple = "#663399";
  var require$$0$2 = {
  	black: black,
  	silver: silver,
  	gray: gray,
  	white: white,
  	maroon: maroon,
  	red: red,
  	purple: purple,
  	fuchsia: fuchsia,
  	green: green,
  	lime: lime,
  	olive: olive,
  	yellow: yellow,
  	navy: navy,
  	blue: blue,
  	teal: teal,
  	aqua: aqua,
  	orange: orange,
  	aliceblue: aliceblue,
  	antiquewhite: antiquewhite,
  	aquamarine: aquamarine,
  	azure: azure,
  	beige: beige,
  	bisque: bisque,
  	blanchedalmond: blanchedalmond,
  	blueviolet: blueviolet,
  	brown: brown,
  	burlywood: burlywood,
  	cadetblue: cadetblue,
  	chartreuse: chartreuse,
  	chocolate: chocolate,
  	coral: coral,
  	cornflowerblue: cornflowerblue,
  	cornsilk: cornsilk,
  	crimson: crimson,
  	darkblue: darkblue,
  	darkcyan: darkcyan,
  	darkgoldenrod: darkgoldenrod,
  	darkgray: darkgray,
  	darkgreen: darkgreen,
  	darkgrey: darkgrey,
  	darkkhaki: darkkhaki,
  	darkmagenta: darkmagenta,
  	darkolivegreen: darkolivegreen,
  	darkorange: darkorange,
  	darkorchid: darkorchid,
  	darkred: darkred,
  	darksalmon: darksalmon,
  	darkseagreen: darkseagreen,
  	darkslateblue: darkslateblue,
  	darkslategray: darkslategray,
  	darkslategrey: darkslategrey,
  	darkturquoise: darkturquoise,
  	darkviolet: darkviolet,
  	deeppink: deeppink,
  	deepskyblue: deepskyblue,
  	dimgray: dimgray,
  	dimgrey: dimgrey,
  	dodgerblue: dodgerblue,
  	firebrick: firebrick,
  	floralwhite: floralwhite,
  	forestgreen: forestgreen,
  	gainsboro: gainsboro,
  	ghostwhite: ghostwhite,
  	gold: gold,
  	goldenrod: goldenrod,
  	greenyellow: greenyellow,
  	grey: grey,
  	honeydew: honeydew,
  	hotpink: hotpink,
  	indianred: indianred,
  	indigo: indigo,
  	ivory: ivory,
  	khaki: khaki,
  	lavender: lavender,
  	lavenderblush: lavenderblush,
  	lawngreen: lawngreen,
  	lemonchiffon: lemonchiffon,
  	lightblue: lightblue,
  	lightcoral: lightcoral,
  	lightcyan: lightcyan,
  	lightgoldenrodyellow: lightgoldenrodyellow,
  	lightgray: lightgray,
  	lightgreen: lightgreen,
  	lightgrey: lightgrey,
  	lightpink: lightpink,
  	lightsalmon: lightsalmon,
  	lightseagreen: lightseagreen,
  	lightskyblue: lightskyblue,
  	lightslategray: lightslategray,
  	lightslategrey: lightslategrey,
  	lightsteelblue: lightsteelblue,
  	lightyellow: lightyellow,
  	limegreen: limegreen,
  	linen: linen,
  	mediumaquamarine: mediumaquamarine,
  	mediumblue: mediumblue,
  	mediumorchid: mediumorchid,
  	mediumpurple: mediumpurple,
  	mediumseagreen: mediumseagreen,
  	mediumslateblue: mediumslateblue,
  	mediumspringgreen: mediumspringgreen,
  	mediumturquoise: mediumturquoise,
  	mediumvioletred: mediumvioletred,
  	midnightblue: midnightblue,
  	mintcream: mintcream,
  	mistyrose: mistyrose,
  	moccasin: moccasin,
  	navajowhite: navajowhite,
  	oldlace: oldlace,
  	olivedrab: olivedrab,
  	orangered: orangered,
  	orchid: orchid,
  	palegoldenrod: palegoldenrod,
  	palegreen: palegreen,
  	paleturquoise: paleturquoise,
  	palevioletred: palevioletred,
  	papayawhip: papayawhip,
  	peachpuff: peachpuff,
  	peru: peru,
  	pink: pink,
  	plum: plum,
  	powderblue: powderblue,
  	rosybrown: rosybrown,
  	royalblue: royalblue,
  	saddlebrown: saddlebrown,
  	salmon: salmon,
  	sandybrown: sandybrown,
  	seagreen: seagreen,
  	seashell: seashell,
  	sienna: sienna,
  	skyblue: skyblue,
  	slateblue: slateblue,
  	slategray: slategray,
  	slategrey: slategrey,
  	snow: snow,
  	springgreen: springgreen,
  	steelblue: steelblue,
  	tan: tan,
  	thistle: thistle,
  	tomato: tomato,
  	turquoise: turquoise,
  	violet: violet,
  	wheat: wheat,
  	whitesmoke: whitesmoke,
  	yellowgreen: yellowgreen,
  	rebeccapurple: rebeccapurple
  };

  var cssColorKeywords = require$$0$2;

  var cssToReactNative = createCommonjsModule(function (module, exports) {

  Object.defineProperty(exports, '__esModule', {
    value: true
  });

  function _interopDefault(ex) {
    return ex && typeof ex === 'object' && 'default' in ex ? ex['default'] : ex;
  }



  var parse__default = _interopDefault(lib$4);

  var camelizeStyleName = _interopDefault(camelize);

  var cssColorKeywords$1 = _interopDefault(cssColorKeywords);

  var matchString = function matchString(node) {
    if (node.type !== 'string') return null;
    return node.value.replace(/\\([0-9a-f]{1,6})(?:\s|$)/gi, function (match, charCode) {
      return String.fromCharCode(parseInt(charCode, 16));
    }).replace(/\\/g, '');
  };

  var hexColorRe = /^(#(?:[0-9a-f]{3,4}){1,2})$/i;
  var cssFunctionNameRe = /^(rgba?|hsla?|hwb|lab|lch|gray|color)$/;

  var matchColor = function matchColor(node) {
    if (node.type === 'word' && (hexColorRe.test(node.value) || node.value in cssColorKeywords$1 || node.value === 'transparent')) {
      return node.value;
    } else if (node.type === 'function' && cssFunctionNameRe.test(node.value)) {
      return lib$4.stringify(node);
    }

    return null;
  };

  var noneRe = /^(none)$/i;
  var autoRe = /^(auto)$/i;
  var identRe = /(^-?[_a-z][_a-z0-9-]*$)/i; // Note if these are wrong, you'll need to change index.js too

  var numberRe = /^([+-]?(?:\d*\.)?\d+(?:e[+-]?\d+)?)$/i; // Note lengthRe is sneaky: you can omit units for 0

  var lengthRe = /^(0$|(?:[+-]?(?:\d*\.)?\d+(?:e[+-]?\d+)?)(?=px$))/i;
  var unsupportedUnitRe = /^([+-]?(?:\d*\.)?\d+(?:e[+-]?\d+)?(ch|em|ex|rem|vh|vw|vmin|vmax|cm|mm|in|pc|pt))$/i;
  var angleRe = /^([+-]?(?:\d*\.)?\d+(?:e[+-]?\d+)?(?:deg|rad))$/i;
  var percentRe = /^([+-]?(?:\d*\.)?\d+(?:e[+-]?\d+)?%)$/i;

  var noopToken = function noopToken(predicate) {
    return function (node) {
      return predicate(node) ? '<token>' : null;
    };
  };

  var valueForTypeToken = function valueForTypeToken(type) {
    return function (node) {
      return node.type === type ? node.value : null;
    };
  };

  var regExpToken = function regExpToken(regExp, transform) {
    if (transform === void 0) {
      transform = String;
    }

    return function (node) {
      if (node.type !== 'word') return null;
      var match = node.value.match(regExp);
      if (match === null) return null;
      var value = transform(match[1]);
      return value;
    };
  };

  var SPACE = noopToken(function (node) {
    return node.type === 'space';
  });
  var SLASH = noopToken(function (node) {
    return node.type === 'div' && node.value === '/';
  });
  var COMMA = noopToken(function (node) {
    return node.type === 'div' && node.value === ',';
  });
  var WORD = valueForTypeToken('word');
  var NONE = regExpToken(noneRe);
  var AUTO = regExpToken(autoRe);
  var NUMBER = regExpToken(numberRe, Number);
  var LENGTH = regExpToken(lengthRe, Number);
  var UNSUPPORTED_LENGTH_UNIT = regExpToken(unsupportedUnitRe);
  var ANGLE = regExpToken(angleRe, function (angle) {
    return angle.toLowerCase();
  });
  var PERCENT = regExpToken(percentRe);
  var IDENT = regExpToken(identRe);
  var STRING = matchString;
  var COLOR = matchColor;
  var LINE = regExpToken(/^(none|underline|line-through)$/i);
  var BORDER_STYLE = regExpToken(/^(solid|dashed|dotted)$/);
  var defaultBorderWidth = 1;
  var defaultBorderColor = 'black';
  var defaultBorderStyle = 'solid';

  var border = function border(tokenStream) {
    var borderWidth;
    var borderColor;
    var borderStyle;

    if (tokenStream.matches(NONE)) {
      tokenStream.expectEmpty();
      return {
        borderWidth: 0,
        borderColor: 'black',
        borderStyle: 'solid'
      };
    }

    var partsParsed = 0;

    while (partsParsed < 3 && tokenStream.hasTokens()) {
      if (partsParsed !== 0) tokenStream.expect(SPACE);

      if (borderWidth === undefined && tokenStream.matches(LENGTH, UNSUPPORTED_LENGTH_UNIT)) {
        borderWidth = tokenStream.lastValue;
      } else if (borderColor === undefined && tokenStream.matches(COLOR)) {
        borderColor = tokenStream.lastValue;
      } else if (borderStyle === undefined && tokenStream.matches(BORDER_STYLE)) {
        borderStyle = tokenStream.lastValue;
      } else {
        tokenStream["throw"]();
      }

      partsParsed += 1;
    }

    tokenStream.expectEmpty();
    if (borderWidth === undefined) borderWidth = defaultBorderWidth;
    if (borderColor === undefined) borderColor = defaultBorderColor;
    if (borderStyle === undefined) borderStyle = defaultBorderStyle;
    return {
      borderWidth: borderWidth,
      borderColor: borderColor,
      borderStyle: borderStyle
    };
  };

  var directionFactory = function directionFactory(_ref) {
    var _ref$types = _ref.types,
        types = _ref$types === void 0 ? [LENGTH, UNSUPPORTED_LENGTH_UNIT, PERCENT] : _ref$types,
        _ref$directions = _ref.directions,
        directions = _ref$directions === void 0 ? ['Top', 'Right', 'Bottom', 'Left'] : _ref$directions,
        _ref$prefix = _ref.prefix,
        prefix = _ref$prefix === void 0 ? '' : _ref$prefix,
        _ref$suffix = _ref.suffix,
        suffix = _ref$suffix === void 0 ? '' : _ref$suffix;
    return function (tokenStream) {
      var _ref2;

      var values = []; // borderWidth doesn't currently allow a percent value, but may do in the future

      values.push(tokenStream.expect.apply(tokenStream, types));

      while (values.length < 4 && tokenStream.hasTokens()) {
        tokenStream.expect(SPACE);
        values.push(tokenStream.expect.apply(tokenStream, types));
      }

      tokenStream.expectEmpty();
      var top = values[0],
          _values$ = values[1],
          right = _values$ === void 0 ? top : _values$,
          _values$2 = values[2],
          bottom = _values$2 === void 0 ? top : _values$2,
          _values$3 = values[3],
          left = _values$3 === void 0 ? right : _values$3;

      var keyFor = function keyFor(n) {
        return "" + prefix + directions[n] + suffix;
      };

      return _ref2 = {}, _ref2[keyFor(0)] = top, _ref2[keyFor(1)] = right, _ref2[keyFor(2)] = bottom, _ref2[keyFor(3)] = left, _ref2;
    };
  };

  var parseShadowOffset = function parseShadowOffset(tokenStream) {
    var width = tokenStream.expect(LENGTH);
    var height = tokenStream.matches(SPACE) ? tokenStream.expect(LENGTH) : width;
    tokenStream.expectEmpty();
    return {
      width: width,
      height: height
    };
  };

  var parseShadow = function parseShadow(tokenStream) {
    var offsetX;
    var offsetY;
    var radius;
    var color;

    if (tokenStream.matches(NONE)) {
      tokenStream.expectEmpty();
      return {
        offset: {
          width: 0,
          height: 0
        },
        radius: 0,
        color: 'black'
      };
    }

    var didParseFirst = false;

    while (tokenStream.hasTokens()) {
      if (didParseFirst) tokenStream.expect(SPACE);

      if (offsetX === undefined && tokenStream.matches(LENGTH, UNSUPPORTED_LENGTH_UNIT)) {
        offsetX = tokenStream.lastValue;
        tokenStream.expect(SPACE);
        offsetY = tokenStream.expect(LENGTH, UNSUPPORTED_LENGTH_UNIT);
        tokenStream.saveRewindPoint();

        if (tokenStream.matches(SPACE) && tokenStream.matches(LENGTH, UNSUPPORTED_LENGTH_UNIT)) {
          radius = tokenStream.lastValue;
        } else {
          tokenStream.rewind();
        }
      } else if (color === undefined && tokenStream.matches(COLOR)) {
        color = tokenStream.lastValue;
      } else {
        tokenStream["throw"]();
      }

      didParseFirst = true;
    }

    if (offsetX === undefined) tokenStream["throw"]();
    return {
      offset: {
        width: offsetX,
        height: offsetY
      },
      radius: radius !== undefined ? radius : 0,
      color: color !== undefined ? color : 'black'
    };
  };

  var boxShadow = function boxShadow(tokenStream) {
    var _parseShadow = parseShadow(tokenStream),
        offset = _parseShadow.offset,
        radius = _parseShadow.radius,
        color = _parseShadow.color;

    return {
      shadowOffset: offset,
      shadowRadius: radius,
      shadowColor: color,
      shadowOpacity: 1
    };
  };

  var defaultFlexGrow = 1;
  var defaultFlexShrink = 1;
  var defaultFlexBasis = 0;

  var flex = function flex(tokenStream) {
    var flexGrow;
    var flexShrink;
    var flexBasis;

    if (tokenStream.matches(NONE)) {
      tokenStream.expectEmpty();
      return {
        flexGrow: 0,
        flexShrink: 0,
        flexBasis: 'auto'
      };
    }

    tokenStream.saveRewindPoint();

    if (tokenStream.matches(AUTO) && !tokenStream.hasTokens()) {
      return {
        flexGrow: 1,
        flexShrink: 1,
        flexBasis: 'auto'
      };
    }

    tokenStream.rewind();
    var partsParsed = 0;

    while (partsParsed < 2 && tokenStream.hasTokens()) {
      if (partsParsed !== 0) tokenStream.expect(SPACE);

      if (flexGrow === undefined && tokenStream.matches(NUMBER)) {
        flexGrow = tokenStream.lastValue;
        tokenStream.saveRewindPoint();

        if (tokenStream.matches(SPACE) && tokenStream.matches(NUMBER)) {
          flexShrink = tokenStream.lastValue;
        } else {
          tokenStream.rewind();
        }
      } else if (flexBasis === undefined && tokenStream.matches(LENGTH, UNSUPPORTED_LENGTH_UNIT, PERCENT)) {
        flexBasis = tokenStream.lastValue;
      } else if (flexBasis === undefined && tokenStream.matches(AUTO)) {
        flexBasis = 'auto';
      } else {
        tokenStream["throw"]();
      }

      partsParsed += 1;
    }

    tokenStream.expectEmpty();
    if (flexGrow === undefined) flexGrow = defaultFlexGrow;
    if (flexShrink === undefined) flexShrink = defaultFlexShrink;
    if (flexBasis === undefined) flexBasis = defaultFlexBasis;
    return {
      flexGrow: flexGrow,
      flexShrink: flexShrink,
      flexBasis: flexBasis
    };
  };

  var FLEX_WRAP = regExpToken(/(nowrap|wrap|wrap-reverse)/);
  var FLEX_DIRECTION = regExpToken(/(row|row-reverse|column|column-reverse)/);
  var defaultFlexWrap = 'nowrap';
  var defaultFlexDirection = 'row';

  var flexFlow = function flexFlow(tokenStream) {
    var flexWrap;
    var flexDirection;
    var partsParsed = 0;

    while (partsParsed < 2 && tokenStream.hasTokens()) {
      if (partsParsed !== 0) tokenStream.expect(SPACE);

      if (flexWrap === undefined && tokenStream.matches(FLEX_WRAP)) {
        flexWrap = tokenStream.lastValue;
      } else if (flexDirection === undefined && tokenStream.matches(FLEX_DIRECTION)) {
        flexDirection = tokenStream.lastValue;
      } else {
        tokenStream["throw"]();
      }

      partsParsed += 1;
    }

    tokenStream.expectEmpty();
    if (flexWrap === undefined) flexWrap = defaultFlexWrap;
    if (flexDirection === undefined) flexDirection = defaultFlexDirection;
    return {
      flexWrap: flexWrap,
      flexDirection: flexDirection
    };
  };

  var fontFamily = function fontFamily(tokenStream) {
    var fontFamily;

    if (tokenStream.matches(STRING)) {
      fontFamily = tokenStream.lastValue;
    } else {
      fontFamily = tokenStream.expect(IDENT);

      while (tokenStream.hasTokens()) {
        tokenStream.expect(SPACE);
        var nextIdent = tokenStream.expect(IDENT);
        fontFamily += " " + nextIdent;
      }
    }

    tokenStream.expectEmpty();
    return {
      fontFamily: fontFamily
    };
  };

  var NORMAL = regExpToken(/^(normal)$/);
  var STYLE = regExpToken(/^(italic)$/);
  var WEIGHT = regExpToken(/^([1-9]00|bold)$/);
  var VARIANT = regExpToken(/^(small-caps)$/);
  var defaultFontStyle = 'normal';
  var defaultFontWeight = 'normal';
  var defaultFontVariant = [];

  var font = function font(tokenStream) {
    var fontStyle;
    var fontWeight;
    var fontVariant; // let fontSize;

    var lineHeight; // let fontFamily;

    var numStyleWeightVariantMatched = 0;

    while (numStyleWeightVariantMatched < 3 && tokenStream.hasTokens()) {
      if (tokenStream.matches(NORMAL)) ;else if (fontStyle === undefined && tokenStream.matches(STYLE)) {
        fontStyle = tokenStream.lastValue;
      } else if (fontWeight === undefined && tokenStream.matches(WEIGHT)) {
        fontWeight = tokenStream.lastValue;
      } else if (fontVariant === undefined && tokenStream.matches(VARIANT)) {
        fontVariant = [tokenStream.lastValue];
      } else {
        break;
      }
      tokenStream.expect(SPACE);
      numStyleWeightVariantMatched += 1;
    }

    var fontSize = tokenStream.expect(LENGTH, UNSUPPORTED_LENGTH_UNIT);

    if (tokenStream.matches(SLASH)) {
      lineHeight = tokenStream.expect(LENGTH, UNSUPPORTED_LENGTH_UNIT);
    }

    tokenStream.expect(SPACE);

    var _fontFamily = fontFamily(tokenStream),
        fontFamily$1 = _fontFamily.fontFamily;

    if (fontStyle === undefined) fontStyle = defaultFontStyle;
    if (fontWeight === undefined) fontWeight = defaultFontWeight;
    if (fontVariant === undefined) fontVariant = defaultFontVariant;
    var out = {
      fontStyle: fontStyle,
      fontWeight: fontWeight,
      fontVariant: fontVariant,
      fontSize: fontSize,
      fontFamily: fontFamily$1
    };
    if (lineHeight !== undefined) out.lineHeight = lineHeight;
    return out;
  };

  var ALIGN_CONTENT = regExpToken(/(flex-(?:start|end)|center|stretch|space-(?:between|around))/);
  var JUSTIFY_CONTENT = regExpToken(/(flex-(?:start|end)|center|space-(?:between|around|evenly))/);

  var placeContent = function placeContent(tokenStream) {
    var alignContent = tokenStream.expect(ALIGN_CONTENT);
    var justifyContent;

    if (tokenStream.hasTokens()) {
      tokenStream.expect(SPACE);
      justifyContent = tokenStream.expect(JUSTIFY_CONTENT);
    } else {
      justifyContent = 'stretch';
    }

    tokenStream.expectEmpty();
    return {
      alignContent: alignContent,
      justifyContent: justifyContent
    };
  };

  var STYLE$1 = regExpToken(/^(solid|double|dotted|dashed)$/);
  var defaultTextDecorationLine = 'none';
  var defaultTextDecorationStyle = 'solid';
  var defaultTextDecorationColor = 'black';

  var textDecoration = function textDecoration(tokenStream) {
    var line;
    var style;
    var color;
    var didParseFirst = false;

    while (tokenStream.hasTokens()) {
      if (didParseFirst) tokenStream.expect(SPACE);

      if (line === undefined && tokenStream.matches(LINE)) {
        var lines = [tokenStream.lastValue.toLowerCase()];
        tokenStream.saveRewindPoint();

        if (lines[0] !== 'none' && tokenStream.matches(SPACE) && tokenStream.matches(LINE)) {
          lines.push(tokenStream.lastValue.toLowerCase()); // Underline comes before line-through

          lines.sort().reverse();
        } else {
          tokenStream.rewind();
        }

        line = lines.join(' ');
      } else if (style === undefined && tokenStream.matches(STYLE$1)) {
        style = tokenStream.lastValue;
      } else if (color === undefined && tokenStream.matches(COLOR)) {
        color = tokenStream.lastValue;
      } else {
        tokenStream["throw"]();
      }

      didParseFirst = true;
    }

    return {
      textDecorationLine: line !== undefined ? line : defaultTextDecorationLine,
      textDecorationColor: color !== undefined ? color : defaultTextDecorationColor,
      textDecorationStyle: style !== undefined ? style : defaultTextDecorationStyle
    };
  };

  var textDecorationLine = function textDecorationLine(tokenStream) {
    var lines = [];
    var didParseFirst = false;

    while (tokenStream.hasTokens()) {
      if (didParseFirst) tokenStream.expect(SPACE);
      lines.push(tokenStream.expect(LINE).toLowerCase());
      didParseFirst = true;
    }

    lines.sort().reverse();
    return {
      textDecorationLine: lines.join(' ')
    };
  };

  var textShadow = function textShadow(tokenStream) {
    var _parseShadow2 = parseShadow(tokenStream),
        offset = _parseShadow2.offset,
        radius = _parseShadow2.radius,
        color = _parseShadow2.color;

    return {
      textShadowOffset: offset,
      textShadowRadius: radius,
      textShadowColor: color
    };
  };

  var oneOfType = function oneOfType(tokenType) {
    return function (functionStream) {
      var value = functionStream.expect(tokenType);
      functionStream.expectEmpty();
      return value;
    };
  };

  var singleNumber = oneOfType(NUMBER);
  var singleLength = oneOfType(LENGTH);
  var singleAngle = oneOfType(ANGLE);

  var xyTransformFactory = function xyTransformFactory(tokenType) {
    return function (key, valueIfOmitted) {
      return function (functionStream) {
        var _ref3, _ref4;

        var x = functionStream.expect(tokenType);
        var y;

        if (functionStream.hasTokens()) {
          functionStream.expect(COMMA);
          y = functionStream.expect(tokenType);
        } else if (valueIfOmitted !== undefined) {
          y = valueIfOmitted;
        } else {
          // Assumption, if x === y, then we can omit XY
          // I.e. scale(5) => [{ scale: 5 }] rather than [{ scaleX: 5 }, { scaleY: 5 }]
          return x;
        }

        functionStream.expectEmpty();
        return [(_ref3 = {}, _ref3[key + "Y"] = y, _ref3), (_ref4 = {}, _ref4[key + "X"] = x, _ref4)];
      };
    };
  };

  var xyNumber = xyTransformFactory(NUMBER);
  var xyLength = xyTransformFactory(LENGTH);
  var xyAngle = xyTransformFactory(ANGLE);
  var partTransforms = {
    perspective: singleNumber,
    scale: xyNumber('scale'),
    scaleX: singleNumber,
    scaleY: singleNumber,
    translate: xyLength('translate', 0),
    translateX: singleLength,
    translateY: singleLength,
    rotate: singleAngle,
    rotateX: singleAngle,
    rotateY: singleAngle,
    rotateZ: singleAngle,
    skewX: singleAngle,
    skewY: singleAngle,
    skew: xyAngle('skew', '0deg')
  };

  var transform = function transform(tokenStream) {
    var transforms = [];
    var didParseFirst = false;

    while (tokenStream.hasTokens()) {
      if (didParseFirst) tokenStream.expect(SPACE);
      var functionStream = tokenStream.expectFunction();
      var functionName = functionStream.functionName;
      var transformedValues = partTransforms[functionName](functionStream);

      if (!Array.isArray(transformedValues)) {
        var _ref5;

        transformedValues = [(_ref5 = {}, _ref5[functionName] = transformedValues, _ref5)];
      }

      transforms = transformedValues.concat(transforms);
      didParseFirst = true;
    }

    return {
      transform: transforms
    };
  };

  var background = function background(tokenStream) {
    return {
      backgroundColor: tokenStream.expect(COLOR)
    };
  };

  var borderColor = directionFactory({
    types: [COLOR],
    prefix: 'border',
    suffix: 'Color'
  });
  var borderRadius = directionFactory({
    directions: ['TopLeft', 'TopRight', 'BottomRight', 'BottomLeft'],
    prefix: 'border',
    suffix: 'Radius'
  });
  var borderWidth = directionFactory({
    prefix: 'border',
    suffix: 'Width'
  });
  var margin = directionFactory({
    types: [LENGTH, UNSUPPORTED_LENGTH_UNIT, PERCENT, AUTO],
    prefix: 'margin'
  });
  var padding = directionFactory({
    prefix: 'padding'
  });

  var fontVariant = function fontVariant(tokenStream) {
    return {
      fontVariant: [tokenStream.expect(IDENT)]
    };
  };

  var fontWeight = function fontWeight(tokenStream) {
    return {
      fontWeight: tokenStream.expect(WORD) // Also match numbers as strings

    };
  };

  var shadowOffset = function shadowOffset(tokenStream) {
    return {
      shadowOffset: parseShadowOffset(tokenStream)
    };
  };

  var textShadowOffset = function textShadowOffset(tokenStream) {
    return {
      textShadowOffset: parseShadowOffset(tokenStream)
    };
  };

  var transforms = {
    background: background,
    border: border,
    borderColor: borderColor,
    borderRadius: borderRadius,
    borderWidth: borderWidth,
    boxShadow: boxShadow,
    flex: flex,
    flexFlow: flexFlow,
    font: font,
    fontFamily: fontFamily,
    fontVariant: fontVariant,
    fontWeight: fontWeight,
    margin: margin,
    padding: padding,
    placeContent: placeContent,
    shadowOffset: shadowOffset,
    textShadow: textShadow,
    textShadowOffset: textShadowOffset,
    textDecoration: textDecoration,
    textDecorationLine: textDecorationLine,
    transform: transform
  };
  var propertiesWithoutUnits;

  {
    propertiesWithoutUnits = ['aspectRatio', 'elevation', 'flexGrow', 'flexShrink', 'opacity', 'shadowOpacity', 'zIndex'];
  }

  var devPropertiesWithUnitsRegExp = propertiesWithoutUnits != null ? new RegExp(propertiesWithoutUnits.join('|')) : null;
  var SYMBOL_MATCH = 'SYMBOL_MATCH';

  var TokenStream =
  /*#__PURE__*/
  function () {
    function TokenStream(nodes, parent) {
      this.index = 0;
      this.nodes = nodes;
      this.functionName = parent != null ? parent.value : null;
      this.lastValue = null;
      this.rewindIndex = -1;
    }

    var _proto = TokenStream.prototype;

    _proto.hasTokens = function hasTokens() {
      return this.index <= this.nodes.length - 1;
    };

    _proto[SYMBOL_MATCH] = function () {
      if (!this.hasTokens()) return null;
      var node = this.nodes[this.index];

      for (var i = 0; i < arguments.length; i += 1) {
        var tokenDescriptor = i < 0 || arguments.length <= i ? undefined : arguments[i];
        var value = tokenDescriptor(node);

        if (value !== null) {
          this.index += 1;
          this.lastValue = value;
          return value;
        }
      }

      return null;
    };

    _proto.matches = function matches() {
      return this[SYMBOL_MATCH].apply(this, arguments) !== null;
    };

    _proto.expect = function expect() {
      var value = this[SYMBOL_MATCH].apply(this, arguments);
      return value !== null ? value : this["throw"]();
    };

    _proto.matchesFunction = function matchesFunction() {
      var node = this.nodes[this.index];
      if (node.type !== 'function') return null;
      var value = new TokenStream(node.nodes, node);
      this.index += 1;
      this.lastValue = null;
      return value;
    };

    _proto.expectFunction = function expectFunction() {
      var value = this.matchesFunction();
      return value !== null ? value : this["throw"]();
    };

    _proto.expectEmpty = function expectEmpty() {
      if (this.hasTokens()) this["throw"]();
    };

    _proto["throw"] = function _throw() {
      throw new Error("Unexpected token type: " + this.nodes[this.index].type);
    };

    _proto.saveRewindPoint = function saveRewindPoint() {
      this.rewindIndex = this.index;
    };

    _proto.rewind = function rewind() {
      if (this.rewindIndex === -1) throw new Error('Internal error');
      this.index = this.rewindIndex;
      this.lastValue = null;
    };

    return TokenStream;
  }();
  /* eslint-disable no-param-reassign */
  // Note if this is wrong, you'll need to change tokenTypes.js too


  var numberOrLengthRe = /^([+-]?(?:\d*\.)?\d+(?:e[+-]?\d+)?)(?:px)?$/i;
  var numberOnlyRe = /^[+-]?(?:\d*\.\d*|[1-9]\d*)(?:e[+-]?\d+)?$/i;
  var boolRe = /^true|false$/i;
  var nullRe = /^null$/i;
  var undefinedRe = /^undefined$/i; // Undocumented export

  var transformRawValue = function transformRawValue(propName, value) {
    {
      var needsUnit = !devPropertiesWithUnitsRegExp.test(propName);
      var isNumberWithoutUnit = numberOnlyRe.test(value);

      if (needsUnit && isNumberWithoutUnit) {
        // eslint-disable-next-line no-console
        console.warn("Expected style \"" + propName + ": " + value + "\" to contain units");
      }

      if (!needsUnit && value !== '0' && !isNumberWithoutUnit) {
        // eslint-disable-next-line no-console
        console.warn("Expected style \"" + propName + ": " + value + "\" to be unitless");
      }
    }

    var numberMatch = value.match(numberOrLengthRe);
    if (numberMatch !== null) return Number(numberMatch[1]);
    var boolMatch = value.match(boolRe);
    if (boolMatch !== null) return boolMatch[0].toLowerCase() === 'true';
    var nullMatch = value.match(nullRe);
    if (nullMatch !== null) return null;
    var undefinedMatch = value.match(undefinedRe);
    if (undefinedMatch !== null) return undefined;
    return value;
  };

  var baseTransformShorthandValue = function baseTransformShorthandValue(propName, value) {
    var ast = parse__default(value);
    var tokenStream = new TokenStream(ast.nodes);
    return transforms[propName](tokenStream);
  };

  var transformShorthandValue = function (propName, value) {
    try {
      return baseTransformShorthandValue(propName, value);
    } catch (e) {
      throw new Error("Failed to parse declaration \"" + propName + ": " + value + "\"");
    }
  };

  var getStylesForProperty = function getStylesForProperty(propName, inputValue, allowShorthand) {
    var _ref6;

    var isRawValue = allowShorthand === false || !(propName in transforms);
    var value = inputValue.trim();
    var propValues = isRawValue ? (_ref6 = {}, _ref6[propName] = transformRawValue(propName, value), _ref6) : transformShorthandValue(propName, value);
    return propValues;
  };

  var getPropertyName = function getPropertyName(propName) {
    var isCustomProp = /^--\w+/.test(propName);

    if (isCustomProp) {
      return propName;
    }

    return camelizeStyleName(propName);
  };

  var index = function index(rules, shorthandBlacklist) {
    if (shorthandBlacklist === void 0) {
      shorthandBlacklist = [];
    }

    return rules.reduce(function (accum, rule) {
      var propertyName = getPropertyName(rule[0]);
      var value = rule[1];
      var allowShorthand = shorthandBlacklist.indexOf(propertyName) === -1;
      return Object.assign(accum, getStylesForProperty(propertyName, value, allowShorthand));
    }, {});
  };

  exports["default"] = index;
  exports.getPropertyName = getPropertyName;
  exports.getStylesForProperty = getStylesForProperty;
  exports.transformRawValue = transformRawValue;
  });

  var transformREMUnitRE = /([+-]+)?([\d.Ee]+)rem/g;

  function rem(value) {
    if (_reactNative.Platform.OS === 'web') {
      return value;
    }

    return value.replace(transformREMUnitRE, function (_, unary, number) {
      return "".concat(unary || '').concat(_reactNative.PixelRatio.getFontScale() * 16 * number, "px");
    });
  }

  var valueRE = /^([+-]?(?:\d+|\d*\.\d+))([a-z]*|%)$/;

  var parseValue = function parseValue(value) {
    if (Array.isArray(value)) {
      return value;
    }

    if (typeof value === 'number') {
      return [value, null];
    }

    var matchedValue = value.match(valueRE);

    if (matchedValue) {
      return [parseFloat(value), matchedValue[2]];
    }

    return [value, undefined];
  };

  var getUnit = function getUnit(left, right) {
    if (!left && !right) {
      return '';
    }

    if (!left) {
      return right;
    }

    if (!right || left === right) {
      return left;
    }

    throw new Error("Different units ".concat(left, " and ").concat(right, " found for arithmetic operation."));
  };

  var POWER = Math.pow(10, 8);

  var fixRounding = function fixRounding(value) {
    return Math.round(value * POWER) / POWER;
  };

  var calculateValue = function calculateValue(leftValue, operator, rightValue) {
    if (operator === '+') {
      return leftValue + rightValue;
    }

    if (operator === '-') {
      return leftValue - rightValue;
    }

    if (operator === '*') {
      return fixRounding(leftValue * rightValue);
    }

    if (operator === '/') {
      return fixRounding(leftValue / rightValue);
    }

    if (operator === '%') {
      return leftValue % rightValue;
    }

    throw new Error('Unknown operator.');
  };

  function calculate(left, operator, right) {
    var _parseValue = parseValue(left),
        _parseValue2 = _slicedToArray(_parseValue, 2),
        leftValue = _parseValue2[0],
        leftUnit = _parseValue2[1];

    var _parseValue3 = parseValue(right),
        _parseValue4 = _slicedToArray(_parseValue3, 2),
        rightValue = _parseValue4[0],
        rightUnit = _parseValue4[1];

    var unit = getUnit(leftUnit, rightUnit);
    return "".concat(calculateValue(leftValue, operator, rightValue)).concat(unit);
  }

  var convertToREM = function convertToREM(value) {
    var remValue = value / (_reactNative.PixelRatio.getFontScale() * 16);
    return [remValue, 'rem'];
  }; // Use calculateAdvanced for mixed px/rem units.


  function calculateAdvanced(left, operator, right) {
    var parsedLeft = parseValue(left);

    var _parsedLeft = _slicedToArray(parsedLeft, 2),
        leftValue = _parsedLeft[0],
        leftUnit = _parsedLeft[1];

    var parsedRight = parseValue(right);

    var _parsedRight = _slicedToArray(parsedRight, 2),
        rightValue = _parsedRight[0],
        rightUnit = _parsedRight[1];

    if (leftUnit === 'px' && rightUnit === 'rem') {
      return calculate(convertToREM(leftValue), operator, parsedRight);
    }

    if (leftUnit === 'rem' && rightUnit === 'px') {
      return calculate(parsedLeft, operator, convertToREM(rightValue));
    }

    return calculate(parsedLeft, operator, parsedRight);
  }

  var formulaRE = /([+-])?([\d.Ee]+)(rem|px)?\s*(\+|-|\*|%)\s*([+-])?([\d.Ee]+)(rem|px)?/g;

  function formula(value) {
    // Naïve approach to calculate simple formulas.
    // TODO: Support more complex formulas including parenthesis.
    return value.replace(formulaRE, function (_) {
      var leftUnary = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
      var leftNumber = arguments.length > 2 ? arguments[2] : undefined;
      var leftUnit = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : null;
      var operator = arguments.length > 4 ? arguments[4] : undefined;
      var rightUnary = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : '';
      var rightNumber = arguments.length > 6 ? arguments[6] : undefined;
      var rightUnit = arguments.length > 7 && arguments[7] !== undefined ? arguments[7] : null;
      var leftValue = [parseFloat("".concat(leftUnary).concat(leftNumber)), leftUnit];
      var rightValue = [parseFloat("".concat(rightUnary).concat(rightNumber)), rightUnit];
      return calculate(leftValue, operator, rightValue);
    });
  }

  function _extends() {
    _extends = Object.assign ? Object.assign.bind() : function (target) {
      for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i];

        for (var key in source) {
          if (Object.prototype.hasOwnProperty.call(source, key)) {
            target[key] = source[key];
          }
        }
      }

      return target;
    };
    return _extends.apply(this, arguments);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }

    return self;
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function _setPrototypeOf(o, p) {
      o.__proto__ = p;
      return o;
    };
    return _setPrototypeOf(o, p);
  }

  function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass);
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };
    return _getPrototypeOf(o);
  }

  function _isNativeFunction(fn) {
    return Function.toString.call(fn).indexOf("[native code]") !== -1;
  }

  function _isNativeReflectConstruct() {
    if (typeof Reflect === "undefined" || !Reflect.construct) return false;
    if (Reflect.construct.sham) return false;
    if (typeof Proxy === "function") return true;

    try {
      Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {}));
      return true;
    } catch (e) {
      return false;
    }
  }

  function _construct(Parent, args, Class) {
    if (_isNativeReflectConstruct()) {
      _construct = Reflect.construct.bind();
    } else {
      _construct = function _construct(Parent, args, Class) {
        var a = [null];
        a.push.apply(a, args);
        var Constructor = Function.bind.apply(Parent, a);
        var instance = new Constructor();
        if (Class) _setPrototypeOf(instance, Class.prototype);
        return instance;
      };
    }

    return _construct.apply(null, arguments);
  }

  function _wrapNativeSuper(Class) {
    var _cache = typeof Map === "function" ? new Map() : undefined;

    _wrapNativeSuper = function _wrapNativeSuper(Class) {
      if (Class === null || !_isNativeFunction(Class)) return Class;

      if (typeof Class !== "function") {
        throw new TypeError("Super expression must either be null or a function");
      }

      if (typeof _cache !== "undefined") {
        if (_cache.has(Class)) return _cache.get(Class);

        _cache.set(Class, Wrapper);
      }

      function Wrapper() {
        return _construct(Class, arguments, _getPrototypeOf(this).constructor);
      }

      Wrapper.prototype = Object.create(Class.prototype, {
        constructor: {
          value: Wrapper,
          enumerable: false,
          writable: true,
          configurable: true
        }
      });
      return _setPrototypeOf(Wrapper, Class);
    };

    return _wrapNativeSuper(Class);
  }

  // based on https://github.com/styled-components/styled-components/blob/fcf6f3804c57a14dd7984dfab7bc06ee2edca044/src/utils/error.js

  /**
   * Parse errors.md and turn it into a simple hash of code: message
   * @private
   */
  var ERRORS = {
    "1": "Passed invalid arguments to hsl, please pass multiple numbers e.g. hsl(360, 0.75, 0.4) or an object e.g. rgb({ hue: 255, saturation: 0.4, lightness: 0.75 }).\n\n",
    "2": "Passed invalid arguments to hsla, please pass multiple numbers e.g. hsla(360, 0.75, 0.4, 0.7) or an object e.g. rgb({ hue: 255, saturation: 0.4, lightness: 0.75, alpha: 0.7 }).\n\n",
    "3": "Passed an incorrect argument to a color function, please pass a string representation of a color.\n\n",
    "4": "Couldn't generate valid rgb string from %s, it returned %s.\n\n",
    "5": "Couldn't parse the color string. Please provide the color as a string in hex, rgb, rgba, hsl or hsla notation.\n\n",
    "6": "Passed invalid arguments to rgb, please pass multiple numbers e.g. rgb(255, 205, 100) or an object e.g. rgb({ red: 255, green: 205, blue: 100 }).\n\n",
    "7": "Passed invalid arguments to rgba, please pass multiple numbers e.g. rgb(255, 205, 100, 0.75) or an object e.g. rgb({ red: 255, green: 205, blue: 100, alpha: 0.75 }).\n\n",
    "8": "Passed invalid argument to toColorString, please pass a RgbColor, RgbaColor, HslColor or HslaColor object.\n\n",
    "9": "Please provide a number of steps to the modularScale helper.\n\n",
    "10": "Please pass a number or one of the predefined scales to the modularScale helper as the ratio.\n\n",
    "11": "Invalid value passed as base to modularScale, expected number or em string but got \"%s\"\n\n",
    "12": "Expected a string ending in \"px\" or a number passed as the first argument to %s(), got \"%s\" instead.\n\n",
    "13": "Expected a string ending in \"px\" or a number passed as the second argument to %s(), got \"%s\" instead.\n\n",
    "14": "Passed invalid pixel value (\"%s\") to %s(), please pass a value like \"12px\" or 12.\n\n",
    "15": "Passed invalid base value (\"%s\") to %s(), please pass a value like \"12px\" or 12.\n\n",
    "16": "You must provide a template to this method.\n\n",
    "17": "You passed an unsupported selector state to this method.\n\n",
    "18": "minScreen and maxScreen must be provided as stringified numbers with the same units.\n\n",
    "19": "fromSize and toSize must be provided as stringified numbers with the same units.\n\n",
    "20": "expects either an array of objects or a single object with the properties prop, fromSize, and toSize.\n\n",
    "21": "expects the objects in the first argument array to have the properties `prop`, `fromSize`, and `toSize`.\n\n",
    "22": "expects the first argument object to have the properties `prop`, `fromSize`, and `toSize`.\n\n",
    "23": "fontFace expects a name of a font-family.\n\n",
    "24": "fontFace expects either the path to the font file(s) or a name of a local copy.\n\n",
    "25": "fontFace expects localFonts to be an array.\n\n",
    "26": "fontFace expects fileFormats to be an array.\n\n",
    "27": "radialGradient requries at least 2 color-stops to properly render.\n\n",
    "28": "Please supply a filename to retinaImage() as the first argument.\n\n",
    "29": "Passed invalid argument to triangle, please pass correct pointingDirection e.g. 'right'.\n\n",
    "30": "Passed an invalid value to `height` or `width`. Please provide a pixel based unit.\n\n",
    "31": "The animation shorthand only takes 8 arguments. See the specification for more information: http://mdn.io/animation\n\n",
    "32": "To pass multiple animations please supply them in arrays, e.g. animation(['rotate', '2s'], ['move', '1s'])\nTo pass a single animation please supply them in simple values, e.g. animation('rotate', '2s')\n\n",
    "33": "The animation shorthand arrays can only have 8 elements. See the specification for more information: http://mdn.io/animation\n\n",
    "34": "borderRadius expects a radius value as a string or number as the second argument.\n\n",
    "35": "borderRadius expects one of \"top\", \"bottom\", \"left\" or \"right\" as the first argument.\n\n",
    "36": "Property must be a string value.\n\n",
    "37": "Syntax Error at %s.\n\n",
    "38": "Formula contains a function that needs parentheses at %s.\n\n",
    "39": "Formula is missing closing parenthesis at %s.\n\n",
    "40": "Formula has too many closing parentheses at %s.\n\n",
    "41": "All values in a formula must have the same unit or be unitless.\n\n",
    "42": "Please provide a number of steps to the modularScale helper.\n\n",
    "43": "Please pass a number or one of the predefined scales to the modularScale helper as the ratio.\n\n",
    "44": "Invalid value passed as base to modularScale, expected number or em/rem string but got %s.\n\n",
    "45": "Passed invalid argument to hslToColorString, please pass a HslColor or HslaColor object.\n\n",
    "46": "Passed invalid argument to rgbToColorString, please pass a RgbColor or RgbaColor object.\n\n",
    "47": "minScreen and maxScreen must be provided as stringified numbers with the same units.\n\n",
    "48": "fromSize and toSize must be provided as stringified numbers with the same units.\n\n",
    "49": "Expects either an array of objects or a single object with the properties prop, fromSize, and toSize.\n\n",
    "50": "Expects the objects in the first argument array to have the properties prop, fromSize, and toSize.\n\n",
    "51": "Expects the first argument object to have the properties prop, fromSize, and toSize.\n\n",
    "52": "fontFace expects either the path to the font file(s) or a name of a local copy.\n\n",
    "53": "fontFace expects localFonts to be an array.\n\n",
    "54": "fontFace expects fileFormats to be an array.\n\n",
    "55": "fontFace expects a name of a font-family.\n\n",
    "56": "linearGradient requries at least 2 color-stops to properly render.\n\n",
    "57": "radialGradient requries at least 2 color-stops to properly render.\n\n",
    "58": "Please supply a filename to retinaImage() as the first argument.\n\n",
    "59": "Passed invalid argument to triangle, please pass correct pointingDirection e.g. 'right'.\n\n",
    "60": "Passed an invalid value to `height` or `width`. Please provide a pixel based unit.\n\n",
    "61": "Property must be a string value.\n\n",
    "62": "borderRadius expects a radius value as a string or number as the second argument.\n\n",
    "63": "borderRadius expects one of \"top\", \"bottom\", \"left\" or \"right\" as the first argument.\n\n",
    "64": "The animation shorthand only takes 8 arguments. See the specification for more information: http://mdn.io/animation.\n\n",
    "65": "To pass multiple animations please supply them in arrays, e.g. animation(['rotate', '2s'], ['move', '1s'])\\nTo pass a single animation please supply them in simple values, e.g. animation('rotate', '2s').\n\n",
    "66": "The animation shorthand arrays can only have 8 elements. See the specification for more information: http://mdn.io/animation.\n\n",
    "67": "You must provide a template to this method.\n\n",
    "68": "You passed an unsupported selector state to this method.\n\n",
    "69": "Expected a string ending in \"px\" or a number passed as the first argument to %s(), got %s instead.\n\n",
    "70": "Expected a string ending in \"px\" or a number passed as the second argument to %s(), got %s instead.\n\n",
    "71": "Passed invalid pixel value %s to %s(), please pass a value like \"12px\" or 12.\n\n",
    "72": "Passed invalid base value %s to %s(), please pass a value like \"12px\" or 12.\n\n",
    "73": "Please provide a valid CSS variable.\n\n",
    "74": "CSS variable not found and no default was provided.\n\n",
    "75": "important requires a valid style object, got a %s instead.\n\n",
    "76": "fromSize and toSize must be provided as stringified numbers with the same units as minScreen and maxScreen.\n\n",
    "77": "remToPx expects a value in \"rem\" but you provided it in \"%s\".\n\n",
    "78": "base must be set in \"px\" or \"%\" but you set it in \"%s\".\n"
  };
  /**
   * super basic version of sprintf
   * @private
   */

  function format() {
    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    var a = args[0];
    var b = [];
    var c;

    for (c = 1; c < args.length; c += 1) {
      b.push(args[c]);
    }

    b.forEach(function (d) {
      a = a.replace(/%[a-z]/, d);
    });
    return a;
  }
  /**
   * Create an error file out of errors.md for development and a simple web link to the full errors
   * in production mode.
   * @private
   */


  var PolishedError = /*#__PURE__*/function (_Error) {
    _inheritsLoose(PolishedError, _Error);

    function PolishedError(code) {
      var _this;

      {
        for (var _len2 = arguments.length, args = new Array(_len2 > 1 ? _len2 - 1 : 0), _key2 = 1; _key2 < _len2; _key2++) {
          args[_key2 - 1] = arguments[_key2];
        }

        _this = _Error.call(this, format.apply(void 0, [ERRORS[code]].concat(args))) || this;
      }

      return _assertThisInitialized(_this);
    }

    return PolishedError;
  }( /*#__PURE__*/_wrapNativeSuper(Error));

  function colorToInt(color) {
    return Math.round(color * 255);
  }

  function convertToInt(red, green, blue) {
    return colorToInt(red) + "," + colorToInt(green) + "," + colorToInt(blue);
  }

  function hslToRgb(hue, saturation, lightness, convert) {
    if (convert === void 0) {
      convert = convertToInt;
    }

    if (saturation === 0) {
      // achromatic
      return convert(lightness, lightness, lightness);
    } // formulae from https://en.wikipedia.org/wiki/HSL_and_HSV


    var huePrime = (hue % 360 + 360) % 360 / 60;
    var chroma = (1 - Math.abs(2 * lightness - 1)) * saturation;
    var secondComponent = chroma * (1 - Math.abs(huePrime % 2 - 1));
    var red = 0;
    var green = 0;
    var blue = 0;

    if (huePrime >= 0 && huePrime < 1) {
      red = chroma;
      green = secondComponent;
    } else if (huePrime >= 1 && huePrime < 2) {
      red = secondComponent;
      green = chroma;
    } else if (huePrime >= 2 && huePrime < 3) {
      green = chroma;
      blue = secondComponent;
    } else if (huePrime >= 3 && huePrime < 4) {
      green = secondComponent;
      blue = chroma;
    } else if (huePrime >= 4 && huePrime < 5) {
      red = secondComponent;
      blue = chroma;
    } else if (huePrime >= 5 && huePrime < 6) {
      red = chroma;
      blue = secondComponent;
    }

    var lightnessModification = lightness - chroma / 2;
    var finalRed = red + lightnessModification;
    var finalGreen = green + lightnessModification;
    var finalBlue = blue + lightnessModification;
    return convert(finalRed, finalGreen, finalBlue);
  }

  var namedColorMap = {
    aliceblue: 'f0f8ff',
    antiquewhite: 'faebd7',
    aqua: '00ffff',
    aquamarine: '7fffd4',
    azure: 'f0ffff',
    beige: 'f5f5dc',
    bisque: 'ffe4c4',
    black: '000',
    blanchedalmond: 'ffebcd',
    blue: '0000ff',
    blueviolet: '8a2be2',
    brown: 'a52a2a',
    burlywood: 'deb887',
    cadetblue: '5f9ea0',
    chartreuse: '7fff00',
    chocolate: 'd2691e',
    coral: 'ff7f50',
    cornflowerblue: '6495ed',
    cornsilk: 'fff8dc',
    crimson: 'dc143c',
    cyan: '00ffff',
    darkblue: '00008b',
    darkcyan: '008b8b',
    darkgoldenrod: 'b8860b',
    darkgray: 'a9a9a9',
    darkgreen: '006400',
    darkgrey: 'a9a9a9',
    darkkhaki: 'bdb76b',
    darkmagenta: '8b008b',
    darkolivegreen: '556b2f',
    darkorange: 'ff8c00',
    darkorchid: '9932cc',
    darkred: '8b0000',
    darksalmon: 'e9967a',
    darkseagreen: '8fbc8f',
    darkslateblue: '483d8b',
    darkslategray: '2f4f4f',
    darkslategrey: '2f4f4f',
    darkturquoise: '00ced1',
    darkviolet: '9400d3',
    deeppink: 'ff1493',
    deepskyblue: '00bfff',
    dimgray: '696969',
    dimgrey: '696969',
    dodgerblue: '1e90ff',
    firebrick: 'b22222',
    floralwhite: 'fffaf0',
    forestgreen: '228b22',
    fuchsia: 'ff00ff',
    gainsboro: 'dcdcdc',
    ghostwhite: 'f8f8ff',
    gold: 'ffd700',
    goldenrod: 'daa520',
    gray: '808080',
    green: '008000',
    greenyellow: 'adff2f',
    grey: '808080',
    honeydew: 'f0fff0',
    hotpink: 'ff69b4',
    indianred: 'cd5c5c',
    indigo: '4b0082',
    ivory: 'fffff0',
    khaki: 'f0e68c',
    lavender: 'e6e6fa',
    lavenderblush: 'fff0f5',
    lawngreen: '7cfc00',
    lemonchiffon: 'fffacd',
    lightblue: 'add8e6',
    lightcoral: 'f08080',
    lightcyan: 'e0ffff',
    lightgoldenrodyellow: 'fafad2',
    lightgray: 'd3d3d3',
    lightgreen: '90ee90',
    lightgrey: 'd3d3d3',
    lightpink: 'ffb6c1',
    lightsalmon: 'ffa07a',
    lightseagreen: '20b2aa',
    lightskyblue: '87cefa',
    lightslategray: '789',
    lightslategrey: '789',
    lightsteelblue: 'b0c4de',
    lightyellow: 'ffffe0',
    lime: '0f0',
    limegreen: '32cd32',
    linen: 'faf0e6',
    magenta: 'f0f',
    maroon: '800000',
    mediumaquamarine: '66cdaa',
    mediumblue: '0000cd',
    mediumorchid: 'ba55d3',
    mediumpurple: '9370db',
    mediumseagreen: '3cb371',
    mediumslateblue: '7b68ee',
    mediumspringgreen: '00fa9a',
    mediumturquoise: '48d1cc',
    mediumvioletred: 'c71585',
    midnightblue: '191970',
    mintcream: 'f5fffa',
    mistyrose: 'ffe4e1',
    moccasin: 'ffe4b5',
    navajowhite: 'ffdead',
    navy: '000080',
    oldlace: 'fdf5e6',
    olive: '808000',
    olivedrab: '6b8e23',
    orange: 'ffa500',
    orangered: 'ff4500',
    orchid: 'da70d6',
    palegoldenrod: 'eee8aa',
    palegreen: '98fb98',
    paleturquoise: 'afeeee',
    palevioletred: 'db7093',
    papayawhip: 'ffefd5',
    peachpuff: 'ffdab9',
    peru: 'cd853f',
    pink: 'ffc0cb',
    plum: 'dda0dd',
    powderblue: 'b0e0e6',
    purple: '800080',
    rebeccapurple: '639',
    red: 'f00',
    rosybrown: 'bc8f8f',
    royalblue: '4169e1',
    saddlebrown: '8b4513',
    salmon: 'fa8072',
    sandybrown: 'f4a460',
    seagreen: '2e8b57',
    seashell: 'fff5ee',
    sienna: 'a0522d',
    silver: 'c0c0c0',
    skyblue: '87ceeb',
    slateblue: '6a5acd',
    slategray: '708090',
    slategrey: '708090',
    snow: 'fffafa',
    springgreen: '00ff7f',
    steelblue: '4682b4',
    tan: 'd2b48c',
    teal: '008080',
    thistle: 'd8bfd8',
    tomato: 'ff6347',
    turquoise: '40e0d0',
    violet: 'ee82ee',
    wheat: 'f5deb3',
    white: 'fff',
    whitesmoke: 'f5f5f5',
    yellow: 'ff0',
    yellowgreen: '9acd32'
  };
  /**
   * Checks if a string is a CSS named color and returns its equivalent hex value, otherwise returns the original color.
   * @private
   */

  function nameToHex(color) {
    if (typeof color !== 'string') return color;
    var normalizedColorName = color.toLowerCase();
    return namedColorMap[normalizedColorName] ? "#" + namedColorMap[normalizedColorName] : color;
  }

  var hexRegex = /^#[a-fA-F0-9]{6}$/;
  var hexRgbaRegex = /^#[a-fA-F0-9]{8}$/;
  var reducedHexRegex = /^#[a-fA-F0-9]{3}$/;
  var reducedRgbaHexRegex = /^#[a-fA-F0-9]{4}$/;
  var rgbRegex = /^rgb\(\s*(\d{1,3})\s*(?:,)?\s*(\d{1,3})\s*(?:,)?\s*(\d{1,3})\s*\)$/i;
  var rgbaRegex = /^rgb(?:a)?\(\s*(\d{1,3})\s*(?:,)?\s*(\d{1,3})\s*(?:,)?\s*(\d{1,3})\s*(?:,|\/)\s*([-+]?\d*[.]?\d+[%]?)\s*\)$/i;
  var hslRegex = /^hsl\(\s*(\d{0,3}[.]?[0-9]+(?:deg)?)\s*(?:,)?\s*(\d{1,3}[.]?[0-9]?)%\s*(?:,)?\s*(\d{1,3}[.]?[0-9]?)%\s*\)$/i;
  var hslaRegex = /^hsl(?:a)?\(\s*(\d{0,3}[.]?[0-9]+(?:deg)?)\s*(?:,)?\s*(\d{1,3}[.]?[0-9]?)%\s*(?:,)?\s*(\d{1,3}[.]?[0-9]?)%\s*(?:,|\/)\s*([-+]?\d*[.]?\d+[%]?)\s*\)$/i;
  /**
   * Returns an RgbColor or RgbaColor object. This utility function is only useful
   * if want to extract a color component. With the color util `toColorString` you
   * can convert a RgbColor or RgbaColor object back to a string.
   *
   * @example
   * // Assigns `{ red: 255, green: 0, blue: 0 }` to color1
   * const color1 = parseToRgb('rgb(255, 0, 0)');
   * // Assigns `{ red: 92, green: 102, blue: 112, alpha: 0.75 }` to color2
   * const color2 = parseToRgb('hsla(210, 10%, 40%, 0.75)');
   */

  function parseToRgb(color) {
    if (typeof color !== 'string') {
      throw new PolishedError(3);
    }

    var normalizedColor = nameToHex(color);

    if (normalizedColor.match(hexRegex)) {
      return {
        red: parseInt("" + normalizedColor[1] + normalizedColor[2], 16),
        green: parseInt("" + normalizedColor[3] + normalizedColor[4], 16),
        blue: parseInt("" + normalizedColor[5] + normalizedColor[6], 16)
      };
    }

    if (normalizedColor.match(hexRgbaRegex)) {
      var alpha = parseFloat((parseInt("" + normalizedColor[7] + normalizedColor[8], 16) / 255).toFixed(2));
      return {
        red: parseInt("" + normalizedColor[1] + normalizedColor[2], 16),
        green: parseInt("" + normalizedColor[3] + normalizedColor[4], 16),
        blue: parseInt("" + normalizedColor[5] + normalizedColor[6], 16),
        alpha: alpha
      };
    }

    if (normalizedColor.match(reducedHexRegex)) {
      return {
        red: parseInt("" + normalizedColor[1] + normalizedColor[1], 16),
        green: parseInt("" + normalizedColor[2] + normalizedColor[2], 16),
        blue: parseInt("" + normalizedColor[3] + normalizedColor[3], 16)
      };
    }

    if (normalizedColor.match(reducedRgbaHexRegex)) {
      var _alpha = parseFloat((parseInt("" + normalizedColor[4] + normalizedColor[4], 16) / 255).toFixed(2));

      return {
        red: parseInt("" + normalizedColor[1] + normalizedColor[1], 16),
        green: parseInt("" + normalizedColor[2] + normalizedColor[2], 16),
        blue: parseInt("" + normalizedColor[3] + normalizedColor[3], 16),
        alpha: _alpha
      };
    }

    var rgbMatched = rgbRegex.exec(normalizedColor);

    if (rgbMatched) {
      return {
        red: parseInt("" + rgbMatched[1], 10),
        green: parseInt("" + rgbMatched[2], 10),
        blue: parseInt("" + rgbMatched[3], 10)
      };
    }

    var rgbaMatched = rgbaRegex.exec(normalizedColor.substring(0, 50));

    if (rgbaMatched) {
      return {
        red: parseInt("" + rgbaMatched[1], 10),
        green: parseInt("" + rgbaMatched[2], 10),
        blue: parseInt("" + rgbaMatched[3], 10),
        alpha: parseFloat("" + rgbaMatched[4]) > 1 ? parseFloat("" + rgbaMatched[4]) / 100 : parseFloat("" + rgbaMatched[4])
      };
    }

    var hslMatched = hslRegex.exec(normalizedColor);

    if (hslMatched) {
      var hue = parseInt("" + hslMatched[1], 10);
      var saturation = parseInt("" + hslMatched[2], 10) / 100;
      var lightness = parseInt("" + hslMatched[3], 10) / 100;
      var rgbColorString = "rgb(" + hslToRgb(hue, saturation, lightness) + ")";
      var hslRgbMatched = rgbRegex.exec(rgbColorString);

      if (!hslRgbMatched) {
        throw new PolishedError(4, normalizedColor, rgbColorString);
      }

      return {
        red: parseInt("" + hslRgbMatched[1], 10),
        green: parseInt("" + hslRgbMatched[2], 10),
        blue: parseInt("" + hslRgbMatched[3], 10)
      };
    }

    var hslaMatched = hslaRegex.exec(normalizedColor.substring(0, 50));

    if (hslaMatched) {
      var _hue = parseInt("" + hslaMatched[1], 10);

      var _saturation = parseInt("" + hslaMatched[2], 10) / 100;

      var _lightness = parseInt("" + hslaMatched[3], 10) / 100;

      var _rgbColorString = "rgb(" + hslToRgb(_hue, _saturation, _lightness) + ")";

      var _hslRgbMatched = rgbRegex.exec(_rgbColorString);

      if (!_hslRgbMatched) {
        throw new PolishedError(4, normalizedColor, _rgbColorString);
      }

      return {
        red: parseInt("" + _hslRgbMatched[1], 10),
        green: parseInt("" + _hslRgbMatched[2], 10),
        blue: parseInt("" + _hslRgbMatched[3], 10),
        alpha: parseFloat("" + hslaMatched[4]) > 1 ? parseFloat("" + hslaMatched[4]) / 100 : parseFloat("" + hslaMatched[4])
      };
    }

    throw new PolishedError(5);
  }

  /**
   * Reduces hex values if possible e.g. #ff8866 to #f86
   * @private
   */
  var reduceHexValue = function reduceHexValue(value) {
    if (value.length === 7 && value[1] === value[2] && value[3] === value[4] && value[5] === value[6]) {
      return "#" + value[1] + value[3] + value[5];
    }

    return value;
  };

  var reduceHexValue$1 = reduceHexValue;

  function numberToHex(value) {
    var hex = value.toString(16);
    return hex.length === 1 ? "0" + hex : hex;
  }

  /**
   * Returns a string value for the color. The returned result is the smallest possible hex notation.
   *
   * @example
   * // Styles as object usage
   * const styles = {
   *   background: rgb(255, 205, 100),
   *   background: rgb({ red: 255, green: 205, blue: 100 }),
   * }
   *
   * // styled-components usage
   * const div = styled.div`
   *   background: ${rgb(255, 205, 100)};
   *   background: ${rgb({ red: 255, green: 205, blue: 100 })};
   * `
   *
   * // CSS in JS Output
   *
   * element {
   *   background: "#ffcd64";
   *   background: "#ffcd64";
   * }
   */
  function rgb(value, green, blue) {
    if (typeof value === 'number' && typeof green === 'number' && typeof blue === 'number') {
      return reduceHexValue$1("#" + numberToHex(value) + numberToHex(green) + numberToHex(blue));
    } else if (typeof value === 'object' && green === undefined && blue === undefined) {
      return reduceHexValue$1("#" + numberToHex(value.red) + numberToHex(value.green) + numberToHex(value.blue));
    }

    throw new PolishedError(6);
  }

  /**
   * Returns a string value for the color. The returned result is the smallest possible rgba or hex notation.
   *
   * Can also be used to fade a color by passing a hex value or named CSS color along with an alpha value.
   *
   * @example
   * // Styles as object usage
   * const styles = {
   *   background: rgba(255, 205, 100, 0.7),
   *   background: rgba({ red: 255, green: 205, blue: 100, alpha: 0.7 }),
   *   background: rgba(255, 205, 100, 1),
   *   background: rgba('#ffffff', 0.4),
   *   background: rgba('black', 0.7),
   * }
   *
   * // styled-components usage
   * const div = styled.div`
   *   background: ${rgba(255, 205, 100, 0.7)};
   *   background: ${rgba({ red: 255, green: 205, blue: 100, alpha: 0.7 })};
   *   background: ${rgba(255, 205, 100, 1)};
   *   background: ${rgba('#ffffff', 0.4)};
   *   background: ${rgba('black', 0.7)};
   * `
   *
   * // CSS in JS Output
   *
   * element {
   *   background: "rgba(255,205,100,0.7)";
   *   background: "rgba(255,205,100,0.7)";
   *   background: "#ffcd64";
   *   background: "rgba(255,255,255,0.4)";
   *   background: "rgba(0,0,0,0.7)";
   * }
   */
  function rgba$1(firstValue, secondValue, thirdValue, fourthValue) {
    if (typeof firstValue === 'string' && typeof secondValue === 'number') {
      var rgbValue = parseToRgb(firstValue);
      return "rgba(" + rgbValue.red + "," + rgbValue.green + "," + rgbValue.blue + "," + secondValue + ")";
    } else if (typeof firstValue === 'number' && typeof secondValue === 'number' && typeof thirdValue === 'number' && typeof fourthValue === 'number') {
      return fourthValue >= 1 ? rgb(firstValue, secondValue, thirdValue) : "rgba(" + firstValue + "," + secondValue + "," + thirdValue + "," + fourthValue + ")";
    } else if (typeof firstValue === 'object' && secondValue === undefined && thirdValue === undefined && fourthValue === undefined) {
      return firstValue.alpha >= 1 ? rgb(firstValue.red, firstValue.green, firstValue.blue) : "rgba(" + firstValue.red + "," + firstValue.green + "," + firstValue.blue + "," + firstValue.alpha + ")";
    }

    throw new PolishedError(7);
  }

  // Type definitions taken from https://github.com/gcanti/flow-static-land/blob/master/src/Fun.js
  // eslint-disable-next-line no-unused-vars
  // eslint-disable-next-line no-unused-vars
  // eslint-disable-next-line no-redeclare
  function curried(f, length, acc) {
    return function fn() {
      // eslint-disable-next-line prefer-rest-params
      var combined = acc.concat(Array.prototype.slice.call(arguments));
      return combined.length >= length ? f.apply(this, combined) : curried(f, length, combined);
    };
  } // eslint-disable-next-line no-redeclare


  function curry(f) {
    // eslint-disable-line no-redeclare
    return curried(f, f.length, []);
  }

  /**
   * Mixes the two provided colors together by calculating the average of each of the RGB components weighted to the first color by the provided weight.
   *
   * @example
   * // Styles as object usage
   * const styles = {
   *   background: mix(0.5, '#f00', '#00f')
   *   background: mix(0.25, '#f00', '#00f')
   *   background: mix('0.5', 'rgba(255, 0, 0, 0.5)', '#00f')
   * }
   *
   * // styled-components usage
   * const div = styled.div`
   *   background: ${mix(0.5, '#f00', '#00f')};
   *   background: ${mix(0.25, '#f00', '#00f')};
   *   background: ${mix('0.5', 'rgba(255, 0, 0, 0.5)', '#00f')};
   * `
   *
   * // CSS in JS Output
   *
   * element {
   *   background: "#7f007f";
   *   background: "#3f00bf";
   *   background: "rgba(63, 0, 191, 0.75)";
   * }
   */

  function mix$1(weight, color, otherColor) {
    if (color === 'transparent') return otherColor;
    if (otherColor === 'transparent') return color;
    if (weight === 0) return otherColor;
    var parsedColor1 = parseToRgb(color);

    var color1 = _extends({}, parsedColor1, {
      alpha: typeof parsedColor1.alpha === 'number' ? parsedColor1.alpha : 1
    });

    var parsedColor2 = parseToRgb(otherColor);

    var color2 = _extends({}, parsedColor2, {
      alpha: typeof parsedColor2.alpha === 'number' ? parsedColor2.alpha : 1
    }); // The formula is copied from the original Sass implementation:
    // http://sass-lang.com/documentation/Sass/Script/Functions.html#mix-instance_method


    var alphaDelta = color1.alpha - color2.alpha;
    var x = parseFloat(weight) * 2 - 1;
    var y = x * alphaDelta === -1 ? x : x + alphaDelta;
    var z = 1 + x * alphaDelta;
    var weight1 = (y / z + 1) / 2.0;
    var weight2 = 1 - weight1;
    var mixedColor = {
      red: Math.floor(color1.red * weight1 + color2.red * weight2),
      green: Math.floor(color1.green * weight1 + color2.green * weight2),
      blue: Math.floor(color1.blue * weight1 + color2.blue * weight2),
      alpha: color1.alpha * parseFloat(weight) + color2.alpha * (1 - parseFloat(weight))
    };
    return rgba$1(mixedColor);
  } // prettier-ignore


  var curriedMix = /*#__PURE__*/curry
  /* ::<number | string, string, string, string> */
  (mix$1);
  var mix$1$1 = curriedMix;

  var transformRgbaRE = /rgba\(\s*([#0-9a-z]+)\s*,\s*([\d.Ee]+)\s*\)/g;

  function rgba(value) {
    return value.replace(transformRgbaRE, function (_, color, alpha) {
      return rgba$1(color, Number(alpha));
    });
  }

  var applyVariables = function applyVariables(variables, key, value) {
    return typeof value === 'function' ? value(variables, key) : value;
  };

  var applyTransforms = function applyTransforms(result) {
    return rgba(formula(rem(result)));
  };

  var resolveValue = function resolveValue(value, definition, theme, options) {
    var variables = options.preferTheme ? _objectSpread2(_objectSpread2({}, definition.variables), theme) : _objectSpread2(_objectSpread2({}, theme), definition.variables); // If there is only one part, we allow other results than strings as well.

    if (value.length === 1) {
      var result = applyVariables(variables, options.key, value[0]);
      return typeof result === 'string' ? applyTransforms(result) : result;
    }

    var stringifiedResult = value.reduce(function (previous, current) {
      return "".concat(previous).concat(applyVariables(variables, options.key, current));
    }, '');
    return applyTransforms(stringifiedResult);
  };

  function transform$2(children, theme) {
    var options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
    var scopes = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : [];
    var variables = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : {};
    var definitions = [{
      scopes: scopes,
      declarations: {},
      variables: _objectSpread2({}, variables)
    }];
    children.forEach(function (child) {
      if (child.type === 'variable' || child.type === 'declaration') {
        // Transform value to react native compatible value.
        var value = resolveValue(child.value, definitions[0], theme, options);

        if (child.type === 'variable') {
          definitions[0].variables[child.name] = value;
        } // Only add value if value is not null.


        if (child.type === 'declaration' && value !== 'null') {
          if (child.name === 'box-shadow') {
            if (_reactNative.Platform.OS === 'web') {
              Object.assign(definitions[0].declarations, {
                boxShadow: value
              });
            }
          } else if (child.name === 'order') {
            if (_reactNative.Platform.OS === 'web') {
              Object.assign(definitions[0].declarations, {
                order: value
              });
            }
          } else if (child.name === 'margin-horizontal' && value === 'auto') {
            // Workaround for react-native issue #350
            // https://github.com/facebook/react-native/issues/350#issuecomment-375238958
            Object.assign(definitions[0].declarations, {
              marginLeft: value,
              marginRight: value
            });
          } else if (child.name === 'border-color' && value.split(' ').length === 1) {
            // Workaround for react-native issue #19981
            // https://github.com/facebook/react-native/issues/19981
            Object.assign(definitions[0].declarations, {
              borderColor: value
            });
          } else {
            // TODO: Pre-process css-to-react-native transformation, so that we only
            // need to insert theme variables here.
            Object.assign(definitions[0].declarations, cssToReactNative.getStylesForProperty(cssToReactNative.getPropertyName(child.name), value));
          }
        }
      }

      if (child.type === 'block') {
        definitions = definitions.concat(transform$2(child.children, theme, options, // Add child scopes to current scopes.
        [].concat(_toConsumableArray(scopes), _toConsumableArray(child.scopes)), // Pass down variables, so that we can extend them.
        definitions[0].variables));
      }
    }); // Filter empty definitions and return.

    return definitions.filter(function (definition) {
      return Object.keys(definition.declarations).length > 0 || Object.keys(definition.variables).length > 0;
    });
  }

  var mediaBreakpointUp$3 = {
    include: function include() {
      return true;
    },
    apply: function apply(scope, _ref) {
      var media = _ref.media;
      return media.up(scope.args[0]) && media.down(scope.args[1]);
    }
  };

  var mediaBreakpointUp$2 = {
    include: function include() {
      return true;
    },
    apply: function apply(scope, _ref) {
      var media = _ref.media;
      return media.down(scope.args[0]);
    }
  };

  var mediaBreakpointUp$1 = {
    include: function include() {
      return true;
    },
    apply: function apply(scope, _ref) {
      var media = _ref.media;
      return media.up(scope.args[0]) && media.down(scope.args[0]);
    }
  };

  var mediaBreakpointUp = {
    include: function include() {
      return true;
    },
    apply: function apply(scope, _ref) {
      var media = _ref.media;
      return media.up(scope.args[0]);
    }
  };

  var platform = {
    include: function include(scope) {
      return scope.args[0] === 'native' ? _reactNative.Platform.OS === 'android' || _reactNative.Platform.OS === 'ios' : _reactNative.Platform.OS === scope.args[0];
    },
    apply: function apply() {
      return true;
    }
  };

  var BOOTSTRAP_RN_STYLE = Symbol.for('bootstrap-rn.style');
  var mixins = {
    'media-breakpoint-between': mediaBreakpointUp$3,
    'media-breakpoint-down': mediaBreakpointUp$2,
    'media-breakpoint-only': mediaBreakpointUp$1,
    'media-breakpoint-up': mediaBreakpointUp,
    platform: platform
  };

  var hasInteraction = function hasInteraction(_ref) {
    var scopes = _ref.scopes;
    return scopes.some(function (scope) {
      return scope.type === 'selector';
    });
  };

  function createStyle(definitions) {
    // If there is only one definition without conditions, return.
    if (definitions.length === 1 && definitions[0].scopes.length === 0) {
      return definitions[0].declarations;
    } // Filter definitions that should not be used based on mixins.


    var platformDefinitions = definitions.filter(function (item) {
      return item.scopes.every(function (scope) {
        if (scope.type !== 'mixin') {
          return true;
        }

        return mixins[scope.name].include(scope);
      });
    }); // Create style sheets.

    var styles = _reactNative.StyleSheet.create(_objectSpread2({}, platformDefinitions.map(function (item) {
      return item.declarations;
    })));

    var resolve = function resolve(state) {
      var interaction = state.interaction;
      var basicStyles = [];
      var interactionStyles = [];
      Object.values(styles).forEach(function (style, key) {
        var active = platformDefinitions[key].scopes.every(function (scope) {
          if (scope.type === 'selector') {
            if (scope.name === 'hover') {
              return interaction && interaction.hovered;
            }

            if (scope.name === 'focus') {
              return interaction && interaction.focused;
            }

            if (scope.name === 'active') {
              return interaction && interaction.pressed;
            }
          }

          if (scope.type === 'mixin') {
            return mixins[scope.name].apply(scope, state);
          }

          throw new Error("Unknown scope type \"".concat(scope.type, "\""));
        });

        if (active) {
          if (hasInteraction(platformDefinitions[key])) {
            interactionStyles.push(style);
          } else {
            basicStyles.push(style);
          }
        }
      });
      return [basicStyles, interactionStyles];
    };

    resolve.$$typeof = BOOTSTRAP_RN_STYLE;
    return resolve;
  }

  function css$1() {
    var ast = parse$5.apply(void 0, arguments);

    var result = function result(theme, key) {
      var transformed = transform$2(ast.children, theme, {
        key: key
      });
      return createStyle(transformed);
    };

    result.ast = ast;
    return result;
  }

  function each(source, apply) {
    return Object.entries(source).map(function (_ref) {
      var _ref2 = _slicedToArray(_ref, 2),
          key = _ref2[0],
          value = _ref2[1];

      var resolve = typeof value === 'function' ? value : function () {
        return value;
      };
      return apply(key, resolve);
    }).reduce(function (carry, item) {
      return Object.assign(carry, item);
    }, {});
  }
  function normalize$1(value) {
    return value.reduce(function (carry, item) {
      return Object.assign(carry, item);
    }, {});
  }
  function makeProxy(name, keys) {
    return keys.reduce(function (result, key) {
      return _objectSpread2(_objectSpread2({}, result), {}, _defineProperty({}, key, function (t) {
        return t[name][key];
      }));
    }, {});
  }
  function makeArray(length, callback) {
    return Array.from({
      length: length
    }, function (_, i) {
      return callback ? callback(i) : i;
    });
  }

  var flattenChildren = function flattenChildren(children) {
    var keyPrefix = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
    var childrenArray = React__default["default"].Children.toArray(children);
    return childrenArray.reduce(function (flatChildren, child) {
      var newKey = "".concat(keyPrefix).concat(child.key);

      if (child.type === React__default["default"].Fragment) {
        return flatChildren.concat(flattenChildren(child.props.children, newKey));
      }

      if ( /*#__PURE__*/React__default["default"].isValidElement(child) && _typeof(child) === 'object') {
        flatChildren.push( /*#__PURE__*/React__default["default"].cloneElement(child, {
          key: newKey
        }));
      } else {
        flatChildren.push(child);
      }

      return flatChildren;
    }, []);
  };

  function makeListChildren(children) {
    var flattenedChildren = flattenChildren(children);
    return React__default["default"].Children.map(flattenedChildren, function (child, index) {
      var first = index === 0;
      var last = index === flattenedChildren.length - 1;
      return /*#__PURE__*/React__default["default"].cloneElement(child, {
        first: first,
        last: last
      });
    });
  }
  function getStyles(styles, keys) {
    return keys.filter(function (key) {
      return !!key;
    }).map(function (key) {
      return styles[key];
    });
  }
  function concatRefs() {
    for (var _len = arguments.length, refs = new Array(_len), _key = 0; _key < _len; _key++) {
      refs[_key] = arguments[_key];
    }

    return function (element) {
      refs.forEach(function (ref) {
        if (typeof ref === 'function') {
          ref(element);
        } else if (ref) {
          // eslint-disable-next-line no-param-reassign
          ref.current = element;
        }
      });
    };
  }
  function concatFns() {
    for (var _len2 = arguments.length, fns = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
      fns[_key2] = arguments[_key2];
    }

    return function (event) {
      fns.forEach(function (fn) {
        if (fn) {
          fn(event);
        }
      });
    };
  }
  function optional(condition, value) {
    return condition ? value : undefined;
  }
  function getElementId(identifier, name) {
    return "".concat(identifier).concat(name ? "-".concat(name) : '');
  }
  function transformPlacement$1(placement) {
    if (placement === 'left') {
      return _reactNative.I18nManager.isRTL ? 'end' : 'start';
    }

    if (placement === 'right') {
      return _reactNative.I18nManager.isRTL ? 'start' : 'end';
    }

    return placement;
  }
  function convertToNumber(value) {
    return parseFloat(value.replace(/([+-])?([\d.Ee]+)rem/g, function (_, unary, number) {
      return "".concat(unary || '').concat(_reactNative.PixelRatio.getFontScale() * 16 * number, "px");
    }));
  }

  // keys, but not the resolved values. The values are added later by the used
  // theme.
  // Color system

  makeProxy('grays', ['100', '200', '300', '400', '500', '600', '700', '800', '900']);
  makeProxy('colors', ['blue', 'indigo', 'purple', 'pink', 'red', 'orange', 'yellow', 'green', 'teal', 'cyan']);
  var THEME_COLORS = makeProxy('theme-colors', ['primary', 'secondary', 'success', 'info', 'warning', 'danger', 'light', 'dark']);
  makeProxy('blues', ['blue-100', 'blue-200', 'blue-300', 'blue-400', 'blue-500', 'blue-600', 'blue-700', 'blue-800', 'blue-900']);
  makeProxy('indigos', ['indigo-100', 'indigo-200', 'indigo-300', 'indigo-400', 'indigo-500', 'indigo-600', 'indigo-700', 'indigo-800', 'indigo-900']);
  makeProxy('purples', ['purple-100', 'purple-200', 'purple-300', 'purple-400', 'purple-500', 'purple-600', 'purple-700', 'purple-800', 'purple-900']);
  makeProxy('pinks', ['pink-100', 'pink-200', 'pink-300', 'pink-400', 'pink-500', 'pink-600', 'pink-700', 'pink-800', 'pink-900']);
  makeProxy('reds', ['red-100', 'red-200', 'red-300', 'red-400', 'red-500', 'red-600', 'red-700', 'red-800', 'red-900']);
  makeProxy('oranges', ['orange-100', 'orange-200', 'orange-300', 'orange-400', 'orange-500', 'orange-600', 'orange-700', 'orange-800', 'orange-900']);
  makeProxy('yellows', ['yellow-100', 'yellow-200', 'yellow-300', 'yellow-400', 'yellow-500', 'yellow-600', 'yellow-700', 'yellow-800', 'yellow-900']);
  makeProxy('greens', ['green-100', 'green-200', 'green-300', 'green-400', 'green-500', 'green-600', 'green-700', 'green-800', 'green-900']);
  makeProxy('teals', ['teal-100', 'teal-200', 'teal-300', 'teal-400', 'teal-500', 'teal-600', 'teal-700', 'teal-800', 'teal-900']);
  makeProxy('cyans', ['cyan-100', 'cyan-200', 'cyan-300', 'cyan-400', 'cyan-500', 'cyan-600', 'cyan-700', 'cyan-800', 'cyan-900']); // Spacing
  //
  // Control the default styling of most Bootstrap elements by modifying these
  // variables. Mostly focused on spacing.
  // You can add more entries to the $spacers map, should you need more variation.

  var SPACERS = makeProxy('spacers', [0, 1, 2, 3, 4, 5]); // Position
  //
  // Define the edge positioning anchors of the position utilities.

  var POSITION_VALUES = makeProxy('position-values', [0, 50, 100]); // Grid breakpoints
  //
  // Define the minimum dimensions at which your layout will change,
  // adapting to different screen sizes, for use in media queries.

  var GRID_BREAKPOINTS = makeProxy('grid-breakpoints', ['xs', 'sm', 'md', 'lg', 'xl', 'xxl']); // Grid containers
  //
  // Define the maximum width of ".container" for different screen sizes.

  var CONTAINER_MAX_WIDTHS = makeProxy('container-max-widths', ['sm', 'md', 'lg', 'xl', 'xxl']); // Grid columns
  //
  // Set the number of columns and specify the width of the gutters.

  var GRID_COLUMNS = 12;
  //
  // Define common padding and border radius sizes and more.

  var BORDER_WIDTHS = makeProxy('border-widths', [1, 2, 3, 4, 5]);
  makeProxy('aspect-ratios', ['1x1', '4x3', '16x9', '21x9']); // Typography
  //
  // Font, line-height, and color for body text, headings, and more.

  var FONT_SIZES = makeProxy('font-sizes', [1, 2, 3, 4, 5, 6]);
  var DISPLAY_FONT_SIZES = makeProxy('display-font-sizes', [1, 2, 3, 4, 5, 6]); // Forms

  var FORM_VALIDATION_STATES = makeProxy('form-validation-states', ['valid', 'invalid']);

  var UTILITIES_COLORS = THEME_COLORS;
  var UTILITIES_TEXT_COLORS = _objectSpread2(_objectSpread2({}, UTILITIES_COLORS), {}, {
    black: function black(t) {
      return t.black;
    },
    white: function white(t) {
      return t.white;
    },
    body: function body(t) {
      return t['body-color'];
    }
  });
  var UTILITIES_BG_COLORS = _objectSpread2(_objectSpread2({}, UTILITIES_COLORS), {}, {
    black: function black(t) {
      return t.black;
    },
    white: function white(t) {
      return t.white;
    },
    body: function body(t) {
      return t['body-bg'];
    }
  });
  var NEGATIVE_SPACERS = each(SPACERS, function (key, value) {
    if (key === 0) {
      return null;
    }

    return _defineProperty({}, "n".concat(key), function n(t) {
      return "-".concat(value(t));
    });
  });

  var utilities = {
    align: {
      property: 'text-align-vertical',
      class: 'align',
      values: {
        // baseline: 'baseline',
        top: 'top',
        center: 'center',
        // 'middle',
        bottom: 'bottom' // 'text-bottom': 'text-bottom',
        // 'text-top': 'text-top',

      }
    },

    /* float: {
      responsive: true,
      property: 'float',
      values: {
        start: 'left',
        end: 'right',
        none: 'none',
      },
    }, */
    // Opacity utilities
    opacity: {
      property: 'opacity',
      values: {
        0: '0',
        25: '0.25',
        50: '0.5',
        75: '0.75',
        100: '1'
      }
    },
    overflow: {
      property: 'overflow',
      values: {
        // auto: 'auto',
        hidden: 'hidden',
        visible: 'visible',
        scroll: 'scroll'
      }
    },
    display: {
      responsive: true,
      print: true,
      property: 'display',
      class: 'd',
      values: {
        // inline: 'inline',
        // 'inline-block': 'inline-block',
        // block: 'block',
        // grid: 'grid',
        // table: 'table',
        // 'table-row': 'table-row',
        // 'table-cell': 'table-cell',
        flex: 'flex',
        // 'inline-flex': 'inline-flex',
        none: 'none'
      }
    },
    shadow: {
      property: 'box-shadow',
      class: 'shadow',
      values: {
        null: function _null(t) {
          return t['box-shadow'];
        },
        sm: function sm(t) {
          return t['box-shadow-sm'];
        },
        lg: function lg(t) {
          return t['box-shadow-lg'];
        },
        none: 'none'
      }
    },
    position: {
      property: 'position',
      values: {
        // static: 'static',
        relative: 'relative',
        absolute: 'absolute' // fixed: 'fixed',
        // sticky: 'sticky',

      }
    },
    top: {
      property: 'top',
      values: POSITION_VALUES
    },
    bottom: {
      property: 'bottom',
      values: POSITION_VALUES
    },
    start: {
      property: 'left',
      class: 'start',
      values: POSITION_VALUES
    },
    end: {
      property: 'right',
      class: 'end',
      values: POSITION_VALUES
    },

    /* translateMiddle: {
      property: 'transform',
      class: 'translate-middle',
      values: {
        null: translate(-50%, -50%),
        x: translateX(-50%),
        y: translateY(-50%),
      },
    }, */
    border: {
      property: 'border',
      values: {
        null: function _null(t) {
          return "".concat(t['border-width'], " solid ").concat(t['border-color']);
        },
        0: '0'
      }
    },
    // TODO: Find a way to write border-top as border-top-width, ...

    /* borderTop: {
      property: 'border-top',
      values: {
        null: (t) => `${t['border-width']} solid ${t['border-color']}`,
        0: '0',
      },
    }, */

    /* borderRight: {
      property: 'border-right',
      class: 'border-end',
      values: {
        null: (t) => `${t['border-width']} solid ${t['border-color']}`,
        0: '0',
      },
    }, */

    /* borderBottom: {
      property: 'border-bottom',
      values: {
        null: (t) => `${t['border-width']} solid ${t['border-color']}`,
        0: '0',
      },
    }, */

    /* borderLeft: {
      property: 'border-left',
      class: 'border-start',
      values: {
        null: (t) => `${t['border-width']} solid ${t['border-color']}`,
        0: '0',
      },
    }, */
    borderColor: {
      property: 'border-color',
      class: 'border',
      values: _objectSpread2(_objectSpread2({}, THEME_COLORS), {}, {
        white: 'white'
      })
    },
    borderWidth: {
      property: 'border-width',
      class: 'border',
      values: BORDER_WIDTHS
    },
    width: {
      property: 'width',
      class: 'w',
      values: {
        25: '25%',
        50: '50%',
        75: '75%',
        100: '100%',
        auto: 'auto'
      }
    },
    maxWidth: {
      property: 'max-width',
      class: 'mw',
      values: {
        100: '100%'
      }
    },
    viewportWidth: {
      property: 'width',
      class: 'vw',
      values: {
        100: '100vw' // TODO: native support

      }
    },
    minViewportWidth: {
      property: 'min-width',
      class: 'min-vw',
      values: {
        100: '100vw' // TODO: native support

      }
    },
    height: {
      property: 'height',
      class: 'h',
      values: {
        25: '25%',
        50: '50%',
        75: '75%',
        100: '100%',
        auto: 'auto'
      }
    },
    maxHeight: {
      property: 'max-height',
      class: 'mh',
      values: {
        100: '100%'
      }
    },
    viewportHeight: {
      property: 'height',
      class: 'vh',
      values: {
        100: '100vh' // TODO: native support

      }
    },
    minViewportHeight: {
      property: 'min-height',
      class: 'min-vh',
      values: {
        100: '100vh' // TODO: native support

      }
    },
    // Flex utilities
    flex: {
      responsive: true,
      property: 'flex',
      values: {
        fill: '1 1 auto'
      }
    },
    flexDirection: {
      responsive: true,
      property: 'flex-direction',
      class: 'flex',
      values: {
        row: 'row',
        column: 'column',
        'row-reverse': 'row-reverse',
        'column-reverse': 'column-reverse'
      }
    },
    flexGrow: {
      responsive: true,
      property: 'flex-grow',
      class: 'flex',
      values: {
        'grow-0': '0',
        'grow-1': '1'
      }
    },
    flexShrink: {
      responsive: true,
      property: 'flex-shrink',
      class: 'flex',
      values: {
        'shrink-0': '0',
        'shrink-1': '1'
      }
    },
    flexWrap: {
      responsive: true,
      property: 'flex-wrap',
      class: 'flex',
      values: {
        wrap: 'wrap',
        nowrap: 'nowrap',
        'wrap-reverse': 'wrap-reverse'
      }
    },

    /* gap: {
      responsive: true,
      property: 'gap',
      class: 'gap',
      values: SPACERS,
    }, */
    justifyContent: {
      responsive: true,
      property: 'justify-content',
      values: {
        start: 'flex-start',
        end: 'flex-end',
        center: 'center',
        between: 'space-between',
        around: 'space-around' // evenly: 'space-evenly', // TODO: For some reason this is converted into "spacNaNvenly"

      }
    },
    alignItems: {
      responsive: true,
      property: 'align-items',
      values: {
        start: 'flex-start',
        end: 'flex-end',
        center: 'center',
        baseline: 'baseline',
        stretch: 'stretch'
      }
    },
    alignContent: {
      responsive: true,
      property: 'align-content',
      values: {
        start: 'flex-start',
        end: 'flex-end',
        center: 'center',
        between: 'space-between',
        around: 'space-around',
        stretch: 'stretch'
      }
    },
    alignSelf: {
      responsive: true,
      property: 'align-self',
      values: {
        auto: 'auto',
        start: 'flex-start',
        end: 'flex-end',
        center: 'center',
        baseline: 'baseline',
        stretch: 'stretch'
      }
    },

    /* order: {
      responsive: true,
      property: 'order',
      values: {
        first: '-1',
        0: '0',
        1: '1',
        2: '2',
        3: '3',
        4: '4',
        5: '5',
        last: '6',
      },
    }, */
    // Margin utilities
    margin: {
      responsive: true,
      property: 'margin',
      class: 'm',
      values: _objectSpread2(_objectSpread2({}, SPACERS), {}, {
        auto: 'auto'
      })
    },
    marginX: {
      responsive: true,
      property: 'margin-horizontal',
      class: 'mx',
      values: _objectSpread2(_objectSpread2({}, SPACERS), {}, {
        auto: 'auto'
      })
    },
    marginY: {
      responsive: true,
      property: 'margin-vertical',
      class: 'my',
      values: _objectSpread2(_objectSpread2({}, SPACERS), {}, {
        auto: 'auto'
      })
    },
    marginTop: {
      responsive: true,
      property: 'margin-top',
      class: 'mt',
      values: _objectSpread2(_objectSpread2({}, SPACERS), {}, {
        auto: 'auto'
      })
    },
    marginEnd: {
      responsive: true,
      property: 'margin-right',
      class: 'me',
      values: _objectSpread2(_objectSpread2({}, SPACERS), {}, {
        auto: 'auto'
      })
    },
    marginBottom: {
      responsive: true,
      property: 'margin-bottom',
      class: 'mb',
      values: _objectSpread2(_objectSpread2({}, SPACERS), {}, {
        auto: 'auto'
      })
    },
    marginStart: {
      responsive: true,
      property: 'margin-left',
      class: 'ms',
      values: _objectSpread2(_objectSpread2({}, SPACERS), {}, {
        auto: 'auto'
      })
    },
    // Negative margin utilities
    negativeMargin: {
      responsive: true,
      property: 'margin',
      class: 'm',
      values: NEGATIVE_SPACERS
    },
    negativeMarginX: {
      responsive: true,
      property: 'margin-horizontal',
      class: 'mx',
      values: NEGATIVE_SPACERS
    },
    negativeMarginY: {
      responsive: true,
      property: 'margin-vertical',
      class: 'my',
      values: NEGATIVE_SPACERS
    },
    negativeMarginTop: {
      responsive: true,
      property: 'margin-top',
      class: 'mt',
      values: NEGATIVE_SPACERS
    },
    negativeMarginEnd: {
      responsive: true,
      property: 'margin-right',
      class: 'me',
      values: NEGATIVE_SPACERS
    },
    negativeMarginBottom: {
      responsive: true,
      property: 'margin-bottom',
      class: 'mb',
      values: NEGATIVE_SPACERS
    },
    negativeMarginStart: {
      responsive: true,
      property: 'margin-left',
      class: 'ms',
      values: NEGATIVE_SPACERS
    },
    // Padding utilities
    padding: {
      responsive: true,
      property: 'padding',
      class: 'p',
      values: SPACERS
    },
    paddingX: {
      responsive: true,
      property: 'padding-horizontal',
      class: 'px',
      values: SPACERS
    },
    paddingY: {
      responsive: true,
      property: 'padding-vertical',
      class: 'py',
      values: SPACERS
    },
    paddingTop: {
      responsive: true,
      property: 'padding-top',
      class: 'pt',
      values: SPACERS
    },
    paddingEnd: {
      responsive: true,
      property: 'padding-right',
      class: 'pe',
      values: SPACERS
    },
    paddingBottom: {
      responsive: true,
      property: 'padding-bottom',
      class: 'pb',
      values: SPACERS
    },
    paddingStart: {
      responsive: true,
      property: 'padding-left',
      class: 'ps',
      values: SPACERS
    },
    // Text
    fontFamily: {
      property: 'font-family',
      class: 'font',
      values: {
        monospace: function monospace(t) {
          return t['font-family-monospace'];
        }
      }
    },
    fontSize: {
      rfs: true,
      property: 'font-size',
      class: 'fs',
      values: FONT_SIZES
    },
    fontStyle: {
      property: 'font-style',
      class: 'fst',
      values: {
        italic: 'italic',
        normal: 'normal'
      }
    },
    fontWeight: {
      property: 'font-weight',
      class: 'fw',
      values: {
        light: function light(t) {
          return t['font-weight-light'];
        },
        // lighter: (t) => t['font-weight-lighter'],
        normal: function normal(t) {
          return t['font-weight-normal'];
        },
        bold: function bold(t) {
          return t['font-weight-bold'];
        } // bolder: (t) => t['font-weight-bolder'],

      }
    },
    lineHeight: {
      property: 'line-height',
      class: 'lh',
      // Multiply line-height with font-size for react-native support.
      values: {
        1: function _(t) {
          return t['font-size-base'];
        },
        sm: function sm(t) {
          return "".concat(t['font-size-sm'], " * ").concat(t['line-height-sm']);
        },
        base: function base(t) {
          return "".concat(t['font-size-base'], " * ").concat(t['line-height-base']);
        },
        lg: function lg(t) {
          return "".concat(t['font-size-lg'], " * ").concat(t['line-height-lg']);
        }
      }
    },
    textAlign: {
      responsive: true,
      property: 'text-align',
      class: 'text',
      values: {
        start: 'left',
        end: 'right',
        center: 'center'
      }
    },
    textDecoration: {
      property: 'text-decoration',
      class: 'text',
      values: {
        none: 'none',
        underline: 'underline',
        'line-through': 'line-through'
      }
    },
    textTransform: {
      property: 'text-transform',
      class: 'text',
      values: {
        lowercase: 'lowercase',
        uppercase: 'uppercase',
        capitalize: 'capitalize'
      }
    },

    /* whiteSpace: {
      property: 'white-space',
      class: 'text',
      values: {
        wrap: 'normal',
        nowrap: 'nowrap',
      },
    }, */

    /* wordWrap: {
      property: ['word-wrap', 'word-break'],
      class: 'text',
      values: {
        break: 'break-word',
      },
      rtl: false,
    }, */
    color: {
      property: 'color',
      class: 'text',
      // 'local-vars': { 'text-opacity': 1 },
      values: _objectSpread2(_objectSpread2({}, UTILITIES_TEXT_COLORS), {}, {
        muted: function muted(t) {
          return t['text-muted'];
        },
        'black-50': function black50(t) {
          return "rgba(".concat(t.black, ", 0.5)");
        },
        'white-50': function white50(t) {
          return "rgba(".concat(t.white, ", 0.5)");
        }
      })
    },
    textOpacity: {
      property: 'opacity',
      // 'css-var': true,
      class: 'text-opacity',
      values: {
        25: '0.25',
        50: '0.5',
        75: '0.75',
        100: '1'
      }
    },
    backgroundColor: {
      property: 'background-color',
      class: 'bg',
      // 'local-vars': { 'bg-opacity': 1 },
      values: _objectSpread2(_objectSpread2({}, UTILITIES_BG_COLORS), {}, {
        transparent: 'transparent'
      })
    },
    bgOpacity: {
      property: 'opacity',
      // 'css-var': true,
      class: 'bg-opacity',
      values: {
        10: '0.1',
        25: '0.25',
        50: '0.50',
        75: '0.75',
        100: '1'
      }
    },

    /* gradient: {
      property: 'background-image',
      class: 'bg',
      values: {
        gradient: 'var(--#{$variable-prefix}gradient))',
      },
    }, */

    /* userSelect: {
      property: 'user-select',
      values: {
        all: 'all',
        auto: 'auto',
        none: 'none',
      },
    }, */

    /* pointerEvents: {
      property: 'pointer-events',
      class: 'pe',
      values: {
        none: 'none',
        auto: 'auto',
      },
    }, */
    rounded: {
      property: 'border-radius',
      class: 'rounded',
      values: {
        null: function _null(t) {
          return t['border-radius'];
        },
        0: '0',
        1: function _(t) {
          return t['border-radius-sm'];
        },
        2: function _(t) {
          return t['border-radius'];
        },
        3: function _(t) {
          return t['border-radius-lg'];
        },
        circle: '500px',
        // TODO: How to implement 50%?
        pill: function pill(t) {
          return t['border-radius-pill'];
        }
      }
    } // TODO: Support multiple properties for rounded-* utilities.

    /* roundedTop: {
      property: ['border-top-left-radius', 'border-top-right-radius'],
      class: 'rounded-top',
      values: {
        null: (t) => t['border-radius'],
      },
    }, */

    /* roundedEnd: {
      property: ['border-top-right-radius', 'border-bottom-right-radius'],
      class: 'rounded-end',
      values: {
        null: (t) => t['border-radius'],
      },
    }, */

    /* roundedBottom: {
      property: ['border-bottom-right-radius', 'border-bottom-left-radius'],
      class: 'rounded-bottom',
      values: {
        null: (t) => t['border-radius'],
      },
    }, */

    /* roundedStart: {
      property: ['border-bottom-left-radius', 'border-top-left-radius'],
      class: 'rounded-start',
      values: {
        null: (t) => t['border-radius'],
      },
    }, */

    /* visibility: {
      property: 'visibility',
      class: 'null',
      values: {
        visible: 'visible',
        invisible: 'hidden',
      },
    }, */

  };

  var _templateObject$1b, _templateObject2$S;
  function makeUtility(options) {
    return each(options.values, function (key, value) {
      var name = options.class || options.property;
      var suffix = key === 'null' ? '' : "-".concat(key);

      var styles = _defineProperty({}, "".concat(name).concat(suffix), css$1(_templateObject$1b || (_templateObject$1b = _taggedTemplateLiteral(["\n        ", ": ", ";\n      "])), options.property, value));

      if (!options.responsive) {
        return styles;
      }

      return _objectSpread2(_objectSpread2({}, styles), each(GRID_BREAKPOINTS, function (breakpoint) {
        if (breakpoint === 'xs') {
          return null;
        }

        return _defineProperty({}, "".concat(name, "-").concat(breakpoint).concat(suffix), css$1(_templateObject2$S || (_templateObject2$S = _taggedTemplateLiteral(["\n            @include media-breakpoint-up(", ") {\n              ", ": ", ";\n            }\n          "])), breakpoint, options.property, value));
      }));
    });
  }
  function makeUtilities(resolve) {
    var customUtilities = typeof resolve === 'function' ? resolve(utilities) : resolve;
    var definitions = Object.values(_objectSpread2(_objectSpread2({}, utilities), customUtilities)).reduce(function (result, utility) {
      if (!utility) {
        return result;
      }

      return Object.assign(result, makeUtility(utility));
    }, {});
    return definitions;
  }

  var _typeof_1 = createCommonjsModule(function (module) {
  function _typeof(obj) {
    "@babel/helpers - typeof";

    return (module.exports = _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) {
      return typeof obj;
    } : function (obj) {
      return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
    }, module.exports.__esModule = true, module.exports["default"] = module.exports), _typeof(obj);
  }

  module.exports = _typeof, module.exports.__esModule = true, module.exports["default"] = module.exports;
  });

  var interopRequireWildcard = createCommonjsModule(function (module) {
  var _typeof = _typeof_1["default"];

  function _getRequireWildcardCache(nodeInterop) {
    if (typeof WeakMap !== "function") return null;
    var cacheBabelInterop = new WeakMap();
    var cacheNodeInterop = new WeakMap();
    return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) {
      return nodeInterop ? cacheNodeInterop : cacheBabelInterop;
    })(nodeInterop);
  }

  function _interopRequireWildcard(obj, nodeInterop) {
    if (!nodeInterop && obj && obj.__esModule) {
      return obj;
    }

    if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
      return {
        "default": obj
      };
    }

    var cache = _getRequireWildcardCache(nodeInterop);

    if (cache && cache.has(obj)) {
      return cache.get(obj);
    }

    var newObj = {};
    var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;

    for (var key in obj) {
      if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) {
        var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;

        if (desc && (desc.get || desc.set)) {
          Object.defineProperty(newObj, key, desc);
        } else {
          newObj[key] = obj[key];
        }
      }
    }

    newObj["default"] = obj;

    if (cache) {
      cache.set(obj, newObj);
    }

    return newObj;
  }

  module.exports = _interopRequireWildcard, module.exports.__esModule = true, module.exports["default"] = module.exports;
  });

  var interopRequireDefault = createCommonjsModule(function (module) {
  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
      "default": obj
    };
  }

  module.exports = _interopRequireDefault, module.exports.__esModule = true, module.exports["default"] = module.exports;
  });

  var assertThisInitialized = createCommonjsModule(function (module) {
  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }

    return self;
  }

  module.exports = _assertThisInitialized, module.exports.__esModule = true, module.exports["default"] = module.exports;
  });

  var possibleConstructorReturn = createCommonjsModule(function (module) {
  var _typeof = _typeof_1["default"];



  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    } else if (call !== void 0) {
      throw new TypeError("Derived constructors may only return object or undefined");
    }

    return assertThisInitialized(self);
  }

  module.exports = _possibleConstructorReturn, module.exports.__esModule = true, module.exports["default"] = module.exports;
  });

  var getPrototypeOf = createCommonjsModule(function (module) {
  function _getPrototypeOf(o) {
    module.exports = _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    }, module.exports.__esModule = true, module.exports["default"] = module.exports;
    return _getPrototypeOf(o);
  }

  module.exports = _getPrototypeOf, module.exports.__esModule = true, module.exports["default"] = module.exports;
  });

  var setPrototypeOf = createCommonjsModule(function (module) {
  function _setPrototypeOf(o, p) {
    module.exports = _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;
      return o;
    }, module.exports.__esModule = true, module.exports["default"] = module.exports;
    return _setPrototypeOf(o, p);
  }

  module.exports = _setPrototypeOf, module.exports.__esModule = true, module.exports["default"] = module.exports;
  });

  var inherits = createCommonjsModule(function (module) {
  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }

    subClass.prototype = Object.create(superClass && superClass.prototype, {
      constructor: {
        value: subClass,
        writable: true,
        configurable: true
      }
    });
    Object.defineProperty(subClass, "prototype", {
      writable: false
    });
    if (superClass) setPrototypeOf(subClass, superClass);
  }

  module.exports = _inherits, module.exports.__esModule = true, module.exports["default"] = module.exports;
  });

  var defineProperty = createCommonjsModule(function (module) {
  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, {
        value: value,
        enumerable: true,
        configurable: true,
        writable: true
      });
    } else {
      obj[key] = value;
    }

    return obj;
  }

  module.exports = _defineProperty, module.exports.__esModule = true, module.exports["default"] = module.exports;
  });

  var classCallCheck = createCommonjsModule(function (module) {
  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  module.exports = _classCallCheck, module.exports.__esModule = true, module.exports["default"] = module.exports;
  });

  var createClass = createCommonjsModule(function (module) {
  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];
      descriptor.enumerable = descriptor.enumerable || false;
      descriptor.configurable = true;
      if ("value" in descriptor) descriptor.writable = true;
      Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);
    if (staticProps) _defineProperties(Constructor, staticProps);
    Object.defineProperty(Constructor, "prototype", {
      writable: false
    });
    return Constructor;
  }

  module.exports = _createClass, module.exports.__esModule = true, module.exports["default"] = module.exports;
  });

  var SvgTouchableMixin_1 = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.default=void 0;var _defineProperty2=interopRequireDefault(defineProperty);function ownKeys(object,enumerableOnly){var keys=Object.keys(object);if(Object.getOwnPropertySymbols){var symbols=Object.getOwnPropertySymbols(object);if(enumerableOnly)symbols=symbols.filter(function(sym){return Object.getOwnPropertyDescriptor(object,sym).enumerable;});keys.push.apply(keys,symbols);}return keys;}function _objectSpread(target){for(var i=1;i<arguments.length;i++){var source=arguments[i]!=null?arguments[i]:{};if(i%2){ownKeys(Object(source),true).forEach(function(key){(0, _defineProperty2.default)(target,key,source[key]);});}else if(Object.getOwnPropertyDescriptors){Object.defineProperties(target,Object.getOwnPropertyDescriptors(source));}else {ownKeys(Object(source)).forEach(function(key){Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key));});}}return target;}var PRESS_RETENTION_OFFSET={top:20,left:20,right:20,bottom:30};var Mixin=_reactNative__default["default"].Touchable.Mixin;var _touchableHandleStartShouldSetResponder=Mixin.touchableHandleStartShouldSetResponder,_touchableHandleResponderTerminationRequest=Mixin.touchableHandleResponderTerminationRequest,_touchableHandleResponderGrant=Mixin.touchableHandleResponderGrant,_touchableHandleResponderMove=Mixin.touchableHandleResponderMove,_touchableHandleResponderRelease=Mixin.touchableHandleResponderRelease,_touchableHandleResponderTerminate=Mixin.touchableHandleResponderTerminate,touchableGetInitialState=Mixin.touchableGetInitialState;var SvgTouchableMixin=_objectSpread({},Mixin,{touchableHandleStartShouldSetResponder:function touchableHandleStartShouldSetResponder(e){var onStartShouldSetResponder=this.props.onStartShouldSetResponder;if(onStartShouldSetResponder){return onStartShouldSetResponder(e);}else {return _touchableHandleStartShouldSetResponder.call(this,e);}},touchableHandleResponderTerminationRequest:function touchableHandleResponderTerminationRequest(e){var onResponderTerminationRequest=this.props.onResponderTerminationRequest;if(onResponderTerminationRequest){return onResponderTerminationRequest(e);}else {return _touchableHandleResponderTerminationRequest.call(this,e);}},touchableHandleResponderGrant:function touchableHandleResponderGrant(e){var onResponderGrant=this.props.onResponderGrant;if(onResponderGrant){return onResponderGrant(e);}else {return _touchableHandleResponderGrant.call(this,e);}},touchableHandleResponderMove:function touchableHandleResponderMove(e){var onResponderMove=this.props.onResponderMove;if(onResponderMove){return onResponderMove(e);}else {return _touchableHandleResponderMove.call(this,e);}},touchableHandleResponderRelease:function touchableHandleResponderRelease(e){var onResponderRelease=this.props.onResponderRelease;if(onResponderRelease){return onResponderRelease(e);}else {return _touchableHandleResponderRelease.call(this,e);}},touchableHandleResponderTerminate:function touchableHandleResponderTerminate(e){var onResponderTerminate=this.props.onResponderTerminate;if(onResponderTerminate){return onResponderTerminate(e);}else {return _touchableHandleResponderTerminate.call(this,e);}},touchableHandlePress:function touchableHandlePress(e){var onPress=this.props.onPress;onPress&&onPress(e);},touchableHandleActivePressIn:function touchableHandleActivePressIn(e){var onPressIn=this.props.onPressIn;onPressIn&&onPressIn(e);},touchableHandleActivePressOut:function touchableHandleActivePressOut(e){var onPressOut=this.props.onPressOut;onPressOut&&onPressOut(e);},touchableHandleLongPress:function touchableHandleLongPress(e){var onLongPress=this.props.onLongPress;onLongPress&&onLongPress(e);},touchableGetPressRectOffset:function touchableGetPressRectOffset(){var pressRetentionOffset=this.props.pressRetentionOffset;return pressRetentionOffset||PRESS_RETENTION_OFFSET;},touchableGetHitSlop:function touchableGetHitSlop(){var hitSlop=this.props.hitSlop;return hitSlop;},touchableGetHighlightDelayMS:function touchableGetHighlightDelayMS(){var delayPressIn=this.props.delayPressIn;return delayPressIn||0;},touchableGetLongPressDelayMS:function touchableGetLongPressDelayMS(){var delayLongPress=this.props.delayLongPress;return delayLongPress===0?0:delayLongPress||500;},touchableGetPressOutDelayMS:function touchableGetPressOutDelayMS(){var delayPressOut=this.props.delayPressOut;return delayPressOut||0;}});var touchKeys=Object.keys(SvgTouchableMixin);var touchVals=touchKeys.map(function(key){return SvgTouchableMixin[key];});var numTouchKeys=touchKeys.length;var _default=function _default(target){for(var i=0;i<numTouchKeys;i++){var key=touchKeys[i];var val=touchVals[i];if(typeof val==='function'){target[key]=val.bind(target);}else {target[key]=val;}}target.state=touchableGetInitialState();};exports.default=_default;

  });

  var Shape_1 = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.multiply_matrices=multiply_matrices;exports.invert=invert;exports.matrixTransform=_matrixTransform;exports.default=exports.ownerSVGElement=exports.SVGPoint=exports.SVGMatrix=void 0;var _possibleConstructorReturn2=interopRequireDefault(possibleConstructorReturn);var _getPrototypeOf2=interopRequireDefault(getPrototypeOf);var _assertThisInitialized2=interopRequireDefault(assertThisInitialized);var _inherits2=interopRequireDefault(inherits);var _defineProperty2=interopRequireDefault(defineProperty);var _classCallCheck2=interopRequireDefault(classCallCheck);var _createClass2=interopRequireDefault(createClass);var _SvgTouchableMixin=interopRequireDefault(SvgTouchableMixin_1);var RNSVGRenderableManager=_reactNative__default["default"].NativeModules.RNSVGRenderableManager;function multiply_matrices(l,r){var al=l.a,bl=l.b,cl=l.c,dl=l.d,el=l.e,fl=l.f;var ar=r.a,br=r.b,cr=r.c,dr=r.d,er=r.e,fr=r.f;var a=al*ar+cl*br;var c=al*cr+cl*dr;var e=al*er+cl*fr+el;var b=bl*ar+dl*br;var d=bl*cr+dl*dr;var f=bl*er+dl*fr+fl;return {a:a,c:c,e:e,b:b,d:d,f:f};}function invert(_ref){var a=_ref.a,b=_ref.b,c=_ref.c,d=_ref.d,e=_ref.e,f=_ref.f;var n=a*d-b*c;return {a:d/n,b:-b/n,c:-c/n,d:a/n,e:(c*f-d*e)/n,f:-(a*f-b*e)/n};}var deg2rad=Math.PI/180;var SVGMatrix=function(){function SVGMatrix(matrix){(0, _classCallCheck2.default)(this,SVGMatrix);if(matrix){var a=matrix.a,b=matrix.b,c=matrix.c,d=matrix.d,e=matrix.e,f=matrix.f;this.a=a;this.b=b;this.c=c;this.d=d;this.e=e;this.f=f;}else {this.a=1;this.b=0;this.c=0;this.d=1;this.e=0;this.f=0;}}(0, _createClass2.default)(SVGMatrix,[{key:"multiply",value:function multiply(secondMatrix){return new SVGMatrix(multiply_matrices(this,secondMatrix));}},{key:"inverse",value:function inverse(){return new SVGMatrix(invert(this));}},{key:"translate",value:function translate(x,y){return new SVGMatrix(multiply_matrices(this,{a:1,b:0,c:0,d:1,e:x,f:y}));}},{key:"scale",value:function scale(scaleFactor){return new SVGMatrix(multiply_matrices(this,{a:scaleFactor,b:0,c:0,d:scaleFactor,e:0,f:0}));}},{key:"scaleNonUniform",value:function scaleNonUniform(scaleFactorX,scaleFactorY){return new SVGMatrix(multiply_matrices(this,{a:scaleFactorX,b:0,c:0,d:scaleFactorY,e:0,f:0}));}},{key:"rotate",value:function rotate(angle){var cos=Math.cos(deg2rad*angle);var sin=Math.sin(deg2rad*angle);return new SVGMatrix(multiply_matrices(this,{a:cos,b:sin,c:-sin,d:cos,e:0,f:0}));}},{key:"rotateFromVector",value:function rotateFromVector(x,y){var angle=Math.atan2(y,x);var cos=Math.cos(deg2rad*angle);var sin=Math.sin(deg2rad*angle);return new SVGMatrix(multiply_matrices(this,{a:cos,b:sin,c:-sin,d:cos,e:0,f:0}));}},{key:"flipX",value:function flipX(){return new SVGMatrix(multiply_matrices(this,{a:-1,b:0,c:0,d:1,e:0,f:0}));}},{key:"flipY",value:function flipY(){return new SVGMatrix(multiply_matrices(this,{a:1,b:0,c:0,d:-1,e:0,f:0}));}},{key:"skewX",value:function skewX(angle){return new SVGMatrix(multiply_matrices(this,{a:1,b:0,c:Math.tan(deg2rad*angle),d:1,e:0,f:0}));}},{key:"skewY",value:function skewY(angle){return new SVGMatrix(multiply_matrices(this,{a:1,b:Math.tan(deg2rad*angle),c:0,d:1,e:0,f:0}));}}]);return SVGMatrix;}();exports.SVGMatrix=SVGMatrix;function _matrixTransform(matrix,point){var a=matrix.a,b=matrix.b,c=matrix.c,d=matrix.d,e=matrix.e,f=matrix.f;var x=point.x,y=point.y;return {x:a*x+c*y+e,y:b*x+d*y+f};}var SVGPoint=function(){function SVGPoint(point){(0, _classCallCheck2.default)(this,SVGPoint);if(point){var _x=point.x,_y=point.y;this.x=_x;this.y=_y;}else {this.x=0;this.y=0;}}(0, _createClass2.default)(SVGPoint,[{key:"matrixTransform",value:function matrixTransform(matrix){return new SVGPoint(_matrixTransform(matrix,this));}}]);return SVGPoint;}();exports.SVGPoint=SVGPoint;var ownerSVGElement={createSVGPoint:function createSVGPoint(){return new SVGPoint();},createSVGMatrix:function createSVGMatrix(){return new SVGMatrix();}};exports.ownerSVGElement=ownerSVGElement;var Shape=function(_Component){(0, _inherits2.default)(Shape,_Component);function Shape(_props,context){var _this;(0, _classCallCheck2.default)(this,Shape);_this=(0, _possibleConstructorReturn2.default)(this,(0, _getPrototypeOf2.default)(Shape).call(this,_props,context));(0, _defineProperty2.default)((0, _assertThisInitialized2.default)(_this),"root",null);(0, _defineProperty2.default)((0, _assertThisInitialized2.default)(_this),"refMethod",function(instance){_this.root=instance;});(0, _defineProperty2.default)((0, _assertThisInitialized2.default)(_this),"setNativeProps",function(props){_this.root&&_this.root.setNativeProps(props);});(0, _defineProperty2.default)((0, _assertThisInitialized2.default)(_this),"getBBox",function(options){var _ref2=options||{},_ref2$fill=_ref2.fill,fill=_ref2$fill===void 0?true:_ref2$fill,_ref2$stroke=_ref2.stroke,stroke=_ref2$stroke===void 0?true:_ref2$stroke,_ref2$markers=_ref2.markers,markers=_ref2$markers===void 0?true:_ref2$markers,_ref2$clipped=_ref2.clipped,clipped=_ref2$clipped===void 0?true:_ref2$clipped;var handle=(0, _reactNative__default["default"].findNodeHandle)(_this.root);return RNSVGRenderableManager.getBBox(handle,{fill:fill,stroke:stroke,markers:markers,clipped:clipped});});(0, _defineProperty2.default)((0, _assertThisInitialized2.default)(_this),"getCTM",function(){var handle=(0, _reactNative__default["default"].findNodeHandle)(_this.root);return new SVGMatrix(RNSVGRenderableManager.getCTM(handle));});(0, _defineProperty2.default)((0, _assertThisInitialized2.default)(_this),"getScreenCTM",function(){var handle=(0, _reactNative__default["default"].findNodeHandle)(_this.root);return new SVGMatrix(RNSVGRenderableManager.getScreenCTM(handle));});(0, _defineProperty2.default)((0, _assertThisInitialized2.default)(_this),"isPointInFill",function(options){var handle=(0, _reactNative__default["default"].findNodeHandle)(_this.root);return RNSVGRenderableManager.isPointInFill(handle,options);});(0, _defineProperty2.default)((0, _assertThisInitialized2.default)(_this),"isPointInStroke",function(options){var handle=(0, _reactNative__default["default"].findNodeHandle)(_this.root);return RNSVGRenderableManager.isPointInStroke(handle,options);});(0, _defineProperty2.default)((0, _assertThisInitialized2.default)(_this),"getTotalLength",function(){var handle=(0, _reactNative__default["default"].findNodeHandle)(_this.root);return RNSVGRenderableManager.getTotalLength(handle);});(0, _defineProperty2.default)((0, _assertThisInitialized2.default)(_this),"getPointAtLength",function(length){var handle=(0, _reactNative__default["default"].findNodeHandle)(_this.root);return new SVGPoint(RNSVGRenderableManager.getPointAtLength(handle,{length:length}));});(0, _SvgTouchableMixin.default)((0, _assertThisInitialized2.default)(_this));return _this;}return Shape;}(React__default["default"].Component);exports.default=Shape;Shape.prototype.ownerSVGElement=ownerSVGElement;

  });

  var _extends_1 = createCommonjsModule(function (module) {
  function _extends() {
    module.exports = _extends = Object.assign || function (target) {
      for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i];

        for (var key in source) {
          if (Object.prototype.hasOwnProperty.call(source, key)) {
            target[key] = source[key];
          }
        }
      }

      return target;
    }, module.exports.__esModule = true, module.exports["default"] = module.exports;
    return _extends.apply(this, arguments);
  }

  module.exports = _extends, module.exports.__esModule = true, module.exports["default"] = module.exports;
  });

  var arrayLikeToArray = createCommonjsModule(function (module) {
  function _arrayLikeToArray(arr, len) {
    if (len == null || len > arr.length) len = arr.length;

    for (var i = 0, arr2 = new Array(len); i < len; i++) {
      arr2[i] = arr[i];
    }

    return arr2;
  }

  module.exports = _arrayLikeToArray, module.exports.__esModule = true, module.exports["default"] = module.exports;
  });

  var arrayWithoutHoles = createCommonjsModule(function (module) {
  function _arrayWithoutHoles(arr) {
    if (Array.isArray(arr)) return arrayLikeToArray(arr);
  }

  module.exports = _arrayWithoutHoles, module.exports.__esModule = true, module.exports["default"] = module.exports;
  });

  var iterableToArray = createCommonjsModule(function (module) {
  function _iterableToArray(iter) {
    if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter);
  }

  module.exports = _iterableToArray, module.exports.__esModule = true, module.exports["default"] = module.exports;
  });

  var unsupportedIterableToArray = createCommonjsModule(function (module) {
  function _unsupportedIterableToArray(o, minLen) {
    if (!o) return;
    if (typeof o === "string") return arrayLikeToArray(o, minLen);
    var n = Object.prototype.toString.call(o).slice(8, -1);
    if (n === "Object" && o.constructor) n = o.constructor.name;
    if (n === "Map" || n === "Set") return Array.from(o);
    if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return arrayLikeToArray(o, minLen);
  }

  module.exports = _unsupportedIterableToArray, module.exports.__esModule = true, module.exports["default"] = module.exports;
  });

  var nonIterableSpread = createCommonjsModule(function (module) {
  function _nonIterableSpread() {
    throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
  }

  module.exports = _nonIterableSpread, module.exports.__esModule = true, module.exports["default"] = module.exports;
  });

  var toConsumableArray = createCommonjsModule(function (module) {
  function _toConsumableArray(arr) {
    return arrayWithoutHoles(arr) || iterableToArray(arr) || unsupportedIterableToArray(arr) || nonIterableSpread();
  }

  module.exports = _toConsumableArray, module.exports.__esModule = true, module.exports["default"] = module.exports;
  });

  var extractColor_1 = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.default=extractColor;exports.integerColor=exports.colorNames=exports.colors=void 0;var colors={aliceblue:[240,248,255],antiquewhite:[250,235,215],aqua:[0,255,255],aquamarine:[127,255,212],azure:[240,255,255],beige:[245,245,220],bisque:[255,228,196],black:[0,0,0],blanchedalmond:[255,235,205],blue:[0,0,255],blueviolet:[138,43,226],brown:[165,42,42],burlywood:[222,184,135],cadetblue:[95,158,160],chartreuse:[127,255,0],chocolate:[210,105,30],coral:[255,127,80],cornflowerblue:[100,149,237],cornsilk:[255,248,220],crimson:[220,20,60],cyan:[0,255,255],darkblue:[0,0,139],darkcyan:[0,139,139],darkgoldenrod:[184,134,11],darkgray:[169,169,169],darkgreen:[0,100,0],darkgrey:[169,169,169],darkkhaki:[189,183,107],darkmagenta:[139,0,139],darkolivegreen:[85,107,47],darkorange:[255,140,0],darkorchid:[153,50,204],darkred:[139,0,0],darksalmon:[233,150,122],darkseagreen:[143,188,143],darkslateblue:[72,61,139],darkslategray:[47,79,79],darkslategrey:[47,79,79],darkturquoise:[0,206,209],darkviolet:[148,0,211],deeppink:[255,20,147],deepskyblue:[0,191,255],dimgray:[105,105,105],dimgrey:[105,105,105],dodgerblue:[30,144,255],firebrick:[178,34,34],floralwhite:[255,250,240],forestgreen:[34,139,34],fuchsia:[255,0,255],gainsboro:[220,220,220],ghostwhite:[248,248,255],gold:[255,215,0],goldenrod:[218,165,32],gray:[128,128,128],green:[0,128,0],greenyellow:[173,255,47],grey:[128,128,128],honeydew:[240,255,240],hotpink:[255,105,180],indianred:[205,92,92],indigo:[75,0,130],ivory:[255,255,240],khaki:[240,230,140],lavender:[230,230,250],lavenderblush:[255,240,245],lawngreen:[124,252,0],lemonchiffon:[255,250,205],lightblue:[173,216,230],lightcoral:[240,128,128],lightcyan:[224,255,255],lightgoldenrodyellow:[250,250,210],lightgray:[211,211,211],lightgreen:[144,238,144],lightgrey:[211,211,211],lightpink:[255,182,193],lightsalmon:[255,160,122],lightseagreen:[32,178,170],lightskyblue:[135,206,250],lightslategray:[119,136,153],lightslategrey:[119,136,153],lightsteelblue:[176,196,222],lightyellow:[255,255,224],lime:[0,255,0],limegreen:[50,205,50],linen:[250,240,230],magenta:[255,0,255],maroon:[128,0,0],mediumaquamarine:[102,205,170],mediumblue:[0,0,205],mediumorchid:[186,85,211],mediumpurple:[147,112,219],mediumseagreen:[60,179,113],mediumslateblue:[123,104,238],mediumspringgreen:[0,250,154],mediumturquoise:[72,209,204],mediumvioletred:[199,21,133],midnightblue:[25,25,112],mintcream:[245,255,250],mistyrose:[255,228,225],moccasin:[255,228,181],navajowhite:[255,222,173],navy:[0,0,128],oldlace:[253,245,230],olive:[128,128,0],olivedrab:[107,142,35],orange:[255,165,0],orangered:[255,69,0],orchid:[218,112,214],palegoldenrod:[238,232,170],palegreen:[152,251,152],paleturquoise:[175,238,238],palevioletred:[219,112,147],papayawhip:[255,239,213],peachpuff:[255,218,185],peru:[205,133,63],pink:[255,192,203],plum:[221,160,221],powderblue:[176,224,230],purple:[128,0,128],rebeccapurple:[102,51,153],red:[255,0,0],rosybrown:[188,143,143],royalblue:[65,105,225],saddlebrown:[139,69,19],salmon:[250,128,114],sandybrown:[244,164,96],seagreen:[46,139,87],seashell:[255,245,238],sienna:[160,82,45],silver:[192,192,192],skyblue:[135,206,235],slateblue:[106,90,205],slategray:[112,128,144],slategrey:[112,128,144],snow:[255,250,250],springgreen:[0,255,127],steelblue:[70,130,180],tan:[210,180,140],teal:[0,128,128],thistle:[216,191,216],tomato:[255,99,71],turquoise:[64,224,208],violet:[238,130,238],wheat:[245,222,179],white:[255,255,255],whitesmoke:[245,245,245],yellow:[255,255,0],yellowgreen:[154,205,50]};exports.colors=colors;var colorNames={};exports.colorNames=colorNames;for(var name in colors){if(colors.hasOwnProperty(name)){var color=colors[name];var r=color[0];var g=color[1];var b=color[2];colorNames[name]=(0xff000000|r<<16|g<<8|b)>>>0;}}Object.freeze(colorNames);function hslToRgb(_h,_s,_l,a){var h=_h/360;var s=_s/100;var l=_l/100;var t1;var t2;var t3;var rgb;var val;if(s===0){val=l;return [val,val,val,a];}if(l<0.5){t2=l*(1+s);}else {t2=l+s-l*s;}t1=2*l-t2;rgb=[0,0,0,a];for(var i=0;i<3;i++){t3=h+1/3*-(i-1);if(t3<0){t3++;}if(t3>1){t3--;}if(6*t3<1){val=t1+(t2-t1)*6*t3;}else if(2*t3<1){val=t2;}else if(3*t3<2){val=t1+(t2-t1)*(2/3-t3)*6;}else {val=t1;}rgb[i]=val;}return rgb;}function hwbToRgb(_h,_w,_b,a){var h=_h/360;var wh=_w/100;var bl=_b/100;var ratio=wh+bl;var i;var v;var f;var n;if(ratio>1){wh/=ratio;bl/=ratio;}i=Math.floor(6*h);v=1-bl;f=6*h-i;if((i&0x01)!==0){f=1-f;}n=wh+f*(v-wh);var r;var g;var b;switch(i){default:case 6:case 0:r=v;g=n;b=wh;break;case 1:r=n;g=v;b=wh;break;case 2:r=wh;g=v;b=n;break;case 3:r=wh;g=n;b=v;break;case 4:r=n;g=wh;b=v;break;case 5:r=v;g=wh;b=n;break;}return [r,g,b,a];}function clamp(num,min,max){return Math.min(Math.max(min,num),max);}var abbr=/^#([a-f0-9]{3,4})$/i;var hex=/^#([a-f0-9]{6})([a-f0-9]{2})?$/i;var rgba=/^rgba?\(\s*([+-]?\d+)\s*,\s*([+-]?\d+)\s*,\s*([+-]?\d+)\s*(?:,\s*([+-]?[\d.]+)\s*)?\)$/;var per=/^rgba?\(\s*([+-]?[\d.]+)%\s*,\s*([+-]?[\d.]+)%\s*,\s*([+-]?[\d.]+)%\s*(?:,\s*([+-]?[\d.]+)\s*)?\)$/;var keyword=/(\D+)/;function rgbFromString(string){var rgb=[0,0,0,1];var match;var i;var hexAlpha;if(match=string.match(hex)){hexAlpha=match[2];match=match[1];for(i=0;i<3;i++){var i2=i*2;rgb[i]=parseInt(match.slice(i2,i2+2),16)/255;}if(hexAlpha){rgb[3]=Math.round(parseInt(hexAlpha,16)/255*100)/100;}}else if(match=string.match(abbr)){match=match[1];hexAlpha=match[3];for(i=0;i<3;i++){rgb[i]=parseInt(match[i]+match[i],16)/255;}if(hexAlpha){rgb[3]=Math.round(parseInt(hexAlpha+hexAlpha,16)/255*100)/100;}}else if(match=string.match(rgba)){for(i=0;i<3;i++){rgb[i]=parseInt(match[i+1],0)/255;}if(match[4]){rgb[3]=parseFloat(match[4]);}}else if(match=string.match(per)){for(i=0;i<3;i++){rgb[i]=parseFloat(match[i+1])/100;}if(match[4]){rgb[3]=parseFloat(match[4]);}}else if(match=string.match(keyword)){if(match[1]==='transparent'){return [0,0,0,0];}var _color=colorNames[match[1]];if(!(typeof _color==='number')){return null;}return integerColor(_color);}else {return null;}for(i=0;i<4;i++){rgb[i]=clamp(rgb[i],0,1);}return rgb;}var hslRegEx=/^hsla?\(\s*([+-]?(?:\d*\.)?\d+)(?:deg)?\s*,\s*([+-]?[\d.]+)%\s*,\s*([+-]?[\d.]+)%\s*(?:,\s*([+-]?[\d.]+)\s*)?\)$/;function rgbFromHslString(string){var match=string.match(hslRegEx);if(!match){return null;}var alpha=parseFloat(match[4]);var h=(parseFloat(match[1])+360)%360;var s=clamp(parseFloat(match[2]),0,100);var l=clamp(parseFloat(match[3]),0,100);var a=isNaN(alpha)?1:clamp(alpha,0,1);return hslToRgb(h,s,l,a);}var hwbRegEx=/^hwb\(\s*([+-]?\d*[.]?\d+)(?:deg)?\s*,\s*([+-]?[\d.]+)%\s*,\s*([+-]?[\d.]+)%\s*(?:,\s*([+-]?[\d.]+)\s*)?\)$/;function rgbFromHwbString(string){var match=string.match(hwbRegEx);if(!match){return null;}var alpha=parseFloat(match[4]);var h=(parseFloat(match[1])%360+360)%360;var w=clamp(parseFloat(match[2]),0,100);var b=clamp(parseFloat(match[3]),0,100);var a=isNaN(alpha)?1:clamp(alpha,0,1);return hwbToRgb(h,w,b,a);}function colorFromString(string){var prefix=string.substring(0,3).toLowerCase();switch(prefix){case'hsl':return rgbFromHslString(string);case'hwb':return rgbFromHwbString(string);default:return rgbFromString(string);}}var identity=function identity(x){return x;};var toSignedInt32=function toSignedInt32(x){return x|0x0;};var integerColor=_reactNative__default["default"].Platform.OS==='android'?toSignedInt32:identity;exports.integerColor=integerColor;function extractColor(color){if(typeof color==='number'){if(color>>>0===color&&color>=0&&color<=0xffffffff){return integerColor(color);}return null;}var parsedColor=typeof color==='string'?colorFromString(color):color;if(!Array.isArray(parsedColor)){return parsedColor;}var r=parsedColor[0];var g=parsedColor[1];var b=parsedColor[2];var a=parsedColor[3];var int32Color=((a===undefined?0xff000000:Math.round(a*255)<<24)|Math.round(r*255)<<16|Math.round(g*255)<<8|Math.round(b*255))>>>0;return integerColor(int32Color);}

  });

  var _default$e=extractBrush;var _extractColor$1=interopRequireWildcard(extractColor_1);var urlIdPattern=/^url\(#(.+)\)$/;var currentColorBrush=[2];var contextFillBrush=[3];var contextStrokeBrush=[4];function extractBrush(color){if(typeof color==='number'){if(color>>>0===color&&color>=0&&color<=0xffffffff){return (0, _extractColor$1.integerColor)(color);}}if(!color||color==='none'){return null;}if(color==='currentColor'){return currentColorBrush;}if(color==='context-fill'){return contextFillBrush;}if(color==='context-stroke'){return contextStrokeBrush;}var brush=typeof color==='string'&&color.match(urlIdPattern);if(brush){return [1,brush[1]];}var int32ARGBColor=(0, _extractColor$1.default)(color);if(typeof int32ARGBColor==='number'){return int32ARGBColor;}console.warn("\"".concat(color,"\" is not a valid color or brush"));return null;}


  var extractBrush_1 = /*#__PURE__*/Object.defineProperty({
  	default: _default$e
  }, '__esModule', {value: true});

  var _default$d=extractOpacity;function extractOpacity(opacity){var value=+opacity;return isNaN(value)?1:value;}


  var extractOpacity_1 = /*#__PURE__*/Object.defineProperty({
  	default: _default$d
  }, '__esModule', {value: true});

  var _default$c=extractFill;var _extractBrush$1=interopRequireDefault(extractBrush_1);var _extractOpacity$3=interopRequireDefault(extractOpacity_1);var fillRules={evenodd:0,nonzero:1};var defaultFill=extractColor_1.colorNames.black;function extractFill(o,props,inherited){var fill=props.fill,fillRule=props.fillRule,fillOpacity=props.fillOpacity;if(fill!=null){inherited.push('fill');o.fill=!fill&&typeof fill!=='number'?defaultFill:(0, _extractBrush$1.default)(fill);}if(fillOpacity!=null){inherited.push('fillOpacity');o.fillOpacity=(0, _extractOpacity$3.default)(fillOpacity);}if(fillRule!=null){inherited.push('fillRule');o.fillRule=fillRule&&fillRules[fillRule]===0?0:1;}}


  var extractFill_1 = /*#__PURE__*/Object.defineProperty({
  	default: _default$c
  }, '__esModule', {value: true});

  var _default$b=extractLengthList;var spaceReg=/\s+/;var commaReg$1=/,/g;function extractLengthList(lengthList){if(Array.isArray(lengthList)){return lengthList;}else if(typeof lengthList==='number'){return [lengthList];}else if(typeof lengthList==='string'){return lengthList.trim().replace(commaReg$1,' ').split(spaceReg);}else {return [];}}


  var extractLengthList_1 = /*#__PURE__*/Object.defineProperty({
  	default: _default$b
  }, '__esModule', {value: true});

  var _default$a=extractStroke;var _extractBrush=interopRequireDefault(extractBrush_1);var _extractOpacity$2=interopRequireDefault(extractOpacity_1);var _extractLengthList$1=interopRequireDefault(extractLengthList_1);var caps$1={butt:0,square:2,round:1};var joins={miter:0,bevel:2,round:1};var vectorEffects={none:0,default:0,nonScalingStroke:1,'non-scaling-stroke':1,inherit:2,uri:3};function extractStroke(o,props,inherited){var stroke=props.stroke,strokeOpacity=props.strokeOpacity,strokeLinecap=props.strokeLinecap,strokeLinejoin=props.strokeLinejoin,strokeDasharray=props.strokeDasharray,strokeWidth=props.strokeWidth,strokeDashoffset=props.strokeDashoffset,strokeMiterlimit=props.strokeMiterlimit,vectorEffect=props.vectorEffect;if(stroke!=null){inherited.push('stroke');o.stroke=(0, _extractBrush.default)(stroke);}if(strokeWidth!=null){inherited.push('strokeWidth');o.strokeWidth=strokeWidth;}if(strokeOpacity!=null){inherited.push('strokeOpacity');o.strokeOpacity=(0, _extractOpacity$2.default)(strokeOpacity);}if(strokeDasharray!=null){inherited.push('strokeDasharray');var strokeDash=!strokeDasharray||strokeDasharray==='none'?null:(0, _extractLengthList$1.default)(strokeDasharray);o.strokeDasharray=strokeDash&&strokeDash.length%2===1?strokeDash.concat(strokeDash):strokeDash;}if(strokeDashoffset!=null){inherited.push('strokeDashoffset');o.strokeDashoffset=strokeDasharray&&strokeDashoffset?+strokeDashoffset||0:null;}if(strokeLinecap!=null){inherited.push('strokeLinecap');o.strokeLinecap=strokeLinecap&&caps$1[strokeLinecap]||0;}if(strokeLinejoin!=null){inherited.push('strokeLinejoin');o.strokeLinejoin=strokeLinejoin&&joins[strokeLinejoin]||0;}if(strokeMiterlimit!=null){inherited.push('strokeMiterlimit');o.strokeMiterlimit=(strokeMiterlimit&&typeof strokeMiterlimit!=='number'?parseFloat(strokeMiterlimit):strokeMiterlimit)||4;}if(vectorEffect!=null){o.vectorEffect=vectorEffect&&vectorEffects[vectorEffect]||0;}}


  var extractStroke_1 = /*#__PURE__*/Object.defineProperty({
  	default: _default$a
  }, '__esModule', {value: true});

  var Matrix2D = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.reset=reset;exports.toArray=toArray;exports.append=append;exports.appendTransform=appendTransform;exports.identity=void 0;var DEG_TO_RAD=Math.PI/180;var identity=[1,0,0,1,0,0];exports.identity=identity;var a=1;var b=0;var c=0;var d=1;var tx=0;var ty=0;var hasInitialState=true;function reset(){if(hasInitialState){return;}a=d=1;b=c=tx=ty=0;hasInitialState=true;}function toArray(){if(hasInitialState){return identity;}return [a,b,c,d,tx,ty];}function append(a2,b2,c2,d2,tx2,ty2){var change=a2!==1||b2!==0||c2!==0||d2!==1;var translate=tx2!==0||ty2!==0;if(!change&&!translate){return;}if(hasInitialState){hasInitialState=false;a=a2;b=b2;c=c2;d=d2;tx=tx2;ty=ty2;return;}var a1=a;var b1=b;var c1=c;var d1=d;if(change){a=a1*a2+c1*b2;b=b1*a2+d1*b2;c=a1*c2+c1*d2;d=b1*c2+d1*d2;}if(translate){tx=a1*tx2+c1*ty2+tx;ty=b1*tx2+d1*ty2+ty;}}function appendTransform(x,y,scaleX,scaleY,rotation,skewX,skewY,regX,regY){if(x===0&&y===0&&scaleX===1&&scaleY===1&&rotation===0&&skewX===0&&skewY===0&&regX===0&&regY===0){return;}var cos,sin;if(rotation%360){var r=rotation*DEG_TO_RAD;cos=Math.cos(r);sin=Math.sin(r);}else {cos=1;sin=0;}var a2=cos*scaleX;var b2=sin*scaleX;var c2=-sin*scaleY;var d2=cos*scaleY;if(skewX||skewY){var b1=Math.tan(skewY*DEG_TO_RAD);var c1=Math.tan(skewX*DEG_TO_RAD);append(a2+c1*b2,b1*a2+b2,c2+c1*d2,b1*c2+d2,x,y);}else {append(a2,b2,c2,d2,x,y);}if(regX||regY){tx-=regX*a+regY*c;ty-=regX*b+regY*d;hasInitialState=false;}}

  });

  function peg$subclass(child,parent){function ctor(){this.constructor=child;}ctor.prototype=parent.prototype;child.prototype=new ctor();}function peg$SyntaxError(message,expected,found,location){this.message=message;this.expected=expected;this.found=found;this.location=location;this.name="SyntaxError";if(typeof Error.captureStackTrace==="function"){Error.captureStackTrace(this,peg$SyntaxError);}}peg$subclass(peg$SyntaxError,Error);peg$SyntaxError.buildMessage=function(expected,found){var DESCRIBE_EXPECTATION_FNS={literal:function literal(expectation){return "\""+literalEscape(expectation.text)+"\"";},"class":function _class(expectation){var escapedParts="",i;for(i=0;i<expectation.parts.length;i++){escapedParts+=expectation.parts[i]instanceof Array?classEscape(expectation.parts[i][0])+"-"+classEscape(expectation.parts[i][1]):classEscape(expectation.parts[i]);}return "["+(expectation.inverted?"^":"")+escapedParts+"]";},any:function any(expectation){return "any character";},end:function end(expectation){return "end of input";},other:function other(expectation){return expectation.description;}};function hex(ch){return ch.charCodeAt(0).toString(16).toUpperCase();}function literalEscape(s){return s.replace(/\\/g,'\\\\').replace(/"/g,'\\"').replace(/\0/g,'\\0').replace(/\t/g,'\\t').replace(/\n/g,'\\n').replace(/\r/g,'\\r').replace(/[\x00-\x0F]/g,function(ch){return '\\x0'+hex(ch);}).replace(/[\x10-\x1F\x7F-\x9F]/g,function(ch){return '\\x'+hex(ch);});}function classEscape(s){return s.replace(/\\/g,'\\\\').replace(/\]/g,'\\]').replace(/\^/g,'\\^').replace(/-/g,'\\-').replace(/\0/g,'\\0').replace(/\t/g,'\\t').replace(/\n/g,'\\n').replace(/\r/g,'\\r').replace(/[\x00-\x0F]/g,function(ch){return '\\x0'+hex(ch);}).replace(/[\x10-\x1F\x7F-\x9F]/g,function(ch){return '\\x'+hex(ch);});}function describeExpectation(expectation){return DESCRIBE_EXPECTATION_FNS[expectation.type](expectation);}function describeExpected(expected){var descriptions=new Array(expected.length),i,j;for(i=0;i<expected.length;i++){descriptions[i]=describeExpectation(expected[i]);}descriptions.sort();if(descriptions.length>0){for(i=1,j=1;i<descriptions.length;i++){if(descriptions[i-1]!==descriptions[i]){descriptions[j]=descriptions[i];j++;}}descriptions.length=j;}switch(descriptions.length){case 1:return descriptions[0];case 2:return descriptions[0]+" or "+descriptions[1];default:return descriptions.slice(0,-1).join(", ")+", or "+descriptions[descriptions.length-1];}}function describeFound(found){return found?"\""+literalEscape(found)+"\"":"end of input";}return "Expected "+describeExpected(expected)+" but "+describeFound(found)+" found.";};function peg$parse(input,options){options=options!==void 0?options:{};var peg$FAILED={},peg$startRuleFunctions={transformList:peg$parsetransformList},peg$startRuleFunction=peg$parsetransformList,peg$c0=function peg$c0(ts){return ts;},peg$c1=function peg$c1(t,ts){return multiply_matrices(t,ts);},peg$c2="matrix",peg$c3=peg$literalExpectation("matrix",false),peg$c4="(",peg$c5=peg$literalExpectation("(",false),peg$c6=")",peg$c7=peg$literalExpectation(")",false),peg$c8=function peg$c8(a,b,c,d,e,f){return [a,c,e,b,d,f];},peg$c9="translate",peg$c10=peg$literalExpectation("translate",false),peg$c11=function peg$c11(tx,ty){return [1,0,tx,0,1,ty||0];},peg$c12="scale",peg$c13=peg$literalExpectation("scale",false),peg$c14=function peg$c14(sx,sy){return [sx,0,0,0,sy===null?sx:sy,0];},peg$c15="rotate",peg$c16=peg$literalExpectation("rotate",false),peg$c17=function peg$c17(angle,c){var cos=Math.cos(deg2rad*angle);var sin=Math.sin(deg2rad*angle);if(c!==null){var x=c[0];var y=c[1];return [cos,-sin,cos*-x+-sin*-y+x,sin,cos,sin*-x+cos*-y+y];}return [cos,-sin,0,sin,cos,0];},peg$c18="skewX",peg$c19=peg$literalExpectation("skewX",false),peg$c20=function peg$c20(angle){return [1,Math.tan(deg2rad*angle),0,0,1,0];},peg$c21="skewY",peg$c22=peg$literalExpectation("skewY",false),peg$c23=function peg$c23(angle){return [1,0,0,Math.tan(deg2rad*angle),1,0];},peg$c24=function peg$c24(f){return parseFloat(f.join(""));},peg$c25=function peg$c25(i){return parseInt(i.join(""));},peg$c26=function peg$c26(n){return n;},peg$c27=function peg$c27(n1,n2){return [n1,n2];},peg$c28=",",peg$c29=peg$literalExpectation(",",false),peg$c30=function peg$c30(ds){return ds.join("");},peg$c31=function peg$c31(f){return f.join("");},peg$c32=function peg$c32(d){return d.join("");},peg$c33=peg$otherExpectation("fractionalConstant"),peg$c34=".",peg$c35=peg$literalExpectation(".",false),peg$c36=function peg$c36(d1,d2){return [d1?d1.join(""):null,".",d2.join("")].join("");},peg$c37=/^[eE]/,peg$c38=peg$classExpectation(["e","E"],false,false),peg$c39=function peg$c39(e){return [e[0],e[1],e[2].join("")].join("");},peg$c40=/^[+\-]/,peg$c41=peg$classExpectation(["+","-"],false,false),peg$c42=/^[0-9]/,peg$c43=peg$classExpectation([["0","9"]],false,false),peg$c44=/^[ \t\r\n]/,peg$c45=peg$classExpectation([" ","\t","\r","\n"],false,false),peg$currPos=0,peg$posDetailsCache=[{line:1,column:1}],peg$maxFailPos=0,peg$maxFailExpected=[],peg$silentFails=0,peg$result;if("startRule"in options){if(!(options.startRule in peg$startRuleFunctions)){throw new Error("Can't start parsing from rule \""+options.startRule+"\".");}peg$startRuleFunction=peg$startRuleFunctions[options.startRule];}function peg$literalExpectation(text,ignoreCase){return {type:"literal",text:text,ignoreCase:ignoreCase};}function peg$classExpectation(parts,inverted,ignoreCase){return {type:"class",parts:parts,inverted:inverted,ignoreCase:ignoreCase};}function peg$endExpectation(){return {type:"end"};}function peg$otherExpectation(description){return {type:"other",description:description};}function peg$computePosDetails(pos){var details=peg$posDetailsCache[pos],p;if(details){return details;}else {p=pos-1;while(!peg$posDetailsCache[p]){p--;}details=peg$posDetailsCache[p];details={line:details.line,column:details.column};while(p<pos){if(input.charCodeAt(p)===10){details.line++;details.column=1;}else {details.column++;}p++;}peg$posDetailsCache[pos]=details;return details;}}function peg$computeLocation(startPos,endPos){var startPosDetails=peg$computePosDetails(startPos),endPosDetails=peg$computePosDetails(endPos);return {start:{offset:startPos,line:startPosDetails.line,column:startPosDetails.column},end:{offset:endPos,line:endPosDetails.line,column:endPosDetails.column}};}function peg$fail(expected){if(peg$currPos<peg$maxFailPos){return;}if(peg$currPos>peg$maxFailPos){peg$maxFailPos=peg$currPos;peg$maxFailExpected=[];}peg$maxFailExpected.push(expected);}function peg$buildStructuredError(expected,found,location){return new peg$SyntaxError(peg$SyntaxError.buildMessage(expected,found),expected,found,location);}function peg$parsetransformList(){var s0,s1,s2,s3,s4;s0=peg$currPos;s1=[];s2=peg$parsewsp();while(s2!==peg$FAILED){s1.push(s2);s2=peg$parsewsp();}if(s1!==peg$FAILED){s2=peg$parsetransforms();if(s2===peg$FAILED){s2=null;}if(s2!==peg$FAILED){s3=[];s4=peg$parsewsp();while(s4!==peg$FAILED){s3.push(s4);s4=peg$parsewsp();}if(s3!==peg$FAILED){s1=peg$c0(s2);s0=s1;}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}return s0;}function peg$parsetransforms(){var s0,s1,s2,s3;s0=peg$currPos;s1=peg$parsetransform();if(s1!==peg$FAILED){s2=[];s3=peg$parsecommaWsp();while(s3!==peg$FAILED){s2.push(s3);s3=peg$parsecommaWsp();}if(s2!==peg$FAILED){s3=peg$parsetransforms();if(s3!==peg$FAILED){s1=peg$c1(s1,s3);s0=s1;}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}if(s0===peg$FAILED){s0=peg$parsetransform();}return s0;}function peg$parsetransform(){var s0;s0=peg$parsematrix();if(s0===peg$FAILED){s0=peg$parsetranslate();if(s0===peg$FAILED){s0=peg$parsescale();if(s0===peg$FAILED){s0=peg$parserotate();if(s0===peg$FAILED){s0=peg$parseskewX();if(s0===peg$FAILED){s0=peg$parseskewY();}}}}}return s0;}function peg$parsematrix(){var s0,s1,s2,s3,s4,s5,s6,s7,s8,s9,s10,s11,s12,s13,s14,s15,s16,s17;s0=peg$currPos;if(input.substr(peg$currPos,6)===peg$c2){s1=peg$c2;peg$currPos+=6;}else {s1=peg$FAILED;if(peg$silentFails===0){peg$fail(peg$c3);}}if(s1!==peg$FAILED){s2=[];s3=peg$parsewsp();while(s3!==peg$FAILED){s2.push(s3);s3=peg$parsewsp();}if(s2!==peg$FAILED){if(input.charCodeAt(peg$currPos)===40){s3=peg$c4;peg$currPos++;}else {s3=peg$FAILED;if(peg$silentFails===0){peg$fail(peg$c5);}}if(s3!==peg$FAILED){s4=[];s5=peg$parsewsp();while(s5!==peg$FAILED){s4.push(s5);s5=peg$parsewsp();}if(s4!==peg$FAILED){s5=peg$parsenumber();if(s5!==peg$FAILED){s6=peg$parsecommaWsp();if(s6!==peg$FAILED){s7=peg$parsenumber();if(s7!==peg$FAILED){s8=peg$parsecommaWsp();if(s8!==peg$FAILED){s9=peg$parsenumber();if(s9!==peg$FAILED){s10=peg$parsecommaWsp();if(s10!==peg$FAILED){s11=peg$parsenumber();if(s11!==peg$FAILED){s12=peg$parsecommaWsp();if(s12!==peg$FAILED){s13=peg$parsenumber();if(s13!==peg$FAILED){s14=peg$parsecommaWsp();if(s14!==peg$FAILED){s15=peg$parsenumber();if(s15!==peg$FAILED){s16=[];s17=peg$parsewsp();while(s17!==peg$FAILED){s16.push(s17);s17=peg$parsewsp();}if(s16!==peg$FAILED){if(input.charCodeAt(peg$currPos)===41){s17=peg$c6;peg$currPos++;}else {s17=peg$FAILED;if(peg$silentFails===0){peg$fail(peg$c7);}}if(s17!==peg$FAILED){s1=peg$c8(s5,s7,s9,s11,s13,s15);s0=s1;}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}return s0;}function peg$parsetranslate(){var s0,s1,s2,s3,s4,s5,s6,s7,s8;s0=peg$currPos;if(input.substr(peg$currPos,9)===peg$c9){s1=peg$c9;peg$currPos+=9;}else {s1=peg$FAILED;if(peg$silentFails===0){peg$fail(peg$c10);}}if(s1!==peg$FAILED){s2=[];s3=peg$parsewsp();while(s3!==peg$FAILED){s2.push(s3);s3=peg$parsewsp();}if(s2!==peg$FAILED){if(input.charCodeAt(peg$currPos)===40){s3=peg$c4;peg$currPos++;}else {s3=peg$FAILED;if(peg$silentFails===0){peg$fail(peg$c5);}}if(s3!==peg$FAILED){s4=[];s5=peg$parsewsp();while(s5!==peg$FAILED){s4.push(s5);s5=peg$parsewsp();}if(s4!==peg$FAILED){s5=peg$parsenumber();if(s5!==peg$FAILED){s6=peg$parsecommaWspNumber();if(s6===peg$FAILED){s6=null;}if(s6!==peg$FAILED){s7=[];s8=peg$parsewsp();while(s8!==peg$FAILED){s7.push(s8);s8=peg$parsewsp();}if(s7!==peg$FAILED){if(input.charCodeAt(peg$currPos)===41){s8=peg$c6;peg$currPos++;}else {s8=peg$FAILED;if(peg$silentFails===0){peg$fail(peg$c7);}}if(s8!==peg$FAILED){s1=peg$c11(s5,s6);s0=s1;}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}return s0;}function peg$parsescale(){var s0,s1,s2,s3,s4,s5,s6,s7,s8;s0=peg$currPos;if(input.substr(peg$currPos,5)===peg$c12){s1=peg$c12;peg$currPos+=5;}else {s1=peg$FAILED;if(peg$silentFails===0){peg$fail(peg$c13);}}if(s1!==peg$FAILED){s2=[];s3=peg$parsewsp();while(s3!==peg$FAILED){s2.push(s3);s3=peg$parsewsp();}if(s2!==peg$FAILED){if(input.charCodeAt(peg$currPos)===40){s3=peg$c4;peg$currPos++;}else {s3=peg$FAILED;if(peg$silentFails===0){peg$fail(peg$c5);}}if(s3!==peg$FAILED){s4=[];s5=peg$parsewsp();while(s5!==peg$FAILED){s4.push(s5);s5=peg$parsewsp();}if(s4!==peg$FAILED){s5=peg$parsenumber();if(s5!==peg$FAILED){s6=peg$parsecommaWspNumber();if(s6===peg$FAILED){s6=null;}if(s6!==peg$FAILED){s7=[];s8=peg$parsewsp();while(s8!==peg$FAILED){s7.push(s8);s8=peg$parsewsp();}if(s7!==peg$FAILED){if(input.charCodeAt(peg$currPos)===41){s8=peg$c6;peg$currPos++;}else {s8=peg$FAILED;if(peg$silentFails===0){peg$fail(peg$c7);}}if(s8!==peg$FAILED){s1=peg$c14(s5,s6);s0=s1;}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}return s0;}function peg$parserotate(){var s0,s1,s2,s3,s4,s5,s6,s7,s8;s0=peg$currPos;if(input.substr(peg$currPos,6)===peg$c15){s1=peg$c15;peg$currPos+=6;}else {s1=peg$FAILED;if(peg$silentFails===0){peg$fail(peg$c16);}}if(s1!==peg$FAILED){s2=[];s3=peg$parsewsp();while(s3!==peg$FAILED){s2.push(s3);s3=peg$parsewsp();}if(s2!==peg$FAILED){if(input.charCodeAt(peg$currPos)===40){s3=peg$c4;peg$currPos++;}else {s3=peg$FAILED;if(peg$silentFails===0){peg$fail(peg$c5);}}if(s3!==peg$FAILED){s4=[];s5=peg$parsewsp();while(s5!==peg$FAILED){s4.push(s5);s5=peg$parsewsp();}if(s4!==peg$FAILED){s5=peg$parsenumber();if(s5!==peg$FAILED){s6=peg$parsecommaWspTwoNumbers();if(s6===peg$FAILED){s6=null;}if(s6!==peg$FAILED){s7=[];s8=peg$parsewsp();while(s8!==peg$FAILED){s7.push(s8);s8=peg$parsewsp();}if(s7!==peg$FAILED){if(input.charCodeAt(peg$currPos)===41){s8=peg$c6;peg$currPos++;}else {s8=peg$FAILED;if(peg$silentFails===0){peg$fail(peg$c7);}}if(s8!==peg$FAILED){s1=peg$c17(s5,s6);s0=s1;}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}return s0;}function peg$parseskewX(){var s0,s1,s2,s3,s4,s5,s6,s7;s0=peg$currPos;if(input.substr(peg$currPos,5)===peg$c18){s1=peg$c18;peg$currPos+=5;}else {s1=peg$FAILED;if(peg$silentFails===0){peg$fail(peg$c19);}}if(s1!==peg$FAILED){s2=[];s3=peg$parsewsp();while(s3!==peg$FAILED){s2.push(s3);s3=peg$parsewsp();}if(s2!==peg$FAILED){if(input.charCodeAt(peg$currPos)===40){s3=peg$c4;peg$currPos++;}else {s3=peg$FAILED;if(peg$silentFails===0){peg$fail(peg$c5);}}if(s3!==peg$FAILED){s4=[];s5=peg$parsewsp();while(s5!==peg$FAILED){s4.push(s5);s5=peg$parsewsp();}if(s4!==peg$FAILED){s5=peg$parsenumber();if(s5!==peg$FAILED){s6=[];s7=peg$parsewsp();while(s7!==peg$FAILED){s6.push(s7);s7=peg$parsewsp();}if(s6!==peg$FAILED){if(input.charCodeAt(peg$currPos)===41){s7=peg$c6;peg$currPos++;}else {s7=peg$FAILED;if(peg$silentFails===0){peg$fail(peg$c7);}}if(s7!==peg$FAILED){s1=peg$c20(s5);s0=s1;}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}return s0;}function peg$parseskewY(){var s0,s1,s2,s3,s4,s5,s6,s7;s0=peg$currPos;if(input.substr(peg$currPos,5)===peg$c21){s1=peg$c21;peg$currPos+=5;}else {s1=peg$FAILED;if(peg$silentFails===0){peg$fail(peg$c22);}}if(s1!==peg$FAILED){s2=[];s3=peg$parsewsp();while(s3!==peg$FAILED){s2.push(s3);s3=peg$parsewsp();}if(s2!==peg$FAILED){if(input.charCodeAt(peg$currPos)===40){s3=peg$c4;peg$currPos++;}else {s3=peg$FAILED;if(peg$silentFails===0){peg$fail(peg$c5);}}if(s3!==peg$FAILED){s4=[];s5=peg$parsewsp();while(s5!==peg$FAILED){s4.push(s5);s5=peg$parsewsp();}if(s4!==peg$FAILED){s5=peg$parsenumber();if(s5!==peg$FAILED){s6=[];s7=peg$parsewsp();while(s7!==peg$FAILED){s6.push(s7);s7=peg$parsewsp();}if(s6!==peg$FAILED){if(input.charCodeAt(peg$currPos)===41){s7=peg$c6;peg$currPos++;}else {s7=peg$FAILED;if(peg$silentFails===0){peg$fail(peg$c7);}}if(s7!==peg$FAILED){s1=peg$c23(s5);s0=s1;}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}return s0;}function peg$parsenumber(){var s0,s1,s2,s3;s0=peg$currPos;s1=peg$currPos;s2=peg$parsesign();if(s2===peg$FAILED){s2=null;}if(s2!==peg$FAILED){s3=peg$parsefloatingPointConstant();if(s3!==peg$FAILED){s2=[s2,s3];s1=s2;}else {peg$currPos=s1;s1=peg$FAILED;}}else {peg$currPos=s1;s1=peg$FAILED;}if(s1!==peg$FAILED){s1=peg$c24(s1);}s0=s1;if(s0===peg$FAILED){s0=peg$currPos;s1=peg$currPos;s2=peg$parsesign();if(s2===peg$FAILED){s2=null;}if(s2!==peg$FAILED){s3=peg$parseintegerConstant();if(s3!==peg$FAILED){s2=[s2,s3];s1=s2;}else {peg$currPos=s1;s1=peg$FAILED;}}else {peg$currPos=s1;s1=peg$FAILED;}if(s1!==peg$FAILED){s1=peg$c25(s1);}s0=s1;}return s0;}function peg$parsecommaWspNumber(){var s0,s1,s2;s0=peg$currPos;s1=peg$parsecommaWsp();if(s1!==peg$FAILED){s2=peg$parsenumber();if(s2!==peg$FAILED){s1=peg$c26(s2);s0=s1;}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}return s0;}function peg$parsecommaWspTwoNumbers(){var s0,s1,s2,s3,s4;s0=peg$currPos;s1=peg$parsecommaWsp();if(s1!==peg$FAILED){s2=peg$parsenumber();if(s2!==peg$FAILED){s3=peg$parsecommaWsp();if(s3!==peg$FAILED){s4=peg$parsenumber();if(s4!==peg$FAILED){s1=peg$c27(s2,s4);s0=s1;}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}return s0;}function peg$parsecommaWsp(){var s0,s1,s2,s3,s4;s0=peg$currPos;s1=[];s2=peg$parsewsp();if(s2!==peg$FAILED){while(s2!==peg$FAILED){s1.push(s2);s2=peg$parsewsp();}}else {s1=peg$FAILED;}if(s1!==peg$FAILED){s2=peg$parsecomma();if(s2===peg$FAILED){s2=null;}if(s2!==peg$FAILED){s3=[];s4=peg$parsewsp();while(s4!==peg$FAILED){s3.push(s4);s4=peg$parsewsp();}if(s3!==peg$FAILED){s1=[s1,s2,s3];s0=s1;}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}if(s0===peg$FAILED){s0=peg$currPos;s1=peg$parsecomma();if(s1!==peg$FAILED){s2=[];s3=peg$parsewsp();while(s3!==peg$FAILED){s2.push(s3);s3=peg$parsewsp();}if(s2!==peg$FAILED){s1=[s1,s2];s0=s1;}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}return s0;}function peg$parsecomma(){var s0;if(input.charCodeAt(peg$currPos)===44){s0=peg$c28;peg$currPos++;}else {s0=peg$FAILED;if(peg$silentFails===0){peg$fail(peg$c29);}}return s0;}function peg$parseintegerConstant(){var s0,s1;s0=peg$currPos;s1=peg$parsedigitSequence();if(s1!==peg$FAILED){s1=peg$c30(s1);}s0=s1;return s0;}function peg$parsefloatingPointConstant(){var s0,s1,s2,s3;s0=peg$currPos;s1=peg$currPos;s2=peg$parsefractionalConstant();if(s2!==peg$FAILED){s3=peg$parseexponent();if(s3===peg$FAILED){s3=null;}if(s3!==peg$FAILED){s2=[s2,s3];s1=s2;}else {peg$currPos=s1;s1=peg$FAILED;}}else {peg$currPos=s1;s1=peg$FAILED;}if(s1!==peg$FAILED){s1=peg$c31(s1);}s0=s1;if(s0===peg$FAILED){s0=peg$currPos;s1=peg$currPos;s2=peg$parsedigitSequence();if(s2!==peg$FAILED){s3=peg$parseexponent();if(s3!==peg$FAILED){s2=[s2,s3];s1=s2;}else {peg$currPos=s1;s1=peg$FAILED;}}else {peg$currPos=s1;s1=peg$FAILED;}if(s1!==peg$FAILED){s1=peg$c32(s1);}s0=s1;}return s0;}function peg$parsefractionalConstant(){var s0,s1,s2,s3;peg$silentFails++;s0=peg$currPos;s1=peg$parsedigitSequence();if(s1===peg$FAILED){s1=null;}if(s1!==peg$FAILED){if(input.charCodeAt(peg$currPos)===46){s2=peg$c34;peg$currPos++;}else {s2=peg$FAILED;if(peg$silentFails===0){peg$fail(peg$c35);}}if(s2!==peg$FAILED){s3=peg$parsedigitSequence();if(s3!==peg$FAILED){s1=peg$c36(s1,s3);s0=s1;}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}if(s0===peg$FAILED){s0=peg$currPos;s1=peg$parsedigitSequence();if(s1!==peg$FAILED){if(input.charCodeAt(peg$currPos)===46){s2=peg$c34;peg$currPos++;}else {s2=peg$FAILED;if(peg$silentFails===0){peg$fail(peg$c35);}}if(s2!==peg$FAILED){s1=peg$c32(s1);s0=s1;}else {peg$currPos=s0;s0=peg$FAILED;}}else {peg$currPos=s0;s0=peg$FAILED;}}peg$silentFails--;if(s0===peg$FAILED){s1=peg$FAILED;if(peg$silentFails===0){peg$fail(peg$c33);}}return s0;}function peg$parseexponent(){var s0,s1,s2,s3,s4;s0=peg$currPos;s1=peg$currPos;if(peg$c37.test(input.charAt(peg$currPos))){s2=input.charAt(peg$currPos);peg$currPos++;}else {s2=peg$FAILED;if(peg$silentFails===0){peg$fail(peg$c38);}}if(s2!==peg$FAILED){s3=peg$parsesign();if(s3===peg$FAILED){s3=null;}if(s3!==peg$FAILED){s4=peg$parsedigitSequence();if(s4!==peg$FAILED){s2=[s2,s3,s4];s1=s2;}else {peg$currPos=s1;s1=peg$FAILED;}}else {peg$currPos=s1;s1=peg$FAILED;}}else {peg$currPos=s1;s1=peg$FAILED;}if(s1!==peg$FAILED){s1=peg$c39(s1);}s0=s1;return s0;}function peg$parsesign(){var s0;if(peg$c40.test(input.charAt(peg$currPos))){s0=input.charAt(peg$currPos);peg$currPos++;}else {s0=peg$FAILED;if(peg$silentFails===0){peg$fail(peg$c41);}}return s0;}function peg$parsedigitSequence(){var s0,s1;s0=[];s1=peg$parsedigit();if(s1!==peg$FAILED){while(s1!==peg$FAILED){s0.push(s1);s1=peg$parsedigit();}}else {s0=peg$FAILED;}return s0;}function peg$parsedigit(){var s0;if(peg$c42.test(input.charAt(peg$currPos))){s0=input.charAt(peg$currPos);peg$currPos++;}else {s0=peg$FAILED;if(peg$silentFails===0){peg$fail(peg$c43);}}return s0;}function peg$parsewsp(){var s0;if(peg$c44.test(input.charAt(peg$currPos))){s0=input.charAt(peg$currPos);peg$currPos++;}else {s0=peg$FAILED;if(peg$silentFails===0){peg$fail(peg$c45);}}return s0;}var deg2rad=Math.PI/180;function multiply_matrices(l,r){var al=l[0];var cl=l[1];var el=l[2];var bl=l[3];var dl=l[4];var fl=l[5];var ar=r[0];var cr=r[1];var er=r[2];var br=r[3];var dr=r[4];var fr=r[5];var a=al*ar+cl*br;var c=al*cr+cl*dr;var e=al*er+cl*fr+el;var b=bl*ar+dl*br;var d=bl*cr+dl*dr;var f=bl*er+dl*fr+fl;return [a,c,e,b,d,f];}peg$result=peg$startRuleFunction();if(peg$result!==peg$FAILED&&peg$currPos===input.length){return peg$result;}else {if(peg$result!==peg$FAILED&&peg$currPos<input.length){peg$fail(peg$endExpectation());}throw peg$buildStructuredError(peg$maxFailExpected,peg$maxFailPos<input.length?input.charAt(peg$maxFailPos):null,peg$maxFailPos<input.length?peg$computeLocation(peg$maxFailPos,peg$maxFailPos+1):peg$computeLocation(peg$maxFailPos,peg$maxFailPos));}}var transform$1={SyntaxError:peg$SyntaxError,parse:peg$parse};

  var props2transform_1=props2transform;var transformToMatrix_1=transformToMatrix;var _default$9=extractTransform;function appendTransformProps(props){var x=props.x,y=props.y,originX=props.originX,originY=props.originY,scaleX=props.scaleX,scaleY=props.scaleY,rotation=props.rotation,skewX=props.skewX,skewY=props.skewY;(0, Matrix2D.appendTransform)(x+originX,y+originY,scaleX,scaleY,rotation,skewX,skewY,originX,originY);}function universal2axis(universal,axisX,axisY,defaultValue){var x;var y;if(typeof universal==='number'){x=y=universal;}else if(typeof universal==='string'){var coords=universal.split(/\s*,\s*/);if(coords.length===2){x=+coords[0];y=+coords[1];}else if(coords.length===1){x=y=+coords[0];}}else if(Array.isArray(universal)){if(universal.length===2){x=+universal[0];y=+universal[1];}else if(universal.length===1){x=y=+universal[0];}}axisX=+axisX;if(!isNaN(axisX)){x=axisX;}axisY=+axisY;if(!isNaN(axisY)){y=axisY;}return [x||defaultValue||0,y||defaultValue||0];}function props2transform(props){var rotation=props.rotation,translate=props.translate,translateX=props.translateX,translateY=props.translateY,origin=props.origin,originX=props.originX,originY=props.originY,scale=props.scale,scaleX=props.scaleX,scaleY=props.scaleY,skew=props.skew,skewX=props.skewX,skewY=props.skewY,x=props.x,y=props.y;if(rotation==null&&translate==null&&translateX==null&&translateY==null&&origin==null&&originX==null&&originY==null&&scale==null&&scaleX==null&&scaleY==null&&skew==null&&skewX==null&&skewY==null&&x==null&&y==null){return null;}if(Array.isArray(x)||Array.isArray(y)){console.warn('Passing SvgLengthList to x or y attribute where SvgLength expected');}var tr=universal2axis(translate,translateX||(Array.isArray(x)?x[0]:x),translateY||(Array.isArray(y)?y[0]:y));var or=universal2axis(origin,originX,originY);var sc=universal2axis(scale,scaleX,scaleY,1);var sk=universal2axis(skew,skewX,skewY);return {rotation:rotation==null?0:+rotation||0,originX:or[0],originY:or[1],scaleX:sc[0],scaleY:sc[1],skewX:sk[0],skewY:sk[1],x:tr[0],y:tr[1]};}function transformToMatrix(props,transform){if(!props&&!transform){return null;}(0, Matrix2D.reset)();props&&appendTransformProps(props);if(transform){if(Array.isArray(transform)){if(typeof transform[0]==='number'){(0, Matrix2D.append)(transform[0],transform[1],transform[2],transform[3],transform[4],transform[5]);}}else if(typeof transform==='string'){try{var t=(0,transform$1.parse)(transform);(0,Matrix2D.append)(t[0],t[3],t[1],t[4],t[2],t[5]);}catch(e){console.error(e);}}else {var transformProps=props2transform(transform);transformProps&&appendTransformProps(transformProps);}}return (0, Matrix2D.toArray)();}function extractTransform(props){if(Array.isArray(props)){return props;}if(typeof props==='string'){try{var t=(0,transform$1.parse)(props);return [t[0],t[3],t[1],t[4],t[2],t[5]];}catch(e){console.error(e);return Matrix2D.identity;}}return transformToMatrix(props2transform(props),props.transform);}


  var extractTransform_1 = /*#__PURE__*/Object.defineProperty({
  	props2transform: props2transform_1,
  	transformToMatrix: transformToMatrix_1,
  	default: _default$9
  }, '__esModule', {value: true});

  var _default$8=extractResponder;var responderKeys=Object.keys(_reactNative__default["default"].PanResponder.create({}).panHandlers);var numResponderKeys=responderKeys.length;function extractResponder(o,props,ref){var onPress=props.onPress,disabled=props.disabled,onPressIn=props.onPressIn,onPressOut=props.onPressOut,onLongPress=props.onLongPress,delayPressIn=props.delayPressIn,delayPressOut=props.delayPressOut,delayLongPress=props.delayLongPress,pointerEvents=props.pointerEvents;var responsible=false;for(var i=0;i<numResponderKeys;i++){var key=responderKeys[i];var value=props[key];if(value){responsible=true;o[key]=value;}}if(pointerEvents){o.pointerEvents=pointerEvents;}var hasTouchableProperty=disabled!=null||onPress||onPressIn||onPressOut||onLongPress||delayPressIn||delayPressOut||delayLongPress;if(hasTouchableProperty){responsible=true;o.onResponderMove=ref.touchableHandleResponderMove;o.onResponderGrant=ref.touchableHandleResponderGrant;o.onResponderRelease=ref.touchableHandleResponderRelease;o.onResponderTerminate=ref.touchableHandleResponderTerminate;o.onStartShouldSetResponder=ref.touchableHandleStartShouldSetResponder;o.onResponderTerminationRequest=ref.touchableHandleResponderTerminationRequest;}if(responsible){o.responsible=true;}}


  var extractResponder_1 = /*#__PURE__*/Object.defineProperty({
  	default: _default$8
  }, '__esModule', {value: true});

  var util$1 = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.pickNotNil=pickNotNil;exports.idPattern=void 0;function pickNotNil(object){var result={};for(var key in object){if(object.hasOwnProperty(key)){var value=object[key];if(value!==undefined&&value!==null){result[key]=value;}}}return result;}var idPattern=/#([^)]+)\)?$/;exports.idPattern=idPattern;

  });

  var propsAndStyles_1=propsAndStyles;var _default$7=extractProps;var extract_1=extract;var withoutXY_1=withoutXY;var _toConsumableArray2=interopRequireDefault(toConsumableArray);var _defineProperty2$1=interopRequireDefault(defineProperty);var _extractFill=interopRequireDefault(extractFill_1);var _extractStroke=interopRequireDefault(extractStroke_1);var _extractResponder=interopRequireDefault(extractResponder_1);var _extractOpacity$1=interopRequireDefault(extractOpacity_1);function ownKeys$1(object,enumerableOnly){var keys=Object.keys(object);if(Object.getOwnPropertySymbols){var symbols=Object.getOwnPropertySymbols(object);if(enumerableOnly)symbols=symbols.filter(function(sym){return Object.getOwnPropertyDescriptor(object,sym).enumerable;});keys.push.apply(keys,symbols);}return keys;}function _objectSpread$1(target){for(var i=1;i<arguments.length;i++){var source=arguments[i]!=null?arguments[i]:{};if(i%2){ownKeys$1(Object(source),true).forEach(function(key){(0, _defineProperty2$1.default)(target,key,source[key]);});}else if(Object.getOwnPropertyDescriptors){Object.defineProperties(target,Object.getOwnPropertyDescriptors(source));}else {ownKeys$1(Object(source)).forEach(function(key){Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key));});}}return target;}var clipRules={evenodd:0,nonzero:1};function propsAndStyles(props){var style=props.style;return !style?props:_objectSpread$1({},Array.isArray(style)?Object.assign.apply(Object,[{}].concat((0, _toConsumableArray2.default)(style))):style,{},props);}function getMarker(marker){if(!marker){return undefined;}var matched=marker.match(util$1.idPattern);return matched?matched[1]:undefined;}function extractProps(props,ref){var id=props.id,opacity=props.opacity,onLayout=props.onLayout,clipPath=props.clipPath,clipRule=props.clipRule,display=props.display,mask=props.mask,marker=props.marker,_props$markerStart=props.markerStart,markerStart=_props$markerStart===void 0?marker:_props$markerStart,_props$markerMid=props.markerMid,markerMid=_props$markerMid===void 0?marker:_props$markerMid,_props$markerEnd=props.markerEnd,markerEnd=_props$markerEnd===void 0?marker:_props$markerEnd,transform=props.transform;var extracted={};var inherited=[];(0, _extractResponder.default)(extracted,props,ref);(0, _extractFill.default)(extracted,props,inherited);(0, _extractStroke.default)(extracted,props,inherited);if(inherited.length){extracted.propList=inherited;}var transformProps=(0, extractTransform_1.props2transform)(props);var matrix=(0, extractTransform_1.transformToMatrix)(transformProps,transform);if(matrix!==null){extracted.matrix=matrix;}if(opacity!=null){extracted.opacity=(0, _extractOpacity$1.default)(opacity);}if(display!=null){extracted.display=display==='none'?'none':undefined;}if(onLayout){extracted.onLayout=onLayout;}if(markerStart){extracted.markerStart=getMarker(markerStart);}if(markerMid){extracted.markerMid=getMarker(markerMid);}if(markerEnd){extracted.markerEnd=getMarker(markerEnd);}if(id){extracted.name=String(id);}if(clipRule){extracted.clipRule=clipRules[clipRule]===0?0:1;}if(clipPath){var matched=clipPath.match(util$1.idPattern);if(matched){extracted.clipPath=matched[1];}else {console.warn('Invalid `clipPath` prop, expected a clipPath like "#id", but got: "'+clipPath+'"');}}if(mask){var _matched=mask.match(util$1.idPattern);if(_matched){extracted.mask=_matched[1];}else {console.warn('Invalid `mask` prop, expected a mask like "#id", but got: "'+mask+'"');}}return extracted;}function extract(instance,props){return extractProps(propsAndStyles(props),instance);}function withoutXY(instance,props){return extractProps(_objectSpread$1({},propsAndStyles(props),{x:null,y:null}),instance);}


  var extractProps_1 = /*#__PURE__*/Object.defineProperty({
  	propsAndStyles: propsAndStyles_1,
  	default: _default$7,
  	extract: extract_1,
  	withoutXY: withoutXY_1
  }, '__esModule', {value: true});

  var NativeComponents = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.RNSVGUse=exports.RNSVGTSpan=exports.RNSVGTextPath=exports.RNSVGText=exports.RNSVGSymbol=exports.RNSVGRect=exports.RNSVGRadialGradient=exports.RNSVGPattern=exports.RNSVGPath=exports.RNSVGMask=exports.RNSVGMarker=exports.RNSVGLinearGradient=exports.RNSVGLine=exports.RNSVGImage=exports.RNSVGGroup=exports.RNSVGForeignObject=exports.RNSVGEllipse=exports.RNSVGDefs=exports.RNSVGClipPath=exports.RNSVGCircle=exports.RNSVGSvg=void 0;var RNSVGSvg=(0, _reactNative__default["default"].requireNativeComponent)('RNSVGSvgView');exports.RNSVGSvg=RNSVGSvg;var RNSVGCircle=(0, _reactNative__default["default"].requireNativeComponent)('RNSVGCircle');exports.RNSVGCircle=RNSVGCircle;var RNSVGClipPath=(0, _reactNative__default["default"].requireNativeComponent)('RNSVGClipPath');exports.RNSVGClipPath=RNSVGClipPath;var RNSVGDefs=(0, _reactNative__default["default"].requireNativeComponent)('RNSVGDefs');exports.RNSVGDefs=RNSVGDefs;var RNSVGEllipse=(0, _reactNative__default["default"].requireNativeComponent)('RNSVGEllipse');exports.RNSVGEllipse=RNSVGEllipse;var RNSVGForeignObject=(0, _reactNative__default["default"].requireNativeComponent)('RNSVGForeignObject');exports.RNSVGForeignObject=RNSVGForeignObject;var RNSVGGroup=(0, _reactNative__default["default"].requireNativeComponent)('RNSVGGroup');exports.RNSVGGroup=RNSVGGroup;var RNSVGImage=(0, _reactNative__default["default"].requireNativeComponent)('RNSVGImage');exports.RNSVGImage=RNSVGImage;var RNSVGLine=(0, _reactNative__default["default"].requireNativeComponent)('RNSVGLine');exports.RNSVGLine=RNSVGLine;var RNSVGLinearGradient=(0, _reactNative__default["default"].requireNativeComponent)('RNSVGLinearGradient');exports.RNSVGLinearGradient=RNSVGLinearGradient;var RNSVGMarker=(0, _reactNative__default["default"].requireNativeComponent)('RNSVGMarker');exports.RNSVGMarker=RNSVGMarker;var RNSVGMask=(0, _reactNative__default["default"].requireNativeComponent)('RNSVGMask');exports.RNSVGMask=RNSVGMask;var RNSVGPath=(0, _reactNative__default["default"].requireNativeComponent)('RNSVGPath');exports.RNSVGPath=RNSVGPath;var RNSVGPattern=(0, _reactNative__default["default"].requireNativeComponent)('RNSVGPattern');exports.RNSVGPattern=RNSVGPattern;var RNSVGRadialGradient=(0, _reactNative__default["default"].requireNativeComponent)('RNSVGRadialGradient');exports.RNSVGRadialGradient=RNSVGRadialGradient;var RNSVGRect=(0, _reactNative__default["default"].requireNativeComponent)('RNSVGRect');exports.RNSVGRect=RNSVGRect;var RNSVGSymbol=(0, _reactNative__default["default"].requireNativeComponent)('RNSVGSymbol');exports.RNSVGSymbol=RNSVGSymbol;var RNSVGText=(0, _reactNative__default["default"].requireNativeComponent)('RNSVGText');exports.RNSVGText=RNSVGText;var RNSVGTextPath=(0, _reactNative__default["default"].requireNativeComponent)('RNSVGTextPath');exports.RNSVGTextPath=RNSVGTextPath;var RNSVGTSpan=(0, _reactNative__default["default"].requireNativeComponent)('RNSVGTSpan');exports.RNSVGTSpan=RNSVGTSpan;var RNSVGUse=(0, _reactNative__default["default"].requireNativeComponent)('RNSVGUse');exports.RNSVGUse=RNSVGUse;

  });

  var Rect_1 = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.default=void 0;var _extends2=interopRequireDefault(_extends_1);var _classCallCheck2=interopRequireDefault(classCallCheck);var _createClass2=interopRequireDefault(createClass);var _possibleConstructorReturn2=interopRequireDefault(possibleConstructorReturn);var _getPrototypeOf2=interopRequireDefault(getPrototypeOf);var _inherits2=interopRequireDefault(inherits);var _defineProperty2=interopRequireDefault(defineProperty);var _react=interopRequireDefault(React__default["default"]);var _Shape2=interopRequireDefault(Shape_1);var _jsxFileName="/Users/horcrux/Work/react-native-svg/src/elements/Rect.tsx";var Rect=function(_Shape){(0, _inherits2.default)(Rect,_Shape);function Rect(){(0, _classCallCheck2.default)(this,Rect);return (0, _possibleConstructorReturn2.default)(this,(0, _getPrototypeOf2.default)(Rect).apply(this,arguments));}(0, _createClass2.default)(Rect,[{key:"render",value:function render(){var props=this.props;var x=props.x,y=props.y,width=props.width,height=props.height,rx=props.rx,ry=props.ry;return _react.default.createElement(NativeComponents.RNSVGRect,(0, _extends2.default)({ref:this.refMethod},(0, extractProps_1.withoutXY)(this,props),{x:x,y:y,width:width,height:height,rx:rx,ry:ry,__source:{fileName:_jsxFileName,lineNumber:28}}));}}]);return Rect;}(_Shape2.default);exports.default=Rect;(0, _defineProperty2.default)(Rect,"displayName",'Rect');(0, _defineProperty2.default)(Rect,"defaultProps",{x:0,y:0,width:0,height:0});

  });

  var Circle_1 = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.default=void 0;var _extends2=interopRequireDefault(_extends_1);var _classCallCheck2=interopRequireDefault(classCallCheck);var _createClass2=interopRequireDefault(createClass);var _possibleConstructorReturn2=interopRequireDefault(possibleConstructorReturn);var _getPrototypeOf2=interopRequireDefault(getPrototypeOf);var _inherits2=interopRequireDefault(inherits);var _defineProperty2=interopRequireDefault(defineProperty);var _react=interopRequireDefault(React__default["default"]);var _Shape2=interopRequireDefault(Shape_1);var _jsxFileName="/Users/horcrux/Work/react-native-svg/src/elements/Circle.tsx";var Circle=function(_Shape){(0, _inherits2.default)(Circle,_Shape);function Circle(){(0, _classCallCheck2.default)(this,Circle);return (0, _possibleConstructorReturn2.default)(this,(0, _getPrototypeOf2.default)(Circle).apply(this,arguments));}(0, _createClass2.default)(Circle,[{key:"render",value:function render(){var props=this.props;var cx=props.cx,cy=props.cy,r=props.r;return _react.default.createElement(NativeComponents.RNSVGCircle,(0, _extends2.default)({ref:this.refMethod},(0, extractProps_1.extract)(this,props),{cx:cx,cy:cy,r:r,__source:{fileName:_jsxFileName,lineNumber:24}}));}}]);return Circle;}(_Shape2.default);exports.default=Circle;(0, _defineProperty2.default)(Circle,"displayName",'Circle');(0, _defineProperty2.default)(Circle,"defaultProps",{cx:0,cy:0,r:0});

  });

  var Ellipse_1 = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.default=void 0;var _extends2=interopRequireDefault(_extends_1);var _classCallCheck2=interopRequireDefault(classCallCheck);var _createClass2=interopRequireDefault(createClass);var _possibleConstructorReturn2=interopRequireDefault(possibleConstructorReturn);var _getPrototypeOf2=interopRequireDefault(getPrototypeOf);var _inherits2=interopRequireDefault(inherits);var _defineProperty2=interopRequireDefault(defineProperty);var _react=interopRequireDefault(React__default["default"]);var _Shape2=interopRequireDefault(Shape_1);var _jsxFileName="/Users/horcrux/Work/react-native-svg/src/elements/Ellipse.tsx";var Ellipse=function(_Shape){(0, _inherits2.default)(Ellipse,_Shape);function Ellipse(){(0, _classCallCheck2.default)(this,Ellipse);return (0, _possibleConstructorReturn2.default)(this,(0, _getPrototypeOf2.default)(Ellipse).apply(this,arguments));}(0, _createClass2.default)(Ellipse,[{key:"render",value:function render(){var props=this.props;var cx=props.cx,cy=props.cy,rx=props.rx,ry=props.ry;return _react.default.createElement(NativeComponents.RNSVGEllipse,(0, _extends2.default)({ref:this.refMethod},(0, extractProps_1.extract)(this,props),{cx:cx,cy:cy,rx:rx,ry:ry,__source:{fileName:_jsxFileName,lineNumber:26}}));}}]);return Ellipse;}(_Shape2.default);exports.default=Ellipse;(0, _defineProperty2.default)(Ellipse,"displayName",'Ellipse');(0, _defineProperty2.default)(Ellipse,"defaultProps",{cx:0,cy:0,rx:0,ry:0});

  });

  var Path_1 = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.default=void 0;var _extends2=interopRequireDefault(_extends_1);var _classCallCheck2=interopRequireDefault(classCallCheck);var _createClass2=interopRequireDefault(createClass);var _possibleConstructorReturn2=interopRequireDefault(possibleConstructorReturn);var _getPrototypeOf2=interopRequireDefault(getPrototypeOf);var _inherits2=interopRequireDefault(inherits);var _defineProperty2=interopRequireDefault(defineProperty);var _react=interopRequireDefault(React__default["default"]);var _Shape2=interopRequireDefault(Shape_1);var _jsxFileName="/Users/horcrux/Work/react-native-svg/src/elements/Path.tsx";var Path=function(_Shape){(0, _inherits2.default)(Path,_Shape);function Path(){(0, _classCallCheck2.default)(this,Path);return (0, _possibleConstructorReturn2.default)(this,(0, _getPrototypeOf2.default)(Path).apply(this,arguments));}(0, _createClass2.default)(Path,[{key:"render",value:function render(){var props=this.props;return _react.default.createElement(NativeComponents.RNSVGPath,(0, _extends2.default)({ref:this.refMethod},(0, extractProps_1.extract)(this,props),{d:props.d,__source:{fileName:_jsxFileName,lineNumber:14}}));}}]);return Path;}(_Shape2.default);exports.default=Path;(0, _defineProperty2.default)(Path,"displayName",'Path');

  });

  var _default$6=extractPolyPoints;function extractPolyPoints(points){var polyPoints=Array.isArray(points)?points.join(','):points;return polyPoints.replace(/[^e]-/,' -').split(/(?:\s+|\s*,\s*)/g).join(' ');}


  var extractPolyPoints_1 = /*#__PURE__*/Object.defineProperty({
  	default: _default$6
  }, '__esModule', {value: true});

  var Polygon_1 = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.default=void 0;var _extends2=interopRequireDefault(_extends_1);var _classCallCheck2=interopRequireDefault(classCallCheck);var _createClass2=interopRequireDefault(createClass);var _possibleConstructorReturn2=interopRequireDefault(possibleConstructorReturn);var _getPrototypeOf3=interopRequireDefault(getPrototypeOf);var _assertThisInitialized2=interopRequireDefault(assertThisInitialized);var _inherits2=interopRequireDefault(inherits);var _defineProperty2=interopRequireDefault(defineProperty);var _react=interopRequireDefault(React__default["default"]);var _Path=interopRequireDefault(Path_1);var _Shape2=interopRequireDefault(Shape_1);var _extractPolyPoints=interopRequireDefault(extractPolyPoints_1);var _jsxFileName="/Users/horcrux/Work/react-native-svg/src/elements/Polygon.tsx";var Polygon=function(_Shape){(0, _inherits2.default)(Polygon,_Shape);function Polygon(){var _getPrototypeOf2;var _this;(0, _classCallCheck2.default)(this,Polygon);for(var _len=arguments.length,args=new Array(_len),_key=0;_key<_len;_key++){args[_key]=arguments[_key];}_this=(0, _possibleConstructorReturn2.default)(this,(_getPrototypeOf2=(0, _getPrototypeOf3.default)(Polygon)).call.apply(_getPrototypeOf2,[this].concat(args)));(0, _defineProperty2.default)((0, _assertThisInitialized2.default)(_this),"setNativeProps",function(props){var points=props.points;if(points){props.d="M".concat((0, _extractPolyPoints.default)(points),"z");}_this.root&&_this.root.setNativeProps(props);});return _this;}(0, _createClass2.default)(Polygon,[{key:"render",value:function render(){var props=this.props;var points=props.points;return _react.default.createElement(_Path.default,(0, _extends2.default)({ref:this.refMethod,d:points&&"M".concat((0, _extractPolyPoints.default)(points),"z")},props,{__source:{fileName:_jsxFileName,lineNumber:31}}));}}]);return Polygon;}(_Shape2.default);exports.default=Polygon;(0, _defineProperty2.default)(Polygon,"displayName",'Polygon');(0, _defineProperty2.default)(Polygon,"defaultProps",{points:''});

  });

  var Polyline_1 = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.default=void 0;var _extends2=interopRequireDefault(_extends_1);var _classCallCheck2=interopRequireDefault(classCallCheck);var _createClass2=interopRequireDefault(createClass);var _possibleConstructorReturn2=interopRequireDefault(possibleConstructorReturn);var _getPrototypeOf3=interopRequireDefault(getPrototypeOf);var _assertThisInitialized2=interopRequireDefault(assertThisInitialized);var _inherits2=interopRequireDefault(inherits);var _defineProperty2=interopRequireDefault(defineProperty);var _react=interopRequireDefault(React__default["default"]);var _Path=interopRequireDefault(Path_1);var _Shape2=interopRequireDefault(Shape_1);var _extractPolyPoints=interopRequireDefault(extractPolyPoints_1);var _jsxFileName="/Users/horcrux/Work/react-native-svg/src/elements/Polyline.tsx";var Polyline=function(_Shape){(0, _inherits2.default)(Polyline,_Shape);function Polyline(){var _getPrototypeOf2;var _this;(0, _classCallCheck2.default)(this,Polyline);for(var _len=arguments.length,args=new Array(_len),_key=0;_key<_len;_key++){args[_key]=arguments[_key];}_this=(0, _possibleConstructorReturn2.default)(this,(_getPrototypeOf2=(0, _getPrototypeOf3.default)(Polyline)).call.apply(_getPrototypeOf2,[this].concat(args)));(0, _defineProperty2.default)((0, _assertThisInitialized2.default)(_this),"setNativeProps",function(props){var points=props.points;if(points){props.d="M".concat((0, _extractPolyPoints.default)(points));}_this.root&&_this.root.setNativeProps(props);});return _this;}(0, _createClass2.default)(Polyline,[{key:"render",value:function render(){var props=this.props;var points=props.points;return _react.default.createElement(_Path.default,(0, _extends2.default)({ref:this.refMethod,d:points&&"M".concat((0, _extractPolyPoints.default)(points))},props,{__source:{fileName:_jsxFileName,lineNumber:31}}));}}]);return Polyline;}(_Shape2.default);exports.default=Polyline;(0, _defineProperty2.default)(Polyline,"displayName",'Polyline');(0, _defineProperty2.default)(Polyline,"defaultProps",{points:''});

  });

  var Line_1 = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.default=void 0;var _extends2=interopRequireDefault(_extends_1);var _classCallCheck2=interopRequireDefault(classCallCheck);var _createClass2=interopRequireDefault(createClass);var _possibleConstructorReturn2=interopRequireDefault(possibleConstructorReturn);var _getPrototypeOf2=interopRequireDefault(getPrototypeOf);var _inherits2=interopRequireDefault(inherits);var _defineProperty2=interopRequireDefault(defineProperty);var _react=interopRequireDefault(React__default["default"]);var _Shape2=interopRequireDefault(Shape_1);var _jsxFileName="/Users/horcrux/Work/react-native-svg/src/elements/Line.tsx";var Line=function(_Shape){(0, _inherits2.default)(Line,_Shape);function Line(){(0, _classCallCheck2.default)(this,Line);return (0, _possibleConstructorReturn2.default)(this,(0, _getPrototypeOf2.default)(Line).apply(this,arguments));}(0, _createClass2.default)(Line,[{key:"render",value:function render(){var props=this.props;var x1=props.x1,y1=props.y1,x2=props.x2,y2=props.y2;return _react.default.createElement(NativeComponents.RNSVGLine,(0, _extends2.default)({ref:this.refMethod},(0, extractProps_1.extract)(this,props),{x1:x1,y1:y1,x2:x2,y2:y2,__source:{fileName:_jsxFileName,lineNumber:26}}));}}]);return Line;}(_Shape2.default);exports.default=Line;(0, _defineProperty2.default)(Line,"displayName",'Line');(0, _defineProperty2.default)(Line,"defaultProps",{x1:0,y1:0,x2:0,y2:0});

  });

  var objectWithoutPropertiesLoose = createCommonjsModule(function (module) {
  function _objectWithoutPropertiesLoose(source, excluded) {
    if (source == null) return {};
    var target = {};
    var sourceKeys = Object.keys(source);
    var key, i;

    for (i = 0; i < sourceKeys.length; i++) {
      key = sourceKeys[i];
      if (excluded.indexOf(key) >= 0) continue;
      target[key] = source[key];
    }

    return target;
  }

  module.exports = _objectWithoutPropertiesLoose, module.exports.__esModule = true, module.exports["default"] = module.exports;
  });

  var objectWithoutProperties = createCommonjsModule(function (module) {
  function _objectWithoutProperties(source, excluded) {
    if (source == null) return {};
    var target = objectWithoutPropertiesLoose(source, excluded);
    var key, i;

    if (Object.getOwnPropertySymbols) {
      var sourceSymbolKeys = Object.getOwnPropertySymbols(source);

      for (i = 0; i < sourceSymbolKeys.length; i++) {
        key = sourceSymbolKeys[i];
        if (excluded.indexOf(key) >= 0) continue;
        if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;
        target[key] = source[key];
      }
    }

    return target;
  }

  module.exports = _objectWithoutProperties, module.exports.__esModule = true, module.exports["default"] = module.exports;
  });

  var extractViewBox_1 = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.default=extractViewBox;exports.alignEnum=exports.meetOrSliceTypes=void 0;var meetOrSliceTypes={meet:0,slice:1,none:2};exports.meetOrSliceTypes=meetOrSliceTypes;var alignEnum=['xMinYMin','xMidYMin','xMaxYMin','xMinYMid','xMidYMid','xMaxYMid','xMinYMax','xMidYMax','xMaxYMax','none'].reduce(function(prev,name){prev[name]=name;return prev;},{});exports.alignEnum=alignEnum;var spacesRegExp=/\s+/;function extractViewBox(props){var viewBox=props.viewBox,preserveAspectRatio=props.preserveAspectRatio;if(!viewBox){return null;}var params=(Array.isArray(viewBox)?viewBox:viewBox.trim().split(spacesRegExp)).map(Number);if(params.length!==4||params.some(isNaN)){console.warn('Invalid `viewBox` prop:'+viewBox);return null;}var modes=preserveAspectRatio?preserveAspectRatio.trim().split(spacesRegExp):[];var align=modes[0];var meetOrSlice=modes[1];return {minX:params[0],minY:params[1],vbWidth:params[2],vbHeight:params[3],align:alignEnum[align]||'xMidYMid',meetOrSlice:meetOrSliceTypes[meetOrSlice]||0};}

  });

  var extractFont_1=extractFont;var setTSpan_1=setTSpan;var _default$5=extractText;var _defineProperty2=interopRequireDefault(defineProperty);var _react$1=interopRequireWildcard(React__default["default"]);var _extractLengthList=interopRequireDefault(extractLengthList_1);var _jsxFileName="/Users/horcrux/Work/react-native-svg/src/lib/extract/extractText.tsx";function ownKeys(object,enumerableOnly){var keys=Object.keys(object);if(Object.getOwnPropertySymbols){var symbols=Object.getOwnPropertySymbols(object);if(enumerableOnly)symbols=symbols.filter(function(sym){return Object.getOwnPropertyDescriptor(object,sym).enumerable;});keys.push.apply(keys,symbols);}return keys;}function _objectSpread(target){for(var i=1;i<arguments.length;i++){var source=arguments[i]!=null?arguments[i]:{};if(i%2){ownKeys(Object(source),true).forEach(function(key){(0, _defineProperty2.default)(target,key,source[key]);});}else if(Object.getOwnPropertyDescriptors){Object.defineProperties(target,Object.getOwnPropertyDescriptors(source));}else {ownKeys(Object(source)).forEach(function(key){Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key));});}}return target;}var fontRegExp=/^\s*((?:(?:normal|bold|italic)\s+)*)(?:(\d+(?:\.\d+)?(?:%|px|em|pt|pc|mm|cm|in]))*(?:\s*\/.*?)?\s+)?\s*"?([^"]*)/i;var fontFamilyPrefix=/^[\s"']*/;var fontFamilySuffix=/[\s"']*$/;var commaReg=/\s*,\s*/g;var cachedFontObjectsFromString={};function extractSingleFontFamily(fontFamilyString){return fontFamilyString?fontFamilyString.split(commaReg)[0].replace(fontFamilyPrefix,'').replace(fontFamilySuffix,''):null;}function parseFontString(font){if(cachedFontObjectsFromString.hasOwnProperty(font)){return cachedFontObjectsFromString[font];}var match=fontRegExp.exec(font);if(!match){cachedFontObjectsFromString[font]=null;return null;}var isBold=/bold/.exec(match[1]);var isItalic=/italic/.exec(match[1]);cachedFontObjectsFromString[font]={fontSize:match[2]||12,fontWeight:isBold?'bold':'normal',fontStyle:isItalic?'italic':'normal',fontFamily:extractSingleFontFamily(match[3])};return cachedFontObjectsFromString[font];}function extractFont(props){var fontData=props.fontData,fontStyle=props.fontStyle,fontVariant=props.fontVariant,fontWeight=props.fontWeight,fontStretch=props.fontStretch,fontSize=props.fontSize,fontFamily=props.fontFamily,textAnchor=props.textAnchor,textDecoration=props.textDecoration,letterSpacing=props.letterSpacing,wordSpacing=props.wordSpacing,kerning=props.kerning,fontFeatureSettings=props.fontFeatureSettings,fontVariantLigatures=props.fontVariantLigatures,fontVariationSettings=props.fontVariationSettings,font=props.font;var ownedFont=(0, util$1.pickNotNil)({fontData:fontData,fontStyle:fontStyle,fontVariant:fontVariant,fontWeight:fontWeight,fontStretch:fontStretch,fontSize:fontSize,fontFamily:extractSingleFontFamily(fontFamily),textAnchor:textAnchor,textDecoration:textDecoration,letterSpacing:letterSpacing,wordSpacing:wordSpacing,kerning:kerning,fontFeatureSettings:fontFeatureSettings,fontVariantLigatures:fontVariantLigatures,fontVariationSettings:fontVariationSettings});var baseFont=typeof font==='string'?parseFontString(font):font;return _objectSpread({},baseFont,{},ownedFont);}var TSpan;function setTSpan(TSpanImplementation){TSpan=TSpanImplementation;}function getChild(child){if(typeof child==='string'||typeof child==='number'){return _react$1.default.createElement(TSpan,{__source:{fileName:_jsxFileName,lineNumber:122}},String(child));}else {return child;}}function extractText(props,container){var x=props.x,y=props.y,dx=props.dx,dy=props.dy,rotate=props.rotate,children=props.children,inlineSize=props.inlineSize,baselineShift=props.baselineShift,verticalAlign=props.verticalAlign,alignmentBaseline=props.alignmentBaseline;var textChildren=typeof children==='string'||typeof children==='number'?container?_react$1.default.createElement(TSpan,{__source:{fileName:_jsxFileName,lineNumber:158}},String(children)):null:_react$1.Children.count(children)>1||Array.isArray(children)?_react$1.Children.map(children,getChild):children;return {content:textChildren===null?String(children):null,children:textChildren,inlineSize:inlineSize,baselineShift:baselineShift,verticalAlign:verticalAlign,alignmentBaseline:alignmentBaseline,font:extractFont(props),x:(0, _extractLengthList.default)(x),y:(0, _extractLengthList.default)(y),dx:(0, _extractLengthList.default)(dx),dy:(0, _extractLengthList.default)(dy),rotate:(0, _extractLengthList.default)(rotate)};}


  var extractText_1 = /*#__PURE__*/Object.defineProperty({
  	extractFont: extractFont_1,
  	setTSpan: setTSpan_1,
  	default: _default$5
  }, '__esModule', {value: true});

  var G_1 = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.default=void 0;var _extends2=interopRequireDefault(_extends_1);var _classCallCheck2=interopRequireDefault(classCallCheck);var _createClass2=interopRequireDefault(createClass);var _possibleConstructorReturn2=interopRequireDefault(possibleConstructorReturn);var _getPrototypeOf3=interopRequireDefault(getPrototypeOf);var _assertThisInitialized2=interopRequireDefault(assertThisInitialized);var _inherits2=interopRequireDefault(inherits);var _defineProperty2=interopRequireDefault(defineProperty);var _react=interopRequireDefault(React__default["default"]);var _extractProps=interopRequireWildcard(extractProps_1);var _extractTransform=interopRequireDefault(extractTransform_1);var _Shape2=interopRequireDefault(Shape_1);var _jsxFileName="/Users/horcrux/Work/react-native-svg/src/elements/G.tsx";var G=function(_Shape){(0, _inherits2.default)(G,_Shape);function G(){var _getPrototypeOf2;var _this;(0, _classCallCheck2.default)(this,G);for(var _len=arguments.length,args=new Array(_len),_key=0;_key<_len;_key++){args[_key]=arguments[_key];}_this=(0, _possibleConstructorReturn2.default)(this,(_getPrototypeOf2=(0, _getPrototypeOf3.default)(G)).call.apply(_getPrototypeOf2,[this].concat(args)));(0, _defineProperty2.default)((0, _assertThisInitialized2.default)(_this),"setNativeProps",function(props){var matrix=!props.matrix&&(0, _extractTransform.default)(props);if(matrix){props.matrix=matrix;}_this.root&&_this.root.setNativeProps(props);});return _this;}(0, _createClass2.default)(G,[{key:"render",value:function render(){var props=this.props;var prop=(0, _extractProps.propsAndStyles)(props);var extractedProps=(0, _extractProps.default)(prop,this);var font=(0, extractText_1.extractFont)(prop);if(hasProps(font)){extractedProps.font=font;}return _react.default.createElement(NativeComponents.RNSVGGroup,(0, _extends2.default)({ref:this.refMethod},extractedProps,{__source:{fileName:_jsxFileName,lineNumber:33}}),props.children);}}]);return G;}(_Shape2.default);exports.default=G;(0, _defineProperty2.default)(G,"displayName",'G');var hasProps=function hasProps(obj){for(var _ in obj){return true;}return false;};

  });

  var Svg_1 = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.default=void 0;var _extends2=interopRequireDefault(_extends_1);var _toConsumableArray2=interopRequireDefault(toConsumableArray);var _objectWithoutProperties2=interopRequireDefault(objectWithoutProperties);var _classCallCheck2=interopRequireDefault(classCallCheck);var _createClass2=interopRequireDefault(createClass);var _possibleConstructorReturn2=interopRequireDefault(possibleConstructorReturn);var _getPrototypeOf3=interopRequireDefault(getPrototypeOf);var _assertThisInitialized2=interopRequireDefault(assertThisInitialized);var _inherits2=interopRequireDefault(inherits);var _defineProperty2=interopRequireDefault(defineProperty);var _react=interopRequireDefault(React__default["default"]);var _extractResponder=interopRequireDefault(extractResponder_1);var _extractViewBox=interopRequireDefault(extractViewBox_1);var _extractColor=interopRequireDefault(extractColor_1);var _Shape2=interopRequireDefault(Shape_1);var _G=interopRequireDefault(G_1);var _jsxFileName="/Users/horcrux/Work/react-native-svg/src/elements/Svg.tsx";function ownKeys(object,enumerableOnly){var keys=Object.keys(object);if(Object.getOwnPropertySymbols){var symbols=Object.getOwnPropertySymbols(object);if(enumerableOnly)symbols=symbols.filter(function(sym){return Object.getOwnPropertyDescriptor(object,sym).enumerable;});keys.push.apply(keys,symbols);}return keys;}function _objectSpread(target){for(var i=1;i<arguments.length;i++){var source=arguments[i]!=null?arguments[i]:{};if(i%2){ownKeys(Object(source),true).forEach(function(key){(0, _defineProperty2.default)(target,key,source[key]);});}else if(Object.getOwnPropertyDescriptors){Object.defineProperties(target,Object.getOwnPropertyDescriptors(source));}else {ownKeys(Object(source)).forEach(function(key){Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key));});}}return target;}var RNSVGSvgViewManager=_reactNative__default["default"].NativeModules.RNSVGSvgViewManager;var styles=_reactNative__default["default"].StyleSheet.create({svg:{backgroundColor:'transparent',borderWidth:0}});var defaultStyle=styles.svg;var Svg=function(_Shape){(0, _inherits2.default)(Svg,_Shape);function Svg(){var _getPrototypeOf2;var _this;(0, _classCallCheck2.default)(this,Svg);for(var _len=arguments.length,args=new Array(_len),_key=0;_key<_len;_key++){args[_key]=arguments[_key];}_this=(0, _possibleConstructorReturn2.default)(this,(_getPrototypeOf2=(0, _getPrototypeOf3.default)(Svg)).call.apply(_getPrototypeOf2,[this].concat(args)));(0, _defineProperty2.default)((0, _assertThisInitialized2.default)(_this),"measureInWindow",function(callback){var _assertThisInitialize=(0, _assertThisInitialized2.default)(_this),root=_assertThisInitialize.root;root&&root.measureInWindow(callback);});(0, _defineProperty2.default)((0, _assertThisInitialized2.default)(_this),"measure",function(callback){var _assertThisInitialize2=(0, _assertThisInitialized2.default)(_this),root=_assertThisInitialize2.root;root&&root.measure(callback);});(0, _defineProperty2.default)((0, _assertThisInitialized2.default)(_this),"measureLayout",function(relativeToNativeNode,onSuccess,onFail){var _assertThisInitialize3=(0, _assertThisInitialized2.default)(_this),root=_assertThisInitialize3.root;root&&root.measureLayout(relativeToNativeNode,onSuccess,onFail);});(0, _defineProperty2.default)((0, _assertThisInitialized2.default)(_this),"setNativeProps",function(props){var width=props.width,height=props.height;if(width){props.bbWidth=width;}if(height){props.bbHeight=height;}var _assertThisInitialize4=(0, _assertThisInitialized2.default)(_this),root=_assertThisInitialize4.root;root&&root.setNativeProps(props);});(0, _defineProperty2.default)((0, _assertThisInitialized2.default)(_this),"toDataURL",function(callback,options){if(!callback){return;}var handle=(0, _reactNative__default["default"].findNodeHandle)(_this.root);RNSVGSvgViewManager.toDataURL(handle,options,callback);});return _this;}(0, _createClass2.default)(Svg,[{key:"render",value:function render(){var _this$props=this.props,style=_this$props.style,opacity=_this$props.opacity,viewBox=_this$props.viewBox,children=_this$props.children,onLayout=_this$props.onLayout,preserveAspectRatio=_this$props.preserveAspectRatio,extracted=(0, _objectWithoutProperties2.default)(_this$props,["style","opacity","viewBox","children","onLayout","preserveAspectRatio"]);var stylesAndProps=_objectSpread({},Array.isArray(style)?Object.assign.apply(Object,[{}].concat((0, _toConsumableArray2.default)(style))):style,{},extracted);var color=stylesAndProps.color,width=stylesAndProps.width,height=stylesAndProps.height,focusable=stylesAndProps.focusable,font=stylesAndProps.font,transform=stylesAndProps.transform,fill=stylesAndProps.fill,fillOpacity=stylesAndProps.fillOpacity,fillRule=stylesAndProps.fillRule,stroke=stylesAndProps.stroke,strokeWidth=stylesAndProps.strokeWidth,strokeOpacity=stylesAndProps.strokeOpacity,strokeDasharray=stylesAndProps.strokeDasharray,strokeDashoffset=stylesAndProps.strokeDashoffset,strokeLinecap=stylesAndProps.strokeLinecap,strokeLinejoin=stylesAndProps.strokeLinejoin,strokeMiterlimit=stylesAndProps.strokeMiterlimit;if(width===undefined&&height===undefined){width=height='100%';}var props=extracted;props.focusable=Boolean(focusable)&&focusable!=='false';var rootStyles=[defaultStyle];if(style){rootStyles.push(style);}var override=false;var overrideStyles={};var o=opacity!=null?+opacity:NaN;if(!isNaN(o)){override=true;overrideStyles.opacity=o;}if(width&&height){override=true;var w=parseInt(width,10);var h=parseInt(height,10);var doNotParseWidth=isNaN(w)||width[width.length-1]==='%';var doNotParseHeight=isNaN(h)||height[height.length-1]==='%';overrideStyles.width=doNotParseWidth?width:w;overrideStyles.height=doNotParseHeight?height:h;overrideStyles.flex=0;}if(override){rootStyles.push(overrideStyles);}props.style=rootStyles.length>1?rootStyles:defaultStyle;if(width!=null){props.bbWidth=width;}if(height!=null){props.bbHeight=height;}(0, _extractResponder.default)(props,props,this);var tint=(0, _extractColor.default)(color);if(tint!=null){props.color=tint;props.tintColor=tint;}if(onLayout!=null){props.onLayout=onLayout;}return _react.default.createElement(NativeComponents.RNSVGSvg,(0, _extends2.default)({},props,{ref:this.refMethod},(0, _extractViewBox.default)({viewBox:viewBox,preserveAspectRatio:preserveAspectRatio}),{__source:{fileName:_jsxFileName,lineNumber:197}}),_react.default.createElement(_G.default,(0, _extends2.default)({children:children,style:style,font:font,transform:transform,fill:fill,fillOpacity:fillOpacity,fillRule:fillRule,stroke:stroke,strokeWidth:strokeWidth,strokeOpacity:strokeOpacity,strokeDasharray:strokeDasharray,strokeDashoffset:strokeDashoffset,strokeLinecap:strokeLinecap,strokeLinejoin:strokeLinejoin,strokeMiterlimit:strokeMiterlimit},{__source:{fileName:_jsxFileName,lineNumber:202}})));}}]);return Svg;}(_Shape2.default);exports.default=Svg;(0, _defineProperty2.default)(Svg,"displayName",'Svg');(0, _defineProperty2.default)(Svg,"defaultProps",{preserveAspectRatio:'xMidYMid meet'});

  });

  var TSpan_1 = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.default=void 0;var _extends2=interopRequireDefault(_extends_1);var _classCallCheck2=interopRequireDefault(classCallCheck);var _createClass2=interopRequireDefault(createClass);var _possibleConstructorReturn2=interopRequireDefault(possibleConstructorReturn);var _getPrototypeOf3=interopRequireDefault(getPrototypeOf);var _assertThisInitialized2=interopRequireDefault(assertThisInitialized);var _inherits2=interopRequireDefault(inherits);var _defineProperty2=interopRequireDefault(defineProperty);var _react=interopRequireDefault(React__default["default"]);var _extractProps=interopRequireWildcard(extractProps_1);var _extractTransform=interopRequireDefault(extractTransform_1);var _extractText=interopRequireWildcard(extractText_1);var _Shape2=interopRequireDefault(Shape_1);var _jsxFileName="/Users/horcrux/Work/react-native-svg/src/elements/TSpan.tsx";function ownKeys(object,enumerableOnly){var keys=Object.keys(object);if(Object.getOwnPropertySymbols){var symbols=Object.getOwnPropertySymbols(object);if(enumerableOnly)symbols=symbols.filter(function(sym){return Object.getOwnPropertyDescriptor(object,sym).enumerable;});keys.push.apply(keys,symbols);}return keys;}function _objectSpread(target){for(var i=1;i<arguments.length;i++){var source=arguments[i]!=null?arguments[i]:{};if(i%2){ownKeys(Object(source),true).forEach(function(key){(0, _defineProperty2.default)(target,key,source[key]);});}else if(Object.getOwnPropertyDescriptors){Object.defineProperties(target,Object.getOwnPropertyDescriptors(source));}else {ownKeys(Object(source)).forEach(function(key){Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key));});}}return target;}var TSpan=function(_Shape){(0, _inherits2.default)(TSpan,_Shape);function TSpan(){var _getPrototypeOf2;var _this;(0, _classCallCheck2.default)(this,TSpan);for(var _len=arguments.length,args=new Array(_len),_key=0;_key<_len;_key++){args[_key]=arguments[_key];}_this=(0, _possibleConstructorReturn2.default)(this,(_getPrototypeOf2=(0, _getPrototypeOf3.default)(TSpan)).call.apply(_getPrototypeOf2,[this].concat(args)));(0, _defineProperty2.default)((0, _assertThisInitialized2.default)(_this),"setNativeProps",function(props){var matrix=!props.matrix&&(0, _extractTransform.default)(props);if(matrix){props.matrix=matrix;}var prop=(0, _extractProps.propsAndStyles)(props);(0, _extends2.default)(prop,(0, util$1.pickNotNil)((0, _extractText.default)(prop,false)));_this.root&&_this.root.setNativeProps(prop);});return _this;}(0, _createClass2.default)(TSpan,[{key:"render",value:function render(){var prop=(0, _extractProps.propsAndStyles)(this.props);var props=(0, _extractProps.default)(_objectSpread({},prop,{x:null,y:null}),this);(0, _extends2.default)(props,(0, _extractText.default)(prop,false));props.ref=this.refMethod;return _react.default.createElement(NativeComponents.RNSVGTSpan,(0, _extends2.default)({},props,{__source:{fileName:_jsxFileName,lineNumber:40}}));}}]);return TSpan;}(_Shape2.default);exports.default=TSpan;(0, _defineProperty2.default)(TSpan,"displayName",'TSpan');(0, _extractText.setTSpan)(TSpan);

  });

  var Text_1 = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.default=void 0;var _extends2=interopRequireDefault(_extends_1);var _classCallCheck2=interopRequireDefault(classCallCheck);var _createClass2=interopRequireDefault(createClass);var _possibleConstructorReturn2=interopRequireDefault(possibleConstructorReturn);var _getPrototypeOf3=interopRequireDefault(getPrototypeOf);var _assertThisInitialized2=interopRequireDefault(assertThisInitialized);var _inherits2=interopRequireDefault(inherits);var _defineProperty2=interopRequireDefault(defineProperty);var _react=interopRequireDefault(React__default["default"]);var _extractText=interopRequireDefault(extractText_1);var _extractProps=interopRequireWildcard(extractProps_1);var _extractTransform=interopRequireDefault(extractTransform_1);var _Shape2=interopRequireDefault(Shape_1);var _jsxFileName="/Users/horcrux/Work/react-native-svg/src/elements/Text.tsx";function ownKeys(object,enumerableOnly){var keys=Object.keys(object);if(Object.getOwnPropertySymbols){var symbols=Object.getOwnPropertySymbols(object);if(enumerableOnly)symbols=symbols.filter(function(sym){return Object.getOwnPropertyDescriptor(object,sym).enumerable;});keys.push.apply(keys,symbols);}return keys;}function _objectSpread(target){for(var i=1;i<arguments.length;i++){var source=arguments[i]!=null?arguments[i]:{};if(i%2){ownKeys(Object(source),true).forEach(function(key){(0, _defineProperty2.default)(target,key,source[key]);});}else if(Object.getOwnPropertyDescriptors){Object.defineProperties(target,Object.getOwnPropertyDescriptors(source));}else {ownKeys(Object(source)).forEach(function(key){Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key));});}}return target;}var Text=function(_Shape){(0, _inherits2.default)(Text,_Shape);function Text(){var _getPrototypeOf2;var _this;(0, _classCallCheck2.default)(this,Text);for(var _len=arguments.length,args=new Array(_len),_key=0;_key<_len;_key++){args[_key]=arguments[_key];}_this=(0, _possibleConstructorReturn2.default)(this,(_getPrototypeOf2=(0, _getPrototypeOf3.default)(Text)).call.apply(_getPrototypeOf2,[this].concat(args)));(0, _defineProperty2.default)((0, _assertThisInitialized2.default)(_this),"setNativeProps",function(props){var matrix=props&&!props.matrix&&(0, _extractTransform.default)(props);if(matrix){props.matrix=matrix;}var prop=(0, _extractProps.propsAndStyles)(props);(0, _extends2.default)(prop,(0, util$1.pickNotNil)((0, _extractText.default)(prop,true)));_this.root&&_this.root.setNativeProps(prop);});return _this;}(0, _createClass2.default)(Text,[{key:"render",value:function render(){var prop=(0, _extractProps.propsAndStyles)(this.props);var props=(0, _extractProps.default)(_objectSpread({},prop,{x:null,y:null}),this);(0, _extends2.default)(props,(0, _extractText.default)(prop,true));props.ref=this.refMethod;return _react.default.createElement(NativeComponents.RNSVGText,(0, _extends2.default)({},props,{__source:{fileName:_jsxFileName,lineNumber:41}}));}}]);return Text;}(_Shape2.default);exports.default=Text;(0, _defineProperty2.default)(Text,"displayName",'Text');

  });

  var TextPath_1 = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.default=void 0;var _objectWithoutProperties2=interopRequireDefault(objectWithoutProperties);var _extends2=interopRequireDefault(_extends_1);var _classCallCheck2=interopRequireDefault(classCallCheck);var _createClass2=interopRequireDefault(createClass);var _possibleConstructorReturn2=interopRequireDefault(possibleConstructorReturn);var _getPrototypeOf3=interopRequireDefault(getPrototypeOf);var _assertThisInitialized2=interopRequireDefault(assertThisInitialized);var _inherits2=interopRequireDefault(inherits);var _defineProperty2=interopRequireDefault(defineProperty);var _react=interopRequireDefault(React__default["default"]);var _extractTransform=interopRequireDefault(extractTransform_1);var _extractText=interopRequireDefault(extractText_1);var _Shape2=interopRequireDefault(Shape_1);var _TSpan=interopRequireDefault(TSpan_1);var _jsxFileName="/Users/horcrux/Work/react-native-svg/src/elements/TextPath.tsx";var TextPath=function(_Shape){(0, _inherits2.default)(TextPath,_Shape);function TextPath(){var _getPrototypeOf2;var _this;(0, _classCallCheck2.default)(this,TextPath);for(var _len=arguments.length,args=new Array(_len),_key=0;_key<_len;_key++){args[_key]=arguments[_key];}_this=(0, _possibleConstructorReturn2.default)(this,(_getPrototypeOf2=(0, _getPrototypeOf3.default)(TextPath)).call.apply(_getPrototypeOf2,[this].concat(args)));(0, _defineProperty2.default)((0, _assertThisInitialized2.default)(_this),"setNativeProps",function(props){var matrix=!props.matrix&&(0, _extractTransform.default)(props);if(matrix){props.matrix=matrix;}(0, _extends2.default)(props,(0, util$1.pickNotNil)((0, _extractText.default)(props,true)));_this.root&&_this.root.setNativeProps(props);});return _this;}(0, _createClass2.default)(TextPath,[{key:"render",value:function render(){var _this$props=this.props,children=_this$props.children,xlinkHref=_this$props.xlinkHref,_this$props$href=_this$props.href,href=_this$props$href===void 0?xlinkHref:_this$props$href,_this$props$startOffs=_this$props.startOffset,startOffset=_this$props$startOffs===void 0?0:_this$props$startOffs,method=_this$props.method,spacing=_this$props.spacing,side=_this$props.side,alignmentBaseline=_this$props.alignmentBaseline,midLine=_this$props.midLine,prop=(0, _objectWithoutProperties2.default)(_this$props,["children","xlinkHref","href","startOffset","method","spacing","side","alignmentBaseline","midLine"]);var matched=href&&href.match(util$1.idPattern);var match=matched&&matched[1];if(match){var props=(0, extractProps_1.withoutXY)(this,prop);(0, _extends2.default)(props,(0, _extractText.default)({children:children},true),{href:match,startOffset:startOffset,method:method,spacing:spacing,side:side,alignmentBaseline:alignmentBaseline,midLine:midLine});props.ref=this.refMethod;return _react.default.createElement(NativeComponents.RNSVGTextPath,(0, _extends2.default)({},props,{__source:{fileName:_jsxFileName,lineNumber:74}}));}console.warn('Invalid `href` prop for `TextPath` element, expected a href like "#id", but got: "'+href+'"');return _react.default.createElement(_TSpan.default,{ref:this.refMethod,__source:{fileName:_jsxFileName,lineNumber:83}},children);}}]);return TextPath;}(_Shape2.default);exports.default=TextPath;(0, _defineProperty2.default)(TextPath,"displayName",'TextPath');

  });

  var Use_1 = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.default=void 0;var _extends2=interopRequireDefault(_extends_1);var _classCallCheck2=interopRequireDefault(classCallCheck);var _createClass2=interopRequireDefault(createClass);var _possibleConstructorReturn2=interopRequireDefault(possibleConstructorReturn);var _getPrototypeOf2=interopRequireDefault(getPrototypeOf);var _inherits2=interopRequireDefault(inherits);var _defineProperty2=interopRequireDefault(defineProperty);var _react=interopRequireDefault(React__default["default"]);var _Shape2=interopRequireDefault(Shape_1);var _jsxFileName="/Users/horcrux/Work/react-native-svg/src/elements/Use.tsx";var Use=function(_Shape){(0, _inherits2.default)(Use,_Shape);function Use(){(0, _classCallCheck2.default)(this,Use);return (0, _possibleConstructorReturn2.default)(this,(0, _getPrototypeOf2.default)(Use).apply(this,arguments));}(0, _createClass2.default)(Use,[{key:"render",value:function render(){var props=this.props;var children=props.children,x=props.x,y=props.y,width=props.width,height=props.height,xlinkHref=props.xlinkHref,_props$href=props.href,href=_props$href===void 0?xlinkHref:_props$href;var matched=href&&href.match(util$1.idPattern);var match=matched&&matched[1];if(!match){console.warn('Invalid `href` prop for `Use` element, expected a href like "#id", but got: "'+href+'"');}return _react.default.createElement(NativeComponents.RNSVGUse,(0, _extends2.default)({ref:this.refMethod},(0, extractProps_1.withoutXY)(this,props),{href:match,x:x,y:y,width:width,height:height,__source:{fileName:_jsxFileName,lineNumber:49}}),children);}}]);return Use;}(_Shape2.default);exports.default=Use;(0, _defineProperty2.default)(Use,"displayName",'Use');(0, _defineProperty2.default)(Use,"defaultProps",{x:0,y:0,width:0,height:0});

  });

  var Image$1 = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.default=void 0;var _extends2=interopRequireDefault(_extends_1);var _classCallCheck2=interopRequireDefault(classCallCheck);var _createClass2=interopRequireDefault(createClass);var _possibleConstructorReturn2=interopRequireDefault(possibleConstructorReturn);var _getPrototypeOf2=interopRequireDefault(getPrototypeOf);var _inherits2=interopRequireDefault(inherits);var _defineProperty2=interopRequireDefault(defineProperty);var _react=interopRequireDefault(React__default["default"]);var _Shape2=interopRequireDefault(Shape_1);var _jsxFileName="/Users/horcrux/Work/react-native-svg/src/elements/Image.tsx";var spacesRegExp=/\s+/;var SvgImage=function(_Shape){(0, _inherits2.default)(SvgImage,_Shape);function SvgImage(){(0, _classCallCheck2.default)(this,SvgImage);return (0, _possibleConstructorReturn2.default)(this,(0, _getPrototypeOf2.default)(SvgImage).apply(this,arguments));}(0, _createClass2.default)(SvgImage,[{key:"render",value:function render(){var props=this.props;var preserveAspectRatio=props.preserveAspectRatio,x=props.x,y=props.y,width=props.width,height=props.height,xlinkHref=props.xlinkHref,_props$href=props.href,href=_props$href===void 0?xlinkHref:_props$href;var modes=preserveAspectRatio?preserveAspectRatio.trim().split(spacesRegExp):[];var align=modes[0];var meetOrSlice=modes[1];return _react.default.createElement(NativeComponents.RNSVGImage,(0, _extends2.default)({ref:this.refMethod},(0, extractProps_1.withoutXY)(this,props),{x:x,y:y,width:width,height:height,meetOrSlice:extractViewBox_1.meetOrSliceTypes[meetOrSlice]||0,align:extractViewBox_1.alignEnum[align]||'xMidYMid',src:!href?null:_reactNative__default["default"].Image.resolveAssetSource(typeof href==='string'?{uri:href}:href),__source:{fileName:_jsxFileName,lineNumber:48}}));}}]);return SvgImage;}(_Shape2.default);exports.default=SvgImage;(0, _defineProperty2.default)(SvgImage,"displayName",'Image');(0, _defineProperty2.default)(SvgImage,"defaultProps",{x:0,y:0,width:0,height:0,preserveAspectRatio:'xMidYMid meet'});

  });

  var _Symbol = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.default=void 0;var _extends2=interopRequireDefault(_extends_1);var _classCallCheck2=interopRequireDefault(classCallCheck);var _createClass2=interopRequireDefault(createClass);var _possibleConstructorReturn2=interopRequireDefault(possibleConstructorReturn);var _getPrototypeOf2=interopRequireDefault(getPrototypeOf);var _inherits2=interopRequireDefault(inherits);var _defineProperty2=interopRequireDefault(defineProperty);var _react=interopRequireDefault(React__default["default"]);var _extractViewBox=interopRequireDefault(extractViewBox_1);var _Shape2=interopRequireDefault(Shape_1);var _jsxFileName="/Users/horcrux/Work/react-native-svg/src/elements/Symbol.tsx";var Symbol=function(_Shape){(0, _inherits2.default)(Symbol,_Shape);function Symbol(){(0, _classCallCheck2.default)(this,Symbol);return (0, _possibleConstructorReturn2.default)(this,(0, _getPrototypeOf2.default)(Symbol).apply(this,arguments));}(0, _createClass2.default)(Symbol,[{key:"render",value:function render(){var props=this.props;var id=props.id,children=props.children;return _react.default.createElement(NativeComponents.RNSVGSymbol,(0, _extends2.default)({ref:this.refMethod,name:id},(0, _extractViewBox.default)(props),{__source:{fileName:_jsxFileName,lineNumber:17}}),children);}}]);return Symbol;}(_Shape2.default);exports.default=Symbol;(0, _defineProperty2.default)(Symbol,"displayName",'Symbol');

  });

  var Defs_1 = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.default=void 0;var _classCallCheck2=interopRequireDefault(classCallCheck);var _createClass2=interopRequireDefault(createClass);var _possibleConstructorReturn2=interopRequireDefault(possibleConstructorReturn);var _getPrototypeOf2=interopRequireDefault(getPrototypeOf);var _inherits2=interopRequireDefault(inherits);var _defineProperty2=interopRequireDefault(defineProperty);var _react=interopRequireWildcard(React__default["default"]);var _jsxFileName="/Users/horcrux/Work/react-native-svg/src/elements/Defs.tsx";var Defs=function(_Component){(0, _inherits2.default)(Defs,_Component);function Defs(){(0, _classCallCheck2.default)(this,Defs);return (0, _possibleConstructorReturn2.default)(this,(0, _getPrototypeOf2.default)(Defs).apply(this,arguments));}(0, _createClass2.default)(Defs,[{key:"render",value:function render(){return _react.default.createElement(NativeComponents.RNSVGDefs,{__source:{fileName:_jsxFileName,lineNumber:8}},this.props.children);}}]);return Defs;}(_react.Component);exports.default=Defs;(0, _defineProperty2.default)(Defs,"displayName",'Defs');

  });

  var units_1 = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.default=exports.units=void 0;var units={objectBoundingBox:0,userSpaceOnUse:1};exports.units=units;var _default=units;exports.default=_default;

  });

  var _default$4=extractGradient;var _react=interopRequireWildcard(React__default["default"]);var _extractColor=interopRequireDefault(extractColor_1);var _extractOpacity=interopRequireDefault(extractOpacity_1);var _extractTransform=interopRequireDefault(extractTransform_1);var _units=interopRequireDefault(units_1);var percentReg=/^([+-]?\d+(?:\.\d+)?(?:[eE][+-]?\d+)?)(%?)$/;function percentToFloat(percent){if(typeof percent==='number'){return percent;}if(typeof percent==='object'&&typeof percent.__getAnimatedValue==='function'){return percent.__getAnimatedValue();}var matched=typeof percent==='string'&&percent.match(percentReg);if(!matched){console.warn("\"".concat(percent,"\" is not a valid number or percentage string."));return 0;}return matched[2]?+matched[1]/100:+matched[1];}var offsetComparator=function offsetComparator(object,other){return object[0]-other[0];};function extractGradient(props,parent){var id=props.id,children=props.children,gradientTransform=props.gradientTransform,transform=props.transform,gradientUnits=props.gradientUnits;if(!id){return null;}var stops=[];var childArray=children?_react.Children.map(children,function(child){return _react.default.cloneElement(child,{parent:parent});}):[];var l=childArray.length;for(var i=0;i<l;i++){var _childArray$i$props=childArray[i].props,style=_childArray$i$props.style,_childArray$i$props$o=_childArray$i$props.offset,offset=_childArray$i$props$o===void 0?style&&style.offset:_childArray$i$props$o,_childArray$i$props$s=_childArray$i$props.stopColor,stopColor=_childArray$i$props$s===void 0?style&&style.stopColor||'#000':_childArray$i$props$s,_childArray$i$props$s2=_childArray$i$props.stopOpacity,stopOpacity=_childArray$i$props$s2===void 0?style&&style.stopOpacity:_childArray$i$props$s2;var offsetNumber=percentToFloat(offset||0);var color=stopColor&&(0, _extractColor.default)(stopColor);if(typeof color!=='number'||isNaN(offsetNumber)){console.warn("\"".concat(stopColor,"\" is not a valid color or \"").concat(offset,"\" is not a valid offset"));continue;}var alpha=Math.round((0, _extractOpacity.default)(stopOpacity)*255);stops.push([offsetNumber,color&0x00ffffff|alpha<<24]);}stops.sort(offsetComparator);var gradient=[];var k=stops.length;for(var j=0;j<k;j++){var s=stops[j];gradient.push(s[0],s[1]);}return {name:id,gradient:gradient,children:childArray,gradientUnits:gradientUnits&&_units.default[gradientUnits]||0,gradientTransform:(0, _extractTransform.default)(gradientTransform||transform||props)};}


  var extractGradient_1 = /*#__PURE__*/Object.defineProperty({
  	default: _default$4
  }, '__esModule', {value: true});

  var LinearGradient_1 = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.default=void 0;var _extends2=interopRequireDefault(_extends_1);var _classCallCheck2=interopRequireDefault(classCallCheck);var _createClass2=interopRequireDefault(createClass);var _possibleConstructorReturn2=interopRequireDefault(possibleConstructorReturn);var _getPrototypeOf2=interopRequireDefault(getPrototypeOf);var _inherits2=interopRequireDefault(inherits);var _defineProperty2=interopRequireDefault(defineProperty);var _react=interopRequireDefault(React__default["default"]);var _extractGradient=interopRequireDefault(extractGradient_1);var _Shape2=interopRequireDefault(Shape_1);var _jsxFileName="/Users/horcrux/Work/react-native-svg/src/elements/LinearGradient.tsx";var LinearGradient=function(_Shape){(0, _inherits2.default)(LinearGradient,_Shape);function LinearGradient(){(0, _classCallCheck2.default)(this,LinearGradient);return (0, _possibleConstructorReturn2.default)(this,(0, _getPrototypeOf2.default)(LinearGradient).apply(this,arguments));}(0, _createClass2.default)(LinearGradient,[{key:"render",value:function render(){var props=this.props;var x1=props.x1,y1=props.y1,x2=props.x2,y2=props.y2;return _react.default.createElement(NativeComponents.RNSVGLinearGradient,(0, _extends2.default)({ref:this.refMethod,x1:x1,y1:y1,x2:x2,y2:y2},(0, _extractGradient.default)(props,this),{__source:{fileName:_jsxFileName,lineNumber:31}}));}}]);return LinearGradient;}(_Shape2.default);exports.default=LinearGradient;(0, _defineProperty2.default)(LinearGradient,"displayName",'LinearGradient');(0, _defineProperty2.default)(LinearGradient,"defaultProps",{x1:'0%',y1:'0%',x2:'100%',y2:'0%'});

  });

  var RadialGradient_1 = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.default=void 0;var _extends2=interopRequireDefault(_extends_1);var _classCallCheck2=interopRequireDefault(classCallCheck);var _createClass2=interopRequireDefault(createClass);var _possibleConstructorReturn2=interopRequireDefault(possibleConstructorReturn);var _getPrototypeOf2=interopRequireDefault(getPrototypeOf);var _inherits2=interopRequireDefault(inherits);var _defineProperty2=interopRequireDefault(defineProperty);var _react=interopRequireDefault(React__default["default"]);var _extractGradient=interopRequireDefault(extractGradient_1);var _Shape2=interopRequireDefault(Shape_1);var _jsxFileName="/Users/horcrux/Work/react-native-svg/src/elements/RadialGradient.tsx";var RadialGradient=function(_Shape){(0, _inherits2.default)(RadialGradient,_Shape);function RadialGradient(){(0, _classCallCheck2.default)(this,RadialGradient);return (0, _possibleConstructorReturn2.default)(this,(0, _getPrototypeOf2.default)(RadialGradient).apply(this,arguments));}(0, _createClass2.default)(RadialGradient,[{key:"render",value:function render(){var props=this.props;var rx=props.rx,ry=props.ry,r=props.r,cx=props.cx,cy=props.cy,_props$fx=props.fx,fx=_props$fx===void 0?cx:_props$fx,_props$fy=props.fy,fy=_props$fy===void 0?cy:_props$fy;return _react.default.createElement(NativeComponents.RNSVGRadialGradient,(0, _extends2.default)({ref:this.refMethod,fx:fx,fy:fy,rx:rx||r,ry:ry||r,cx:cx,cy:cy},(0, _extractGradient.default)(props,this),{__source:{fileName:_jsxFileName,lineNumber:33}}));}}]);return RadialGradient;}(_Shape2.default);exports.default=RadialGradient;(0, _defineProperty2.default)(RadialGradient,"displayName",'RadialGradient');(0, _defineProperty2.default)(RadialGradient,"defaultProps",{cx:'50%',cy:'50%',r:'50%'});

  });

  var Stop_1 = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.default=void 0;var _classCallCheck2=interopRequireDefault(classCallCheck);var _createClass2=interopRequireDefault(createClass);var _possibleConstructorReturn2=interopRequireDefault(possibleConstructorReturn);var _getPrototypeOf3=interopRequireDefault(getPrototypeOf);var _assertThisInitialized2=interopRequireDefault(assertThisInitialized);var _inherits2=interopRequireDefault(inherits);var _defineProperty2=interopRequireDefault(defineProperty);var Stop=function(_Component){(0, _inherits2.default)(Stop,_Component);function Stop(){var _getPrototypeOf2;var _this;(0, _classCallCheck2.default)(this,Stop);for(var _len=arguments.length,args=new Array(_len),_key=0;_key<_len;_key++){args[_key]=arguments[_key];}_this=(0, _possibleConstructorReturn2.default)(this,(_getPrototypeOf2=(0, _getPrototypeOf3.default)(Stop)).call.apply(_getPrototypeOf2,[this].concat(args)));(0, _defineProperty2.default)((0, _assertThisInitialized2.default)(_this),"props",void 0);(0, _defineProperty2.default)((0, _assertThisInitialized2.default)(_this),"setNativeProps",function(){var parent=_this.props.parent;if(parent){parent.forceUpdate();}});return _this;}(0, _createClass2.default)(Stop,[{key:"render",value:function render(){return null;}}]);return Stop;}(React__default["default"].Component);exports.default=Stop;(0, _defineProperty2.default)(Stop,"displayName",'Stop');

  });

  var ClipPath_1 = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.default=void 0;var _extends2=interopRequireDefault(_extends_1);var _classCallCheck2=interopRequireDefault(classCallCheck);var _createClass2=interopRequireDefault(createClass);var _possibleConstructorReturn2=interopRequireDefault(possibleConstructorReturn);var _getPrototypeOf2=interopRequireDefault(getPrototypeOf);var _inherits2=interopRequireDefault(inherits);var _defineProperty2=interopRequireDefault(defineProperty);var _react=interopRequireDefault(React__default["default"]);var _Shape2=interopRequireDefault(Shape_1);var _jsxFileName="/Users/horcrux/Work/react-native-svg/src/elements/ClipPath.tsx";var ClipPath=function(_Shape){(0, _inherits2.default)(ClipPath,_Shape);function ClipPath(){(0, _classCallCheck2.default)(this,ClipPath);return (0, _possibleConstructorReturn2.default)(this,(0, _getPrototypeOf2.default)(ClipPath).apply(this,arguments));}(0, _createClass2.default)(ClipPath,[{key:"render",value:function render(){var props=this.props;return _react.default.createElement(NativeComponents.RNSVGClipPath,(0, _extends2.default)({ref:this.refMethod},(0, extractProps_1.extract)(this,props),{__source:{fileName:_jsxFileName,lineNumber:12}}),props.children);}}]);return ClipPath;}(_Shape2.default);exports.default=ClipPath;(0, _defineProperty2.default)(ClipPath,"displayName",'ClipPath');

  });

  var Pattern_1 = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.default=void 0;var _extends2=interopRequireDefault(_extends_1);var _classCallCheck2=interopRequireDefault(classCallCheck);var _createClass2=interopRequireDefault(createClass);var _possibleConstructorReturn2=interopRequireDefault(possibleConstructorReturn);var _getPrototypeOf2=interopRequireDefault(getPrototypeOf);var _inherits2=interopRequireDefault(inherits);var _defineProperty2=interopRequireDefault(defineProperty);var _react=interopRequireDefault(React__default["default"]);var _extractTransform=interopRequireDefault(extractTransform_1);var _extractViewBox=interopRequireDefault(extractViewBox_1);var _units=interopRequireDefault(units_1);var _Shape2=interopRequireDefault(Shape_1);var _jsxFileName="/Users/horcrux/Work/react-native-svg/src/elements/Pattern.tsx";var Pattern=function(_Shape){(0, _inherits2.default)(Pattern,_Shape);function Pattern(){(0, _classCallCheck2.default)(this,Pattern);return (0, _possibleConstructorReturn2.default)(this,(0, _getPrototypeOf2.default)(Pattern).apply(this,arguments));}(0, _createClass2.default)(Pattern,[{key:"render",value:function render(){var props=this.props;var patternTransform=props.patternTransform,transform=props.transform,id=props.id,x=props.x,y=props.y,width=props.width,height=props.height,patternUnits=props.patternUnits,patternContentUnits=props.patternContentUnits,children=props.children,viewBox=props.viewBox,preserveAspectRatio=props.preserveAspectRatio;var matrix=(0, _extractTransform.default)(patternTransform||transform||props);return _react.default.createElement(NativeComponents.RNSVGPattern,(0, _extends2.default)({ref:this.refMethod,name:id,x:x,y:y,width:width,height:height,matrix:matrix,patternTransform:matrix,patternUnits:patternUnits&&_units.default[patternUnits]||0,patternContentUnits:patternContentUnits?_units.default[patternContentUnits]:1},(0, _extractViewBox.default)({viewBox:viewBox,preserveAspectRatio:preserveAspectRatio}),{__source:{fileName:_jsxFileName,lineNumber:49}}),children);}}]);return Pattern;}(_Shape2.default);exports.default=Pattern;(0, _defineProperty2.default)(Pattern,"displayName",'Pattern');(0, _defineProperty2.default)(Pattern,"defaultProps",{x:'0%',y:'0%',width:'100%',height:'100%'});

  });

  var Mask_1 = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.default=void 0;var _extends2=interopRequireDefault(_extends_1);var _classCallCheck2=interopRequireDefault(classCallCheck);var _createClass2=interopRequireDefault(createClass);var _possibleConstructorReturn2=interopRequireDefault(possibleConstructorReturn);var _getPrototypeOf2=interopRequireDefault(getPrototypeOf);var _inherits2=interopRequireDefault(inherits);var _defineProperty2=interopRequireDefault(defineProperty);var _react=interopRequireDefault(React__default["default"]);var _extractTransform=interopRequireDefault(extractTransform_1);var _units=interopRequireDefault(units_1);var _Shape2=interopRequireDefault(Shape_1);var _jsxFileName="/Users/horcrux/Work/react-native-svg/src/elements/Mask.tsx";var Mask=function(_Shape){(0, _inherits2.default)(Mask,_Shape);function Mask(){(0, _classCallCheck2.default)(this,Mask);return (0, _possibleConstructorReturn2.default)(this,(0, _getPrototypeOf2.default)(Mask).apply(this,arguments));}(0, _createClass2.default)(Mask,[{key:"render",value:function render(){var props=this.props;var maskTransform=props.maskTransform,transform=props.transform,x=props.x,y=props.y,width=props.width,height=props.height,maskUnits=props.maskUnits,maskContentUnits=props.maskContentUnits,children=props.children;return _react.default.createElement(NativeComponents.RNSVGMask,(0, _extends2.default)({ref:this.refMethod},(0, extractProps_1.withoutXY)(this,props),{x:x,y:y,width:width,height:height,maskTransform:(0, _extractTransform.default)(maskTransform||transform||props),maskUnits:maskUnits!==undefined?_units.default[maskUnits]:0,maskContentUnits:maskContentUnits!==undefined?_units.default[maskContentUnits]:1,__source:{fileName:_jsxFileName,lineNumber:42}}),children);}}]);return Mask;}(_Shape2.default);exports.default=Mask;(0, _defineProperty2.default)(Mask,"displayName",'Mask');(0, _defineProperty2.default)(Mask,"defaultProps",{x:'0%',y:'0%',width:'100%',height:'100%'});

  });

  var Marker_1 = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.default=void 0;var _extends2=interopRequireDefault(_extends_1);var _classCallCheck2=interopRequireDefault(classCallCheck);var _createClass2=interopRequireDefault(createClass);var _possibleConstructorReturn2=interopRequireDefault(possibleConstructorReturn);var _getPrototypeOf2=interopRequireDefault(getPrototypeOf);var _inherits2=interopRequireDefault(inherits);var _defineProperty2=interopRequireDefault(defineProperty);var _react=interopRequireDefault(React__default["default"]);var _extractViewBox=interopRequireDefault(extractViewBox_1);var _Shape2=interopRequireDefault(Shape_1);var _jsxFileName="/Users/horcrux/Work/react-native-svg/src/elements/Marker.tsx";var Marker=function(_Shape){(0, _inherits2.default)(Marker,_Shape);function Marker(){(0, _classCallCheck2.default)(this,Marker);return (0, _possibleConstructorReturn2.default)(this,(0, _getPrototypeOf2.default)(Marker).apply(this,arguments));}(0, _createClass2.default)(Marker,[{key:"render",value:function render(){var props=this.props;var id=props.id,viewBox=props.viewBox,preserveAspectRatio=props.preserveAspectRatio,refX=props.refX,refY=props.refY,markerUnits=props.markerUnits,orient=props.orient,markerWidth=props.markerWidth,markerHeight=props.markerHeight,children=props.children;return _react.default.createElement(NativeComponents.RNSVGMarker,(0, _extends2.default)({ref:this.refMethod,name:id,refX:refX,refY:refY,orient:String(orient),markerUnits:markerUnits,markerWidth:markerWidth,markerHeight:markerHeight},(0, _extractViewBox.default)({viewBox:viewBox,preserveAspectRatio:preserveAspectRatio}),{__source:{fileName:_jsxFileName,lineNumber:44}}),children);}}]);return Marker;}(_Shape2.default);exports.default=Marker;(0, _defineProperty2.default)(Marker,"displayName",'Marker');(0, _defineProperty2.default)(Marker,"defaultProps",{refX:0,refY:0,orient:'0',markerWidth:3,markerHeight:3,markerUnits:'strokeWidth'});

  });

  var ForeignObject_1 = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.default=void 0;var _extends2=interopRequireDefault(_extends_1);var _classCallCheck2=interopRequireDefault(classCallCheck);var _createClass2=interopRequireDefault(createClass);var _possibleConstructorReturn2=interopRequireDefault(possibleConstructorReturn);var _getPrototypeOf2=interopRequireDefault(getPrototypeOf);var _inherits2=interopRequireDefault(inherits);var _defineProperty2=interopRequireDefault(defineProperty);var _react=interopRequireDefault(React__default["default"]);var _G2=interopRequireDefault(G_1);var _jsxFileName="/Users/horcrux/Work/react-native-svg/src/elements/ForeignObject.tsx";var ForeignObject=function(_G){(0, _inherits2.default)(ForeignObject,_G);function ForeignObject(){(0, _classCallCheck2.default)(this,ForeignObject);return (0, _possibleConstructorReturn2.default)(this,(0, _getPrototypeOf2.default)(ForeignObject).apply(this,arguments));}(0, _createClass2.default)(ForeignObject,[{key:"render",value:function render(){var props=this.props;var x=props.x,y=props.y,width=props.width,height=props.height,children=props.children;return _react.default.createElement(NativeComponents.RNSVGForeignObject,(0, _extends2.default)({ref:this.refMethod},(0, extractProps_1.withoutXY)(this,props),{x:x,y:y,width:width,height:height,__source:{fileName:_jsxFileName,lineNumber:26}}),children);}}]);return ForeignObject;}(_G2.default);exports.default=ForeignObject;(0, _defineProperty2.default)(ForeignObject,"displayName",'ForeignObject');(0, _defineProperty2.default)(ForeignObject,"defaultProps",{x:'0%',y:'0%',width:'100%',height:'100%'});

  });

  var arrayWithHoles = createCommonjsModule(function (module) {
  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  module.exports = _arrayWithHoles, module.exports.__esModule = true, module.exports["default"] = module.exports;
  });

  var iterableToArrayLimit = createCommonjsModule(function (module) {
  function _iterableToArrayLimit(arr, i) {
    var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"];

    if (_i == null) return;
    var _arr = [];
    var _n = true;
    var _d = false;

    var _s, _e;

    try {
      for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);

        if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;
      _e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }

    return _arr;
  }

  module.exports = _iterableToArrayLimit, module.exports.__esModule = true, module.exports["default"] = module.exports;
  });

  var nonIterableRest = createCommonjsModule(function (module) {
  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
  }

  module.exports = _nonIterableRest, module.exports.__esModule = true, module.exports["default"] = module.exports;
  });

  var slicedToArray = createCommonjsModule(function (module) {
  function _slicedToArray(arr, i) {
    return arrayWithHoles(arr) || iterableToArrayLimit(arr, i) || unsupportedIterableToArray(arr, i) || nonIterableRest();
  }

  module.exports = _slicedToArray, module.exports.__esModule = true, module.exports["default"] = module.exports;
  });

  /**
   * Copyright (c) 2014-present, Facebook, Inc.
   *
   * This source code is licensed under the MIT license found in the
   * LICENSE file in the root directory of this source tree.
   */

  var runtime_1 = createCommonjsModule(function (module) {
  var runtime = (function (exports) {

    var Op = Object.prototype;
    var hasOwn = Op.hasOwnProperty;
    var undefined$1; // More compressible than void 0.
    var $Symbol = typeof Symbol === "function" ? Symbol : {};
    var iteratorSymbol = $Symbol.iterator || "@@iterator";
    var asyncIteratorSymbol = $Symbol.asyncIterator || "@@asyncIterator";
    var toStringTagSymbol = $Symbol.toStringTag || "@@toStringTag";

    function define(obj, key, value) {
      Object.defineProperty(obj, key, {
        value: value,
        enumerable: true,
        configurable: true,
        writable: true
      });
      return obj[key];
    }
    try {
      // IE 8 has a broken Object.defineProperty that only works on DOM objects.
      define({}, "");
    } catch (err) {
      define = function(obj, key, value) {
        return obj[key] = value;
      };
    }

    function wrap(innerFn, outerFn, self, tryLocsList) {
      // If outerFn provided and outerFn.prototype is a Generator, then outerFn.prototype instanceof Generator.
      var protoGenerator = outerFn && outerFn.prototype instanceof Generator ? outerFn : Generator;
      var generator = Object.create(protoGenerator.prototype);
      var context = new Context(tryLocsList || []);

      // The ._invoke method unifies the implementations of the .next,
      // .throw, and .return methods.
      generator._invoke = makeInvokeMethod(innerFn, self, context);

      return generator;
    }
    exports.wrap = wrap;

    // Try/catch helper to minimize deoptimizations. Returns a completion
    // record like context.tryEntries[i].completion. This interface could
    // have been (and was previously) designed to take a closure to be
    // invoked without arguments, but in all the cases we care about we
    // already have an existing method we want to call, so there's no need
    // to create a new function object. We can even get away with assuming
    // the method takes exactly one argument, since that happens to be true
    // in every case, so we don't have to touch the arguments object. The
    // only additional allocation required is the completion record, which
    // has a stable shape and so hopefully should be cheap to allocate.
    function tryCatch(fn, obj, arg) {
      try {
        return { type: "normal", arg: fn.call(obj, arg) };
      } catch (err) {
        return { type: "throw", arg: err };
      }
    }

    var GenStateSuspendedStart = "suspendedStart";
    var GenStateSuspendedYield = "suspendedYield";
    var GenStateExecuting = "executing";
    var GenStateCompleted = "completed";

    // Returning this object from the innerFn has the same effect as
    // breaking out of the dispatch switch statement.
    var ContinueSentinel = {};

    // Dummy constructor functions that we use as the .constructor and
    // .constructor.prototype properties for functions that return Generator
    // objects. For full spec compliance, you may wish to configure your
    // minifier not to mangle the names of these two functions.
    function Generator() {}
    function GeneratorFunction() {}
    function GeneratorFunctionPrototype() {}

    // This is a polyfill for %IteratorPrototype% for environments that
    // don't natively support it.
    var IteratorPrototype = {};
    define(IteratorPrototype, iteratorSymbol, function () {
      return this;
    });

    var getProto = Object.getPrototypeOf;
    var NativeIteratorPrototype = getProto && getProto(getProto(values([])));
    if (NativeIteratorPrototype &&
        NativeIteratorPrototype !== Op &&
        hasOwn.call(NativeIteratorPrototype, iteratorSymbol)) {
      // This environment has a native %IteratorPrototype%; use it instead
      // of the polyfill.
      IteratorPrototype = NativeIteratorPrototype;
    }

    var Gp = GeneratorFunctionPrototype.prototype =
      Generator.prototype = Object.create(IteratorPrototype);
    GeneratorFunction.prototype = GeneratorFunctionPrototype;
    define(Gp, "constructor", GeneratorFunctionPrototype);
    define(GeneratorFunctionPrototype, "constructor", GeneratorFunction);
    GeneratorFunction.displayName = define(
      GeneratorFunctionPrototype,
      toStringTagSymbol,
      "GeneratorFunction"
    );

    // Helper for defining the .next, .throw, and .return methods of the
    // Iterator interface in terms of a single ._invoke method.
    function defineIteratorMethods(prototype) {
      ["next", "throw", "return"].forEach(function(method) {
        define(prototype, method, function(arg) {
          return this._invoke(method, arg);
        });
      });
    }

    exports.isGeneratorFunction = function(genFun) {
      var ctor = typeof genFun === "function" && genFun.constructor;
      return ctor
        ? ctor === GeneratorFunction ||
          // For the native GeneratorFunction constructor, the best we can
          // do is to check its .name property.
          (ctor.displayName || ctor.name) === "GeneratorFunction"
        : false;
    };

    exports.mark = function(genFun) {
      if (Object.setPrototypeOf) {
        Object.setPrototypeOf(genFun, GeneratorFunctionPrototype);
      } else {
        genFun.__proto__ = GeneratorFunctionPrototype;
        define(genFun, toStringTagSymbol, "GeneratorFunction");
      }
      genFun.prototype = Object.create(Gp);
      return genFun;
    };

    // Within the body of any async function, `await x` is transformed to
    // `yield regeneratorRuntime.awrap(x)`, so that the runtime can test
    // `hasOwn.call(value, "__await")` to determine if the yielded value is
    // meant to be awaited.
    exports.awrap = function(arg) {
      return { __await: arg };
    };

    function AsyncIterator(generator, PromiseImpl) {
      function invoke(method, arg, resolve, reject) {
        var record = tryCatch(generator[method], generator, arg);
        if (record.type === "throw") {
          reject(record.arg);
        } else {
          var result = record.arg;
          var value = result.value;
          if (value &&
              typeof value === "object" &&
              hasOwn.call(value, "__await")) {
            return PromiseImpl.resolve(value.__await).then(function(value) {
              invoke("next", value, resolve, reject);
            }, function(err) {
              invoke("throw", err, resolve, reject);
            });
          }

          return PromiseImpl.resolve(value).then(function(unwrapped) {
            // When a yielded Promise is resolved, its final value becomes
            // the .value of the Promise<{value,done}> result for the
            // current iteration.
            result.value = unwrapped;
            resolve(result);
          }, function(error) {
            // If a rejected Promise was yielded, throw the rejection back
            // into the async generator function so it can be handled there.
            return invoke("throw", error, resolve, reject);
          });
        }
      }

      var previousPromise;

      function enqueue(method, arg) {
        function callInvokeWithMethodAndArg() {
          return new PromiseImpl(function(resolve, reject) {
            invoke(method, arg, resolve, reject);
          });
        }

        return previousPromise =
          // If enqueue has been called before, then we want to wait until
          // all previous Promises have been resolved before calling invoke,
          // so that results are always delivered in the correct order. If
          // enqueue has not been called before, then it is important to
          // call invoke immediately, without waiting on a callback to fire,
          // so that the async generator function has the opportunity to do
          // any necessary setup in a predictable way. This predictability
          // is why the Promise constructor synchronously invokes its
          // executor callback, and why async functions synchronously
          // execute code before the first await. Since we implement simple
          // async functions in terms of async generators, it is especially
          // important to get this right, even though it requires care.
          previousPromise ? previousPromise.then(
            callInvokeWithMethodAndArg,
            // Avoid propagating failures to Promises returned by later
            // invocations of the iterator.
            callInvokeWithMethodAndArg
          ) : callInvokeWithMethodAndArg();
      }

      // Define the unified helper method that is used to implement .next,
      // .throw, and .return (see defineIteratorMethods).
      this._invoke = enqueue;
    }

    defineIteratorMethods(AsyncIterator.prototype);
    define(AsyncIterator.prototype, asyncIteratorSymbol, function () {
      return this;
    });
    exports.AsyncIterator = AsyncIterator;

    // Note that simple async functions are implemented on top of
    // AsyncIterator objects; they just return a Promise for the value of
    // the final result produced by the iterator.
    exports.async = function(innerFn, outerFn, self, tryLocsList, PromiseImpl) {
      if (PromiseImpl === void 0) PromiseImpl = Promise;

      var iter = new AsyncIterator(
        wrap(innerFn, outerFn, self, tryLocsList),
        PromiseImpl
      );

      return exports.isGeneratorFunction(outerFn)
        ? iter // If outerFn is a generator, return the full iterator.
        : iter.next().then(function(result) {
            return result.done ? result.value : iter.next();
          });
    };

    function makeInvokeMethod(innerFn, self, context) {
      var state = GenStateSuspendedStart;

      return function invoke(method, arg) {
        if (state === GenStateExecuting) {
          throw new Error("Generator is already running");
        }

        if (state === GenStateCompleted) {
          if (method === "throw") {
            throw arg;
          }

          // Be forgiving, per 25.3.3.3.3 of the spec:
          // https://people.mozilla.org/~jorendorff/es6-draft.html#sec-generatorresume
          return doneResult();
        }

        context.method = method;
        context.arg = arg;

        while (true) {
          var delegate = context.delegate;
          if (delegate) {
            var delegateResult = maybeInvokeDelegate(delegate, context);
            if (delegateResult) {
              if (delegateResult === ContinueSentinel) continue;
              return delegateResult;
            }
          }

          if (context.method === "next") {
            // Setting context._sent for legacy support of Babel's
            // function.sent implementation.
            context.sent = context._sent = context.arg;

          } else if (context.method === "throw") {
            if (state === GenStateSuspendedStart) {
              state = GenStateCompleted;
              throw context.arg;
            }

            context.dispatchException(context.arg);

          } else if (context.method === "return") {
            context.abrupt("return", context.arg);
          }

          state = GenStateExecuting;

          var record = tryCatch(innerFn, self, context);
          if (record.type === "normal") {
            // If an exception is thrown from innerFn, we leave state ===
            // GenStateExecuting and loop back for another invocation.
            state = context.done
              ? GenStateCompleted
              : GenStateSuspendedYield;

            if (record.arg === ContinueSentinel) {
              continue;
            }

            return {
              value: record.arg,
              done: context.done
            };

          } else if (record.type === "throw") {
            state = GenStateCompleted;
            // Dispatch the exception by looping back around to the
            // context.dispatchException(context.arg) call above.
            context.method = "throw";
            context.arg = record.arg;
          }
        }
      };
    }

    // Call delegate.iterator[context.method](context.arg) and handle the
    // result, either by returning a { value, done } result from the
    // delegate iterator, or by modifying context.method and context.arg,
    // setting context.delegate to null, and returning the ContinueSentinel.
    function maybeInvokeDelegate(delegate, context) {
      var method = delegate.iterator[context.method];
      if (method === undefined$1) {
        // A .throw or .return when the delegate iterator has no .throw
        // method always terminates the yield* loop.
        context.delegate = null;

        if (context.method === "throw") {
          // Note: ["return"] must be used for ES3 parsing compatibility.
          if (delegate.iterator["return"]) {
            // If the delegate iterator has a return method, give it a
            // chance to clean up.
            context.method = "return";
            context.arg = undefined$1;
            maybeInvokeDelegate(delegate, context);

            if (context.method === "throw") {
              // If maybeInvokeDelegate(context) changed context.method from
              // "return" to "throw", let that override the TypeError below.
              return ContinueSentinel;
            }
          }

          context.method = "throw";
          context.arg = new TypeError(
            "The iterator does not provide a 'throw' method");
        }

        return ContinueSentinel;
      }

      var record = tryCatch(method, delegate.iterator, context.arg);

      if (record.type === "throw") {
        context.method = "throw";
        context.arg = record.arg;
        context.delegate = null;
        return ContinueSentinel;
      }

      var info = record.arg;

      if (! info) {
        context.method = "throw";
        context.arg = new TypeError("iterator result is not an object");
        context.delegate = null;
        return ContinueSentinel;
      }

      if (info.done) {
        // Assign the result of the finished delegate to the temporary
        // variable specified by delegate.resultName (see delegateYield).
        context[delegate.resultName] = info.value;

        // Resume execution at the desired location (see delegateYield).
        context.next = delegate.nextLoc;

        // If context.method was "throw" but the delegate handled the
        // exception, let the outer generator proceed normally. If
        // context.method was "next", forget context.arg since it has been
        // "consumed" by the delegate iterator. If context.method was
        // "return", allow the original .return call to continue in the
        // outer generator.
        if (context.method !== "return") {
          context.method = "next";
          context.arg = undefined$1;
        }

      } else {
        // Re-yield the result returned by the delegate method.
        return info;
      }

      // The delegate iterator is finished, so forget it and continue with
      // the outer generator.
      context.delegate = null;
      return ContinueSentinel;
    }

    // Define Generator.prototype.{next,throw,return} in terms of the
    // unified ._invoke helper method.
    defineIteratorMethods(Gp);

    define(Gp, toStringTagSymbol, "Generator");

    // A Generator should always return itself as the iterator object when the
    // @@iterator function is called on it. Some browsers' implementations of the
    // iterator prototype chain incorrectly implement this, causing the Generator
    // object to not be returned from this call. This ensures that doesn't happen.
    // See https://github.com/facebook/regenerator/issues/274 for more details.
    define(Gp, iteratorSymbol, function() {
      return this;
    });

    define(Gp, "toString", function() {
      return "[object Generator]";
    });

    function pushTryEntry(locs) {
      var entry = { tryLoc: locs[0] };

      if (1 in locs) {
        entry.catchLoc = locs[1];
      }

      if (2 in locs) {
        entry.finallyLoc = locs[2];
        entry.afterLoc = locs[3];
      }

      this.tryEntries.push(entry);
    }

    function resetTryEntry(entry) {
      var record = entry.completion || {};
      record.type = "normal";
      delete record.arg;
      entry.completion = record;
    }

    function Context(tryLocsList) {
      // The root entry object (effectively a try statement without a catch
      // or a finally block) gives us a place to store values thrown from
      // locations where there is no enclosing try statement.
      this.tryEntries = [{ tryLoc: "root" }];
      tryLocsList.forEach(pushTryEntry, this);
      this.reset(true);
    }

    exports.keys = function(object) {
      var keys = [];
      for (var key in object) {
        keys.push(key);
      }
      keys.reverse();

      // Rather than returning an object with a next method, we keep
      // things simple and return the next function itself.
      return function next() {
        while (keys.length) {
          var key = keys.pop();
          if (key in object) {
            next.value = key;
            next.done = false;
            return next;
          }
        }

        // To avoid creating an additional object, we just hang the .value
        // and .done properties off the next function object itself. This
        // also ensures that the minifier will not anonymize the function.
        next.done = true;
        return next;
      };
    };

    function values(iterable) {
      if (iterable) {
        var iteratorMethod = iterable[iteratorSymbol];
        if (iteratorMethod) {
          return iteratorMethod.call(iterable);
        }

        if (typeof iterable.next === "function") {
          return iterable;
        }

        if (!isNaN(iterable.length)) {
          var i = -1, next = function next() {
            while (++i < iterable.length) {
              if (hasOwn.call(iterable, i)) {
                next.value = iterable[i];
                next.done = false;
                return next;
              }
            }

            next.value = undefined$1;
            next.done = true;

            return next;
          };

          return next.next = next;
        }
      }

      // Return an iterator with no values.
      return { next: doneResult };
    }
    exports.values = values;

    function doneResult() {
      return { value: undefined$1, done: true };
    }

    Context.prototype = {
      constructor: Context,

      reset: function(skipTempReset) {
        this.prev = 0;
        this.next = 0;
        // Resetting context._sent for legacy support of Babel's
        // function.sent implementation.
        this.sent = this._sent = undefined$1;
        this.done = false;
        this.delegate = null;

        this.method = "next";
        this.arg = undefined$1;

        this.tryEntries.forEach(resetTryEntry);

        if (!skipTempReset) {
          for (var name in this) {
            // Not sure about the optimal order of these conditions:
            if (name.charAt(0) === "t" &&
                hasOwn.call(this, name) &&
                !isNaN(+name.slice(1))) {
              this[name] = undefined$1;
            }
          }
        }
      },

      stop: function() {
        this.done = true;

        var rootEntry = this.tryEntries[0];
        var rootRecord = rootEntry.completion;
        if (rootRecord.type === "throw") {
          throw rootRecord.arg;
        }

        return this.rval;
      },

      dispatchException: function(exception) {
        if (this.done) {
          throw exception;
        }

        var context = this;
        function handle(loc, caught) {
          record.type = "throw";
          record.arg = exception;
          context.next = loc;

          if (caught) {
            // If the dispatched exception was caught by a catch block,
            // then let that catch block handle the exception normally.
            context.method = "next";
            context.arg = undefined$1;
          }

          return !! caught;
        }

        for (var i = this.tryEntries.length - 1; i >= 0; --i) {
          var entry = this.tryEntries[i];
          var record = entry.completion;

          if (entry.tryLoc === "root") {
            // Exception thrown outside of any try block that could handle
            // it, so set the completion value of the entire function to
            // throw the exception.
            return handle("end");
          }

          if (entry.tryLoc <= this.prev) {
            var hasCatch = hasOwn.call(entry, "catchLoc");
            var hasFinally = hasOwn.call(entry, "finallyLoc");

            if (hasCatch && hasFinally) {
              if (this.prev < entry.catchLoc) {
                return handle(entry.catchLoc, true);
              } else if (this.prev < entry.finallyLoc) {
                return handle(entry.finallyLoc);
              }

            } else if (hasCatch) {
              if (this.prev < entry.catchLoc) {
                return handle(entry.catchLoc, true);
              }

            } else if (hasFinally) {
              if (this.prev < entry.finallyLoc) {
                return handle(entry.finallyLoc);
              }

            } else {
              throw new Error("try statement without catch or finally");
            }
          }
        }
      },

      abrupt: function(type, arg) {
        for (var i = this.tryEntries.length - 1; i >= 0; --i) {
          var entry = this.tryEntries[i];
          if (entry.tryLoc <= this.prev &&
              hasOwn.call(entry, "finallyLoc") &&
              this.prev < entry.finallyLoc) {
            var finallyEntry = entry;
            break;
          }
        }

        if (finallyEntry &&
            (type === "break" ||
             type === "continue") &&
            finallyEntry.tryLoc <= arg &&
            arg <= finallyEntry.finallyLoc) {
          // Ignore the finally entry if control is not jumping to a
          // location outside the try/catch block.
          finallyEntry = null;
        }

        var record = finallyEntry ? finallyEntry.completion : {};
        record.type = type;
        record.arg = arg;

        if (finallyEntry) {
          this.method = "next";
          this.next = finallyEntry.finallyLoc;
          return ContinueSentinel;
        }

        return this.complete(record);
      },

      complete: function(record, afterLoc) {
        if (record.type === "throw") {
          throw record.arg;
        }

        if (record.type === "break" ||
            record.type === "continue") {
          this.next = record.arg;
        } else if (record.type === "return") {
          this.rval = this.arg = record.arg;
          this.method = "return";
          this.next = "end";
        } else if (record.type === "normal" && afterLoc) {
          this.next = afterLoc;
        }

        return ContinueSentinel;
      },

      finish: function(finallyLoc) {
        for (var i = this.tryEntries.length - 1; i >= 0; --i) {
          var entry = this.tryEntries[i];
          if (entry.finallyLoc === finallyLoc) {
            this.complete(entry.completion, entry.afterLoc);
            resetTryEntry(entry);
            return ContinueSentinel;
          }
        }
      },

      "catch": function(tryLoc) {
        for (var i = this.tryEntries.length - 1; i >= 0; --i) {
          var entry = this.tryEntries[i];
          if (entry.tryLoc === tryLoc) {
            var record = entry.completion;
            if (record.type === "throw") {
              var thrown = record.arg;
              resetTryEntry(entry);
            }
            return thrown;
          }
        }

        // The context.catch method must only be called with a location
        // argument that corresponds to a known catch block.
        throw new Error("illegal catch attempt");
      },

      delegateYield: function(iterable, resultName, nextLoc) {
        this.delegate = {
          iterator: values(iterable),
          resultName: resultName,
          nextLoc: nextLoc
        };

        if (this.method === "next") {
          // Deliberately forget the last sent value so that we don't
          // accidentally pass it on to the delegate.
          this.arg = undefined$1;
        }

        return ContinueSentinel;
      }
    };

    // Regardless of whether this script is executing as a CommonJS module
    // or not, return the runtime object so that we can declare the variable
    // regeneratorRuntime in the outer scope, which allows this module to be
    // injected easily by `bin/regenerator --include-runtime script.js`.
    return exports;

  }(
    // If this script is executing as a CommonJS module, use module.exports
    // as the regeneratorRuntime namespace. Otherwise create a new empty
    // object. Either way, the resulting object will be used to initialize
    // the regeneratorRuntime variable at the top of this file.
    module.exports 
  ));

  try {
    regeneratorRuntime = runtime;
  } catch (accidentalStrictMode) {
    // This module should not be running in strict mode, so the above
    // assignment should always work unless something is misconfigured. Just
    // in case runtime.js accidentally runs in strict mode, in modern engines
    // we can explicitly access globalThis. In older engines we can escape
    // strict mode using a global Function call. This could conceivably fail
    // if a Content Security Policy forbids using Function, but in that case
    // the proper solution is to fix the accidental strict mode problem. If
    // you've misconfigured your bundler to force strict mode and applied a
    // CSP to forbid Function, and you're not willing to fix either of those
    // problems, please detail your unique predicament in a GitHub issue.
    if (typeof globalThis === "object") {
      globalThis.regeneratorRuntime = runtime;
    } else {
      Function("r", "regeneratorRuntime = r")(runtime);
    }
  }
  });

  var regenerator = runtime_1;

  var xml = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.SvgAst=SvgAst;exports.SvgXml=SvgXml;exports.fetchText=fetchText;exports.SvgUri=SvgUri;exports.getStyle=getStyle;exports.astToReact=astToReact;exports.parse=_parse;exports.camelCase=exports.SvgFromUri=exports.SvgFromXml=exports.err=exports.tags=void 0;var _classCallCheck2=interopRequireDefault(classCallCheck);var _createClass2=interopRequireDefault(createClass);var _possibleConstructorReturn2=interopRequireDefault(possibleConstructorReturn);var _getPrototypeOf4=interopRequireDefault(getPrototypeOf);var _assertThisInitialized2=interopRequireDefault(assertThisInitialized);var _inherits2=interopRequireDefault(inherits);var _defineProperty2=interopRequireDefault(defineProperty);var _slicedToArray2=interopRequireDefault(slicedToArray);var _regenerator=interopRequireDefault(regenerator);var _extends2=interopRequireDefault(_extends_1);var _react=interopRequireWildcard(React__default["default"]);var _Rect=interopRequireDefault(Rect_1);var _Circle=interopRequireDefault(Circle_1);var _Ellipse=interopRequireDefault(Ellipse_1);var _Polygon=interopRequireDefault(Polygon_1);var _Polyline=interopRequireDefault(Polyline_1);var _Line=interopRequireDefault(Line_1);var _Svg=interopRequireDefault(Svg_1);var _Path=interopRequireDefault(Path_1);var _G=interopRequireDefault(G_1);var _Text=interopRequireDefault(Text_1);var _TSpan=interopRequireDefault(TSpan_1);var _TextPath=interopRequireDefault(TextPath_1);var _Use=interopRequireDefault(Use_1);var _Image=interopRequireDefault(Image$1);var _Symbol$1=interopRequireDefault(_Symbol);var _Defs=interopRequireDefault(Defs_1);var _LinearGradient=interopRequireDefault(LinearGradient_1);var _RadialGradient=interopRequireDefault(RadialGradient_1);var _Stop=interopRequireDefault(Stop_1);var _ClipPath=interopRequireDefault(ClipPath_1);var _Pattern=interopRequireDefault(Pattern_1);var _Mask=interopRequireDefault(Mask_1);var _Marker=interopRequireDefault(Marker_1);var _jsxFileName="/Users/horcrux/Work/react-native-svg/src/xml.tsx";var tags={svg:_Svg.default,circle:_Circle.default,ellipse:_Ellipse.default,g:_G.default,text:_Text.default,tspan:_TSpan.default,textPath:_TextPath.default,path:_Path.default,polygon:_Polygon.default,polyline:_Polyline.default,line:_Line.default,rect:_Rect.default,use:_Use.default,image:_Image.default,symbol:_Symbol$1.default,defs:_Defs.default,linearGradient:_LinearGradient.default,radialGradient:_RadialGradient.default,stop:_Stop.default,clipPath:_ClipPath.default,pattern:_Pattern.default,mask:_Mask.default,marker:_Marker.default};exports.tags=tags;function missingTag(){return null;}function SvgAst(_ref){var ast=_ref.ast,override=_ref.override;if(!ast){return null;}var props=ast.props,children=ast.children;return _react.default.createElement(_Svg.default,(0, _extends2.default)({},props,override,{__source:{fileName:_jsxFileName,lineNumber:103}}),children);}var err=console.error.bind(console);exports.err=err;function SvgXml(props){var _props$onError=props.onError,onError=_props$onError===void 0?err:_props$onError,xml=props.xml,override=props.override;var ast=(0, _react.useMemo)(function(){return xml!==null?_parse(xml):null;},[xml]);try{return _react.default.createElement(SvgAst,{ast:ast,override:override||props,__source:{fileName:_jsxFileName,lineNumber:118}});}catch(error){onError(error);return null;}}function fetchText(uri){var response;return _regenerator.default.async(function fetchText$(_context){while(1){switch(_context.prev=_context.next){case 0:_context.next=2;return _regenerator.default.awrap(fetch(uri));case 2:response=_context.sent;_context.next=5;return _regenerator.default.awrap(response.text());case 5:return _context.abrupt("return",_context.sent);case 6:case"end":return _context.stop();}}},null,null,null,Promise);}function SvgUri(props){var _props$onError2=props.onError,onError=_props$onError2===void 0?err:_props$onError2,uri=props.uri;var _useState=(0, _react.useState)(null),_useState2=(0, _slicedToArray2.default)(_useState,2),xml=_useState2[0],setXml=_useState2[1];(0, _react.useEffect)(function(){uri?fetchText(uri).then(setXml).catch(onError):setXml(null);},[onError,uri]);return _react.default.createElement(SvgXml,{xml:xml,override:props,__source:{fileName:_jsxFileName,lineNumber:140}});}var SvgFromXml=function(_Component){(0, _inherits2.default)(SvgFromXml,_Component);function SvgFromXml(){var _getPrototypeOf2;var _this;(0, _classCallCheck2.default)(this,SvgFromXml);for(var _len=arguments.length,args=new Array(_len),_key=0;_key<_len;_key++){args[_key]=arguments[_key];}_this=(0, _possibleConstructorReturn2.default)(this,(_getPrototypeOf2=(0, _getPrototypeOf4.default)(SvgFromXml)).call.apply(_getPrototypeOf2,[this].concat(args)));(0, _defineProperty2.default)((0, _assertThisInitialized2.default)(_this),"state",{ast:null});return _this;}(0, _createClass2.default)(SvgFromXml,[{key:"componentDidMount",value:function componentDidMount(){this.parse(this.props.xml);}},{key:"componentDidUpdate",value:function componentDidUpdate(prevProps){var xml=this.props.xml;if(xml!==prevProps.xml){this.parse(xml);}}},{key:"parse",value:function parse(xml){try{this.setState({ast:xml?_parse(xml):null});}catch(e){console.error(e);}}},{key:"render",value:function render(){var props=this.props,ast=this.state.ast;return _react.default.createElement(SvgAst,{ast:ast,override:props.override||props,__source:{fileName:_jsxFileName,lineNumber:168}});}}]);return SvgFromXml;}(_react.Component);exports.SvgFromXml=SvgFromXml;var SvgFromUri=function(_Component2){(0, _inherits2.default)(SvgFromUri,_Component2);function SvgFromUri(){var _getPrototypeOf3;var _this2;(0, _classCallCheck2.default)(this,SvgFromUri);for(var _len3=arguments.length,args=new Array(_len3),_key3=0;_key3<_len3;_key3++){args[_key3]=arguments[_key3];}_this2=(0, _possibleConstructorReturn2.default)(this,(_getPrototypeOf3=(0, _getPrototypeOf4.default)(SvgFromUri)).call.apply(_getPrototypeOf3,[this].concat(args)));(0, _defineProperty2.default)((0, _assertThisInitialized2.default)(_this2),"state",{xml:null});return _this2;}(0, _createClass2.default)(SvgFromUri,[{key:"componentDidMount",value:function componentDidMount(){this.fetch(this.props.uri);}},{key:"componentDidUpdate",value:function componentDidUpdate(prevProps){var uri=this.props.uri;if(uri!==prevProps.uri){this.fetch(uri);}}},{key:"fetch",value:function fetch(uri){return _regenerator.default.async(function fetch$(_context2){while(1){switch(_context2.prev=_context2.next){case 0:_context2.prev=0;_context2.t0=this;if(!uri){_context2.next=8;break;}_context2.next=5;return _regenerator.default.awrap(fetchText(uri));case 5:_context2.t1=_context2.sent;_context2.next=9;break;case 8:_context2.t1=null;case 9:_context2.t2=_context2.t1;_context2.t3={xml:_context2.t2};_context2.t0.setState.call(_context2.t0,_context2.t3);_context2.next=17;break;case 14:_context2.prev=14;_context2.t4=_context2["catch"](0);console.error(_context2.t4);case 17:case"end":return _context2.stop();}}},null,this,[[0,14]],Promise);}},{key:"render",value:function render(){var props=this.props,xml=this.state.xml;return _react.default.createElement(SvgFromXml,{xml:xml,override:props,__source:{fileName:_jsxFileName,lineNumber:195}});}}]);return SvgFromUri;}(_react.Component);exports.SvgFromUri=SvgFromUri;var upperCase=function upperCase(_match,letter){return letter.toUpperCase();};var camelCase=function camelCase(phrase){return phrase.replace(/[:-]([a-z])/g,upperCase);};exports.camelCase=camelCase;function getStyle(string){var style={};var declarations=string.split(';');var length=declarations.length;for(var i=0;i<length;i++){var declaration=declarations[i];if(declaration.length!==0){var split=declaration.split(':');var _property=split[0];var value=split[1];style[camelCase(_property.trim())]=value.trim();}}return style;}function astToReact(value,index){if(typeof value==='object'){var Tag=value.Tag,props=value.props,children=value.children;return _react.default.createElement(Tag,(0, _extends2.default)({key:index},props,{__source:{fileName:_jsxFileName,lineNumber:229}}),children.map(astToReact));}return value;}function repeat(str,i){var result='';while(i--){result+=str;}return result;}var toSpaces=function toSpaces(tabs){return repeat('  ',tabs.length);};function locate(source,i){var lines=source.split('\n');var nLines=lines.length;var column=i;var line=0;for(;line<nLines;line++){var length=lines[line].length;if(column>=length){column-=length;}else {break;}}var before=source.slice(0,i).replace(/^\t+/,toSpaces);var beforeExec=/(^|\n).*$/.exec(before);var beforeLine=beforeExec&&beforeExec[0]||'';var after=source.slice(i);var afterExec=/.*(\n|$)/.exec(after);var afterLine=afterExec&&afterExec[0];var pad=repeat(' ',beforeLine.length);var snippet="".concat(beforeLine).concat(afterLine,"\n").concat(pad,"^");return {line:line,column:column,snippet:snippet};}var validNameCharacters=/[a-zA-Z0-9:_-]/;var whitespace=/[\s\t\r\n]/;var quotemarks=/['"]/;function _parse(source,middleware){var length=source.length;var currentElement=null;var state=metadata;var children=null;var root;var stack=[];function error(message){var _locate=locate(source,i),line=_locate.line,column=_locate.column,snippet=_locate.snippet;throw new Error("".concat(message," (").concat(line,":").concat(column,"). If this is valid SVG, it's probably a bug. Please raise an issue\n\n").concat(snippet));}function metadata(){while(i+1<length&&(source[i]!=='<'||!validNameCharacters.test(source[i+1]))){i++;}return neutral();}function neutral(){var text='';var char;while(i<length&&(char=source[i])!=='<'){text+=char;i+=1;}if(/\S/.test(text)){children.push(text);}if(source[i]==='<'){return openingTag;}return neutral;}function openingTag(){var char=source[i];if(char==='?'){return neutral;}if(char==='!'){var start=i+1;if(source.slice(start,i+3)==='--'){return comment;}var end=i+8;if(source.slice(start,end)==='[CDATA['){return cdata;}if(/doctype/i.test(source.slice(start,end))){return neutral;}}if(char==='/'){return closingTag;}var tag=getName();var props={};var element={tag:tag,props:props,children:[],parent:currentElement,Tag:tags[tag]||missingTag};if(currentElement){children.push(element);}else {root=element;}getAttributes(props);var style=props.style;if(typeof style==='string'){element.styles=style;props.style=getStyle(style);}var selfClosing=false;if(source[i]==='/'){i+=1;selfClosing=true;}if(source[i]!=='>'){error('Expected >');}if(!selfClosing){currentElement=element;children=element.children;stack.push(element);}return neutral;}function comment(){var index=source.indexOf('-->',i);if(!~index){error('expected -->');}i=index+2;return neutral;}function cdata(){var index=source.indexOf(']]>',i);if(!~index){error('expected ]]>');}children.push(source.slice(i+7,index));i=index+2;return neutral;}function closingTag(){var tag=getName();if(!tag){error('Expected tag name');}if(currentElement&&tag!==currentElement.tag){error("Expected closing tag </".concat(tag,"> to match opening tag <").concat(currentElement.tag,">"));}if(source[i]!=='>'){error('Expected >');}stack.pop();currentElement=stack[stack.length-1];if(currentElement){var _currentElement=currentElement;children=_currentElement.children;}return neutral;}function getName(){var name='';var char;while(i<length&&validNameCharacters.test(char=source[i])){name+=char;i+=1;}return name;}function getAttributes(props){while(i<length){if(!whitespace.test(source[i])){return;}allowSpaces();var name=getName();if(!name){return;}var value=true;allowSpaces();if(source[i]==='='){i+=1;allowSpaces();value=getAttributeValue();if(!isNaN(+value)&&value.trim()!==''){value=+value;}}props[camelCase(name)]=value;}}function getAttributeValue(){return quotemarks.test(source[i])?getQuotedAttributeValue():getUnquotedAttributeValue();}function getUnquotedAttributeValue(){var value='';do{var char=source[i];if(char===' '||char==='>'||char==='/'){return value;}value+=char;i+=1;}while(i<length);return value;}function getQuotedAttributeValue(){var quotemark=source[i++];var value='';var escaped=false;while(i<length){var char=source[i++];if(char===quotemark&&!escaped){return value;}if(char==='\\'&&!escaped){escaped=true;}value+=escaped?"\\".concat(char):char;escaped=false;}return value;}function allowSpaces(){while(i<length&&whitespace.test(source[i])){i+=1;}}var i=0;while(i<length){if(!state){error('Unexpected character');}state=state();i+=1;}if(state!==neutral){error('Unexpected end of input');}if(root){var xml=(middleware?middleware(root):root)||root;var _ast=xml.children.map(astToReact);var jsx=xml;jsx.children=_ast;return jsx;}return null;}

  });

  //
  //                              list
  //                            ┌──────┐
  //             ┌──────────────┼─head │
  //             │              │ tail─┼──────────────┐
  //             │              └──────┘              │
  //             ▼                                    ▼
  //            item        item        item        item
  //          ┌──────┐    ┌──────┐    ┌──────┐    ┌──────┐
  //  null ◀──┼─prev │◀───┼─prev │◀───┼─prev │◀───┼─prev │
  //          │ next─┼───▶│ next─┼───▶│ next─┼───▶│ next─┼──▶ null
  //          ├──────┤    ├──────┤    ├──────┤    ├──────┤
  //          │ data │    │ data │    │ data │    │ data │
  //          └──────┘    └──────┘    └──────┘    └──────┘
  //

  function createItem(data) {
      return {
          prev: null,
          next: null,
          data: data
      };
  }

  function allocateCursor(node, prev, next) {
      var cursor;

      if (cursors !== null) {
          cursor = cursors;
          cursors = cursors.cursor;
          cursor.prev = prev;
          cursor.next = next;
          cursor.cursor = node.cursor;
      } else {
          cursor = {
              prev: prev,
              next: next,
              cursor: node.cursor
          };
      }

      node.cursor = cursor;

      return cursor;
  }

  function releaseCursor(node) {
      var cursor = node.cursor;

      node.cursor = cursor.cursor;
      cursor.prev = null;
      cursor.next = null;
      cursor.cursor = cursors;
      cursors = cursor;
  }

  var cursors = null;
  var List = function() {
      this.cursor = null;
      this.head = null;
      this.tail = null;
  };

  List.createItem = createItem;
  List.prototype.createItem = createItem;

  List.prototype.updateCursors = function(prevOld, prevNew, nextOld, nextNew) {
      var cursor = this.cursor;

      while (cursor !== null) {
          if (cursor.prev === prevOld) {
              cursor.prev = prevNew;
          }

          if (cursor.next === nextOld) {
              cursor.next = nextNew;
          }

          cursor = cursor.cursor;
      }
  };

  List.prototype.getSize = function() {
      var size = 0;
      var cursor = this.head;

      while (cursor) {
          size++;
          cursor = cursor.next;
      }

      return size;
  };

  List.prototype.fromArray = function(array) {
      var cursor = null;

      this.head = null;

      for (var i = 0; i < array.length; i++) {
          var item = createItem(array[i]);

          if (cursor !== null) {
              cursor.next = item;
          } else {
              this.head = item;
          }

          item.prev = cursor;
          cursor = item;
      }

      this.tail = cursor;

      return this;
  };

  List.prototype.toArray = function() {
      var cursor = this.head;
      var result = [];

      while (cursor) {
          result.push(cursor.data);
          cursor = cursor.next;
      }

      return result;
  };

  List.prototype.toJSON = List.prototype.toArray;

  List.prototype.isEmpty = function() {
      return this.head === null;
  };

  List.prototype.first = function() {
      return this.head && this.head.data;
  };

  List.prototype.last = function() {
      return this.tail && this.tail.data;
  };

  List.prototype.each = function(fn, context) {
      var item;

      if (context === undefined) {
          context = this;
      }

      // push cursor
      var cursor = allocateCursor(this, null, this.head);

      while (cursor.next !== null) {
          item = cursor.next;
          cursor.next = item.next;

          fn.call(context, item.data, item, this);
      }

      // pop cursor
      releaseCursor(this);
  };

  List.prototype.forEach = List.prototype.each;

  List.prototype.eachRight = function(fn, context) {
      var item;

      if (context === undefined) {
          context = this;
      }

      // push cursor
      var cursor = allocateCursor(this, this.tail, null);

      while (cursor.prev !== null) {
          item = cursor.prev;
          cursor.prev = item.prev;

          fn.call(context, item.data, item, this);
      }

      // pop cursor
      releaseCursor(this);
  };

  List.prototype.forEachRight = List.prototype.eachRight;

  List.prototype.reduce = function(fn, initialValue, context) {
      var item;

      if (context === undefined) {
          context = this;
      }

      // push cursor
      var cursor = allocateCursor(this, null, this.head);
      var acc = initialValue;

      while (cursor.next !== null) {
          item = cursor.next;
          cursor.next = item.next;

          acc = fn.call(context, acc, item.data, item, this);
      }

      // pop cursor
      releaseCursor(this);

      return acc;
  };

  List.prototype.reduceRight = function(fn, initialValue, context) {
      var item;

      if (context === undefined) {
          context = this;
      }

      // push cursor
      var cursor = allocateCursor(this, this.tail, null);
      var acc = initialValue;

      while (cursor.prev !== null) {
          item = cursor.prev;
          cursor.prev = item.prev;

          acc = fn.call(context, acc, item.data, item, this);
      }

      // pop cursor
      releaseCursor(this);

      return acc;
  };

  List.prototype.nextUntil = function(start, fn, context) {
      if (start === null) {
          return;
      }

      var item;

      if (context === undefined) {
          context = this;
      }

      // push cursor
      var cursor = allocateCursor(this, null, start);

      while (cursor.next !== null) {
          item = cursor.next;
          cursor.next = item.next;

          if (fn.call(context, item.data, item, this)) {
              break;
          }
      }

      // pop cursor
      releaseCursor(this);
  };

  List.prototype.prevUntil = function(start, fn, context) {
      if (start === null) {
          return;
      }

      var item;

      if (context === undefined) {
          context = this;
      }

      // push cursor
      var cursor = allocateCursor(this, start, null);

      while (cursor.prev !== null) {
          item = cursor.prev;
          cursor.prev = item.prev;

          if (fn.call(context, item.data, item, this)) {
              break;
          }
      }

      // pop cursor
      releaseCursor(this);
  };

  List.prototype.some = function(fn, context) {
      var cursor = this.head;

      if (context === undefined) {
          context = this;
      }

      while (cursor !== null) {
          if (fn.call(context, cursor.data, cursor, this)) {
              return true;
          }

          cursor = cursor.next;
      }

      return false;
  };

  List.prototype.map = function(fn, context) {
      var result = new List();
      var cursor = this.head;

      if (context === undefined) {
          context = this;
      }

      while (cursor !== null) {
          result.appendData(fn.call(context, cursor.data, cursor, this));
          cursor = cursor.next;
      }

      return result;
  };

  List.prototype.filter = function(fn, context) {
      var result = new List();
      var cursor = this.head;

      if (context === undefined) {
          context = this;
      }

      while (cursor !== null) {
          if (fn.call(context, cursor.data, cursor, this)) {
              result.appendData(cursor.data);
          }
          cursor = cursor.next;
      }

      return result;
  };

  List.prototype.clear = function() {
      this.head = null;
      this.tail = null;
  };

  List.prototype.copy = function() {
      var result = new List();
      var cursor = this.head;

      while (cursor !== null) {
          result.insert(createItem(cursor.data));
          cursor = cursor.next;
      }

      return result;
  };

  List.prototype.prepend = function(item) {
      //      head
      //    ^
      // item
      this.updateCursors(null, item, this.head, item);

      // insert to the beginning of the list
      if (this.head !== null) {
          // new item <- first item
          this.head.prev = item;

          // new item -> first item
          item.next = this.head;
      } else {
          // if list has no head, then it also has no tail
          // in this case tail points to the new item
          this.tail = item;
      }

      // head always points to new item
      this.head = item;

      return this;
  };

  List.prototype.prependData = function(data) {
      return this.prepend(createItem(data));
  };

  List.prototype.append = function(item) {
      return this.insert(item);
  };

  List.prototype.appendData = function(data) {
      return this.insert(createItem(data));
  };

  List.prototype.insert = function(item, before) {
      if (before !== undefined && before !== null) {
          // prev   before
          //      ^
          //     item
          this.updateCursors(before.prev, item, before, item);

          if (before.prev === null) {
              // insert to the beginning of list
              if (this.head !== before) {
                  throw new Error('before doesn\'t belong to list');
              }

              // since head points to before therefore list doesn't empty
              // no need to check tail
              this.head = item;
              before.prev = item;
              item.next = before;

              this.updateCursors(null, item);
          } else {

              // insert between two items
              before.prev.next = item;
              item.prev = before.prev;

              before.prev = item;
              item.next = before;
          }
      } else {
          // tail
          //      ^
          //      item
          this.updateCursors(this.tail, item, null, item);

          // insert to the ending of the list
          if (this.tail !== null) {
              // last item -> new item
              this.tail.next = item;

              // last item <- new item
              item.prev = this.tail;
          } else {
              // if list has no tail, then it also has no head
              // in this case head points to new item
              this.head = item;
          }

          // tail always points to new item
          this.tail = item;
      }

      return this;
  };

  List.prototype.insertData = function(data, before) {
      return this.insert(createItem(data), before);
  };

  List.prototype.remove = function(item) {
      //      item
      //       ^
      // prev     next
      this.updateCursors(item, item.prev, item, item.next);

      if (item.prev !== null) {
          item.prev.next = item.next;
      } else {
          if (this.head !== item) {
              throw new Error('item doesn\'t belong to list');
          }

          this.head = item.next;
      }

      if (item.next !== null) {
          item.next.prev = item.prev;
      } else {
          if (this.tail !== item) {
              throw new Error('item doesn\'t belong to list');
          }

          this.tail = item.prev;
      }

      item.prev = null;
      item.next = null;

      return item;
  };

  List.prototype.push = function(data) {
      this.insert(createItem(data));
  };

  List.prototype.pop = function() {
      if (this.tail !== null) {
          return this.remove(this.tail);
      }
  };

  List.prototype.unshift = function(data) {
      this.prepend(createItem(data));
  };

  List.prototype.shift = function() {
      if (this.head !== null) {
          return this.remove(this.head);
      }
  };

  List.prototype.prependList = function(list) {
      return this.insertList(list, this.head);
  };

  List.prototype.appendList = function(list) {
      return this.insertList(list);
  };

  List.prototype.insertList = function(list, before) {
      // ignore empty lists
      if (list.head === null) {
          return this;
      }

      if (before !== undefined && before !== null) {
          this.updateCursors(before.prev, list.tail, before, list.head);

          // insert in the middle of dist list
          if (before.prev !== null) {
              // before.prev <-> list.head
              before.prev.next = list.head;
              list.head.prev = before.prev;
          } else {
              this.head = list.head;
          }

          before.prev = list.tail;
          list.tail.next = before;
      } else {
          this.updateCursors(this.tail, list.tail, null, list.head);

          // insert to end of the list
          if (this.tail !== null) {
              // if destination list has a tail, then it also has a head,
              // but head doesn't change

              // dest tail -> source head
              this.tail.next = list.head;

              // dest tail <- source head
              list.head.prev = this.tail;
          } else {
              // if list has no a tail, then it also has no a head
              // in this case points head to new item
              this.head = list.head;
          }

          // tail always start point to new item
          this.tail = list.tail;
      }

      list.head = null;
      list.tail = null;

      return this;
  };

  List.prototype.replace = function(oldItem, newItemOrList) {
      if ('head' in newItemOrList) {
          this.insertList(newItemOrList, oldItem);
      } else {
          this.insert(newItemOrList, oldItem);
      }

      this.remove(oldItem);
  };

  var List_1 = List;

  var createCustomError = function createCustomError(name, message) {
      // use Object.create(), because some VMs prevent setting line/column otherwise
      // (iOS Safari 10 even throws an exception)
      var error = Object.create(SyntaxError.prototype);
      var errorStack = new Error();

      error.name = name;
      error.message = message;

      Object.defineProperty(error, 'stack', {
          get: function() {
              return (errorStack.stack || '').replace(/^(.+\n){1,3}/, name + ': ' + message + '\n');
          }
      });

      return error;
  };

  var MAX_LINE_LENGTH = 100;
  var OFFSET_CORRECTION = 60;
  var TAB_REPLACEMENT = '    ';

  function sourceFragment(error, extraLines) {
      function processLines(start, end) {
          return lines.slice(start, end).map(function(line, idx) {
              var num = String(start + idx + 1);

              while (num.length < maxNumLength) {
                  num = ' ' + num;
              }

              return num + ' |' + line;
          }).join('\n');
      }

      var lines = error.source.split(/\r\n?|\n|\f/);
      var line = error.line;
      var column = error.column;
      var startLine = Math.max(1, line - extraLines) - 1;
      var endLine = Math.min(line + extraLines, lines.length + 1);
      var maxNumLength = Math.max(4, String(endLine).length) + 1;
      var cutLeft = 0;

      // column correction according to replaced tab before column
      column += (TAB_REPLACEMENT.length - 1) * (lines[line - 1].substr(0, column - 1).match(/\t/g) || []).length;

      if (column > MAX_LINE_LENGTH) {
          cutLeft = column - OFFSET_CORRECTION + 3;
          column = OFFSET_CORRECTION - 2;
      }

      for (var i = startLine; i <= endLine; i++) {
          if (i >= 0 && i < lines.length) {
              lines[i] = lines[i].replace(/\t/g, TAB_REPLACEMENT);
              lines[i] =
                  (cutLeft > 0 && lines[i].length > cutLeft ? '\u2026' : '') +
                  lines[i].substr(cutLeft, MAX_LINE_LENGTH - 2) +
                  (lines[i].length > cutLeft + MAX_LINE_LENGTH - 1 ? '\u2026' : '');
          }
      }

      return [
          processLines(startLine, line),
          new Array(column + maxNumLength + 2).join('-') + '^',
          processLines(line, endLine)
      ].filter(Boolean).join('\n');
  }

  var SyntaxError$1 = function(message, source, offset, line, column) {
      var error = createCustomError('SyntaxError', message);

      error.source = source;
      error.offset = offset;
      error.line = line;
      error.column = column;

      error.sourceFragment = function(extraLines) {
          return sourceFragment(error, isNaN(extraLines) ? 0 : extraLines);
      };
      Object.defineProperty(error, 'formattedMessage', {
          get: function() {
              return (
                  'Parse error: ' + error.message + '\n' +
                  sourceFragment(error, 2)
              );
          }
      });

      // for backward capability
      error.parseError = {
          offset: offset,
          line: line,
          column: column
      };

      return error;
  };

  var _SyntaxError$1 = SyntaxError$1;

  // CSS Syntax Module Level 3
  // https://www.w3.org/TR/css-syntax-3/
  var TYPE$H = {
      EOF: 0,                 // <EOF-token>
      Ident: 1,               // <ident-token>
      Function: 2,            // <function-token>
      AtKeyword: 3,           // <at-keyword-token>
      Hash: 4,                // <hash-token>
      String: 5,              // <string-token>
      BadString: 6,           // <bad-string-token>
      Url: 7,                 // <url-token>
      BadUrl: 8,              // <bad-url-token>
      Delim: 9,               // <delim-token>
      Number: 10,             // <number-token>
      Percentage: 11,         // <percentage-token>
      Dimension: 12,          // <dimension-token>
      WhiteSpace: 13,         // <whitespace-token>
      CDO: 14,                // <CDO-token>
      CDC: 15,                // <CDC-token>
      Colon: 16,              // <colon-token>     :
      Semicolon: 17,          // <semicolon-token> ;
      Comma: 18,              // <comma-token>     ,
      LeftSquareBracket: 19,  // <[-token>
      RightSquareBracket: 20, // <]-token>
      LeftParenthesis: 21,    // <(-token>
      RightParenthesis: 22,   // <)-token>
      LeftCurlyBracket: 23,   // <{-token>
      RightCurlyBracket: 24,  // <}-token>
      Comment: 25
  };

  var NAME$3 = Object.keys(TYPE$H).reduce(function(result, key) {
      result[TYPE$H[key]] = key;
      return result;
  }, {});

  var _const = {
      TYPE: TYPE$H,
      NAME: NAME$3
  };

  var EOF$1 = 0;

  // https://drafts.csswg.org/css-syntax-3/
  // § 4.2. Definitions

  // digit
  // A code point between U+0030 DIGIT ZERO (0) and U+0039 DIGIT NINE (9).
  function isDigit$5(code) {
      return code >= 0x0030 && code <= 0x0039;
  }

  // hex digit
  // A digit, or a code point between U+0041 LATIN CAPITAL LETTER A (A) and U+0046 LATIN CAPITAL LETTER F (F),
  // or a code point between U+0061 LATIN SMALL LETTER A (a) and U+0066 LATIN SMALL LETTER F (f).
  function isHexDigit$4(code) {
      return (
          isDigit$5(code) || // 0 .. 9
          (code >= 0x0041 && code <= 0x0046) || // A .. F
          (code >= 0x0061 && code <= 0x0066)    // a .. f
      );
  }

  // uppercase letter
  // A code point between U+0041 LATIN CAPITAL LETTER A (A) and U+005A LATIN CAPITAL LETTER Z (Z).
  function isUppercaseLetter$1(code) {
      return code >= 0x0041 && code <= 0x005A;
  }

  // lowercase letter
  // A code point between U+0061 LATIN SMALL LETTER A (a) and U+007A LATIN SMALL LETTER Z (z).
  function isLowercaseLetter(code) {
      return code >= 0x0061 && code <= 0x007A;
  }

  // letter
  // An uppercase letter or a lowercase letter.
  function isLetter(code) {
      return isUppercaseLetter$1(code) || isLowercaseLetter(code);
  }

  // non-ASCII code point
  // A code point with a value equal to or greater than U+0080 <control>.
  function isNonAscii(code) {
      return code >= 0x0080;
  }

  // name-start code point
  // A letter, a non-ASCII code point, or U+005F LOW LINE (_).
  function isNameStart(code) {
      return isLetter(code) || isNonAscii(code) || code === 0x005F;
  }

  // name code point
  // A name-start code point, a digit, or U+002D HYPHEN-MINUS (-).
  function isName$2(code) {
      return isNameStart(code) || isDigit$5(code) || code === 0x002D;
  }

  // non-printable code point
  // A code point between U+0000 NULL and U+0008 BACKSPACE, or U+000B LINE TABULATION,
  // or a code point between U+000E SHIFT OUT and U+001F INFORMATION SEPARATOR ONE, or U+007F DELETE.
  function isNonPrintable(code) {
      return (
          (code >= 0x0000 && code <= 0x0008) ||
          (code === 0x000B) ||
          (code >= 0x000E && code <= 0x001F) ||
          (code === 0x007F)
      );
  }

  // newline
  // U+000A LINE FEED. Note that U+000D CARRIAGE RETURN and U+000C FORM FEED are not included in this definition,
  // as they are converted to U+000A LINE FEED during preprocessing.
  // TODO: we doesn't do a preprocessing, so check a code point for U+000D CARRIAGE RETURN and U+000C FORM FEED
  function isNewline$1(code) {
      return code === 0x000A || code === 0x000D || code === 0x000C;
  }

  // whitespace
  // A newline, U+0009 CHARACTER TABULATION, or U+0020 SPACE.
  function isWhiteSpace$2(code) {
      return isNewline$1(code) || code === 0x0020 || code === 0x0009;
  }

  // § 4.3.8. Check if two code points are a valid escape
  function isValidEscape$2(first, second) {
      // If the first code point is not U+005C REVERSE SOLIDUS (\), return false.
      if (first !== 0x005C) {
          return false;
      }

      // Otherwise, if the second code point is a newline or EOF, return false.
      if (isNewline$1(second) || second === EOF$1) {
          return false;
      }

      // Otherwise, return true.
      return true;
  }

  // § 4.3.9. Check if three code points would start an identifier
  function isIdentifierStart$2(first, second, third) {
      // Look at the first code point:

      // U+002D HYPHEN-MINUS
      if (first === 0x002D) {
          // If the second code point is a name-start code point or a U+002D HYPHEN-MINUS,
          // or the second and third code points are a valid escape, return true. Otherwise, return false.
          return (
              isNameStart(second) ||
              second === 0x002D ||
              isValidEscape$2(second, third)
          );
      }

      // name-start code point
      if (isNameStart(first)) {
          // Return true.
          return true;
      }

      // U+005C REVERSE SOLIDUS (\)
      if (first === 0x005C) {
          // If the first and second code points are a valid escape, return true. Otherwise, return false.
          return isValidEscape$2(first, second);
      }

      // anything else
      // Return false.
      return false;
  }

  // § 4.3.10. Check if three code points would start a number
  function isNumberStart$1(first, second, third) {
      // Look at the first code point:

      // U+002B PLUS SIGN (+)
      // U+002D HYPHEN-MINUS (-)
      if (first === 0x002B || first === 0x002D) {
          // If the second code point is a digit, return true.
          if (isDigit$5(second)) {
              return 2;
          }

          // Otherwise, if the second code point is a U+002E FULL STOP (.)
          // and the third code point is a digit, return true.
          // Otherwise, return false.
          return second === 0x002E && isDigit$5(third) ? 3 : 0;
      }

      // U+002E FULL STOP (.)
      if (first === 0x002E) {
          // If the second code point is a digit, return true. Otherwise, return false.
          return isDigit$5(second) ? 2 : 0;
      }

      // digit
      if (isDigit$5(first)) {
          // Return true.
          return 1;
      }

      // anything else
      // Return false.
      return 0;
  }

  //
  // Misc
  //

  // detect BOM (https://en.wikipedia.org/wiki/Byte_order_mark)
  function isBOM$2(code) {
      // UTF-16BE
      if (code === 0xFEFF) {
          return 1;
      }

      // UTF-16LE
      if (code === 0xFFFE) {
          return 1;
      }

      return 0;
  }

  // Fast code category
  //
  // https://drafts.csswg.org/css-syntax/#tokenizer-definitions
  // > non-ASCII code point
  // >   A code point with a value equal to or greater than U+0080 <control>
  // > name-start code point
  // >   A letter, a non-ASCII code point, or U+005F LOW LINE (_).
  // > name code point
  // >   A name-start code point, a digit, or U+002D HYPHEN-MINUS (-)
  // That means only ASCII code points has a special meaning and we define a maps for 0..127 codes only
  var CATEGORY = new Array(0x80);
  charCodeCategory$1.Eof = 0x80;
  charCodeCategory$1.WhiteSpace = 0x82;
  charCodeCategory$1.Digit = 0x83;
  charCodeCategory$1.NameStart = 0x84;
  charCodeCategory$1.NonPrintable = 0x85;

  for (var i = 0; i < CATEGORY.length; i++) {
      switch (true) {
          case isWhiteSpace$2(i):
              CATEGORY[i] = charCodeCategory$1.WhiteSpace;
              break;

          case isDigit$5(i):
              CATEGORY[i] = charCodeCategory$1.Digit;
              break;

          case isNameStart(i):
              CATEGORY[i] = charCodeCategory$1.NameStart;
              break;

          case isNonPrintable(i):
              CATEGORY[i] = charCodeCategory$1.NonPrintable;
              break;

          default:
              CATEGORY[i] = i || charCodeCategory$1.Eof;
      }
  }

  function charCodeCategory$1(code) {
      return code < 0x80 ? CATEGORY[code] : charCodeCategory$1.NameStart;
  }
  var charCodeDefinitions = {
      isDigit: isDigit$5,
      isHexDigit: isHexDigit$4,
      isUppercaseLetter: isUppercaseLetter$1,
      isLowercaseLetter: isLowercaseLetter,
      isLetter: isLetter,
      isNonAscii: isNonAscii,
      isNameStart: isNameStart,
      isName: isName$2,
      isNonPrintable: isNonPrintable,
      isNewline: isNewline$1,
      isWhiteSpace: isWhiteSpace$2,
      isValidEscape: isValidEscape$2,
      isIdentifierStart: isIdentifierStart$2,
      isNumberStart: isNumberStart$1,

      isBOM: isBOM$2,
      charCodeCategory: charCodeCategory$1
  };

  var isDigit$4 = charCodeDefinitions.isDigit;
  var isHexDigit$3 = charCodeDefinitions.isHexDigit;
  var isUppercaseLetter = charCodeDefinitions.isUppercaseLetter;
  var isName$1 = charCodeDefinitions.isName;
  var isWhiteSpace$1 = charCodeDefinitions.isWhiteSpace;
  var isValidEscape$1 = charCodeDefinitions.isValidEscape;

  function getCharCode(source, offset) {
      return offset < source.length ? source.charCodeAt(offset) : 0;
  }

  function getNewlineLength$1(source, offset, code) {
      if (code === 13 /* \r */ && getCharCode(source, offset + 1) === 10 /* \n */) {
          return 2;
      }

      return 1;
  }

  function cmpChar$5(testStr, offset, referenceCode) {
      var code = testStr.charCodeAt(offset);

      // code.toLowerCase() for A..Z
      if (isUppercaseLetter(code)) {
          code = code | 32;
      }

      return code === referenceCode;
  }

  function cmpStr$6(testStr, start, end, referenceStr) {
      if (end - start !== referenceStr.length) {
          return false;
      }

      if (start < 0 || end > testStr.length) {
          return false;
      }

      for (var i = start; i < end; i++) {
          var testCode = testStr.charCodeAt(i);
          var referenceCode = referenceStr.charCodeAt(i - start);

          // testCode.toLowerCase() for A..Z
          if (isUppercaseLetter(testCode)) {
              testCode = testCode | 32;
          }

          if (testCode !== referenceCode) {
              return false;
          }
      }

      return true;
  }

  function findWhiteSpaceStart$1(source, offset) {
      for (; offset >= 0; offset--) {
          if (!isWhiteSpace$1(source.charCodeAt(offset))) {
              break;
          }
      }

      return offset + 1;
  }

  function findWhiteSpaceEnd$1(source, offset) {
      for (; offset < source.length; offset++) {
          if (!isWhiteSpace$1(source.charCodeAt(offset))) {
              break;
          }
      }

      return offset;
  }

  function findDecimalNumberEnd(source, offset) {
      for (; offset < source.length; offset++) {
          if (!isDigit$4(source.charCodeAt(offset))) {
              break;
          }
      }

      return offset;
  }

  // § 4.3.7. Consume an escaped code point
  function consumeEscaped$1(source, offset) {
      // It assumes that the U+005C REVERSE SOLIDUS (\) has already been consumed and
      // that the next input code point has already been verified to be part of a valid escape.
      offset += 2;

      // hex digit
      if (isHexDigit$3(getCharCode(source, offset - 1))) {
          // Consume as many hex digits as possible, but no more than 5.
          // Note that this means 1-6 hex digits have been consumed in total.
          for (var maxOffset = Math.min(source.length, offset + 5); offset < maxOffset; offset++) {
              if (!isHexDigit$3(getCharCode(source, offset))) {
                  break;
              }
          }

          // If the next input code point is whitespace, consume it as well.
          var code = getCharCode(source, offset);
          if (isWhiteSpace$1(code)) {
              offset += getNewlineLength$1(source, offset, code);
          }
      }

      return offset;
  }

  // §4.3.11. Consume a name
  // Note: This algorithm does not do the verification of the first few code points that are necessary
  // to ensure the returned code points would constitute an <ident-token>. If that is the intended use,
  // ensure that the stream starts with an identifier before calling this algorithm.
  function consumeName$1(source, offset) {
      // Let result initially be an empty string.
      // Repeatedly consume the next input code point from the stream:
      for (; offset < source.length; offset++) {
          var code = source.charCodeAt(offset);

          // name code point
          if (isName$1(code)) {
              // Append the code point to result.
              continue;
          }

          // the stream starts with a valid escape
          if (isValidEscape$1(code, getCharCode(source, offset + 1))) {
              // Consume an escaped code point. Append the returned code point to result.
              offset = consumeEscaped$1(source, offset) - 1;
              continue;
          }

          // anything else
          // Reconsume the current input code point. Return result.
          break;
      }

      return offset;
  }

  // §4.3.12. Consume a number
  function consumeNumber$5(source, offset) {
      var code = source.charCodeAt(offset);

      // 2. If the next input code point is U+002B PLUS SIGN (+) or U+002D HYPHEN-MINUS (-),
      // consume it and append it to repr.
      if (code === 0x002B || code === 0x002D) {
          code = source.charCodeAt(offset += 1);
      }

      // 3. While the next input code point is a digit, consume it and append it to repr.
      if (isDigit$4(code)) {
          offset = findDecimalNumberEnd(source, offset + 1);
          code = source.charCodeAt(offset);
      }

      // 4. If the next 2 input code points are U+002E FULL STOP (.) followed by a digit, then:
      if (code === 0x002E && isDigit$4(source.charCodeAt(offset + 1))) {
          // 4.1 Consume them.
          // 4.2 Append them to repr.
          code = source.charCodeAt(offset += 2);

          // 4.3 Set type to "number".
          // TODO

          // 4.4 While the next input code point is a digit, consume it and append it to repr.

          offset = findDecimalNumberEnd(source, offset);
      }

      // 5. If the next 2 or 3 input code points are U+0045 LATIN CAPITAL LETTER E (E)
      // or U+0065 LATIN SMALL LETTER E (e), ... , followed by a digit, then:
      if (cmpChar$5(source, offset, 101 /* e */)) {
          var sign = 0;
          code = source.charCodeAt(offset + 1);

          // ... optionally followed by U+002D HYPHEN-MINUS (-) or U+002B PLUS SIGN (+) ...
          if (code === 0x002D || code === 0x002B) {
              sign = 1;
              code = source.charCodeAt(offset + 2);
          }

          // ... followed by a digit
          if (isDigit$4(code)) {
              // 5.1 Consume them.
              // 5.2 Append them to repr.

              // 5.3 Set type to "number".
              // TODO

              // 5.4 While the next input code point is a digit, consume it and append it to repr.
              offset = findDecimalNumberEnd(source, offset + 1 + sign + 1);
          }
      }

      return offset;
  }

  // § 4.3.14. Consume the remnants of a bad url
  // ... its sole use is to consume enough of the input stream to reach a recovery point
  // where normal tokenizing can resume.
  function consumeBadUrlRemnants$1(source, offset) {
      // Repeatedly consume the next input code point from the stream:
      for (; offset < source.length; offset++) {
          var code = source.charCodeAt(offset);

          // U+0029 RIGHT PARENTHESIS ())
          // EOF
          if (code === 0x0029) {
              // Return.
              offset++;
              break;
          }

          if (isValidEscape$1(code, getCharCode(source, offset + 1))) {
              // Consume an escaped code point.
              // Note: This allows an escaped right parenthesis ("\)") to be encountered
              // without ending the <bad-url-token>. This is otherwise identical to
              // the "anything else" clause.
              offset = consumeEscaped$1(source, offset);
          }
      }

      return offset;
  }

  var utils = {
      consumeEscaped: consumeEscaped$1,
      consumeName: consumeName$1,
      consumeNumber: consumeNumber$5,
      consumeBadUrlRemnants: consumeBadUrlRemnants$1,

      cmpChar: cmpChar$5,
      cmpStr: cmpStr$6,

      getNewlineLength: getNewlineLength$1,
      findWhiteSpaceStart: findWhiteSpaceStart$1,
      findWhiteSpaceEnd: findWhiteSpaceEnd$1
  };

  var TYPE$G = _const.TYPE;
  var NAME$2 = _const.NAME;


  var cmpStr$5 = utils.cmpStr;

  var EOF = TYPE$G.EOF;
  var WHITESPACE$c = TYPE$G.WhiteSpace;
  var COMMENT$a = TYPE$G.Comment;

  var OFFSET_MASK$1 = 0x00FFFFFF;
  var TYPE_SHIFT$1 = 24;

  var TokenStream = function() {
      this.offsetAndType = null;
      this.balance = null;

      this.reset();
  };

  TokenStream.prototype = {
      reset: function() {
          this.eof = false;
          this.tokenIndex = -1;
          this.tokenType = 0;
          this.tokenStart = this.firstCharOffset;
          this.tokenEnd = this.firstCharOffset;
      },

      lookupType: function(offset) {
          offset += this.tokenIndex;

          if (offset < this.tokenCount) {
              return this.offsetAndType[offset] >> TYPE_SHIFT$1;
          }

          return EOF;
      },
      lookupOffset: function(offset) {
          offset += this.tokenIndex;

          if (offset < this.tokenCount) {
              return this.offsetAndType[offset - 1] & OFFSET_MASK$1;
          }

          return this.source.length;
      },
      lookupValue: function(offset, referenceStr) {
          offset += this.tokenIndex;

          if (offset < this.tokenCount) {
              return cmpStr$5(
                  this.source,
                  this.offsetAndType[offset - 1] & OFFSET_MASK$1,
                  this.offsetAndType[offset] & OFFSET_MASK$1,
                  referenceStr
              );
          }

          return false;
      },
      getTokenStart: function(tokenIndex) {
          if (tokenIndex === this.tokenIndex) {
              return this.tokenStart;
          }

          if (tokenIndex > 0) {
              return tokenIndex < this.tokenCount
                  ? this.offsetAndType[tokenIndex - 1] & OFFSET_MASK$1
                  : this.offsetAndType[this.tokenCount] & OFFSET_MASK$1;
          }

          return this.firstCharOffset;
      },

      // TODO: -> skipUntilBalanced
      getRawLength: function(startToken, mode) {
          var cursor = startToken;
          var balanceEnd;
          var offset = this.offsetAndType[Math.max(cursor - 1, 0)] & OFFSET_MASK$1;
          var type;

          loop:
          for (; cursor < this.tokenCount; cursor++) {
              balanceEnd = this.balance[cursor];

              // stop scanning on balance edge that points to offset before start token
              if (balanceEnd < startToken) {
                  break loop;
              }

              type = this.offsetAndType[cursor] >> TYPE_SHIFT$1;

              // check token is stop type
              switch (mode(type, this.source, offset)) {
                  case 1:
                      break loop;

                  case 2:
                      cursor++;
                      break loop;

                  default:
                      // fast forward to the end of balanced block
                      if (this.balance[balanceEnd] === cursor) {
                          cursor = balanceEnd;
                      }

                      offset = this.offsetAndType[cursor] & OFFSET_MASK$1;
              }
          }

          return cursor - this.tokenIndex;
      },
      isBalanceEdge: function(pos) {
          return this.balance[this.tokenIndex] < pos;
      },
      isDelim: function(code, offset) {
          if (offset) {
              return (
                  this.lookupType(offset) === TYPE$G.Delim &&
                  this.source.charCodeAt(this.lookupOffset(offset)) === code
              );
          }

          return (
              this.tokenType === TYPE$G.Delim &&
              this.source.charCodeAt(this.tokenStart) === code
          );
      },

      getTokenValue: function() {
          return this.source.substring(this.tokenStart, this.tokenEnd);
      },
      getTokenLength: function() {
          return this.tokenEnd - this.tokenStart;
      },
      substrToCursor: function(start) {
          return this.source.substring(start, this.tokenStart);
      },

      skipWS: function() {
          for (var i = this.tokenIndex, skipTokenCount = 0; i < this.tokenCount; i++, skipTokenCount++) {
              if ((this.offsetAndType[i] >> TYPE_SHIFT$1) !== WHITESPACE$c) {
                  break;
              }
          }

          if (skipTokenCount > 0) {
              this.skip(skipTokenCount);
          }
      },
      skipSC: function() {
          while (this.tokenType === WHITESPACE$c || this.tokenType === COMMENT$a) {
              this.next();
          }
      },
      skip: function(tokenCount) {
          var next = this.tokenIndex + tokenCount;

          if (next < this.tokenCount) {
              this.tokenIndex = next;
              this.tokenStart = this.offsetAndType[next - 1] & OFFSET_MASK$1;
              next = this.offsetAndType[next];
              this.tokenType = next >> TYPE_SHIFT$1;
              this.tokenEnd = next & OFFSET_MASK$1;
          } else {
              this.tokenIndex = this.tokenCount;
              this.next();
          }
      },
      next: function() {
          var next = this.tokenIndex + 1;

          if (next < this.tokenCount) {
              this.tokenIndex = next;
              this.tokenStart = this.tokenEnd;
              next = this.offsetAndType[next];
              this.tokenType = next >> TYPE_SHIFT$1;
              this.tokenEnd = next & OFFSET_MASK$1;
          } else {
              this.tokenIndex = this.tokenCount;
              this.eof = true;
              this.tokenType = EOF;
              this.tokenStart = this.tokenEnd = this.source.length;
          }
      },

      forEachToken(fn) {
          for (var i = 0, offset = this.firstCharOffset; i < this.tokenCount; i++) {
              var start = offset;
              var item = this.offsetAndType[i];
              var end = item & OFFSET_MASK$1;
              var type = item >> TYPE_SHIFT$1;

              offset = end;

              fn(type, start, end, i);
          }
      },

      dump() {
          var tokens = new Array(this.tokenCount);

          this.forEachToken((type, start, end, index) => {
              tokens[index] = {
                  idx: index,
                  type: NAME$2[type],
                  chunk: this.source.substring(start, end),
                  balance: this.balance[index]
              };
          });

          return tokens;
      }
  };

  var TokenStream_1 = TokenStream;

  function noop$3(value) {
      return value;
  }

  function generateMultiplier(multiplier) {
      if (multiplier.min === 0 && multiplier.max === 0) {
          return '*';
      }

      if (multiplier.min === 0 && multiplier.max === 1) {
          return '?';
      }

      if (multiplier.min === 1 && multiplier.max === 0) {
          return multiplier.comma ? '#' : '+';
      }

      if (multiplier.min === 1 && multiplier.max === 1) {
          return '';
      }

      return (
          (multiplier.comma ? '#' : '') +
          (multiplier.min === multiplier.max
              ? '{' + multiplier.min + '}'
              : '{' + multiplier.min + ',' + (multiplier.max !== 0 ? multiplier.max : '') + '}'
          )
      );
  }

  function generateTypeOpts(node) {
      switch (node.type) {
          case 'Range':
              return (
                  ' [' +
                  (node.min === null ? '-∞' : node.min) +
                  ',' +
                  (node.max === null ? '∞' : node.max) +
                  ']'
              );

          default:
              throw new Error('Unknown node type `' + node.type + '`');
      }
  }

  function generateSequence(node, decorate, forceBraces, compact) {
      var combinator = node.combinator === ' ' || compact ? node.combinator : ' ' + node.combinator + ' ';
      var result = node.terms.map(function(term) {
          return generate(term, decorate, forceBraces, compact);
      }).join(combinator);

      if (node.explicit || forceBraces) {
          result = (compact || result[0] === ',' ? '[' : '[ ') + result + (compact ? ']' : ' ]');
      }

      return result;
  }

  function generate(node, decorate, forceBraces, compact) {
      var result;

      switch (node.type) {
          case 'Group':
              result =
                  generateSequence(node, decorate, forceBraces, compact) +
                  (node.disallowEmpty ? '!' : '');
              break;

          case 'Multiplier':
              // return since node is a composition
              return (
                  generate(node.term, decorate, forceBraces, compact) +
                  decorate(generateMultiplier(node), node)
              );

          case 'Type':
              result = '<' + node.name + (node.opts ? decorate(generateTypeOpts(node.opts), node.opts) : '') + '>';
              break;

          case 'Property':
              result = '<\'' + node.name + '\'>';
              break;

          case 'Keyword':
              result = node.name;
              break;

          case 'AtKeyword':
              result = '@' + node.name;
              break;

          case 'Function':
              result = node.name + '(';
              break;

          case 'String':
          case 'Token':
              result = node.value;
              break;

          case 'Comma':
              result = ',';
              break;

          default:
              throw new Error('Unknown node type `' + node.type + '`');
      }

      return decorate(result, node);
  }

  var generate_1 = function(node, options) {
      var decorate = noop$3;
      var forceBraces = false;
      var compact = false;

      if (typeof options === 'function') {
          decorate = options;
      } else if (options) {
          forceBraces = Boolean(options.forceBraces);
          compact = Boolean(options.compact);
          if (typeof options.decorate === 'function') {
              decorate = options.decorate;
          }
      }

      return generate(node, decorate, forceBraces, compact);
  };

  const defaultLoc = { offset: 0, line: 1, column: 1 };

  function locateMismatch(matchResult, node) {
      const tokens = matchResult.tokens;
      const longestMatch = matchResult.longestMatch;
      const mismatchNode = longestMatch < tokens.length ? tokens[longestMatch].node || null : null;
      const badNode = mismatchNode !== node ? mismatchNode : null;
      let mismatchOffset = 0;
      let mismatchLength = 0;
      let entries = 0;
      let css = '';
      let start;
      let end;

      for (let i = 0; i < tokens.length; i++) {
          const token = tokens[i].value;

          if (i === longestMatch) {
              mismatchLength = token.length;
              mismatchOffset = css.length;
          }

          if (badNode !== null && tokens[i].node === badNode) {
              if (i <= longestMatch) {
                  entries++;
              } else {
                  entries = 0;
              }
          }

          css += token;
      }

      if (longestMatch === tokens.length || entries > 1) { // last
          start = fromLoc(badNode || node, 'end') || buildLoc(defaultLoc, css);
          end = buildLoc(start);
      } else {
          start = fromLoc(badNode, 'start') ||
              buildLoc(fromLoc(node, 'start') || defaultLoc, css.slice(0, mismatchOffset));
          end = fromLoc(badNode, 'end') ||
              buildLoc(start, css.substr(mismatchOffset, mismatchLength));
      }

      return {
          css,
          mismatchOffset,
          mismatchLength,
          start,
          end
      };
  }

  function fromLoc(node, point) {
      const value = node && node.loc && node.loc[point];

      if (value) {
          return 'line' in value ? buildLoc(value) : value;
      }

      return null;
  }

  function buildLoc({ offset, line, column }, extra) {
      const loc = {
          offset,
          line,
          column
      };

      if (extra) {
          const lines = extra.split(/\n|\r\n?|\f/);

          loc.offset += extra.length;
          loc.line += lines.length - 1;
          loc.column = lines.length === 1 ? loc.column + extra.length : lines.pop().length + 1;
      }

      return loc;
  }

  const SyntaxReferenceError$1 = function(type, referenceName) {
      const error = createCustomError(
          'SyntaxReferenceError',
          type + (referenceName ? ' `' + referenceName + '`' : '')
      );

      error.reference = referenceName;

      return error;
  };

  const SyntaxMatchError$1 = function(message, syntax, node, matchResult) {
      const error = createCustomError('SyntaxMatchError', message);
      const {
          css,
          mismatchOffset,
          mismatchLength,
          start,
          end
      } = locateMismatch(matchResult, node);

      error.rawMessage = message;
      error.syntax = syntax ? generate_1(syntax) : '<generic>';
      error.css = css;
      error.mismatchOffset = mismatchOffset;
      error.mismatchLength = mismatchLength;
      error.message = message + '\n' +
          '  syntax: ' + error.syntax + '\n' +
          '   value: ' + (css || '<empty string>') + '\n' +
          '  --------' + new Array(error.mismatchOffset + 1).join('-') + '^';

      Object.assign(error, start);
      error.loc = {
          source: (node && node.loc && node.loc.source) || '<unknown>',
          start,
          end
      };

      return error;
  };

  var error = {
      SyntaxReferenceError: SyntaxReferenceError$1,
      SyntaxMatchError: SyntaxMatchError$1
  };

  var hasOwnProperty$7 = Object.prototype.hasOwnProperty;
  var keywords$1 = Object.create(null);
  var properties$1 = Object.create(null);
  var HYPHENMINUS$5 = 45; // '-'.charCodeAt()

  function isCustomProperty$1(str, offset) {
      offset = offset || 0;

      return str.length - offset >= 2 &&
             str.charCodeAt(offset) === HYPHENMINUS$5 &&
             str.charCodeAt(offset + 1) === HYPHENMINUS$5;
  }

  function getVendorPrefix(str, offset) {
      offset = offset || 0;

      // verdor prefix should be at least 3 chars length
      if (str.length - offset >= 3) {
          // vendor prefix starts with hyper minus following non-hyper minus
          if (str.charCodeAt(offset) === HYPHENMINUS$5 &&
              str.charCodeAt(offset + 1) !== HYPHENMINUS$5) {
              // vendor prefix should contain a hyper minus at the ending
              var secondDashIndex = str.indexOf('-', offset + 2);

              if (secondDashIndex !== -1) {
                  return str.substring(offset, secondDashIndex + 1);
              }
          }
      }

      return '';
  }

  function getKeywordDescriptor(keyword) {
      if (hasOwnProperty$7.call(keywords$1, keyword)) {
          return keywords$1[keyword];
      }

      var name = keyword.toLowerCase();

      if (hasOwnProperty$7.call(keywords$1, name)) {
          return keywords$1[keyword] = keywords$1[name];
      }

      var custom = isCustomProperty$1(name, 0);
      var vendor = !custom ? getVendorPrefix(name, 0) : '';

      return keywords$1[keyword] = Object.freeze({
          basename: name.substr(vendor.length),
          name: name,
          vendor: vendor,
          prefix: vendor,
          custom: custom
      });
  }

  function getPropertyDescriptor(property) {
      if (hasOwnProperty$7.call(properties$1, property)) {
          return properties$1[property];
      }

      var name = property;
      var hack = property[0];

      if (hack === '/') {
          hack = property[1] === '/' ? '//' : '/';
      } else if (hack !== '_' &&
                 hack !== '*' &&
                 hack !== '$' &&
                 hack !== '#' &&
                 hack !== '+' &&
                 hack !== '&') {
          hack = '';
      }

      var custom = isCustomProperty$1(name, hack.length);

      // re-use result when possible (the same as for lower case)
      if (!custom) {
          name = name.toLowerCase();
          if (hasOwnProperty$7.call(properties$1, name)) {
              return properties$1[property] = properties$1[name];
          }
      }

      var vendor = !custom ? getVendorPrefix(name, hack.length) : '';
      var prefix = name.substr(0, hack.length + vendor.length);

      return properties$1[property] = Object.freeze({
          basename: name.substr(prefix.length),
          name: name.substr(hack.length),
          hack: hack,
          vendor: vendor,
          prefix: prefix,
          custom: custom
      });
  }

  var names = {
      keyword: getKeywordDescriptor,
      property: getPropertyDescriptor,
      isCustomProperty: isCustomProperty$1,
      vendorPrefix: getVendorPrefix
  };

  var MIN_SIZE = 16 * 1024;
  var SafeUint32Array = typeof Uint32Array !== 'undefined' ? Uint32Array : Array; // fallback on Array when TypedArray is not supported

  var adoptBuffer = function adoptBuffer(buffer, size) {
      if (buffer === null || buffer.length < size) {
          return new SafeUint32Array(Math.max(size + 1024, MIN_SIZE));
      }

      return buffer;
  };

  var TYPE$F = _const.TYPE;


  var isNewline = charCodeDefinitions.isNewline;
  var isName = charCodeDefinitions.isName;
  var isValidEscape = charCodeDefinitions.isValidEscape;
  var isNumberStart = charCodeDefinitions.isNumberStart;
  var isIdentifierStart$1 = charCodeDefinitions.isIdentifierStart;
  var charCodeCategory = charCodeDefinitions.charCodeCategory;
  var isBOM$1 = charCodeDefinitions.isBOM;


  var cmpStr$4 = utils.cmpStr;
  var getNewlineLength = utils.getNewlineLength;
  var findWhiteSpaceEnd = utils.findWhiteSpaceEnd;
  var consumeEscaped = utils.consumeEscaped;
  var consumeName = utils.consumeName;
  var consumeNumber$4 = utils.consumeNumber;
  var consumeBadUrlRemnants = utils.consumeBadUrlRemnants;

  var OFFSET_MASK = 0x00FFFFFF;
  var TYPE_SHIFT = 24;

  function tokenize(source, stream) {
      function getCharCode(offset) {
          return offset < sourceLength ? source.charCodeAt(offset) : 0;
      }

      // § 4.3.3. Consume a numeric token
      function consumeNumericToken() {
          // Consume a number and let number be the result.
          offset = consumeNumber$4(source, offset);

          // If the next 3 input code points would start an identifier, then:
          if (isIdentifierStart$1(getCharCode(offset), getCharCode(offset + 1), getCharCode(offset + 2))) {
              // Create a <dimension-token> with the same value and type flag as number, and a unit set initially to the empty string.
              // Consume a name. Set the <dimension-token>’s unit to the returned value.
              // Return the <dimension-token>.
              type = TYPE$F.Dimension;
              offset = consumeName(source, offset);
              return;
          }

          // Otherwise, if the next input code point is U+0025 PERCENTAGE SIGN (%), consume it.
          if (getCharCode(offset) === 0x0025) {
              // Create a <percentage-token> with the same value as number, and return it.
              type = TYPE$F.Percentage;
              offset++;
              return;
          }

          // Otherwise, create a <number-token> with the same value and type flag as number, and return it.
          type = TYPE$F.Number;
      }

      // § 4.3.4. Consume an ident-like token
      function consumeIdentLikeToken() {
          const nameStartOffset = offset;

          // Consume a name, and let string be the result.
          offset = consumeName(source, offset);

          // If string’s value is an ASCII case-insensitive match for "url",
          // and the next input code point is U+0028 LEFT PARENTHESIS ((), consume it.
          if (cmpStr$4(source, nameStartOffset, offset, 'url') && getCharCode(offset) === 0x0028) {
              // While the next two input code points are whitespace, consume the next input code point.
              offset = findWhiteSpaceEnd(source, offset + 1);

              // If the next one or two input code points are U+0022 QUOTATION MARK ("), U+0027 APOSTROPHE ('),
              // or whitespace followed by U+0022 QUOTATION MARK (") or U+0027 APOSTROPHE ('),
              // then create a <function-token> with its value set to string and return it.
              if (getCharCode(offset) === 0x0022 ||
                  getCharCode(offset) === 0x0027) {
                  type = TYPE$F.Function;
                  offset = nameStartOffset + 4;
                  return;
              }

              // Otherwise, consume a url token, and return it.
              consumeUrlToken();
              return;
          }

          // Otherwise, if the next input code point is U+0028 LEFT PARENTHESIS ((), consume it.
          // Create a <function-token> with its value set to string and return it.
          if (getCharCode(offset) === 0x0028) {
              type = TYPE$F.Function;
              offset++;
              return;
          }

          // Otherwise, create an <ident-token> with its value set to string and return it.
          type = TYPE$F.Ident;
      }

      // § 4.3.5. Consume a string token
      function consumeStringToken(endingCodePoint) {
          // This algorithm may be called with an ending code point, which denotes the code point
          // that ends the string. If an ending code point is not specified,
          // the current input code point is used.
          if (!endingCodePoint) {
              endingCodePoint = getCharCode(offset++);
          }

          // Initially create a <string-token> with its value set to the empty string.
          type = TYPE$F.String;

          // Repeatedly consume the next input code point from the stream:
          for (; offset < source.length; offset++) {
              var code = source.charCodeAt(offset);

              switch (charCodeCategory(code)) {
                  // ending code point
                  case endingCodePoint:
                      // Return the <string-token>.
                      offset++;
                      return;

                  // EOF
                  case charCodeCategory.Eof:
                      // This is a parse error. Return the <string-token>.
                      return;

                  // newline
                  case charCodeCategory.WhiteSpace:
                      if (isNewline(code)) {
                          // This is a parse error. Reconsume the current input code point,
                          // create a <bad-string-token>, and return it.
                          offset += getNewlineLength(source, offset, code);
                          type = TYPE$F.BadString;
                          return;
                      }
                      break;

                  // U+005C REVERSE SOLIDUS (\)
                  case 0x005C:
                      // If the next input code point is EOF, do nothing.
                      if (offset === source.length - 1) {
                          break;
                      }

                      var nextCode = getCharCode(offset + 1);

                      // Otherwise, if the next input code point is a newline, consume it.
                      if (isNewline(nextCode)) {
                          offset += getNewlineLength(source, offset + 1, nextCode);
                      } else if (isValidEscape(code, nextCode)) {
                          // Otherwise, (the stream starts with a valid escape) consume
                          // an escaped code point and append the returned code point to
                          // the <string-token>’s value.
                          offset = consumeEscaped(source, offset) - 1;
                      }
                      break;

                  // anything else
                  // Append the current input code point to the <string-token>’s value.
              }
          }
      }

      // § 4.3.6. Consume a url token
      // Note: This algorithm assumes that the initial "url(" has already been consumed.
      // This algorithm also assumes that it’s being called to consume an "unquoted" value, like url(foo).
      // A quoted value, like url("foo"), is parsed as a <function-token>. Consume an ident-like token
      // automatically handles this distinction; this algorithm shouldn’t be called directly otherwise.
      function consumeUrlToken() {
          // Initially create a <url-token> with its value set to the empty string.
          type = TYPE$F.Url;

          // Consume as much whitespace as possible.
          offset = findWhiteSpaceEnd(source, offset);

          // Repeatedly consume the next input code point from the stream:
          for (; offset < source.length; offset++) {
              var code = source.charCodeAt(offset);

              switch (charCodeCategory(code)) {
                  // U+0029 RIGHT PARENTHESIS ())
                  case 0x0029:
                      // Return the <url-token>.
                      offset++;
                      return;

                  // EOF
                  case charCodeCategory.Eof:
                      // This is a parse error. Return the <url-token>.
                      return;

                  // whitespace
                  case charCodeCategory.WhiteSpace:
                      // Consume as much whitespace as possible.
                      offset = findWhiteSpaceEnd(source, offset);

                      // If the next input code point is U+0029 RIGHT PARENTHESIS ()) or EOF,
                      // consume it and return the <url-token>
                      // (if EOF was encountered, this is a parse error);
                      if (getCharCode(offset) === 0x0029 || offset >= source.length) {
                          if (offset < source.length) {
                              offset++;
                          }
                          return;
                      }

                      // otherwise, consume the remnants of a bad url, create a <bad-url-token>,
                      // and return it.
                      offset = consumeBadUrlRemnants(source, offset);
                      type = TYPE$F.BadUrl;
                      return;

                  // U+0022 QUOTATION MARK (")
                  // U+0027 APOSTROPHE (')
                  // U+0028 LEFT PARENTHESIS (()
                  // non-printable code point
                  case 0x0022:
                  case 0x0027:
                  case 0x0028:
                  case charCodeCategory.NonPrintable:
                      // This is a parse error. Consume the remnants of a bad url,
                      // create a <bad-url-token>, and return it.
                      offset = consumeBadUrlRemnants(source, offset);
                      type = TYPE$F.BadUrl;
                      return;

                  // U+005C REVERSE SOLIDUS (\)
                  case 0x005C:
                      // If the stream starts with a valid escape, consume an escaped code point and
                      // append the returned code point to the <url-token>’s value.
                      if (isValidEscape(code, getCharCode(offset + 1))) {
                          offset = consumeEscaped(source, offset) - 1;
                          break;
                      }

                      // Otherwise, this is a parse error. Consume the remnants of a bad url,
                      // create a <bad-url-token>, and return it.
                      offset = consumeBadUrlRemnants(source, offset);
                      type = TYPE$F.BadUrl;
                      return;

                  // anything else
                  // Append the current input code point to the <url-token>’s value.
              }
          }
      }

      if (!stream) {
          stream = new TokenStream_1();
      }

      // ensure source is a string
      source = String(source || '');

      var sourceLength = source.length;
      var offsetAndType = adoptBuffer(stream.offsetAndType, sourceLength + 1); // +1 because of eof-token
      var balance = adoptBuffer(stream.balance, sourceLength + 1);
      var tokenCount = 0;
      var start = isBOM$1(getCharCode(0));
      var offset = start;
      var balanceCloseType = 0;
      var balanceStart = 0;
      var balancePrev = 0;

      // https://drafts.csswg.org/css-syntax-3/#consume-token
      // § 4.3.1. Consume a token
      while (offset < sourceLength) {
          var code = source.charCodeAt(offset);
          var type = 0;

          balance[tokenCount] = sourceLength;

          switch (charCodeCategory(code)) {
              // whitespace
              case charCodeCategory.WhiteSpace:
                  // Consume as much whitespace as possible. Return a <whitespace-token>.
                  type = TYPE$F.WhiteSpace;
                  offset = findWhiteSpaceEnd(source, offset + 1);
                  break;

              // U+0022 QUOTATION MARK (")
              case 0x0022:
                  // Consume a string token and return it.
                  consumeStringToken();
                  break;

              // U+0023 NUMBER SIGN (#)
              case 0x0023:
                  // If the next input code point is a name code point or the next two input code points are a valid escape, then:
                  if (isName(getCharCode(offset + 1)) || isValidEscape(getCharCode(offset + 1), getCharCode(offset + 2))) {
                      // Create a <hash-token>.
                      type = TYPE$F.Hash;

                      // If the next 3 input code points would start an identifier, set the <hash-token>’s type flag to "id".
                      // if (isIdentifierStart(getCharCode(offset + 1), getCharCode(offset + 2), getCharCode(offset + 3))) {
                      //     // TODO: set id flag
                      // }

                      // Consume a name, and set the <hash-token>’s value to the returned string.
                      offset = consumeName(source, offset + 1);

                      // Return the <hash-token>.
                  } else {
                      // Otherwise, return a <delim-token> with its value set to the current input code point.
                      type = TYPE$F.Delim;
                      offset++;
                  }

                  break;

              // U+0027 APOSTROPHE (')
              case 0x0027:
                  // Consume a string token and return it.
                  consumeStringToken();
                  break;

              // U+0028 LEFT PARENTHESIS (()
              case 0x0028:
                  // Return a <(-token>.
                  type = TYPE$F.LeftParenthesis;
                  offset++;
                  break;

              // U+0029 RIGHT PARENTHESIS ())
              case 0x0029:
                  // Return a <)-token>.
                  type = TYPE$F.RightParenthesis;
                  offset++;
                  break;

              // U+002B PLUS SIGN (+)
              case 0x002B:
                  // If the input stream starts with a number, ...
                  if (isNumberStart(code, getCharCode(offset + 1), getCharCode(offset + 2))) {
                      // ... reconsume the current input code point, consume a numeric token, and return it.
                      consumeNumericToken();
                  } else {
                      // Otherwise, return a <delim-token> with its value set to the current input code point.
                      type = TYPE$F.Delim;
                      offset++;
                  }
                  break;

              // U+002C COMMA (,)
              case 0x002C:
                  // Return a <comma-token>.
                  type = TYPE$F.Comma;
                  offset++;
                  break;

              // U+002D HYPHEN-MINUS (-)
              case 0x002D:
                  // If the input stream starts with a number, reconsume the current input code point, consume a numeric token, and return it.
                  if (isNumberStart(code, getCharCode(offset + 1), getCharCode(offset + 2))) {
                      consumeNumericToken();
                  } else {
                      // Otherwise, if the next 2 input code points are U+002D HYPHEN-MINUS U+003E GREATER-THAN SIGN (->), consume them and return a <CDC-token>.
                      if (getCharCode(offset + 1) === 0x002D &&
                          getCharCode(offset + 2) === 0x003E) {
                          type = TYPE$F.CDC;
                          offset = offset + 3;
                      } else {
                          // Otherwise, if the input stream starts with an identifier, ...
                          if (isIdentifierStart$1(code, getCharCode(offset + 1), getCharCode(offset + 2))) {
                              // ... reconsume the current input code point, consume an ident-like token, and return it.
                              consumeIdentLikeToken();
                          } else {
                              // Otherwise, return a <delim-token> with its value set to the current input code point.
                              type = TYPE$F.Delim;
                              offset++;
                          }
                      }
                  }
                  break;

              // U+002E FULL STOP (.)
              case 0x002E:
                  // If the input stream starts with a number, ...
                  if (isNumberStart(code, getCharCode(offset + 1), getCharCode(offset + 2))) {
                      // ... reconsume the current input code point, consume a numeric token, and return it.
                      consumeNumericToken();
                  } else {
                      // Otherwise, return a <delim-token> with its value set to the current input code point.
                      type = TYPE$F.Delim;
                      offset++;
                  }

                  break;

              // U+002F SOLIDUS (/)
              case 0x002F:
                  // If the next two input code point are U+002F SOLIDUS (/) followed by a U+002A ASTERISK (*),
                  if (getCharCode(offset + 1) === 0x002A) {
                      // ... consume them and all following code points up to and including the first U+002A ASTERISK (*)
                      // followed by a U+002F SOLIDUS (/), or up to an EOF code point.
                      type = TYPE$F.Comment;
                      offset = source.indexOf('*/', offset + 2) + 2;
                      if (offset === 1) {
                          offset = source.length;
                      }
                  } else {
                      type = TYPE$F.Delim;
                      offset++;
                  }
                  break;

              // U+003A COLON (:)
              case 0x003A:
                  // Return a <colon-token>.
                  type = TYPE$F.Colon;
                  offset++;
                  break;

              // U+003B SEMICOLON (;)
              case 0x003B:
                  // Return a <semicolon-token>.
                  type = TYPE$F.Semicolon;
                  offset++;
                  break;

              // U+003C LESS-THAN SIGN (<)
              case 0x003C:
                  // If the next 3 input code points are U+0021 EXCLAMATION MARK U+002D HYPHEN-MINUS U+002D HYPHEN-MINUS (!--), ...
                  if (getCharCode(offset + 1) === 0x0021 &&
                      getCharCode(offset + 2) === 0x002D &&
                      getCharCode(offset + 3) === 0x002D) {
                      // ... consume them and return a <CDO-token>.
                      type = TYPE$F.CDO;
                      offset = offset + 4;
                  } else {
                      // Otherwise, return a <delim-token> with its value set to the current input code point.
                      type = TYPE$F.Delim;
                      offset++;
                  }

                  break;

              // U+0040 COMMERCIAL AT (@)
              case 0x0040:
                  // If the next 3 input code points would start an identifier, ...
                  if (isIdentifierStart$1(getCharCode(offset + 1), getCharCode(offset + 2), getCharCode(offset + 3))) {
                      // ... consume a name, create an <at-keyword-token> with its value set to the returned value, and return it.
                      type = TYPE$F.AtKeyword;
                      offset = consumeName(source, offset + 1);
                  } else {
                      // Otherwise, return a <delim-token> with its value set to the current input code point.
                      type = TYPE$F.Delim;
                      offset++;
                  }

                  break;

              // U+005B LEFT SQUARE BRACKET ([)
              case 0x005B:
                  // Return a <[-token>.
                  type = TYPE$F.LeftSquareBracket;
                  offset++;
                  break;

              // U+005C REVERSE SOLIDUS (\)
              case 0x005C:
                  // If the input stream starts with a valid escape, ...
                  if (isValidEscape(code, getCharCode(offset + 1))) {
                      // ... reconsume the current input code point, consume an ident-like token, and return it.
                      consumeIdentLikeToken();
                  } else {
                      // Otherwise, this is a parse error. Return a <delim-token> with its value set to the current input code point.
                      type = TYPE$F.Delim;
                      offset++;
                  }
                  break;

              // U+005D RIGHT SQUARE BRACKET (])
              case 0x005D:
                  // Return a <]-token>.
                  type = TYPE$F.RightSquareBracket;
                  offset++;
                  break;

              // U+007B LEFT CURLY BRACKET ({)
              case 0x007B:
                  // Return a <{-token>.
                  type = TYPE$F.LeftCurlyBracket;
                  offset++;
                  break;

              // U+007D RIGHT CURLY BRACKET (})
              case 0x007D:
                  // Return a <}-token>.
                  type = TYPE$F.RightCurlyBracket;
                  offset++;
                  break;

              // digit
              case charCodeCategory.Digit:
                  // Reconsume the current input code point, consume a numeric token, and return it.
                  consumeNumericToken();
                  break;

              // name-start code point
              case charCodeCategory.NameStart:
                  // Reconsume the current input code point, consume an ident-like token, and return it.
                  consumeIdentLikeToken();
                  break;

              // EOF
              case charCodeCategory.Eof:
                  // Return an <EOF-token>.
                  break;

              // anything else
              default:
                  // Return a <delim-token> with its value set to the current input code point.
                  type = TYPE$F.Delim;
                  offset++;
          }

          switch (type) {
              case balanceCloseType:
                  balancePrev = balanceStart & OFFSET_MASK;
                  balanceStart = balance[balancePrev];
                  balanceCloseType = balanceStart >> TYPE_SHIFT;
                  balance[tokenCount] = balancePrev;
                  balance[balancePrev++] = tokenCount;
                  for (; balancePrev < tokenCount; balancePrev++) {
                      if (balance[balancePrev] === sourceLength) {
                          balance[balancePrev] = tokenCount;
                      }
                  }
                  break;

              case TYPE$F.LeftParenthesis:
              case TYPE$F.Function:
                  balance[tokenCount] = balanceStart;
                  balanceCloseType = TYPE$F.RightParenthesis;
                  balanceStart = (balanceCloseType << TYPE_SHIFT) | tokenCount;
                  break;

              case TYPE$F.LeftSquareBracket:
                  balance[tokenCount] = balanceStart;
                  balanceCloseType = TYPE$F.RightSquareBracket;
                  balanceStart = (balanceCloseType << TYPE_SHIFT) | tokenCount;
                  break;

              case TYPE$F.LeftCurlyBracket:
                  balance[tokenCount] = balanceStart;
                  balanceCloseType = TYPE$F.RightCurlyBracket;
                  balanceStart = (balanceCloseType << TYPE_SHIFT) | tokenCount;
                  break;
          }

          offsetAndType[tokenCount++] = (type << TYPE_SHIFT) | offset;
      }

      // finalize buffers
      offsetAndType[tokenCount] = (TYPE$F.EOF << TYPE_SHIFT) | offset; // <EOF-token>
      balance[tokenCount] = sourceLength;
      balance[sourceLength] = sourceLength; // prevents false positive balance match with any token
      while (balanceStart !== 0) {
          balancePrev = balanceStart & OFFSET_MASK;
          balanceStart = balance[balancePrev];
          balance[balancePrev] = sourceLength;
      }

      // update stream
      stream.source = source;
      stream.firstCharOffset = start;
      stream.offsetAndType = offsetAndType;
      stream.tokenCount = tokenCount;
      stream.balance = balance;
      stream.reset();
      stream.next();

      return stream;
  }

  // extend tokenizer with constants
  Object.keys(_const).forEach(function(key) {
      tokenize[key] = _const[key];
  });

  // extend tokenizer with static methods from utils
  Object.keys(charCodeDefinitions).forEach(function(key) {
      tokenize[key] = charCodeDefinitions[key];
  });
  Object.keys(utils).forEach(function(key) {
      tokenize[key] = utils[key];
  });

  var tokenizer$1 = tokenize;

  var isDigit$3 = tokenizer$1.isDigit;
  var cmpChar$4 = tokenizer$1.cmpChar;
  var TYPE$E = tokenizer$1.TYPE;

  var DELIM$6 = TYPE$E.Delim;
  var WHITESPACE$b = TYPE$E.WhiteSpace;
  var COMMENT$9 = TYPE$E.Comment;
  var IDENT$i = TYPE$E.Ident;
  var NUMBER$9 = TYPE$E.Number;
  var DIMENSION$7 = TYPE$E.Dimension;
  var PLUSSIGN$8 = 0x002B;    // U+002B PLUS SIGN (+)
  var HYPHENMINUS$4 = 0x002D; // U+002D HYPHEN-MINUS (-)
  var N$4 = 0x006E;           // U+006E LATIN SMALL LETTER N (n)
  var DISALLOW_SIGN$1 = true;
  var ALLOW_SIGN$1 = false;

  function isDelim$1(token, code) {
      return token !== null && token.type === DELIM$6 && token.value.charCodeAt(0) === code;
  }

  function skipSC(token, offset, getNextToken) {
      while (token !== null && (token.type === WHITESPACE$b || token.type === COMMENT$9)) {
          token = getNextToken(++offset);
      }

      return offset;
  }

  function checkInteger$1(token, valueOffset, disallowSign, offset) {
      if (!token) {
          return 0;
      }

      var code = token.value.charCodeAt(valueOffset);

      if (code === PLUSSIGN$8 || code === HYPHENMINUS$4) {
          if (disallowSign) {
              // Number sign is not allowed
              return 0;
          }
          valueOffset++;
      }

      for (; valueOffset < token.value.length; valueOffset++) {
          if (!isDigit$3(token.value.charCodeAt(valueOffset))) {
              // Integer is expected
              return 0;
          }
      }

      return offset + 1;
  }

  // ... <signed-integer>
  // ... ['+' | '-'] <signless-integer>
  function consumeB$1(token, offset_, getNextToken) {
      var sign = false;
      var offset = skipSC(token, offset_, getNextToken);

      token = getNextToken(offset);

      if (token === null) {
          return offset_;
      }

      if (token.type !== NUMBER$9) {
          if (isDelim$1(token, PLUSSIGN$8) || isDelim$1(token, HYPHENMINUS$4)) {
              sign = true;
              offset = skipSC(getNextToken(++offset), offset, getNextToken);
              token = getNextToken(offset);

              if (token === null && token.type !== NUMBER$9) {
                  return 0;
              }
          } else {
              return offset_;
          }
      }

      if (!sign) {
          var code = token.value.charCodeAt(0);
          if (code !== PLUSSIGN$8 && code !== HYPHENMINUS$4) {
              // Number sign is expected
              return 0;
          }
      }

      return checkInteger$1(token, sign ? 0 : 1, sign, offset);
  }

  // An+B microsyntax https://www.w3.org/TR/css-syntax-3/#anb
  var genericAnPlusB = function anPlusB(token, getNextToken) {
      /* eslint-disable brace-style*/
      var offset = 0;

      if (!token) {
          return 0;
      }

      // <integer>
      if (token.type === NUMBER$9) {
          return checkInteger$1(token, 0, ALLOW_SIGN$1, offset); // b
      }

      // -n
      // -n <signed-integer>
      // -n ['+' | '-'] <signless-integer>
      // -n- <signless-integer>
      // <dashndashdigit-ident>
      else if (token.type === IDENT$i && token.value.charCodeAt(0) === HYPHENMINUS$4) {
          // expect 1st char is N
          if (!cmpChar$4(token.value, 1, N$4)) {
              return 0;
          }

          switch (token.value.length) {
              // -n
              // -n <signed-integer>
              // -n ['+' | '-'] <signless-integer>
              case 2:
                  return consumeB$1(getNextToken(++offset), offset, getNextToken);

              // -n- <signless-integer>
              case 3:
                  if (token.value.charCodeAt(2) !== HYPHENMINUS$4) {
                      return 0;
                  }

                  offset = skipSC(getNextToken(++offset), offset, getNextToken);
                  token = getNextToken(offset);

                  return checkInteger$1(token, 0, DISALLOW_SIGN$1, offset);

              // <dashndashdigit-ident>
              default:
                  if (token.value.charCodeAt(2) !== HYPHENMINUS$4) {
                      return 0;
                  }

                  return checkInteger$1(token, 3, DISALLOW_SIGN$1, offset);
          }
      }

      // '+'? n
      // '+'? n <signed-integer>
      // '+'? n ['+' | '-'] <signless-integer>
      // '+'? n- <signless-integer>
      // '+'? <ndashdigit-ident>
      else if (token.type === IDENT$i || (isDelim$1(token, PLUSSIGN$8) && getNextToken(offset + 1).type === IDENT$i)) {
          // just ignore a plus
          if (token.type !== IDENT$i) {
              token = getNextToken(++offset);
          }

          if (token === null || !cmpChar$4(token.value, 0, N$4)) {
              return 0;
          }

          switch (token.value.length) {
              // '+'? n
              // '+'? n <signed-integer>
              // '+'? n ['+' | '-'] <signless-integer>
              case 1:
                  return consumeB$1(getNextToken(++offset), offset, getNextToken);

              // '+'? n- <signless-integer>
              case 2:
                  if (token.value.charCodeAt(1) !== HYPHENMINUS$4) {
                      return 0;
                  }

                  offset = skipSC(getNextToken(++offset), offset, getNextToken);
                  token = getNextToken(offset);

                  return checkInteger$1(token, 0, DISALLOW_SIGN$1, offset);

              // '+'? <ndashdigit-ident>
              default:
                  if (token.value.charCodeAt(1) !== HYPHENMINUS$4) {
                      return 0;
                  }

                  return checkInteger$1(token, 2, DISALLOW_SIGN$1, offset);
          }
      }

      // <ndashdigit-dimension>
      // <ndash-dimension> <signless-integer>
      // <n-dimension>
      // <n-dimension> <signed-integer>
      // <n-dimension> ['+' | '-'] <signless-integer>
      else if (token.type === DIMENSION$7) {
          var code = token.value.charCodeAt(0);
          var sign = code === PLUSSIGN$8 || code === HYPHENMINUS$4 ? 1 : 0;

          for (var i = sign; i < token.value.length; i++) {
              if (!isDigit$3(token.value.charCodeAt(i))) {
                  break;
              }
          }

          if (i === sign) {
              // Integer is expected
              return 0;
          }

          if (!cmpChar$4(token.value, i, N$4)) {
              return 0;
          }

          // <n-dimension>
          // <n-dimension> <signed-integer>
          // <n-dimension> ['+' | '-'] <signless-integer>
          if (i + 1 === token.value.length) {
              return consumeB$1(getNextToken(++offset), offset, getNextToken);
          } else {
              if (token.value.charCodeAt(i + 1) !== HYPHENMINUS$4) {
                  return 0;
              }

              // <ndash-dimension> <signless-integer>
              if (i + 2 === token.value.length) {
                  offset = skipSC(getNextToken(++offset), offset, getNextToken);
                  token = getNextToken(offset);

                  return checkInteger$1(token, 0, DISALLOW_SIGN$1, offset);
              }
              // <ndashdigit-dimension>
              else {
                  return checkInteger$1(token, i + 2, DISALLOW_SIGN$1, offset);
              }
          }
      }

      return 0;
  };

  var isHexDigit$2 = tokenizer$1.isHexDigit;
  var cmpChar$3 = tokenizer$1.cmpChar;
  var TYPE$D = tokenizer$1.TYPE;

  var IDENT$h = TYPE$D.Ident;
  var DELIM$5 = TYPE$D.Delim;
  var NUMBER$8 = TYPE$D.Number;
  var DIMENSION$6 = TYPE$D.Dimension;
  var PLUSSIGN$7 = 0x002B;     // U+002B PLUS SIGN (+)
  var HYPHENMINUS$3 = 0x002D;  // U+002D HYPHEN-MINUS (-)
  var QUESTIONMARK$2 = 0x003F; // U+003F QUESTION MARK (?)
  var U$2 = 0x0075;            // U+0075 LATIN SMALL LETTER U (u)

  function isDelim(token, code) {
      return token !== null && token.type === DELIM$5 && token.value.charCodeAt(0) === code;
  }

  function startsWith$1(token, code) {
      return token.value.charCodeAt(0) === code;
  }

  function hexSequence(token, offset, allowDash) {
      for (var pos = offset, hexlen = 0; pos < token.value.length; pos++) {
          var code = token.value.charCodeAt(pos);

          if (code === HYPHENMINUS$3 && allowDash && hexlen !== 0) {
              if (hexSequence(token, offset + hexlen + 1, false) > 0) {
                  return 6; // dissallow following question marks
              }

              return 0; // dash at the ending of a hex sequence is not allowed
          }

          if (!isHexDigit$2(code)) {
              return 0; // not a hex digit
          }

          if (++hexlen > 6) {
              return 0; // too many hex digits
          }    }

      return hexlen;
  }

  function withQuestionMarkSequence(consumed, length, getNextToken) {
      if (!consumed) {
          return 0; // nothing consumed
      }

      while (isDelim(getNextToken(length), QUESTIONMARK$2)) {
          if (++consumed > 6) {
              return 0; // too many question marks
          }

          length++;
      }

      return length;
  }

  // https://drafts.csswg.org/css-syntax/#urange
  // Informally, the <urange> production has three forms:
  // U+0001
  //      Defines a range consisting of a single code point, in this case the code point "1".
  // U+0001-00ff
  //      Defines a range of codepoints between the first and the second value, in this case
  //      the range between "1" and "ff" (255 in decimal) inclusive.
  // U+00??
  //      Defines a range of codepoints where the "?" characters range over all hex digits,
  //      in this case defining the same as the value U+0000-00ff.
  // In each form, a maximum of 6 digits is allowed for each hexadecimal number (if you treat "?" as a hexadecimal digit).
  //
  // <urange> =
  //   u '+' <ident-token> '?'* |
  //   u <dimension-token> '?'* |
  //   u <number-token> '?'* |
  //   u <number-token> <dimension-token> |
  //   u <number-token> <number-token> |
  //   u '+' '?'+
  var genericUrange = function urange(token, getNextToken) {
      var length = 0;

      // should start with `u` or `U`
      if (token === null || token.type !== IDENT$h || !cmpChar$3(token.value, 0, U$2)) {
          return 0;
      }

      token = getNextToken(++length);
      if (token === null) {
          return 0;
      }

      // u '+' <ident-token> '?'*
      // u '+' '?'+
      if (isDelim(token, PLUSSIGN$7)) {
          token = getNextToken(++length);
          if (token === null) {
              return 0;
          }

          if (token.type === IDENT$h) {
              // u '+' <ident-token> '?'*
              return withQuestionMarkSequence(hexSequence(token, 0, true), ++length, getNextToken);
          }

          if (isDelim(token, QUESTIONMARK$2)) {
              // u '+' '?'+
              return withQuestionMarkSequence(1, ++length, getNextToken);
          }

          // Hex digit or question mark is expected
          return 0;
      }

      // u <number-token> '?'*
      // u <number-token> <dimension-token>
      // u <number-token> <number-token>
      if (token.type === NUMBER$8) {
          if (!startsWith$1(token, PLUSSIGN$7)) {
              return 0;
          }

          var consumedHexLength = hexSequence(token, 1, true);
          if (consumedHexLength === 0) {
              return 0;
          }

          token = getNextToken(++length);
          if (token === null) {
              // u <number-token> <eof>
              return length;
          }

          if (token.type === DIMENSION$6 || token.type === NUMBER$8) {
              // u <number-token> <dimension-token>
              // u <number-token> <number-token>
              if (!startsWith$1(token, HYPHENMINUS$3) || !hexSequence(token, 1, false)) {
                  return 0;
              }

              return length + 1;
          }

          // u <number-token> '?'*
          return withQuestionMarkSequence(consumedHexLength, length, getNextToken);
      }

      // u <dimension-token> '?'*
      if (token.type === DIMENSION$6) {
          if (!startsWith$1(token, PLUSSIGN$7)) {
              return 0;
          }

          return withQuestionMarkSequence(hexSequence(token, 1, true), ++length, getNextToken);
      }

      return 0;
  };

  var isIdentifierStart = tokenizer$1.isIdentifierStart;
  var isHexDigit$1 = tokenizer$1.isHexDigit;
  var isDigit$2 = tokenizer$1.isDigit;
  var cmpStr$3 = tokenizer$1.cmpStr;
  var consumeNumber$3 = tokenizer$1.consumeNumber;
  var TYPE$C = tokenizer$1.TYPE;



  var cssWideKeywords$1 = ['unset', 'initial', 'inherit'];
  var calcFunctionNames = ['calc(', '-moz-calc(', '-webkit-calc('];

  // https://www.w3.org/TR/css-values-3/#lengths
  var LENGTH = {
      // absolute length units
      'px': true,
      'mm': true,
      'cm': true,
      'in': true,
      'pt': true,
      'pc': true,
      'q': true,

      // relative length units
      'em': true,
      'ex': true,
      'ch': true,
      'rem': true,

      // viewport-percentage lengths
      'vh': true,
      'vw': true,
      'vmin': true,
      'vmax': true,
      'vm': true
  };

  var ANGLE = {
      'deg': true,
      'grad': true,
      'rad': true,
      'turn': true
  };

  var TIME = {
      's': true,
      'ms': true
  };

  var FREQUENCY = {
      'hz': true,
      'khz': true
  };

  // https://www.w3.org/TR/css-values-3/#resolution (https://drafts.csswg.org/css-values/#resolution)
  var RESOLUTION = {
      'dpi': true,
      'dpcm': true,
      'dppx': true,
      'x': true      // https://github.com/w3c/csswg-drafts/issues/461
  };

  // https://drafts.csswg.org/css-grid/#fr-unit
  var FLEX = {
      'fr': true
  };

  // https://www.w3.org/TR/css3-speech/#mixing-props-voice-volume
  var DECIBEL = {
      'db': true
  };

  // https://www.w3.org/TR/css3-speech/#voice-props-voice-pitch
  var SEMITONES = {
      'st': true
  };

  // safe char code getter
  function charCode(str, index) {
      return index < str.length ? str.charCodeAt(index) : 0;
  }

  function eqStr(actual, expected) {
      return cmpStr$3(actual, 0, actual.length, expected);
  }

  function eqStrAny(actual, expected) {
      for (var i = 0; i < expected.length; i++) {
          if (eqStr(actual, expected[i])) {
              return true;
          }
      }

      return false;
  }

  // IE postfix hack, i.e. 123\0 or 123px\9
  function isPostfixIeHack(str, offset) {
      if (offset !== str.length - 2) {
          return false;
      }

      return (
          str.charCodeAt(offset) === 0x005C &&  // U+005C REVERSE SOLIDUS (\)
          isDigit$2(str.charCodeAt(offset + 1))
      );
  }

  function outOfRange(opts, value, numEnd) {
      if (opts && opts.type === 'Range') {
          var num = Number(
              numEnd !== undefined && numEnd !== value.length
                  ? value.substr(0, numEnd)
                  : value
          );

          if (isNaN(num)) {
              return true;
          }

          if (opts.min !== null && num < opts.min) {
              return true;
          }

          if (opts.max !== null && num > opts.max) {
              return true;
          }
      }

      return false;
  }

  function consumeFunction(token, getNextToken) {
      var startIdx = token.index;
      var length = 0;

      // balanced token consuming
      do {
          length++;

          if (token.balance <= startIdx) {
              break;
          }
      } while (token = getNextToken(length));

      return length;
  }

  // TODO: implement
  // can be used wherever <length>, <frequency>, <angle>, <time>, <percentage>, <number>, or <integer> values are allowed
  // https://drafts.csswg.org/css-values/#calc-notation
  function calc(next) {
      return function(token, getNextToken, opts) {
          if (token === null) {
              return 0;
          }

          if (token.type === TYPE$C.Function && eqStrAny(token.value, calcFunctionNames)) {
              return consumeFunction(token, getNextToken);
          }

          return next(token, getNextToken, opts);
      };
  }

  function tokenType(expectedTokenType) {
      return function(token) {
          if (token === null || token.type !== expectedTokenType) {
              return 0;
          }

          return 1;
      };
  }

  function func(name) {
      name = name + '(';

      return function(token, getNextToken) {
          if (token !== null && eqStr(token.value, name)) {
              return consumeFunction(token, getNextToken);
          }

          return 0;
      };
  }

  // =========================
  // Complex types
  //

  // https://drafts.csswg.org/css-values-4/#custom-idents
  // 4.2. Author-defined Identifiers: the <custom-ident> type
  // Some properties accept arbitrary author-defined identifiers as a component value.
  // This generic data type is denoted by <custom-ident>, and represents any valid CSS identifier
  // that would not be misinterpreted as a pre-defined keyword in that property’s value definition.
  //
  // See also: https://developer.mozilla.org/en-US/docs/Web/CSS/custom-ident
  function customIdent(token) {
      if (token === null || token.type !== TYPE$C.Ident) {
          return 0;
      }

      var name = token.value.toLowerCase();

      // The CSS-wide keywords are not valid <custom-ident>s
      if (eqStrAny(name, cssWideKeywords$1)) {
          return 0;
      }

      // The default keyword is reserved and is also not a valid <custom-ident>
      if (eqStr(name, 'default')) {
          return 0;
      }

      // TODO: ignore property specific keywords (as described https://developer.mozilla.org/en-US/docs/Web/CSS/custom-ident)
      // Specifications using <custom-ident> must specify clearly what other keywords
      // are excluded from <custom-ident>, if any—for example by saying that any pre-defined keywords
      // in that property’s value definition are excluded. Excluded keywords are excluded
      // in all ASCII case permutations.

      return 1;
  }

  // https://drafts.csswg.org/css-variables/#typedef-custom-property-name
  // A custom property is any property whose name starts with two dashes (U+002D HYPHEN-MINUS), like --foo.
  // The <custom-property-name> production corresponds to this: it’s defined as any valid identifier
  // that starts with two dashes, except -- itself, which is reserved for future use by CSS.
  // NOTE: Current implementation treat `--` as a valid name since most (all?) major browsers treat it as valid.
  function customPropertyName(token) {
      // ... defined as any valid identifier
      if (token === null || token.type !== TYPE$C.Ident) {
          return 0;
      }

      // ... that starts with two dashes (U+002D HYPHEN-MINUS)
      if (charCode(token.value, 0) !== 0x002D || charCode(token.value, 1) !== 0x002D) {
          return 0;
      }

      return 1;
  }

  // https://drafts.csswg.org/css-color-4/#hex-notation
  // The syntax of a <hex-color> is a <hash-token> token whose value consists of 3, 4, 6, or 8 hexadecimal digits.
  // In other words, a hex color is written as a hash character, "#", followed by some number of digits 0-9 or
  // letters a-f (the case of the letters doesn’t matter - #00ff00 is identical to #00FF00).
  function hexColor(token) {
      if (token === null || token.type !== TYPE$C.Hash) {
          return 0;
      }

      var length = token.value.length;

      // valid values (length): #rgb (4), #rgba (5), #rrggbb (7), #rrggbbaa (9)
      if (length !== 4 && length !== 5 && length !== 7 && length !== 9) {
          return 0;
      }

      for (var i = 1; i < length; i++) {
          if (!isHexDigit$1(token.value.charCodeAt(i))) {
              return 0;
          }
      }

      return 1;
  }

  function idSelector(token) {
      if (token === null || token.type !== TYPE$C.Hash) {
          return 0;
      }

      if (!isIdentifierStart(charCode(token.value, 1), charCode(token.value, 2), charCode(token.value, 3))) {
          return 0;
      }

      return 1;
  }

  // https://drafts.csswg.org/css-syntax/#any-value
  // It represents the entirety of what a valid declaration can have as its value.
  function declarationValue(token, getNextToken) {
      if (!token) {
          return 0;
      }

      var length = 0;
      var level = 0;
      var startIdx = token.index;

      // The <declaration-value> production matches any sequence of one or more tokens,
      // so long as the sequence ...
      scan:
      do {
          switch (token.type) {
              // ... does not contain <bad-string-token>, <bad-url-token>,
              case TYPE$C.BadString:
              case TYPE$C.BadUrl:
                  break scan;

              // ... unmatched <)-token>, <]-token>, or <}-token>,
              case TYPE$C.RightCurlyBracket:
              case TYPE$C.RightParenthesis:
              case TYPE$C.RightSquareBracket:
                  if (token.balance > token.index || token.balance < startIdx) {
                      break scan;
                  }

                  level--;
                  break;

              // ... or top-level <semicolon-token> tokens
              case TYPE$C.Semicolon:
                  if (level === 0) {
                      break scan;
                  }

                  break;

              // ... or <delim-token> tokens with a value of "!"
              case TYPE$C.Delim:
                  if (token.value === '!' && level === 0) {
                      break scan;
                  }

                  break;

              case TYPE$C.Function:
              case TYPE$C.LeftParenthesis:
              case TYPE$C.LeftSquareBracket:
              case TYPE$C.LeftCurlyBracket:
                  level++;
                  break;
          }

          length++;

          // until balance closing
          if (token.balance <= startIdx) {
              break;
          }
      } while (token = getNextToken(length));

      return length;
  }

  // https://drafts.csswg.org/css-syntax/#any-value
  // The <any-value> production is identical to <declaration-value>, but also
  // allows top-level <semicolon-token> tokens and <delim-token> tokens
  // with a value of "!". It represents the entirety of what valid CSS can be in any context.
  function anyValue(token, getNextToken) {
      if (!token) {
          return 0;
      }

      var startIdx = token.index;
      var length = 0;

      // The <any-value> production matches any sequence of one or more tokens,
      // so long as the sequence ...
      scan:
      do {
          switch (token.type) {
              // ... does not contain <bad-string-token>, <bad-url-token>,
              case TYPE$C.BadString:
              case TYPE$C.BadUrl:
                  break scan;

              // ... unmatched <)-token>, <]-token>, or <}-token>,
              case TYPE$C.RightCurlyBracket:
              case TYPE$C.RightParenthesis:
              case TYPE$C.RightSquareBracket:
                  if (token.balance > token.index || token.balance < startIdx) {
                      break scan;
                  }

                  break;
          }

          length++;

          // until balance closing
          if (token.balance <= startIdx) {
              break;
          }
      } while (token = getNextToken(length));

      return length;
  }

  // =========================
  // Dimensions
  //

  function dimension(type) {
      return function(token, getNextToken, opts) {
          if (token === null || token.type !== TYPE$C.Dimension) {
              return 0;
          }

          var numberEnd = consumeNumber$3(token.value, 0);

          // check unit
          if (type !== null) {
              // check for IE postfix hack, i.e. 123px\0 or 123px\9
              var reverseSolidusOffset = token.value.indexOf('\\', numberEnd);
              var unit = reverseSolidusOffset === -1 || !isPostfixIeHack(token.value, reverseSolidusOffset)
                  ? token.value.substr(numberEnd)
                  : token.value.substring(numberEnd, reverseSolidusOffset);

              if (type.hasOwnProperty(unit.toLowerCase()) === false) {
                  return 0;
              }
          }

          // check range if specified
          if (outOfRange(opts, token.value, numberEnd)) {
              return 0;
          }

          return 1;
      };
  }

  // =========================
  // Percentage
  //

  // §5.5. Percentages: the <percentage> type
  // https://drafts.csswg.org/css-values-4/#percentages
  function percentage(token, getNextToken, opts) {
      // ... corresponds to the <percentage-token> production
      if (token === null || token.type !== TYPE$C.Percentage) {
          return 0;
      }

      // check range if specified
      if (outOfRange(opts, token.value, token.value.length - 1)) {
          return 0;
      }

      return 1;
  }

  // =========================
  // Numeric
  //

  // https://drafts.csswg.org/css-values-4/#numbers
  // The value <zero> represents a literal number with the value 0. Expressions that merely
  // evaluate to a <number> with the value 0 (for example, calc(0)) do not match <zero>;
  // only literal <number-token>s do.
  function zero(next) {
      if (typeof next !== 'function') {
          next = function() {
              return 0;
          };
      }

      return function(token, getNextToken, opts) {
          if (token !== null && token.type === TYPE$C.Number) {
              if (Number(token.value) === 0) {
                  return 1;
              }
          }

          return next(token, getNextToken, opts);
      };
  }

  // § 5.3. Real Numbers: the <number> type
  // https://drafts.csswg.org/css-values-4/#numbers
  // Number values are denoted by <number>, and represent real numbers, possibly with a fractional component.
  // ... It corresponds to the <number-token> production
  function number(token, getNextToken, opts) {
      if (token === null) {
          return 0;
      }

      var numberEnd = consumeNumber$3(token.value, 0);
      var isNumber = numberEnd === token.value.length;
      if (!isNumber && !isPostfixIeHack(token.value, numberEnd)) {
          return 0;
      }

      // check range if specified
      if (outOfRange(opts, token.value, numberEnd)) {
          return 0;
      }

      return 1;
  }

  // §5.2. Integers: the <integer> type
  // https://drafts.csswg.org/css-values-4/#integers
  function integer(token, getNextToken, opts) {
      // ... corresponds to a subset of the <number-token> production
      if (token === null || token.type !== TYPE$C.Number) {
          return 0;
      }

      // The first digit of an integer may be immediately preceded by `-` or `+` to indicate the integer’s sign.
      var i = token.value.charCodeAt(0) === 0x002B ||       // U+002B PLUS SIGN (+)
              token.value.charCodeAt(0) === 0x002D ? 1 : 0; // U+002D HYPHEN-MINUS (-)

      // When written literally, an integer is one or more decimal digits 0 through 9 ...
      for (; i < token.value.length; i++) {
          if (!isDigit$2(token.value.charCodeAt(i))) {
              return 0;
          }
      }

      // check range if specified
      if (outOfRange(opts, token.value, i)) {
          return 0;
      }

      return 1;
  }

  var generic = {
      // token types
      'ident-token': tokenType(TYPE$C.Ident),
      'function-token': tokenType(TYPE$C.Function),
      'at-keyword-token': tokenType(TYPE$C.AtKeyword),
      'hash-token': tokenType(TYPE$C.Hash),
      'string-token': tokenType(TYPE$C.String),
      'bad-string-token': tokenType(TYPE$C.BadString),
      'url-token': tokenType(TYPE$C.Url),
      'bad-url-token': tokenType(TYPE$C.BadUrl),
      'delim-token': tokenType(TYPE$C.Delim),
      'number-token': tokenType(TYPE$C.Number),
      'percentage-token': tokenType(TYPE$C.Percentage),
      'dimension-token': tokenType(TYPE$C.Dimension),
      'whitespace-token': tokenType(TYPE$C.WhiteSpace),
      'CDO-token': tokenType(TYPE$C.CDO),
      'CDC-token': tokenType(TYPE$C.CDC),
      'colon-token': tokenType(TYPE$C.Colon),
      'semicolon-token': tokenType(TYPE$C.Semicolon),
      'comma-token': tokenType(TYPE$C.Comma),
      '[-token': tokenType(TYPE$C.LeftSquareBracket),
      ']-token': tokenType(TYPE$C.RightSquareBracket),
      '(-token': tokenType(TYPE$C.LeftParenthesis),
      ')-token': tokenType(TYPE$C.RightParenthesis),
      '{-token': tokenType(TYPE$C.LeftCurlyBracket),
      '}-token': tokenType(TYPE$C.RightCurlyBracket),

      // token type aliases
      'string': tokenType(TYPE$C.String),
      'ident': tokenType(TYPE$C.Ident),

      // complex types
      'custom-ident': customIdent,
      'custom-property-name': customPropertyName,
      'hex-color': hexColor,
      'id-selector': idSelector, // element( <id-selector> )
      'an-plus-b': genericAnPlusB,
      'urange': genericUrange,
      'declaration-value': declarationValue,
      'any-value': anyValue,

      // dimensions
      'dimension': calc(dimension(null)),
      'angle': calc(dimension(ANGLE)),
      'decibel': calc(dimension(DECIBEL)),
      'frequency': calc(dimension(FREQUENCY)),
      'flex': calc(dimension(FLEX)),
      'length': calc(zero(dimension(LENGTH))),
      'resolution': calc(dimension(RESOLUTION)),
      'semitones': calc(dimension(SEMITONES)),
      'time': calc(dimension(TIME)),

      // percentage
      'percentage': calc(percentage),

      // numeric
      'zero': zero(),
      'number': calc(number),
      'integer': calc(integer),

      // old IE stuff
      '-ms-legacy-expression': func('expression')
  };

  var _SyntaxError = function SyntaxError(message, input, offset) {
      var error = createCustomError('SyntaxError', message);

      error.input = input;
      error.offset = offset;
      error.rawMessage = message;
      error.message = error.rawMessage + '\n' +
          '  ' + error.input + '\n' +
          '--' + new Array((error.offset || error.input.length) + 1).join('-') + '^';

      return error;
  };

  var TAB$1 = 9;
  var N$3 = 10;
  var F$2 = 12;
  var R$2 = 13;
  var SPACE$2 = 32;

  var Tokenizer = function(str) {
      this.str = str;
      this.pos = 0;
  };

  Tokenizer.prototype = {
      charCodeAt: function(pos) {
          return pos < this.str.length ? this.str.charCodeAt(pos) : 0;
      },
      charCode: function() {
          return this.charCodeAt(this.pos);
      },
      nextCharCode: function() {
          return this.charCodeAt(this.pos + 1);
      },
      nextNonWsCode: function(pos) {
          return this.charCodeAt(this.findWsEnd(pos));
      },
      findWsEnd: function(pos) {
          for (; pos < this.str.length; pos++) {
              var code = this.str.charCodeAt(pos);
              if (code !== R$2 && code !== N$3 && code !== F$2 && code !== SPACE$2 && code !== TAB$1) {
                  break;
              }
          }

          return pos;
      },
      substringToPos: function(end) {
          return this.str.substring(this.pos, this.pos = end);
      },
      eat: function(code) {
          if (this.charCode() !== code) {
              this.error('Expect `' + String.fromCharCode(code) + '`');
          }

          this.pos++;
      },
      peek: function() {
          return this.pos < this.str.length ? this.str.charAt(this.pos++) : '';
      },
      error: function(message) {
          throw new _SyntaxError(message, this.str, this.pos);
      }
  };

  var tokenizer = Tokenizer;

  var TAB = 9;
  var N$2 = 10;
  var F$1 = 12;
  var R$1 = 13;
  var SPACE$1 = 32;
  var EXCLAMATIONMARK$3 = 33;    // !
  var NUMBERSIGN$4 = 35;         // #
  var AMPERSAND$1 = 38;          // &
  var APOSTROPHE = 39;         // '
  var LEFTPARENTHESIS$7 = 40;    // (
  var RIGHTPARENTHESIS$7 = 41;   // )
  var ASTERISK$6 = 42;           // *
  var PLUSSIGN$6 = 43;           // +
  var COMMA$4 = 44;              // ,
  var HYPERMINUS = 45;         // -
  var LESSTHANSIGN = 60;       // <
  var GREATERTHANSIGN$2 = 62;    // >
  var QUESTIONMARK$1 = 63;       // ?
  var COMMERCIALAT = 64;       // @
  var LEFTSQUAREBRACKET$4 = 91;  // [
  var RIGHTSQUAREBRACKET$2 = 93; // ]
  var LEFTCURLYBRACKET$4 = 123;  // {
  var VERTICALLINE$3 = 124;      // |
  var RIGHTCURLYBRACKET$2 = 125; // }
  var INFINITY = 8734;         // ∞
  var NAME_CHAR = createCharMap(function(ch) {
      return /[a-zA-Z0-9\-]/.test(ch);
  });
  var COMBINATOR_PRECEDENCE = {
      ' ': 1,
      '&&': 2,
      '||': 3,
      '|': 4
  };

  function createCharMap(fn) {
      var array = typeof Uint32Array === 'function' ? new Uint32Array(128) : new Array(128);
      for (var i = 0; i < 128; i++) {
          array[i] = fn(String.fromCharCode(i)) ? 1 : 0;
      }
      return array;
  }

  function scanSpaces(tokenizer) {
      return tokenizer.substringToPos(
          tokenizer.findWsEnd(tokenizer.pos)
      );
  }

  function scanWord(tokenizer) {
      var end = tokenizer.pos;

      for (; end < tokenizer.str.length; end++) {
          var code = tokenizer.str.charCodeAt(end);
          if (code >= 128 || NAME_CHAR[code] === 0) {
              break;
          }
      }

      if (tokenizer.pos === end) {
          tokenizer.error('Expect a keyword');
      }

      return tokenizer.substringToPos(end);
  }

  function scanNumber(tokenizer) {
      var end = tokenizer.pos;

      for (; end < tokenizer.str.length; end++) {
          var code = tokenizer.str.charCodeAt(end);
          if (code < 48 || code > 57) {
              break;
          }
      }

      if (tokenizer.pos === end) {
          tokenizer.error('Expect a number');
      }

      return tokenizer.substringToPos(end);
  }

  function scanString(tokenizer) {
      var end = tokenizer.str.indexOf('\'', tokenizer.pos + 1);

      if (end === -1) {
          tokenizer.pos = tokenizer.str.length;
          tokenizer.error('Expect an apostrophe');
      }

      return tokenizer.substringToPos(end + 1);
  }

  function readMultiplierRange(tokenizer) {
      var min = null;
      var max = null;

      tokenizer.eat(LEFTCURLYBRACKET$4);

      min = scanNumber(tokenizer);

      if (tokenizer.charCode() === COMMA$4) {
          tokenizer.pos++;
          if (tokenizer.charCode() !== RIGHTCURLYBRACKET$2) {
              max = scanNumber(tokenizer);
          }
      } else {
          max = min;
      }

      tokenizer.eat(RIGHTCURLYBRACKET$2);

      return {
          min: Number(min),
          max: max ? Number(max) : 0
      };
  }

  function readMultiplier(tokenizer) {
      var range = null;
      var comma = false;

      switch (tokenizer.charCode()) {
          case ASTERISK$6:
              tokenizer.pos++;

              range = {
                  min: 0,
                  max: 0
              };

              break;

          case PLUSSIGN$6:
              tokenizer.pos++;

              range = {
                  min: 1,
                  max: 0
              };

              break;

          case QUESTIONMARK$1:
              tokenizer.pos++;

              range = {
                  min: 0,
                  max: 1
              };

              break;

          case NUMBERSIGN$4:
              tokenizer.pos++;

              comma = true;

              if (tokenizer.charCode() === LEFTCURLYBRACKET$4) {
                  range = readMultiplierRange(tokenizer);
              } else {
                  range = {
                      min: 1,
                      max: 0
                  };
              }

              break;

          case LEFTCURLYBRACKET$4:
              range = readMultiplierRange(tokenizer);
              break;

          default:
              return null;
      }

      return {
          type: 'Multiplier',
          comma: comma,
          min: range.min,
          max: range.max,
          term: null
      };
  }

  function maybeMultiplied(tokenizer, node) {
      var multiplier = readMultiplier(tokenizer);

      if (multiplier !== null) {
          multiplier.term = node;
          return multiplier;
      }

      return node;
  }

  function maybeToken(tokenizer) {
      var ch = tokenizer.peek();

      if (ch === '') {
          return null;
      }

      return {
          type: 'Token',
          value: ch
      };
  }

  function readProperty$1(tokenizer) {
      var name;

      tokenizer.eat(LESSTHANSIGN);
      tokenizer.eat(APOSTROPHE);

      name = scanWord(tokenizer);

      tokenizer.eat(APOSTROPHE);
      tokenizer.eat(GREATERTHANSIGN$2);

      return maybeMultiplied(tokenizer, {
          type: 'Property',
          name: name
      });
  }

  // https://drafts.csswg.org/css-values-3/#numeric-ranges
  // 4.1. Range Restrictions and Range Definition Notation
  //
  // Range restrictions can be annotated in the numeric type notation using CSS bracketed
  // range notation—[min,max]—within the angle brackets, after the identifying keyword,
  // indicating a closed range between (and including) min and max.
  // For example, <integer [0, 10]> indicates an integer between 0 and 10, inclusive.
  function readTypeRange(tokenizer) {
      // use null for Infinity to make AST format JSON serializable/deserializable
      var min = null; // -Infinity
      var max = null; // Infinity
      var sign = 1;

      tokenizer.eat(LEFTSQUAREBRACKET$4);

      if (tokenizer.charCode() === HYPERMINUS) {
          tokenizer.peek();
          sign = -1;
      }

      if (sign == -1 && tokenizer.charCode() === INFINITY) {
          tokenizer.peek();
      } else {
          min = sign * Number(scanNumber(tokenizer));
      }

      scanSpaces(tokenizer);
      tokenizer.eat(COMMA$4);
      scanSpaces(tokenizer);

      if (tokenizer.charCode() === INFINITY) {
          tokenizer.peek();
      } else {
          sign = 1;

          if (tokenizer.charCode() === HYPERMINUS) {
              tokenizer.peek();
              sign = -1;
          }

          max = sign * Number(scanNumber(tokenizer));
      }

      tokenizer.eat(RIGHTSQUAREBRACKET$2);

      // If no range is indicated, either by using the bracketed range notation
      // or in the property description, then [−∞,∞] is assumed.
      if (min === null && max === null) {
          return null;
      }

      return {
          type: 'Range',
          min: min,
          max: max
      };
  }

  function readType(tokenizer) {
      var name;
      var opts = null;

      tokenizer.eat(LESSTHANSIGN);
      name = scanWord(tokenizer);

      if (tokenizer.charCode() === LEFTPARENTHESIS$7 &&
          tokenizer.nextCharCode() === RIGHTPARENTHESIS$7) {
          tokenizer.pos += 2;
          name += '()';
      }

      if (tokenizer.charCodeAt(tokenizer.findWsEnd(tokenizer.pos)) === LEFTSQUAREBRACKET$4) {
          scanSpaces(tokenizer);
          opts = readTypeRange(tokenizer);
      }

      tokenizer.eat(GREATERTHANSIGN$2);

      return maybeMultiplied(tokenizer, {
          type: 'Type',
          name: name,
          opts: opts
      });
  }

  function readKeywordOrFunction(tokenizer) {
      var name;

      name = scanWord(tokenizer);

      if (tokenizer.charCode() === LEFTPARENTHESIS$7) {
          tokenizer.pos++;

          return {
              type: 'Function',
              name: name
          };
      }

      return maybeMultiplied(tokenizer, {
          type: 'Keyword',
          name: name
      });
  }

  function regroupTerms(terms, combinators) {
      function createGroup(terms, combinator) {
          return {
              type: 'Group',
              terms: terms,
              combinator: combinator,
              disallowEmpty: false,
              explicit: false
          };
      }

      combinators = Object.keys(combinators).sort(function(a, b) {
          return COMBINATOR_PRECEDENCE[a] - COMBINATOR_PRECEDENCE[b];
      });

      while (combinators.length > 0) {
          var combinator = combinators.shift();
          for (var i = 0, subgroupStart = 0; i < terms.length; i++) {
              var term = terms[i];
              if (term.type === 'Combinator') {
                  if (term.value === combinator) {
                      if (subgroupStart === -1) {
                          subgroupStart = i - 1;
                      }
                      terms.splice(i, 1);
                      i--;
                  } else {
                      if (subgroupStart !== -1 && i - subgroupStart > 1) {
                          terms.splice(
                              subgroupStart,
                              i - subgroupStart,
                              createGroup(terms.slice(subgroupStart, i), combinator)
                          );
                          i = subgroupStart + 1;
                      }
                      subgroupStart = -1;
                  }
              }
          }

          if (subgroupStart !== -1 && combinators.length) {
              terms.splice(
                  subgroupStart,
                  i - subgroupStart,
                  createGroup(terms.slice(subgroupStart, i), combinator)
              );
          }
      }

      return combinator;
  }

  function readImplicitGroup(tokenizer) {
      var terms = [];
      var combinators = {};
      var token;
      var prevToken = null;
      var prevTokenPos = tokenizer.pos;

      while (token = peek(tokenizer)) {
          if (token.type !== 'Spaces') {
              if (token.type === 'Combinator') {
                  // check for combinator in group beginning and double combinator sequence
                  if (prevToken === null || prevToken.type === 'Combinator') {
                      tokenizer.pos = prevTokenPos;
                      tokenizer.error('Unexpected combinator');
                  }

                  combinators[token.value] = true;
              } else if (prevToken !== null && prevToken.type !== 'Combinator') {
                  combinators[' '] = true;  // a b
                  terms.push({
                      type: 'Combinator',
                      value: ' '
                  });
              }

              terms.push(token);
              prevToken = token;
              prevTokenPos = tokenizer.pos;
          }
      }

      // check for combinator in group ending
      if (prevToken !== null && prevToken.type === 'Combinator') {
          tokenizer.pos -= prevTokenPos;
          tokenizer.error('Unexpected combinator');
      }

      return {
          type: 'Group',
          terms: terms,
          combinator: regroupTerms(terms, combinators) || ' ',
          disallowEmpty: false,
          explicit: false
      };
  }

  function readGroup(tokenizer) {
      var result;

      tokenizer.eat(LEFTSQUAREBRACKET$4);
      result = readImplicitGroup(tokenizer);
      tokenizer.eat(RIGHTSQUAREBRACKET$2);

      result.explicit = true;

      if (tokenizer.charCode() === EXCLAMATIONMARK$3) {
          tokenizer.pos++;
          result.disallowEmpty = true;
      }

      return result;
  }

  function peek(tokenizer) {
      var code = tokenizer.charCode();

      if (code < 128 && NAME_CHAR[code] === 1) {
          return readKeywordOrFunction(tokenizer);
      }

      switch (code) {
          case RIGHTSQUAREBRACKET$2:
              // don't eat, stop scan a group
              break;

          case LEFTSQUAREBRACKET$4:
              return maybeMultiplied(tokenizer, readGroup(tokenizer));

          case LESSTHANSIGN:
              return tokenizer.nextCharCode() === APOSTROPHE
                  ? readProperty$1(tokenizer)
                  : readType(tokenizer);

          case VERTICALLINE$3:
              return {
                  type: 'Combinator',
                  value: tokenizer.substringToPos(
                      tokenizer.nextCharCode() === VERTICALLINE$3
                          ? tokenizer.pos + 2
                          : tokenizer.pos + 1
                  )
              };

          case AMPERSAND$1:
              tokenizer.pos++;
              tokenizer.eat(AMPERSAND$1);

              return {
                  type: 'Combinator',
                  value: '&&'
              };

          case COMMA$4:
              tokenizer.pos++;
              return {
                  type: 'Comma'
              };

          case APOSTROPHE:
              return maybeMultiplied(tokenizer, {
                  type: 'String',
                  value: scanString(tokenizer)
              });

          case SPACE$1:
          case TAB:
          case N$2:
          case R$1:
          case F$1:
              return {
                  type: 'Spaces',
                  value: scanSpaces(tokenizer)
              };

          case COMMERCIALAT:
              code = tokenizer.nextCharCode();

              if (code < 128 && NAME_CHAR[code] === 1) {
                  tokenizer.pos++;
                  return {
                      type: 'AtKeyword',
                      name: scanWord(tokenizer)
                  };
              }

              return maybeToken(tokenizer);

          case ASTERISK$6:
          case PLUSSIGN$6:
          case QUESTIONMARK$1:
          case NUMBERSIGN$4:
          case EXCLAMATIONMARK$3:
              // prohibited tokens (used as a multiplier start)
              break;

          case LEFTCURLYBRACKET$4:
              // LEFTCURLYBRACKET is allowed since mdn/data uses it w/o quoting
              // check next char isn't a number, because it's likely a disjoined multiplier
              code = tokenizer.nextCharCode();

              if (code < 48 || code > 57) {
                  return maybeToken(tokenizer);
              }

              break;

          default:
              return maybeToken(tokenizer);
      }
  }

  function parse$3(source) {
      var tokenizer$1 = new tokenizer(source);
      var result = readImplicitGroup(tokenizer$1);

      if (tokenizer$1.pos !== source.length) {
          tokenizer$1.error('Unexpected input');
      }

      // reduce redundant groups with single group term
      if (result.terms.length === 1 && result.terms[0].type === 'Group') {
          result = result.terms[0];
      }

      return result;
  }

  // warm up parse to elimitate code branches that never execute
  // fix soft deoptimizations (insufficient type feedback)
  parse$3('[a&&<b>#|<\'c\'>*||e() f{2} /,(% g#{1,2} h{2,})]!');

  var parse_1$3 = parse$3;

  var noop$2 = function() {};

  function ensureFunction$1(value) {
      return typeof value === 'function' ? value : noop$2;
  }

  var walk = function(node, options, context) {
      function walk(node) {
          enter.call(context, node);

          switch (node.type) {
              case 'Group':
                  node.terms.forEach(walk);
                  break;

              case 'Multiplier':
                  walk(node.term);
                  break;

              case 'Type':
              case 'Property':
              case 'Keyword':
              case 'AtKeyword':
              case 'Function':
              case 'String':
              case 'Token':
              case 'Comma':
                  break;

              default:
                  throw new Error('Unknown type: ' + node.type);
          }

          leave.call(context, node);
      }

      var enter = noop$2;
      var leave = noop$2;

      if (typeof options === 'function') {
          enter = options;
      } else if (options) {
          enter = ensureFunction$1(options.enter);
          leave = ensureFunction$1(options.leave);
      }

      if (enter === noop$2 && leave === noop$2) {
          throw new Error('Neither `enter` nor `leave` walker handler is set or both aren\'t a function');
      }

      walk(node);
  };

  var tokenStream = new TokenStream_1();
  var astToTokens = {
      decorator: function(handlers) {
          var curNode = null;
          var prev = { len: 0, node: null };
          var nodes = [prev];
          var buffer = '';

          return {
              children: handlers.children,
              node: function(node) {
                  var tmp = curNode;
                  curNode = node;
                  handlers.node.call(this, node);
                  curNode = tmp;
              },
              chunk: function(chunk) {
                  buffer += chunk;
                  if (prev.node !== curNode) {
                      nodes.push({
                          len: chunk.length,
                          node: curNode
                      });
                  } else {
                      prev.len += chunk.length;
                  }
              },
              result: function() {
                  return prepareTokens(buffer, nodes);
              }
          };
      }
  };

  function prepareTokens(str, nodes) {
      var tokens = [];
      var nodesOffset = 0;
      var nodesIndex = 0;
      var currentNode = nodes ? nodes[nodesIndex].node : null;

      tokenizer$1(str, tokenStream);

      while (!tokenStream.eof) {
          if (nodes) {
              while (nodesIndex < nodes.length && nodesOffset + nodes[nodesIndex].len <= tokenStream.tokenStart) {
                  nodesOffset += nodes[nodesIndex++].len;
                  currentNode = nodes[nodesIndex].node;
              }
          }

          tokens.push({
              type: tokenStream.tokenType,
              value: tokenStream.getTokenValue(),
              index: tokenStream.tokenIndex, // TODO: remove it, temporary solution
              balance: tokenStream.balance[tokenStream.tokenIndex], // TODO: remove it, temporary solution
              node: currentNode
          });
          tokenStream.next();
          // console.log({ ...tokens[tokens.length - 1], node: undefined });
      }

      return tokens;
  }

  var prepareTokens_1 = function(value, syntax) {
      if (typeof value === 'string') {
          return prepareTokens(value, null);
      }

      return syntax.generate(value, astToTokens);
  };

  var MATCH$1 = { type: 'Match' };
  var MISMATCH$1 = { type: 'Mismatch' };
  var DISALLOW_EMPTY$1 = { type: 'DisallowEmpty' };
  var LEFTPARENTHESIS$6 = 40;  // (
  var RIGHTPARENTHESIS$6 = 41; // )

  function createCondition(match, thenBranch, elseBranch) {
      // reduce node count
      if (thenBranch === MATCH$1 && elseBranch === MISMATCH$1) {
          return match;
      }

      if (match === MATCH$1 && thenBranch === MATCH$1 && elseBranch === MATCH$1) {
          return match;
      }

      if (match.type === 'If' && match.else === MISMATCH$1 && thenBranch === MATCH$1) {
          thenBranch = match.then;
          match = match.match;
      }

      return {
          type: 'If',
          match: match,
          then: thenBranch,
          else: elseBranch
      };
  }

  function isFunctionType(name) {
      return (
          name.length > 2 &&
          name.charCodeAt(name.length - 2) === LEFTPARENTHESIS$6 &&
          name.charCodeAt(name.length - 1) === RIGHTPARENTHESIS$6
      );
  }

  function isEnumCapatible(term) {
      return (
          term.type === 'Keyword' ||
          term.type === 'AtKeyword' ||
          term.type === 'Function' ||
          term.type === 'Type' && isFunctionType(term.name)
      );
  }

  function buildGroupMatchGraph(combinator, terms, atLeastOneTermMatched) {
      switch (combinator) {
          case ' ':
              // Juxtaposing components means that all of them must occur, in the given order.
              //
              // a b c
              // =
              // match a
              //   then match b
              //     then match c
              //       then MATCH
              //       else MISMATCH
              //     else MISMATCH
              //   else MISMATCH
              var result = MATCH$1;

              for (var i = terms.length - 1; i >= 0; i--) {
                  var term = terms[i];

                  result = createCondition(
                      term,
                      result,
                      MISMATCH$1
                  );
              }
              return result;

          case '|':
              // A bar (|) separates two or more alternatives: exactly one of them must occur.
              //
              // a | b | c
              // =
              // match a
              //   then MATCH
              //   else match b
              //     then MATCH
              //     else match c
              //       then MATCH
              //       else MISMATCH

              var result = MISMATCH$1;
              var map = null;

              for (var i = terms.length - 1; i >= 0; i--) {
                  var term = terms[i];

                  // reduce sequence of keywords into a Enum
                  if (isEnumCapatible(term)) {
                      if (map === null && i > 0 && isEnumCapatible(terms[i - 1])) {
                          map = Object.create(null);
                          result = createCondition(
                              {
                                  type: 'Enum',
                                  map: map
                              },
                              MATCH$1,
                              result
                          );
                      }

                      if (map !== null) {
                          var key = (isFunctionType(term.name) ? term.name.slice(0, -1) : term.name).toLowerCase();
                          if (key in map === false) {
                              map[key] = term;
                              continue;
                          }
                      }
                  }

                  map = null;

                  // create a new conditonal node
                  result = createCondition(
                      term,
                      MATCH$1,
                      result
                  );
              }
              return result;

          case '&&':
              // A double ampersand (&&) separates two or more components,
              // all of which must occur, in any order.

              // Use MatchOnce for groups with a large number of terms,
              // since &&-groups produces at least N!-node trees
              if (terms.length > 5) {
                  return {
                      type: 'MatchOnce',
                      terms: terms,
                      all: true
                  };
              }

              // Use a combination tree for groups with small number of terms
              //
              // a && b && c
              // =
              // match a
              //   then [b && c]
              //   else match b
              //     then [a && c]
              //     else match c
              //       then [a && b]
              //       else MISMATCH
              //
              // a && b
              // =
              // match a
              //   then match b
              //     then MATCH
              //     else MISMATCH
              //   else match b
              //     then match a
              //       then MATCH
              //       else MISMATCH
              //     else MISMATCH
              var result = MISMATCH$1;

              for (var i = terms.length - 1; i >= 0; i--) {
                  var term = terms[i];
                  var thenClause;

                  if (terms.length > 1) {
                      thenClause = buildGroupMatchGraph(
                          combinator,
                          terms.filter(function(newGroupTerm) {
                              return newGroupTerm !== term;
                          }),
                          false
                      );
                  } else {
                      thenClause = MATCH$1;
                  }

                  result = createCondition(
                      term,
                      thenClause,
                      result
                  );
              }
              return result;

          case '||':
              // A double bar (||) separates two or more options:
              // one or more of them must occur, in any order.

              // Use MatchOnce for groups with a large number of terms,
              // since ||-groups produces at least N!-node trees
              if (terms.length > 5) {
                  return {
                      type: 'MatchOnce',
                      terms: terms,
                      all: false
                  };
              }

              // Use a combination tree for groups with small number of terms
              //
              // a || b || c
              // =
              // match a
              //   then [b || c]
              //   else match b
              //     then [a || c]
              //     else match c
              //       then [a || b]
              //       else MISMATCH
              //
              // a || b
              // =
              // match a
              //   then match b
              //     then MATCH
              //     else MATCH
              //   else match b
              //     then match a
              //       then MATCH
              //       else MATCH
              //     else MISMATCH
              var result = atLeastOneTermMatched ? MATCH$1 : MISMATCH$1;

              for (var i = terms.length - 1; i >= 0; i--) {
                  var term = terms[i];
                  var thenClause;

                  if (terms.length > 1) {
                      thenClause = buildGroupMatchGraph(
                          combinator,
                          terms.filter(function(newGroupTerm) {
                              return newGroupTerm !== term;
                          }),
                          true
                      );
                  } else {
                      thenClause = MATCH$1;
                  }

                  result = createCondition(
                      term,
                      thenClause,
                      result
                  );
              }
              return result;
      }
  }

  function buildMultiplierMatchGraph(node) {
      var result = MATCH$1;
      var matchTerm = buildMatchGraph$1(node.term);

      if (node.max === 0) {
          // disable repeating of empty match to prevent infinite loop
          matchTerm = createCondition(
              matchTerm,
              DISALLOW_EMPTY$1,
              MISMATCH$1
          );

          // an occurrence count is not limited, make a cycle;
          // to collect more terms on each following matching mismatch
          result = createCondition(
              matchTerm,
              null, // will be a loop
              MISMATCH$1
          );

          result.then = createCondition(
              MATCH$1,
              MATCH$1,
              result // make a loop
          );

          if (node.comma) {
              result.then.else = createCondition(
                  { type: 'Comma', syntax: node },
                  result,
                  MISMATCH$1
              );
          }
      } else {
          // create a match node chain for [min .. max] interval with optional matches
          for (var i = node.min || 1; i <= node.max; i++) {
              if (node.comma && result !== MATCH$1) {
                  result = createCondition(
                      { type: 'Comma', syntax: node },
                      result,
                      MISMATCH$1
                  );
              }

              result = createCondition(
                  matchTerm,
                  createCondition(
                      MATCH$1,
                      MATCH$1,
                      result
                  ),
                  MISMATCH$1
              );
          }
      }

      if (node.min === 0) {
          // allow zero match
          result = createCondition(
              MATCH$1,
              MATCH$1,
              result
          );
      } else {
          // create a match node chain to collect [0 ... min - 1] required matches
          for (var i = 0; i < node.min - 1; i++) {
              if (node.comma && result !== MATCH$1) {
                  result = createCondition(
                      { type: 'Comma', syntax: node },
                      result,
                      MISMATCH$1
                  );
              }

              result = createCondition(
                  matchTerm,
                  result,
                  MISMATCH$1
              );
          }
      }

      return result;
  }

  function buildMatchGraph$1(node) {
      if (typeof node === 'function') {
          return {
              type: 'Generic',
              fn: node
          };
      }

      switch (node.type) {
          case 'Group':
              var result = buildGroupMatchGraph(
                  node.combinator,
                  node.terms.map(buildMatchGraph$1),
                  false
              );

              if (node.disallowEmpty) {
                  result = createCondition(
                      result,
                      DISALLOW_EMPTY$1,
                      MISMATCH$1
                  );
              }

              return result;

          case 'Multiplier':
              return buildMultiplierMatchGraph(node);

          case 'Type':
          case 'Property':
              return {
                  type: node.type,
                  name: node.name,
                  syntax: node
              };

          case 'Keyword':
              return {
                  type: node.type,
                  name: node.name.toLowerCase(),
                  syntax: node
              };

          case 'AtKeyword':
              return {
                  type: node.type,
                  name: '@' + node.name.toLowerCase(),
                  syntax: node
              };

          case 'Function':
              return {
                  type: node.type,
                  name: node.name.toLowerCase() + '(',
                  syntax: node
              };

          case 'String':
              // convert a one char length String to a Token
              if (node.value.length === 3) {
                  return {
                      type: 'Token',
                      value: node.value.charAt(1),
                      syntax: node
                  };
              }

              // otherwise use it as is
              return {
                  type: node.type,
                  value: node.value.substr(1, node.value.length - 2).replace(/\\'/g, '\''),
                  syntax: node
              };

          case 'Token':
              return {
                  type: node.type,
                  value: node.value,
                  syntax: node
              };

          case 'Comma':
              return {
                  type: node.type,
                  syntax: node
              };

          default:
              throw new Error('Unknown node type:', node.type);
      }
  }

  var matchGraph = {
      MATCH: MATCH$1,
      MISMATCH: MISMATCH$1,
      DISALLOW_EMPTY: DISALLOW_EMPTY$1,
      buildMatchGraph: function(syntaxTree, ref) {
          if (typeof syntaxTree === 'string') {
              syntaxTree = parse_1$3(syntaxTree);
          }

          return {
              type: 'MatchGraph',
              match: buildMatchGraph$1(syntaxTree),
              syntax: ref || null,
              source: syntaxTree
          };
      }
  };

  var hasOwnProperty$6 = Object.prototype.hasOwnProperty;

  var MATCH = matchGraph.MATCH;
  var MISMATCH = matchGraph.MISMATCH;
  var DISALLOW_EMPTY = matchGraph.DISALLOW_EMPTY;
  var TYPE$B = _const.TYPE;

  var STUB = 0;
  var TOKEN = 1;
  var OPEN_SYNTAX = 2;
  var CLOSE_SYNTAX = 3;

  var EXIT_REASON_MATCH = 'Match';
  var EXIT_REASON_MISMATCH = 'Mismatch';
  var EXIT_REASON_ITERATION_LIMIT = 'Maximum iteration number exceeded (please fill an issue on https://github.com/csstree/csstree/issues)';

  var ITERATION_LIMIT = 15000;
  var totalIterationCount = 0;

  function reverseList(list) {
      var prev = null;
      var next = null;
      var item = list;

      while (item !== null) {
          next = item.prev;
          item.prev = prev;
          prev = item;
          item = next;
      }

      return prev;
  }

  function areStringsEqualCaseInsensitive(testStr, referenceStr) {
      if (testStr.length !== referenceStr.length) {
          return false;
      }

      for (var i = 0; i < testStr.length; i++) {
          var testCode = testStr.charCodeAt(i);
          var referenceCode = referenceStr.charCodeAt(i);

          // testCode.toLowerCase() for U+0041 LATIN CAPITAL LETTER A (A) .. U+005A LATIN CAPITAL LETTER Z (Z).
          if (testCode >= 0x0041 && testCode <= 0x005A) {
              testCode = testCode | 32;
          }

          if (testCode !== referenceCode) {
              return false;
          }
      }

      return true;
  }

  function isContextEdgeDelim(token) {
      if (token.type !== TYPE$B.Delim) {
          return false;
      }

      // Fix matching for unicode-range: U+30??, U+FF00-FF9F
      // Probably we need to check out previous match instead
      return token.value !== '?';
  }

  function isCommaContextStart(token) {
      if (token === null) {
          return true;
      }

      return (
          token.type === TYPE$B.Comma ||
          token.type === TYPE$B.Function ||
          token.type === TYPE$B.LeftParenthesis ||
          token.type === TYPE$B.LeftSquareBracket ||
          token.type === TYPE$B.LeftCurlyBracket ||
          isContextEdgeDelim(token)
      );
  }

  function isCommaContextEnd(token) {
      if (token === null) {
          return true;
      }

      return (
          token.type === TYPE$B.RightParenthesis ||
          token.type === TYPE$B.RightSquareBracket ||
          token.type === TYPE$B.RightCurlyBracket ||
          token.type === TYPE$B.Delim
      );
  }

  function internalMatch(tokens, state, syntaxes) {
      function moveToNextToken() {
          do {
              tokenIndex++;
              token = tokenIndex < tokens.length ? tokens[tokenIndex] : null;
          } while (token !== null && (token.type === TYPE$B.WhiteSpace || token.type === TYPE$B.Comment));
      }

      function getNextToken(offset) {
          var nextIndex = tokenIndex + offset;

          return nextIndex < tokens.length ? tokens[nextIndex] : null;
      }

      function stateSnapshotFromSyntax(nextState, prev) {
          return {
              nextState: nextState,
              matchStack: matchStack,
              syntaxStack: syntaxStack,
              thenStack: thenStack,
              tokenIndex: tokenIndex,
              prev: prev
          };
      }

      function pushThenStack(nextState) {
          thenStack = {
              nextState: nextState,
              matchStack: matchStack,
              syntaxStack: syntaxStack,
              prev: thenStack
          };
      }

      function pushElseStack(nextState) {
          elseStack = stateSnapshotFromSyntax(nextState, elseStack);
      }

      function addTokenToMatch() {
          matchStack = {
              type: TOKEN,
              syntax: state.syntax,
              token: token,
              prev: matchStack
          };

          moveToNextToken();
          syntaxStash = null;

          if (tokenIndex > longestMatch) {
              longestMatch = tokenIndex;
          }
      }

      function openSyntax() {
          syntaxStack = {
              syntax: state.syntax,
              opts: state.syntax.opts || (syntaxStack !== null && syntaxStack.opts) || null,
              prev: syntaxStack
          };

          matchStack = {
              type: OPEN_SYNTAX,
              syntax: state.syntax,
              token: matchStack.token,
              prev: matchStack
          };
      }

      function closeSyntax() {
          if (matchStack.type === OPEN_SYNTAX) {
              matchStack = matchStack.prev;
          } else {
              matchStack = {
                  type: CLOSE_SYNTAX,
                  syntax: syntaxStack.syntax,
                  token: matchStack.token,
                  prev: matchStack
              };
          }

          syntaxStack = syntaxStack.prev;
      }

      var syntaxStack = null;
      var thenStack = null;
      var elseStack = null;

      // null – stashing allowed, nothing stashed
      // false – stashing disabled, nothing stashed
      // anithing else – fail stashable syntaxes, some syntax stashed
      var syntaxStash = null;

      var iterationCount = 0; // count iterations and prevent infinite loop
      var exitReason = null;

      var token = null;
      var tokenIndex = -1;
      var longestMatch = 0;
      var matchStack = {
          type: STUB,
          syntax: null,
          token: null,
          prev: null
      };

      moveToNextToken();

      while (exitReason === null && ++iterationCount < ITERATION_LIMIT) {
          // function mapList(list, fn) {
          //     var result = [];
          //     while (list) {
          //         result.unshift(fn(list));
          //         list = list.prev;
          //     }
          //     return result;
          // }
          // console.log('--\n',
          //     '#' + iterationCount,
          //     require('util').inspect({
          //         match: mapList(matchStack, x => x.type === TOKEN ? x.token && x.token.value : x.syntax ? ({ [OPEN_SYNTAX]: '<', [CLOSE_SYNTAX]: '</' }[x.type] || x.type) + '!' + x.syntax.name : null),
          //         token: token && token.value,
          //         tokenIndex,
          //         syntax: syntax.type + (syntax.id ? ' #' + syntax.id : '')
          //     }, { depth: null })
          // );
          switch (state.type) {
              case 'Match':
                  if (thenStack === null) {
                      // turn to MISMATCH when some tokens left unmatched
                      if (token !== null) {
                          // doesn't mismatch if just one token left and it's an IE hack
                          if (tokenIndex !== tokens.length - 1 || (token.value !== '\\0' && token.value !== '\\9')) {
                              state = MISMATCH;
                              break;
                          }
                      }

                      // break the main loop, return a result - MATCH
                      exitReason = EXIT_REASON_MATCH;
                      break;
                  }

                  // go to next syntax (`then` branch)
                  state = thenStack.nextState;

                  // check match is not empty
                  if (state === DISALLOW_EMPTY) {
                      if (thenStack.matchStack === matchStack) {
                          state = MISMATCH;
                          break;
                      } else {
                          state = MATCH;
                      }
                  }

                  // close syntax if needed
                  while (thenStack.syntaxStack !== syntaxStack) {
                      closeSyntax();
                  }

                  // pop stack
                  thenStack = thenStack.prev;
                  break;

              case 'Mismatch':
                  // when some syntax is stashed
                  if (syntaxStash !== null && syntaxStash !== false) {
                      // there is no else branches or a branch reduce match stack
                      if (elseStack === null || tokenIndex > elseStack.tokenIndex) {
                          // restore state from the stash
                          elseStack = syntaxStash;
                          syntaxStash = false; // disable stashing
                      }
                  } else if (elseStack === null) {
                      // no else branches -> break the main loop
                      // return a result - MISMATCH
                      exitReason = EXIT_REASON_MISMATCH;
                      break;
                  }

                  // go to next syntax (`else` branch)
                  state = elseStack.nextState;

                  // restore all the rest stack states
                  thenStack = elseStack.thenStack;
                  syntaxStack = elseStack.syntaxStack;
                  matchStack = elseStack.matchStack;
                  tokenIndex = elseStack.tokenIndex;
                  token = tokenIndex < tokens.length ? tokens[tokenIndex] : null;

                  // pop stack
                  elseStack = elseStack.prev;
                  break;

              case 'MatchGraph':
                  state = state.match;
                  break;

              case 'If':
                  // IMPORTANT: else stack push must go first,
                  // since it stores the state of thenStack before changes
                  if (state.else !== MISMATCH) {
                      pushElseStack(state.else);
                  }

                  if (state.then !== MATCH) {
                      pushThenStack(state.then);
                  }

                  state = state.match;
                  break;

              case 'MatchOnce':
                  state = {
                      type: 'MatchOnceBuffer',
                      syntax: state,
                      index: 0,
                      mask: 0
                  };
                  break;

              case 'MatchOnceBuffer':
                  var terms = state.syntax.terms;

                  if (state.index === terms.length) {
                      // no matches at all or it's required all terms to be matched
                      if (state.mask === 0 || state.syntax.all) {
                          state = MISMATCH;
                          break;
                      }

                      // a partial match is ok
                      state = MATCH;
                      break;
                  }

                  // all terms are matched
                  if (state.mask === (1 << terms.length) - 1) {
                      state = MATCH;
                      break;
                  }

                  for (; state.index < terms.length; state.index++) {
                      var matchFlag = 1 << state.index;

                      if ((state.mask & matchFlag) === 0) {
                          // IMPORTANT: else stack push must go first,
                          // since it stores the state of thenStack before changes
                          pushElseStack(state);
                          pushThenStack({
                              type: 'AddMatchOnce',
                              syntax: state.syntax,
                              mask: state.mask | matchFlag
                          });

                          // match
                          state = terms[state.index++];
                          break;
                      }
                  }
                  break;

              case 'AddMatchOnce':
                  state = {
                      type: 'MatchOnceBuffer',
                      syntax: state.syntax,
                      index: 0,
                      mask: state.mask
                  };
                  break;

              case 'Enum':
                  if (token !== null) {
                      var name = token.value.toLowerCase();

                      // drop \0 and \9 hack from keyword name
                      if (name.indexOf('\\') !== -1) {
                          name = name.replace(/\\[09].*$/, '');
                      }

                      if (hasOwnProperty$6.call(state.map, name)) {
                          state = state.map[name];
                          break;
                      }
                  }

                  state = MISMATCH;
                  break;

              case 'Generic':
                  var opts = syntaxStack !== null ? syntaxStack.opts : null;
                  var lastTokenIndex = tokenIndex + Math.floor(state.fn(token, getNextToken, opts));

                  if (!isNaN(lastTokenIndex) && lastTokenIndex > tokenIndex) {
                      while (tokenIndex < lastTokenIndex) {
                          addTokenToMatch();
                      }

                      state = MATCH;
                  } else {
                      state = MISMATCH;
                  }

                  break;

              case 'Type':
              case 'Property':
                  var syntaxDict = state.type === 'Type' ? 'types' : 'properties';
                  var dictSyntax = hasOwnProperty$6.call(syntaxes, syntaxDict) ? syntaxes[syntaxDict][state.name] : null;

                  if (!dictSyntax || !dictSyntax.match) {
                      throw new Error(
                          'Bad syntax reference: ' +
                          (state.type === 'Type'
                              ? '<' + state.name + '>'
                              : '<\'' + state.name + '\'>')
                      );
                  }

                  // stash a syntax for types with low priority
                  if (syntaxStash !== false && token !== null && state.type === 'Type') {
                      var lowPriorityMatching =
                          // https://drafts.csswg.org/css-values-4/#custom-idents
                          // When parsing positionally-ambiguous keywords in a property value, a <custom-ident> production
                          // can only claim the keyword if no other unfulfilled production can claim it.
                          (state.name === 'custom-ident' && token.type === TYPE$B.Ident) ||

                          // https://drafts.csswg.org/css-values-4/#lengths
                          // ... if a `0` could be parsed as either a <number> or a <length> in a property (such as line-height),
                          // it must parse as a <number>
                          (state.name === 'length' && token.value === '0');

                      if (lowPriorityMatching) {
                          if (syntaxStash === null) {
                              syntaxStash = stateSnapshotFromSyntax(state, elseStack);
                          }

                          state = MISMATCH;
                          break;
                      }
                  }

                  openSyntax();
                  state = dictSyntax.match;
                  break;

              case 'Keyword':
                  var name = state.name;

                  if (token !== null) {
                      var keywordName = token.value;

                      // drop \0 and \9 hack from keyword name
                      if (keywordName.indexOf('\\') !== -1) {
                          keywordName = keywordName.replace(/\\[09].*$/, '');
                      }

                      if (areStringsEqualCaseInsensitive(keywordName, name)) {
                          addTokenToMatch();
                          state = MATCH;
                          break;
                      }
                  }

                  state = MISMATCH;
                  break;

              case 'AtKeyword':
              case 'Function':
                  if (token !== null && areStringsEqualCaseInsensitive(token.value, state.name)) {
                      addTokenToMatch();
                      state = MATCH;
                      break;
                  }

                  state = MISMATCH;
                  break;

              case 'Token':
                  if (token !== null && token.value === state.value) {
                      addTokenToMatch();
                      state = MATCH;
                      break;
                  }

                  state = MISMATCH;
                  break;

              case 'Comma':
                  if (token !== null && token.type === TYPE$B.Comma) {
                      if (isCommaContextStart(matchStack.token)) {
                          state = MISMATCH;
                      } else {
                          addTokenToMatch();
                          state = isCommaContextEnd(token) ? MISMATCH : MATCH;
                      }
                  } else {
                      state = isCommaContextStart(matchStack.token) || isCommaContextEnd(token) ? MATCH : MISMATCH;
                  }

                  break;

              case 'String':
                  var string = '';

                  for (var lastTokenIndex = tokenIndex; lastTokenIndex < tokens.length && string.length < state.value.length; lastTokenIndex++) {
                      string += tokens[lastTokenIndex].value;
                  }

                  if (areStringsEqualCaseInsensitive(string, state.value)) {
                      while (tokenIndex < lastTokenIndex) {
                          addTokenToMatch();
                      }

                      state = MATCH;
                  } else {
                      state = MISMATCH;
                  }

                  break;

              default:
                  throw new Error('Unknown node type: ' + state.type);
          }
      }

      totalIterationCount += iterationCount;

      switch (exitReason) {
          case null:
              console.warn('[csstree-match] BREAK after ' + ITERATION_LIMIT + ' iterations');
              exitReason = EXIT_REASON_ITERATION_LIMIT;
              matchStack = null;
              break;

          case EXIT_REASON_MATCH:
              while (syntaxStack !== null) {
                  closeSyntax();
              }
              break;

          default:
              matchStack = null;
      }

      return {
          tokens: tokens,
          reason: exitReason,
          iterations: iterationCount,
          match: matchStack,
          longestMatch: longestMatch
      };
  }

  function matchAsList(tokens, matchGraph, syntaxes) {
      var matchResult = internalMatch(tokens, matchGraph, syntaxes || {});

      if (matchResult.match !== null) {
          var item = reverseList(matchResult.match).prev;

          matchResult.match = [];

          while (item !== null) {
              switch (item.type) {
                  case STUB:
                      break;

                  case OPEN_SYNTAX:
                  case CLOSE_SYNTAX:
                      matchResult.match.push({
                          type: item.type,
                          syntax: item.syntax
                      });
                      break;

                  default:
                      matchResult.match.push({
                          token: item.token.value,
                          node: item.token.node
                      });
                      break;
              }

              item = item.prev;
          }
      }

      return matchResult;
  }

  function matchAsTree$1(tokens, matchGraph, syntaxes) {
      var matchResult = internalMatch(tokens, matchGraph, syntaxes || {});

      if (matchResult.match === null) {
          return matchResult;
      }

      var item = matchResult.match;
      var host = matchResult.match = {
          syntax: matchGraph.syntax || null,
          match: []
      };
      var hostStack = [host];

      // revert a list and start with 2nd item since 1st is a stub item
      item = reverseList(item).prev;

      // build a tree
      while (item !== null) {
          switch (item.type) {
              case OPEN_SYNTAX:
                  host.match.push(host = {
                      syntax: item.syntax,
                      match: []
                  });
                  hostStack.push(host);
                  break;

              case CLOSE_SYNTAX:
                  hostStack.pop();
                  host = hostStack[hostStack.length - 1];
                  break;

              default:
                  host.match.push({
                      syntax: item.syntax || null,
                      token: item.token.value,
                      node: item.token.node
                  });
          }

          item = item.prev;
      }

      return matchResult;
  }

  var match = {
      matchAsList: matchAsList,
      matchAsTree: matchAsTree$1,
      getTotalIterationCount: function() {
          return totalIterationCount;
      }
  };

  function getTrace(node) {
      function shouldPutToTrace(syntax) {
          if (syntax === null) {
              return false;
          }

          return (
              syntax.type === 'Type' ||
              syntax.type === 'Property' ||
              syntax.type === 'Keyword'
          );
      }

      function hasMatch(matchNode) {
          if (Array.isArray(matchNode.match)) {
              // use for-loop for better perfomance
              for (var i = 0; i < matchNode.match.length; i++) {
                  if (hasMatch(matchNode.match[i])) {
                      if (shouldPutToTrace(matchNode.syntax)) {
                          result.unshift(matchNode.syntax);
                      }

                      return true;
                  }
              }
          } else if (matchNode.node === node) {
              result = shouldPutToTrace(matchNode.syntax)
                  ? [matchNode.syntax]
                  : [];

              return true;
          }

          return false;
      }

      var result = null;

      if (this.matched !== null) {
          hasMatch(this.matched);
      }

      return result;
  }

  function testNode(match, node, fn) {
      var trace = getTrace.call(match, node);

      if (trace === null) {
          return false;
      }

      return trace.some(fn);
  }

  function isType(node, type) {
      return testNode(this, node, function(matchNode) {
          return matchNode.type === 'Type' && matchNode.name === type;
      });
  }

  function isProperty(node, property) {
      return testNode(this, node, function(matchNode) {
          return matchNode.type === 'Property' && matchNode.name === property;
      });
  }

  function isKeyword(node) {
      return testNode(this, node, function(matchNode) {
          return matchNode.type === 'Keyword';
      });
  }

  var trace = {
      getTrace: getTrace,
      isType: isType,
      isProperty: isProperty,
      isKeyword: isKeyword
  };

  function getFirstMatchNode(matchNode) {
      if ('node' in matchNode) {
          return matchNode.node;
      }

      return getFirstMatchNode(matchNode.match[0]);
  }

  function getLastMatchNode(matchNode) {
      if ('node' in matchNode) {
          return matchNode.node;
      }

      return getLastMatchNode(matchNode.match[matchNode.match.length - 1]);
  }

  function matchFragments(lexer, ast, match, type, name) {
      function findFragments(matchNode) {
          if (matchNode.syntax !== null &&
              matchNode.syntax.type === type &&
              matchNode.syntax.name === name) {
              var start = getFirstMatchNode(matchNode);
              var end = getLastMatchNode(matchNode);

              lexer.syntax.walk(ast, function(node, item, list) {
                  if (node === start) {
                      var nodes = new List_1();

                      do {
                          nodes.appendData(item.data);

                          if (item.data === end) {
                              break;
                          }

                          item = item.next;
                      } while (item !== null);

                      fragments.push({
                          parent: list,
                          nodes: nodes
                      });
                  }
              });
          }

          if (Array.isArray(matchNode.match)) {
              matchNode.match.forEach(findFragments);
          }
      }

      var fragments = [];

      if (match.matched !== null) {
          findFragments(match.matched);
      }

      return fragments;
  }

  var search = {
      matchFragments: matchFragments
  };

  var hasOwnProperty$5 = Object.prototype.hasOwnProperty;

  function isValidNumber(value) {
      // Number.isInteger(value) && value >= 0
      return (
          typeof value === 'number' &&
          isFinite(value) &&
          Math.floor(value) === value &&
          value >= 0
      );
  }

  function isValidLocation(loc) {
      return (
          Boolean(loc) &&
          isValidNumber(loc.offset) &&
          isValidNumber(loc.line) &&
          isValidNumber(loc.column)
      );
  }

  function createNodeStructureChecker(type, fields) {
      return function checkNode(node, warn) {
          if (!node || node.constructor !== Object) {
              return warn(node, 'Type of node should be an Object');
          }

          for (var key in node) {
              var valid = true;

              if (hasOwnProperty$5.call(node, key) === false) {
                  continue;
              }

              if (key === 'type') {
                  if (node.type !== type) {
                      warn(node, 'Wrong node type `' + node.type + '`, expected `' + type + '`');
                  }
              } else if (key === 'loc') {
                  if (node.loc === null) {
                      continue;
                  } else if (node.loc && node.loc.constructor === Object) {
                      if (typeof node.loc.source !== 'string') {
                          key += '.source';
                      } else if (!isValidLocation(node.loc.start)) {
                          key += '.start';
                      } else if (!isValidLocation(node.loc.end)) {
                          key += '.end';
                      } else {
                          continue;
                      }
                  }

                  valid = false;
              } else if (fields.hasOwnProperty(key)) {
                  for (var i = 0, valid = false; !valid && i < fields[key].length; i++) {
                      var fieldType = fields[key][i];

                      switch (fieldType) {
                          case String:
                              valid = typeof node[key] === 'string';
                              break;

                          case Boolean:
                              valid = typeof node[key] === 'boolean';
                              break;

                          case null:
                              valid = node[key] === null;
                              break;

                          default:
                              if (typeof fieldType === 'string') {
                                  valid = node[key] && node[key].type === fieldType;
                              } else if (Array.isArray(fieldType)) {
                                  valid = node[key] instanceof List_1;
                              }
                      }
                  }
              } else {
                  warn(node, 'Unknown field `' + key + '` for ' + type + ' node type');
              }

              if (!valid) {
                  warn(node, 'Bad value for `' + type + '.' + key + '`');
              }
          }

          for (var key in fields) {
              if (hasOwnProperty$5.call(fields, key) &&
                  hasOwnProperty$5.call(node, key) === false) {
                  warn(node, 'Field `' + type + '.' + key + '` is missed');
              }
          }
      };
  }

  function processStructure(name, nodeType) {
      var structure = nodeType.structure;
      var fields = {
          type: String,
          loc: true
      };
      var docs = {
          type: '"' + name + '"'
      };

      for (var key in structure) {
          if (hasOwnProperty$5.call(structure, key) === false) {
              continue;
          }

          var docsTypes = [];
          var fieldTypes = fields[key] = Array.isArray(structure[key])
              ? structure[key].slice()
              : [structure[key]];

          for (var i = 0; i < fieldTypes.length; i++) {
              var fieldType = fieldTypes[i];
              if (fieldType === String || fieldType === Boolean) {
                  docsTypes.push(fieldType.name);
              } else if (fieldType === null) {
                  docsTypes.push('null');
              } else if (typeof fieldType === 'string') {
                  docsTypes.push('<' + fieldType + '>');
              } else if (Array.isArray(fieldType)) {
                  docsTypes.push('List'); // TODO: use type enum
              } else {
                  throw new Error('Wrong value `' + fieldType + '` in `' + name + '.' + key + '` structure definition');
              }
          }

          docs[key] = docsTypes.join(' | ');
      }

      return {
          docs: docs,
          check: createNodeStructureChecker(name, fields)
      };
  }

  var structure = {
      getStructureFromConfig: function(config) {
          var structure = {};

          if (config.node) {
              for (var name in config.node) {
                  if (hasOwnProperty$5.call(config.node, name)) {
                      var nodeType = config.node[name];

                      if (nodeType.structure) {
                          structure[name] = processStructure(name, nodeType);
                      } else {
                          throw new Error('Missed `structure` field in `' + name + '` node type definition');
                      }
                  }
              }
          }

          return structure;
      }
  };

  var SyntaxReferenceError = error.SyntaxReferenceError;
  var SyntaxMatchError = error.SyntaxMatchError;






  var buildMatchGraph = matchGraph.buildMatchGraph;
  var matchAsTree = match.matchAsTree;


  var getStructureFromConfig = structure.getStructureFromConfig;
  var cssWideKeywords = buildMatchGraph('inherit | initial | unset');
  var cssWideKeywordsWithExpression = buildMatchGraph('inherit | initial | unset | <-ms-legacy-expression>');

  function dumpMapSyntax(map, compact, syntaxAsAst) {
      var result = {};

      for (var name in map) {
          if (map[name].syntax) {
              result[name] = syntaxAsAst
                  ? map[name].syntax
                  : generate_1(map[name].syntax, { compact: compact });
          }
      }

      return result;
  }

  function dumpAtruleMapSyntax(map, compact, syntaxAsAst) {
      const result = {};

      for (const [name, atrule] of Object.entries(map)) {
          result[name] = {
              prelude: atrule.prelude && (
                  syntaxAsAst
                      ? atrule.prelude.syntax
                      : generate_1(atrule.prelude.syntax, { compact })
              ),
              descriptors: atrule.descriptors && dumpMapSyntax(atrule.descriptors, compact, syntaxAsAst)
          };
      }

      return result;
  }

  function valueHasVar(tokens) {
      for (var i = 0; i < tokens.length; i++) {
          if (tokens[i].value.toLowerCase() === 'var(') {
              return true;
          }
      }

      return false;
  }

  function buildMatchResult(match, error, iterations) {
      return {
          matched: match,
          iterations: iterations,
          error: error,
          getTrace: trace.getTrace,
          isType: trace.isType,
          isProperty: trace.isProperty,
          isKeyword: trace.isKeyword
      };
  }

  function matchSyntax(lexer, syntax, value, useCommon) {
      var tokens = prepareTokens_1(value, lexer.syntax);
      var result;

      if (valueHasVar(tokens)) {
          return buildMatchResult(null, new Error('Matching for a tree with var() is not supported'));
      }

      if (useCommon) {
          result = matchAsTree(tokens, lexer.valueCommonSyntax, lexer);
      }

      if (!useCommon || !result.match) {
          result = matchAsTree(tokens, syntax.match, lexer);
          if (!result.match) {
              return buildMatchResult(
                  null,
                  new SyntaxMatchError(result.reason, syntax.syntax, value, result),
                  result.iterations
              );
          }
      }

      return buildMatchResult(result.match, null, result.iterations);
  }

  var Lexer = function(config, syntax, structure) {
      this.valueCommonSyntax = cssWideKeywords;
      this.syntax = syntax;
      this.generic = false;
      this.atrules = {};
      this.properties = {};
      this.types = {};
      this.structure = structure || getStructureFromConfig(config);

      if (config) {
          if (config.types) {
              for (var name in config.types) {
                  this.addType_(name, config.types[name]);
              }
          }

          if (config.generic) {
              this.generic = true;
              for (var name in generic) {
                  this.addType_(name, generic[name]);
              }
          }

          if (config.atrules) {
              for (var name in config.atrules) {
                  this.addAtrule_(name, config.atrules[name]);
              }
          }

          if (config.properties) {
              for (var name in config.properties) {
                  this.addProperty_(name, config.properties[name]);
              }
          }
      }
  };

  Lexer.prototype = {
      structure: {},
      checkStructure: function(ast) {
          function collectWarning(node, message) {
              warns.push({
                  node: node,
                  message: message
              });
          }

          var structure = this.structure;
          var warns = [];

          this.syntax.walk(ast, function(node) {
              if (structure.hasOwnProperty(node.type)) {
                  structure[node.type].check(node, collectWarning);
              } else {
                  collectWarning(node, 'Unknown node type `' + node.type + '`');
              }
          });

          return warns.length ? warns : false;
      },

      createDescriptor: function(syntax, type, name, parent = null) {
          var ref = {
              type: type,
              name: name
          };
          var descriptor = {
              type: type,
              name: name,
              parent: parent,
              syntax: null,
              match: null
          };

          if (typeof syntax === 'function') {
              descriptor.match = buildMatchGraph(syntax, ref);
          } else {
              if (typeof syntax === 'string') {
                  // lazy parsing on first access
                  Object.defineProperty(descriptor, 'syntax', {
                      get: function() {
                          Object.defineProperty(descriptor, 'syntax', {
                              value: parse_1$3(syntax)
                          });

                          return descriptor.syntax;
                      }
                  });
              } else {
                  descriptor.syntax = syntax;
              }

              // lazy graph build on first access
              Object.defineProperty(descriptor, 'match', {
                  get: function() {
                      Object.defineProperty(descriptor, 'match', {
                          value: buildMatchGraph(descriptor.syntax, ref)
                      });

                      return descriptor.match;
                  }
              });
          }

          return descriptor;
      },
      addAtrule_: function(name, syntax) {
          if (!syntax) {
              return;
          }

          this.atrules[name] = {
              type: 'Atrule',
              name: name,
              prelude: syntax.prelude ? this.createDescriptor(syntax.prelude, 'AtrulePrelude', name) : null,
              descriptors: syntax.descriptors
                  ? Object.keys(syntax.descriptors).reduce((res, descName) => {
                      res[descName] = this.createDescriptor(syntax.descriptors[descName], 'AtruleDescriptor', descName, name);
                      return res;
                  }, {})
                  : null
          };
      },
      addProperty_: function(name, syntax) {
          if (!syntax) {
              return;
          }

          this.properties[name] = this.createDescriptor(syntax, 'Property', name);
      },
      addType_: function(name, syntax) {
          if (!syntax) {
              return;
          }

          this.types[name] = this.createDescriptor(syntax, 'Type', name);

          if (syntax === generic['-ms-legacy-expression']) {
              this.valueCommonSyntax = cssWideKeywordsWithExpression;
          }
      },

      checkAtruleName: function(atruleName) {
          if (!this.getAtrule(atruleName)) {
              return new SyntaxReferenceError('Unknown at-rule', '@' + atruleName);
          }
      },
      checkAtrulePrelude: function(atruleName, prelude) {
          let error = this.checkAtruleName(atruleName);

          if (error) {
              return error;
          }

          var atrule = this.getAtrule(atruleName);

          if (!atrule.prelude && prelude) {
              return new SyntaxError('At-rule `@' + atruleName + '` should not contain a prelude');
          }

          if (atrule.prelude && !prelude) {
              return new SyntaxError('At-rule `@' + atruleName + '` should contain a prelude');
          }
      },
      checkAtruleDescriptorName: function(atruleName, descriptorName) {
          let error = this.checkAtruleName(atruleName);

          if (error) {
              return error;
          }

          var atrule = this.getAtrule(atruleName);
          var descriptor = names.keyword(descriptorName);

          if (!atrule.descriptors) {
              return new SyntaxError('At-rule `@' + atruleName + '` has no known descriptors');
          }

          if (!atrule.descriptors[descriptor.name] &&
              !atrule.descriptors[descriptor.basename]) {
              return new SyntaxReferenceError('Unknown at-rule descriptor', descriptorName);
          }
      },
      checkPropertyName: function(propertyName) {
          var property = names.property(propertyName);

          // don't match syntax for a custom property
          if (property.custom) {
              return new Error('Lexer matching doesn\'t applicable for custom properties');
          }

          if (!this.getProperty(propertyName)) {
              return new SyntaxReferenceError('Unknown property', propertyName);
          }
      },

      matchAtrulePrelude: function(atruleName, prelude) {
          var error = this.checkAtrulePrelude(atruleName, prelude);

          if (error) {
              return buildMatchResult(null, error);
          }

          if (!prelude) {
              return buildMatchResult(null, null);
          }

          return matchSyntax(this, this.getAtrule(atruleName).prelude, prelude, false);
      },
      matchAtruleDescriptor: function(atruleName, descriptorName, value) {
          var error = this.checkAtruleDescriptorName(atruleName, descriptorName);

          if (error) {
              return buildMatchResult(null, error);
          }

          var atrule = this.getAtrule(atruleName);
          var descriptor = names.keyword(descriptorName);

          return matchSyntax(this, atrule.descriptors[descriptor.name] || atrule.descriptors[descriptor.basename], value, false);
      },
      matchDeclaration: function(node) {
          if (node.type !== 'Declaration') {
              return buildMatchResult(null, new Error('Not a Declaration node'));
          }

          return this.matchProperty(node.property, node.value);
      },
      matchProperty: function(propertyName, value) {
          var error = this.checkPropertyName(propertyName);

          if (error) {
              return buildMatchResult(null, error);
          }

          return matchSyntax(this, this.getProperty(propertyName), value, true);
      },
      matchType: function(typeName, value) {
          var typeSyntax = this.getType(typeName);

          if (!typeSyntax) {
              return buildMatchResult(null, new SyntaxReferenceError('Unknown type', typeName));
          }

          return matchSyntax(this, typeSyntax, value, false);
      },
      match: function(syntax, value) {
          if (typeof syntax !== 'string' && (!syntax || !syntax.type)) {
              return buildMatchResult(null, new SyntaxReferenceError('Bad syntax'));
          }

          if (typeof syntax === 'string' || !syntax.match) {
              syntax = this.createDescriptor(syntax, 'Type', 'anonymous');
          }

          return matchSyntax(this, syntax, value, false);
      },

      findValueFragments: function(propertyName, value, type, name) {
          return search.matchFragments(this, value, this.matchProperty(propertyName, value), type, name);
      },
      findDeclarationValueFragments: function(declaration, type, name) {
          return search.matchFragments(this, declaration.value, this.matchDeclaration(declaration), type, name);
      },
      findAllFragments: function(ast, type, name) {
          var result = [];

          this.syntax.walk(ast, {
              visit: 'Declaration',
              enter: function(declaration) {
                  result.push.apply(result, this.findDeclarationValueFragments(declaration, type, name));
              }.bind(this)
          });

          return result;
      },

      getAtrule: function(atruleName, fallbackBasename = true) {
          var atrule = names.keyword(atruleName);
          var atruleEntry = atrule.vendor && fallbackBasename
              ? this.atrules[atrule.name] || this.atrules[atrule.basename]
              : this.atrules[atrule.name];

          return atruleEntry || null;
      },
      getAtrulePrelude: function(atruleName, fallbackBasename = true) {
          const atrule = this.getAtrule(atruleName, fallbackBasename);

          return atrule && atrule.prelude || null;
      },
      getAtruleDescriptor: function(atruleName, name) {
          return this.atrules.hasOwnProperty(atruleName) && this.atrules.declarators
              ? this.atrules[atruleName].declarators[name] || null
              : null;
      },
      getProperty: function(propertyName, fallbackBasename = true) {
          var property = names.property(propertyName);
          var propertyEntry = property.vendor && fallbackBasename
              ? this.properties[property.name] || this.properties[property.basename]
              : this.properties[property.name];

          return propertyEntry || null;
      },
      getType: function(name) {
          return this.types.hasOwnProperty(name) ? this.types[name] : null;
      },

      validate: function() {
          function validate(syntax, name, broken, descriptor) {
              if (broken.hasOwnProperty(name)) {
                  return broken[name];
              }

              broken[name] = false;
              if (descriptor.syntax !== null) {
                  walk(descriptor.syntax, function(node) {
                      if (node.type !== 'Type' && node.type !== 'Property') {
                          return;
                      }

                      var map = node.type === 'Type' ? syntax.types : syntax.properties;
                      var brokenMap = node.type === 'Type' ? brokenTypes : brokenProperties;

                      if (!map.hasOwnProperty(node.name) || validate(syntax, node.name, brokenMap, map[node.name])) {
                          broken[name] = true;
                      }
                  }, this);
              }
          }

          var brokenTypes = {};
          var brokenProperties = {};

          for (var key in this.types) {
              validate(this, key, brokenTypes, this.types[key]);
          }

          for (var key in this.properties) {
              validate(this, key, brokenProperties, this.properties[key]);
          }

          brokenTypes = Object.keys(brokenTypes).filter(function(name) {
              return brokenTypes[name];
          });
          brokenProperties = Object.keys(brokenProperties).filter(function(name) {
              return brokenProperties[name];
          });

          if (brokenTypes.length || brokenProperties.length) {
              return {
                  types: brokenTypes,
                  properties: brokenProperties
              };
          }

          return null;
      },
      dump: function(syntaxAsAst, pretty) {
          return {
              generic: this.generic,
              types: dumpMapSyntax(this.types, !pretty, syntaxAsAst),
              properties: dumpMapSyntax(this.properties, !pretty, syntaxAsAst),
              atrules: dumpAtruleMapSyntax(this.atrules, !pretty, syntaxAsAst)
          };
      },
      toString: function() {
          return JSON.stringify(this.dump());
      }
  };

  var Lexer_1 = Lexer;

  var definitionSyntax = {
      SyntaxError: _SyntaxError,
      parse: parse_1$3,
      generate: generate_1,
      walk: walk
  };

  var isBOM = tokenizer$1.isBOM;

  var N$1 = 10;
  var F = 12;
  var R = 13;

  function computeLinesAndColumns(host, source) {
      var sourceLength = source.length;
      var lines = adoptBuffer(host.lines, sourceLength); // +1
      var line = host.startLine;
      var columns = adoptBuffer(host.columns, sourceLength);
      var column = host.startColumn;
      var startOffset = source.length > 0 ? isBOM(source.charCodeAt(0)) : 0;

      for (var i = startOffset; i < sourceLength; i++) { // -1
          var code = source.charCodeAt(i);

          lines[i] = line;
          columns[i] = column++;

          if (code === N$1 || code === R || code === F) {
              if (code === R && i + 1 < sourceLength && source.charCodeAt(i + 1) === N$1) {
                  i++;
                  lines[i] = line;
                  columns[i] = column;
              }

              line++;
              column = 1;
          }
      }

      lines[i] = line;
      columns[i] = column;

      host.lines = lines;
      host.columns = columns;
  }

  var OffsetToLocation = function() {
      this.lines = null;
      this.columns = null;
      this.linesAndColumnsComputed = false;
  };

  OffsetToLocation.prototype = {
      setSource: function(source, startOffset, startLine, startColumn) {
          this.source = source;
          this.startOffset = typeof startOffset === 'undefined' ? 0 : startOffset;
          this.startLine = typeof startLine === 'undefined' ? 1 : startLine;
          this.startColumn = typeof startColumn === 'undefined' ? 1 : startColumn;
          this.linesAndColumnsComputed = false;
      },

      ensureLinesAndColumnsComputed: function() {
          if (!this.linesAndColumnsComputed) {
              computeLinesAndColumns(this, this.source);
              this.linesAndColumnsComputed = true;
          }
      },
      getLocation: function(offset, filename) {
          this.ensureLinesAndColumnsComputed();

          return {
              source: filename,
              offset: this.startOffset + offset,
              line: this.lines[offset],
              column: this.columns[offset]
          };
      },
      getLocationRange: function(start, end, filename) {
          this.ensureLinesAndColumnsComputed();

          return {
              source: filename,
              start: {
                  offset: this.startOffset + start,
                  line: this.lines[start],
                  column: this.columns[start]
              },
              end: {
                  offset: this.startOffset + end,
                  line: this.lines[end],
                  column: this.columns[end]
              }
          };
      }
  };

  var OffsetToLocation_1 = OffsetToLocation;

  var TYPE$A = tokenizer$1.TYPE;
  var WHITESPACE$a = TYPE$A.WhiteSpace;
  var COMMENT$8 = TYPE$A.Comment;

  var sequence = function readSequence(recognizer) {
      var children = this.createList();
      var child = null;
      var context = {
          recognizer: recognizer,
          space: null,
          ignoreWS: false,
          ignoreWSAfter: false
      };

      this.scanner.skipSC();

      while (!this.scanner.eof) {
          switch (this.scanner.tokenType) {
              case COMMENT$8:
                  this.scanner.next();
                  continue;

              case WHITESPACE$a:
                  if (context.ignoreWS) {
                      this.scanner.next();
                  } else {
                      context.space = this.WhiteSpace();
                  }
                  continue;
          }

          child = recognizer.getNode.call(this, context);

          if (child === undefined) {
              break;
          }

          if (context.space !== null) {
              children.push(context.space);
              context.space = null;
          }

          children.push(child);

          if (context.ignoreWSAfter) {
              context.ignoreWSAfter = false;
              context.ignoreWS = true;
          } else {
              context.ignoreWS = false;
          }
      }

      return children;
  };

  var { findWhiteSpaceStart, cmpStr: cmpStr$2 } = utils;

  var noop$1 = function() {};

  var TYPE$z = _const.TYPE;
  var NAME$1 = _const.NAME;
  var WHITESPACE$9 = TYPE$z.WhiteSpace;
  var COMMENT$7 = TYPE$z.Comment;
  var IDENT$g = TYPE$z.Ident;
  var FUNCTION$6 = TYPE$z.Function;
  var URL$3 = TYPE$z.Url;
  var HASH$5 = TYPE$z.Hash;
  var PERCENTAGE$3 = TYPE$z.Percentage;
  var NUMBER$7 = TYPE$z.Number;
  var NUMBERSIGN$3 = 0x0023; // U+0023 NUMBER SIGN (#)
  var NULL = 0;

  function createParseContext(name) {
      return function() {
          return this[name]();
      };
  }

  function processConfig(config) {
      var parserConfig = {
          context: {},
          scope: {},
          atrule: {},
          pseudo: {}
      };

      if (config.parseContext) {
          for (var name in config.parseContext) {
              switch (typeof config.parseContext[name]) {
                  case 'function':
                      parserConfig.context[name] = config.parseContext[name];
                      break;

                  case 'string':
                      parserConfig.context[name] = createParseContext(config.parseContext[name]);
                      break;
              }
          }
      }

      if (config.scope) {
          for (var name in config.scope) {
              parserConfig.scope[name] = config.scope[name];
          }
      }

      if (config.atrule) {
          for (var name in config.atrule) {
              var atrule = config.atrule[name];

              if (atrule.parse) {
                  parserConfig.atrule[name] = atrule.parse;
              }
          }
      }

      if (config.pseudo) {
          for (var name in config.pseudo) {
              var pseudo = config.pseudo[name];

              if (pseudo.parse) {
                  parserConfig.pseudo[name] = pseudo.parse;
              }
          }
      }

      if (config.node) {
          for (var name in config.node) {
              parserConfig[name] = config.node[name].parse;
          }
      }

      return parserConfig;
  }

  var create$4 = function createParser(config) {
      var parser = {
          scanner: new TokenStream_1(),
          locationMap: new OffsetToLocation_1(),

          filename: '<unknown>',
          needPositions: false,
          onParseError: noop$1,
          onParseErrorThrow: false,
          parseAtrulePrelude: true,
          parseRulePrelude: true,
          parseValue: true,
          parseCustomProperty: false,

          readSequence: sequence,

          createList: function() {
              return new List_1();
          },
          createSingleNodeList: function(node) {
              return new List_1().appendData(node);
          },
          getFirstListNode: function(list) {
              return list && list.first();
          },
          getLastListNode: function(list) {
              return list.last();
          },

          parseWithFallback: function(consumer, fallback) {
              var startToken = this.scanner.tokenIndex;

              try {
                  return consumer.call(this);
              } catch (e) {
                  if (this.onParseErrorThrow) {
                      throw e;
                  }

                  var fallbackNode = fallback.call(this, startToken);

                  this.onParseErrorThrow = true;
                  this.onParseError(e, fallbackNode);
                  this.onParseErrorThrow = false;

                  return fallbackNode;
              }
          },

          lookupNonWSType: function(offset) {
              do {
                  var type = this.scanner.lookupType(offset++);
                  if (type !== WHITESPACE$9) {
                      return type;
                  }
              } while (type !== NULL);

              return NULL;
          },

          eat: function(tokenType) {
              if (this.scanner.tokenType !== tokenType) {
                  var offset = this.scanner.tokenStart;
                  var message = NAME$1[tokenType] + ' is expected';

                  // tweak message and offset
                  switch (tokenType) {
                      case IDENT$g:
                          // when identifier is expected but there is a function or url
                          if (this.scanner.tokenType === FUNCTION$6 || this.scanner.tokenType === URL$3) {
                              offset = this.scanner.tokenEnd - 1;
                              message = 'Identifier is expected but function found';
                          } else {
                              message = 'Identifier is expected';
                          }
                          break;

                      case HASH$5:
                          if (this.scanner.isDelim(NUMBERSIGN$3)) {
                              this.scanner.next();
                              offset++;
                              message = 'Name is expected';
                          }
                          break;

                      case PERCENTAGE$3:
                          if (this.scanner.tokenType === NUMBER$7) {
                              offset = this.scanner.tokenEnd;
                              message = 'Percent sign is expected';
                          }
                          break;

                      default:
                          // when test type is part of another token show error for current position + 1
                          // e.g. eat(HYPHENMINUS) will fail on "-foo", but pointing on "-" is odd
                          if (this.scanner.source.charCodeAt(this.scanner.tokenStart) === tokenType) {
                              offset = offset + 1;
                          }
                  }

                  this.error(message, offset);
              }

              this.scanner.next();
          },

          consume: function(tokenType) {
              var value = this.scanner.getTokenValue();

              this.eat(tokenType);

              return value;
          },
          consumeFunctionName: function() {
              var name = this.scanner.source.substring(this.scanner.tokenStart, this.scanner.tokenEnd - 1);

              this.eat(FUNCTION$6);

              return name;
          },

          getLocation: function(start, end) {
              if (this.needPositions) {
                  return this.locationMap.getLocationRange(
                      start,
                      end,
                      this.filename
                  );
              }

              return null;
          },
          getLocationFromList: function(list) {
              if (this.needPositions) {
                  var head = this.getFirstListNode(list);
                  var tail = this.getLastListNode(list);
                  return this.locationMap.getLocationRange(
                      head !== null ? head.loc.start.offset - this.locationMap.startOffset : this.scanner.tokenStart,
                      tail !== null ? tail.loc.end.offset - this.locationMap.startOffset : this.scanner.tokenStart,
                      this.filename
                  );
              }

              return null;
          },

          error: function(message, offset) {
              var location = typeof offset !== 'undefined' && offset < this.scanner.source.length
                  ? this.locationMap.getLocation(offset)
                  : this.scanner.eof
                      ? this.locationMap.getLocation(findWhiteSpaceStart(this.scanner.source, this.scanner.source.length - 1))
                      : this.locationMap.getLocation(this.scanner.tokenStart);

              throw new _SyntaxError$1(
                  message || 'Unexpected input',
                  this.scanner.source,
                  location.offset,
                  location.line,
                  location.column
              );
          }
      };

      config = processConfig(config || {});
      for (var key in config) {
          parser[key] = config[key];
      }

      return function(source, options) {
          options = options || {};

          var context = options.context || 'default';
          var onComment = options.onComment;
          var ast;

          tokenizer$1(source, parser.scanner);
          parser.locationMap.setSource(
              source,
              options.offset,
              options.line,
              options.column
          );

          parser.filename = options.filename || '<unknown>';
          parser.needPositions = Boolean(options.positions);
          parser.onParseError = typeof options.onParseError === 'function' ? options.onParseError : noop$1;
          parser.onParseErrorThrow = false;
          parser.parseAtrulePrelude = 'parseAtrulePrelude' in options ? Boolean(options.parseAtrulePrelude) : true;
          parser.parseRulePrelude = 'parseRulePrelude' in options ? Boolean(options.parseRulePrelude) : true;
          parser.parseValue = 'parseValue' in options ? Boolean(options.parseValue) : true;
          parser.parseCustomProperty = 'parseCustomProperty' in options ? Boolean(options.parseCustomProperty) : false;

          if (!parser.context.hasOwnProperty(context)) {
              throw new Error('Unknown context `' + context + '`');
          }

          if (typeof onComment === 'function') {
              parser.scanner.forEachToken((type, start, end) => {
                  if (type === COMMENT$7) {
                      const loc = parser.getLocation(start, end);
                      const value = cmpStr$2(source, end - 2, end, '*/')
                          ? source.slice(start + 2, end - 2)
                          : source.slice(start + 2, end);

                      onComment(value, loc);
                  }
              });
          }

          ast = parser.context[context].call(parser, options);

          if (!parser.scanner.eof) {
              parser.error();
          }

          return ast;
      };
  };

  /* -*- Mode: js; js-indent-level: 2; -*- */
  /*
   * Copyright 2011 Mozilla Foundation and contributors
   * Licensed under the New BSD license. See LICENSE or:
   * http://opensource.org/licenses/BSD-3-Clause
   */

  var intToCharMap = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/'.split('');

  /**
   * Encode an integer in the range of 0 to 63 to a single base 64 digit.
   */
  var encode$2 = function (number) {
    if (0 <= number && number < intToCharMap.length) {
      return intToCharMap[number];
    }
    throw new TypeError("Must be between 0 and 63: " + number);
  };

  /**
   * Decode a single base 64 character code digit to an integer. Returns -1 on
   * failure.
   */
  var decode$2 = function (charCode) {
    var bigA = 65;     // 'A'
    var bigZ = 90;     // 'Z'

    var littleA = 97;  // 'a'
    var littleZ = 122; // 'z'

    var zero = 48;     // '0'
    var nine = 57;     // '9'

    var plus = 43;     // '+'
    var slash = 47;    // '/'

    var littleOffset = 26;
    var numberOffset = 52;

    // 0 - 25: ABCDEFGHIJKLMNOPQRSTUVWXYZ
    if (bigA <= charCode && charCode <= bigZ) {
      return (charCode - bigA);
    }

    // 26 - 51: abcdefghijklmnopqrstuvwxyz
    if (littleA <= charCode && charCode <= littleZ) {
      return (charCode - littleA + littleOffset);
    }

    // 52 - 61: 0123456789
    if (zero <= charCode && charCode <= nine) {
      return (charCode - zero + numberOffset);
    }

    // 62: +
    if (charCode == plus) {
      return 62;
    }

    // 63: /
    if (charCode == slash) {
      return 63;
    }

    // Invalid base64 digit.
    return -1;
  };

  var base64 = {
  	encode: encode$2,
  	decode: decode$2
  };

  /* -*- Mode: js; js-indent-level: 2; -*- */

  /*
   * Copyright 2011 Mozilla Foundation and contributors
   * Licensed under the New BSD license. See LICENSE or:
   * http://opensource.org/licenses/BSD-3-Clause
   *
   * Based on the Base 64 VLQ implementation in Closure Compiler:
   * https://code.google.com/p/closure-compiler/source/browse/trunk/src/com/google/debugging/sourcemap/Base64VLQ.java
   *
   * Copyright 2011 The Closure Compiler Authors. All rights reserved.
   * Redistribution and use in source and binary forms, with or without
   * modification, are permitted provided that the following conditions are
   * met:
   *
   *  * Redistributions of source code must retain the above copyright
   *    notice, this list of conditions and the following disclaimer.
   *  * Redistributions in binary form must reproduce the above
   *    copyright notice, this list of conditions and the following
   *    disclaimer in the documentation and/or other materials provided
   *    with the distribution.
   *  * Neither the name of Google Inc. nor the names of its
   *    contributors may be used to endorse or promote products derived
   *    from this software without specific prior written permission.
   *
   * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
   * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
   * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
   * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
   * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
   * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
   * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
   * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
   */



  // A single base 64 digit can contain 6 bits of data. For the base 64 variable
  // length quantities we use in the source map spec, the first bit is the sign,
  // the next four bits are the actual value, and the 6th bit is the
  // continuation bit. The continuation bit tells us whether there are more
  // digits in this value following this digit.
  //
  //   Continuation
  //   |    Sign
  //   |    |
  //   V    V
  //   101011

  var VLQ_BASE_SHIFT = 5;

  // binary: 100000
  var VLQ_BASE = 1 << VLQ_BASE_SHIFT;

  // binary: 011111
  var VLQ_BASE_MASK = VLQ_BASE - 1;

  // binary: 100000
  var VLQ_CONTINUATION_BIT = VLQ_BASE;

  /**
   * Converts from a two-complement value to a value where the sign bit is
   * placed in the least significant bit.  For example, as decimals:
   *   1 becomes 2 (10 binary), -1 becomes 3 (11 binary)
   *   2 becomes 4 (100 binary), -2 becomes 5 (101 binary)
   */
  function toVLQSigned(aValue) {
    return aValue < 0
      ? ((-aValue) << 1) + 1
      : (aValue << 1) + 0;
  }

  /**
   * Converts to a two-complement value from a value where the sign bit is
   * placed in the least significant bit.  For example, as decimals:
   *   2 (10 binary) becomes 1, 3 (11 binary) becomes -1
   *   4 (100 binary) becomes 2, 5 (101 binary) becomes -2
   */
  function fromVLQSigned(aValue) {
    var isNegative = (aValue & 1) === 1;
    var shifted = aValue >> 1;
    return isNegative
      ? -shifted
      : shifted;
  }

  /**
   * Returns the base 64 VLQ encoded value.
   */
  var encode$1 = function base64VLQ_encode(aValue) {
    var encoded = "";
    var digit;

    var vlq = toVLQSigned(aValue);

    do {
      digit = vlq & VLQ_BASE_MASK;
      vlq >>>= VLQ_BASE_SHIFT;
      if (vlq > 0) {
        // There are still more digits in this value, so we must make sure the
        // continuation bit is marked.
        digit |= VLQ_CONTINUATION_BIT;
      }
      encoded += base64.encode(digit);
    } while (vlq > 0);

    return encoded;
  };

  /**
   * Decodes the next base 64 VLQ value from the given string and returns the
   * value and the rest of the string via the out parameter.
   */
  var decode$1 = function base64VLQ_decode(aStr, aIndex, aOutParam) {
    var strLen = aStr.length;
    var result = 0;
    var shift = 0;
    var continuation, digit;

    do {
      if (aIndex >= strLen) {
        throw new Error("Expected more digits in base 64 VLQ value.");
      }

      digit = base64.decode(aStr.charCodeAt(aIndex++));
      if (digit === -1) {
        throw new Error("Invalid base64 digit: " + aStr.charAt(aIndex - 1));
      }

      continuation = !!(digit & VLQ_CONTINUATION_BIT);
      digit &= VLQ_BASE_MASK;
      result = result + (digit << shift);
      shift += VLQ_BASE_SHIFT;
    } while (continuation);

    aOutParam.value = fromVLQSigned(result);
    aOutParam.rest = aIndex;
  };

  var base64Vlq = {
  	encode: encode$1,
  	decode: decode$1
  };

  /* -*- Mode: js; js-indent-level: 2; -*- */

  var util = createCommonjsModule(function (module, exports) {
  /*
   * Copyright 2011 Mozilla Foundation and contributors
   * Licensed under the New BSD license. See LICENSE or:
   * http://opensource.org/licenses/BSD-3-Clause
   */

  /**
   * This is a helper function for getting values from parameter/options
   * objects.
   *
   * @param args The object we are extracting values from
   * @param name The name of the property we are getting.
   * @param defaultValue An optional value to return if the property is missing
   * from the object. If this is not specified and the property is missing, an
   * error will be thrown.
   */
  function getArg(aArgs, aName, aDefaultValue) {
    if (aName in aArgs) {
      return aArgs[aName];
    } else if (arguments.length === 3) {
      return aDefaultValue;
    } else {
      throw new Error('"' + aName + '" is a required argument.');
    }
  }
  exports.getArg = getArg;

  var urlRegexp = /^(?:([\w+\-.]+):)?\/\/(?:(\w+:\w+)@)?([\w.-]*)(?::(\d+))?(.*)$/;
  var dataUrlRegexp = /^data:.+\,.+$/;

  function urlParse(aUrl) {
    var match = aUrl.match(urlRegexp);
    if (!match) {
      return null;
    }
    return {
      scheme: match[1],
      auth: match[2],
      host: match[3],
      port: match[4],
      path: match[5]
    };
  }
  exports.urlParse = urlParse;

  function urlGenerate(aParsedUrl) {
    var url = '';
    if (aParsedUrl.scheme) {
      url += aParsedUrl.scheme + ':';
    }
    url += '//';
    if (aParsedUrl.auth) {
      url += aParsedUrl.auth + '@';
    }
    if (aParsedUrl.host) {
      url += aParsedUrl.host;
    }
    if (aParsedUrl.port) {
      url += ":" + aParsedUrl.port;
    }
    if (aParsedUrl.path) {
      url += aParsedUrl.path;
    }
    return url;
  }
  exports.urlGenerate = urlGenerate;

  /**
   * Normalizes a path, or the path portion of a URL:
   *
   * - Replaces consecutive slashes with one slash.
   * - Removes unnecessary '.' parts.
   * - Removes unnecessary '<dir>/..' parts.
   *
   * Based on code in the Node.js 'path' core module.
   *
   * @param aPath The path or url to normalize.
   */
  function normalize(aPath) {
    var path = aPath;
    var url = urlParse(aPath);
    if (url) {
      if (!url.path) {
        return aPath;
      }
      path = url.path;
    }
    var isAbsolute = exports.isAbsolute(path);

    var parts = path.split(/\/+/);
    for (var part, up = 0, i = parts.length - 1; i >= 0; i--) {
      part = parts[i];
      if (part === '.') {
        parts.splice(i, 1);
      } else if (part === '..') {
        up++;
      } else if (up > 0) {
        if (part === '') {
          // The first part is blank if the path is absolute. Trying to go
          // above the root is a no-op. Therefore we can remove all '..' parts
          // directly after the root.
          parts.splice(i + 1, up);
          up = 0;
        } else {
          parts.splice(i, 2);
          up--;
        }
      }
    }
    path = parts.join('/');

    if (path === '') {
      path = isAbsolute ? '/' : '.';
    }

    if (url) {
      url.path = path;
      return urlGenerate(url);
    }
    return path;
  }
  exports.normalize = normalize;

  /**
   * Joins two paths/URLs.
   *
   * @param aRoot The root path or URL.
   * @param aPath The path or URL to be joined with the root.
   *
   * - If aPath is a URL or a data URI, aPath is returned, unless aPath is a
   *   scheme-relative URL: Then the scheme of aRoot, if any, is prepended
   *   first.
   * - Otherwise aPath is a path. If aRoot is a URL, then its path portion
   *   is updated with the result and aRoot is returned. Otherwise the result
   *   is returned.
   *   - If aPath is absolute, the result is aPath.
   *   - Otherwise the two paths are joined with a slash.
   * - Joining for example 'http://' and 'www.example.com' is also supported.
   */
  function join(aRoot, aPath) {
    if (aRoot === "") {
      aRoot = ".";
    }
    if (aPath === "") {
      aPath = ".";
    }
    var aPathUrl = urlParse(aPath);
    var aRootUrl = urlParse(aRoot);
    if (aRootUrl) {
      aRoot = aRootUrl.path || '/';
    }

    // `join(foo, '//www.example.org')`
    if (aPathUrl && !aPathUrl.scheme) {
      if (aRootUrl) {
        aPathUrl.scheme = aRootUrl.scheme;
      }
      return urlGenerate(aPathUrl);
    }

    if (aPathUrl || aPath.match(dataUrlRegexp)) {
      return aPath;
    }

    // `join('http://', 'www.example.com')`
    if (aRootUrl && !aRootUrl.host && !aRootUrl.path) {
      aRootUrl.host = aPath;
      return urlGenerate(aRootUrl);
    }

    var joined = aPath.charAt(0) === '/'
      ? aPath
      : normalize(aRoot.replace(/\/+$/, '') + '/' + aPath);

    if (aRootUrl) {
      aRootUrl.path = joined;
      return urlGenerate(aRootUrl);
    }
    return joined;
  }
  exports.join = join;

  exports.isAbsolute = function (aPath) {
    return aPath.charAt(0) === '/' || urlRegexp.test(aPath);
  };

  /**
   * Make a path relative to a URL or another path.
   *
   * @param aRoot The root path or URL.
   * @param aPath The path or URL to be made relative to aRoot.
   */
  function relative(aRoot, aPath) {
    if (aRoot === "") {
      aRoot = ".";
    }

    aRoot = aRoot.replace(/\/$/, '');

    // It is possible for the path to be above the root. In this case, simply
    // checking whether the root is a prefix of the path won't work. Instead, we
    // need to remove components from the root one by one, until either we find
    // a prefix that fits, or we run out of components to remove.
    var level = 0;
    while (aPath.indexOf(aRoot + '/') !== 0) {
      var index = aRoot.lastIndexOf("/");
      if (index < 0) {
        return aPath;
      }

      // If the only part of the root that is left is the scheme (i.e. http://,
      // file:///, etc.), one or more slashes (/), or simply nothing at all, we
      // have exhausted all components, so the path is not relative to the root.
      aRoot = aRoot.slice(0, index);
      if (aRoot.match(/^([^\/]+:\/)?\/*$/)) {
        return aPath;
      }

      ++level;
    }

    // Make sure we add a "../" for each component we removed from the root.
    return Array(level + 1).join("../") + aPath.substr(aRoot.length + 1);
  }
  exports.relative = relative;

  var supportsNullProto = (function () {
    var obj = Object.create(null);
    return !('__proto__' in obj);
  }());

  function identity (s) {
    return s;
  }

  /**
   * Because behavior goes wacky when you set `__proto__` on objects, we
   * have to prefix all the strings in our set with an arbitrary character.
   *
   * See https://github.com/mozilla/source-map/pull/31 and
   * https://github.com/mozilla/source-map/issues/30
   *
   * @param String aStr
   */
  function toSetString(aStr) {
    if (isProtoString(aStr)) {
      return '$' + aStr;
    }

    return aStr;
  }
  exports.toSetString = supportsNullProto ? identity : toSetString;

  function fromSetString(aStr) {
    if (isProtoString(aStr)) {
      return aStr.slice(1);
    }

    return aStr;
  }
  exports.fromSetString = supportsNullProto ? identity : fromSetString;

  function isProtoString(s) {
    if (!s) {
      return false;
    }

    var length = s.length;

    if (length < 9 /* "__proto__".length */) {
      return false;
    }

    if (s.charCodeAt(length - 1) !== 95  /* '_' */ ||
        s.charCodeAt(length - 2) !== 95  /* '_' */ ||
        s.charCodeAt(length - 3) !== 111 /* 'o' */ ||
        s.charCodeAt(length - 4) !== 116 /* 't' */ ||
        s.charCodeAt(length - 5) !== 111 /* 'o' */ ||
        s.charCodeAt(length - 6) !== 114 /* 'r' */ ||
        s.charCodeAt(length - 7) !== 112 /* 'p' */ ||
        s.charCodeAt(length - 8) !== 95  /* '_' */ ||
        s.charCodeAt(length - 9) !== 95  /* '_' */) {
      return false;
    }

    for (var i = length - 10; i >= 0; i--) {
      if (s.charCodeAt(i) !== 36 /* '$' */) {
        return false;
      }
    }

    return true;
  }

  /**
   * Comparator between two mappings where the original positions are compared.
   *
   * Optionally pass in `true` as `onlyCompareGenerated` to consider two
   * mappings with the same original source/line/column, but different generated
   * line and column the same. Useful when searching for a mapping with a
   * stubbed out mapping.
   */
  function compareByOriginalPositions(mappingA, mappingB, onlyCompareOriginal) {
    var cmp = strcmp(mappingA.source, mappingB.source);
    if (cmp !== 0) {
      return cmp;
    }

    cmp = mappingA.originalLine - mappingB.originalLine;
    if (cmp !== 0) {
      return cmp;
    }

    cmp = mappingA.originalColumn - mappingB.originalColumn;
    if (cmp !== 0 || onlyCompareOriginal) {
      return cmp;
    }

    cmp = mappingA.generatedColumn - mappingB.generatedColumn;
    if (cmp !== 0) {
      return cmp;
    }

    cmp = mappingA.generatedLine - mappingB.generatedLine;
    if (cmp !== 0) {
      return cmp;
    }

    return strcmp(mappingA.name, mappingB.name);
  }
  exports.compareByOriginalPositions = compareByOriginalPositions;

  /**
   * Comparator between two mappings with deflated source and name indices where
   * the generated positions are compared.
   *
   * Optionally pass in `true` as `onlyCompareGenerated` to consider two
   * mappings with the same generated line and column, but different
   * source/name/original line and column the same. Useful when searching for a
   * mapping with a stubbed out mapping.
   */
  function compareByGeneratedPositionsDeflated(mappingA, mappingB, onlyCompareGenerated) {
    var cmp = mappingA.generatedLine - mappingB.generatedLine;
    if (cmp !== 0) {
      return cmp;
    }

    cmp = mappingA.generatedColumn - mappingB.generatedColumn;
    if (cmp !== 0 || onlyCompareGenerated) {
      return cmp;
    }

    cmp = strcmp(mappingA.source, mappingB.source);
    if (cmp !== 0) {
      return cmp;
    }

    cmp = mappingA.originalLine - mappingB.originalLine;
    if (cmp !== 0) {
      return cmp;
    }

    cmp = mappingA.originalColumn - mappingB.originalColumn;
    if (cmp !== 0) {
      return cmp;
    }

    return strcmp(mappingA.name, mappingB.name);
  }
  exports.compareByGeneratedPositionsDeflated = compareByGeneratedPositionsDeflated;

  function strcmp(aStr1, aStr2) {
    if (aStr1 === aStr2) {
      return 0;
    }

    if (aStr1 === null) {
      return 1; // aStr2 !== null
    }

    if (aStr2 === null) {
      return -1; // aStr1 !== null
    }

    if (aStr1 > aStr2) {
      return 1;
    }

    return -1;
  }

  /**
   * Comparator between two mappings with inflated source and name strings where
   * the generated positions are compared.
   */
  function compareByGeneratedPositionsInflated(mappingA, mappingB) {
    var cmp = mappingA.generatedLine - mappingB.generatedLine;
    if (cmp !== 0) {
      return cmp;
    }

    cmp = mappingA.generatedColumn - mappingB.generatedColumn;
    if (cmp !== 0) {
      return cmp;
    }

    cmp = strcmp(mappingA.source, mappingB.source);
    if (cmp !== 0) {
      return cmp;
    }

    cmp = mappingA.originalLine - mappingB.originalLine;
    if (cmp !== 0) {
      return cmp;
    }

    cmp = mappingA.originalColumn - mappingB.originalColumn;
    if (cmp !== 0) {
      return cmp;
    }

    return strcmp(mappingA.name, mappingB.name);
  }
  exports.compareByGeneratedPositionsInflated = compareByGeneratedPositionsInflated;

  /**
   * Strip any JSON XSSI avoidance prefix from the string (as documented
   * in the source maps specification), and then parse the string as
   * JSON.
   */
  function parseSourceMapInput(str) {
    return JSON.parse(str.replace(/^\)]}'[^\n]*\n/, ''));
  }
  exports.parseSourceMapInput = parseSourceMapInput;

  /**
   * Compute the URL of a source given the the source root, the source's
   * URL, and the source map's URL.
   */
  function computeSourceURL(sourceRoot, sourceURL, sourceMapURL) {
    sourceURL = sourceURL || '';

    if (sourceRoot) {
      // This follows what Chrome does.
      if (sourceRoot[sourceRoot.length - 1] !== '/' && sourceURL[0] !== '/') {
        sourceRoot += '/';
      }
      // The spec says:
      //   Line 4: An optional source root, useful for relocating source
      //   files on a server or removing repeated values in the
      //   “sources” entry.  This value is prepended to the individual
      //   entries in the “source” field.
      sourceURL = sourceRoot + sourceURL;
    }

    // Historically, SourceMapConsumer did not take the sourceMapURL as
    // a parameter.  This mode is still somewhat supported, which is why
    // this code block is conditional.  However, it's preferable to pass
    // the source map URL to SourceMapConsumer, so that this function
    // can implement the source URL resolution algorithm as outlined in
    // the spec.  This block is basically the equivalent of:
    //    new URL(sourceURL, sourceMapURL).toString()
    // ... except it avoids using URL, which wasn't available in the
    // older releases of node still supported by this library.
    //
    // The spec says:
    //   If the sources are not absolute URLs after prepending of the
    //   “sourceRoot”, the sources are resolved relative to the
    //   SourceMap (like resolving script src in a html document).
    if (sourceMapURL) {
      var parsed = urlParse(sourceMapURL);
      if (!parsed) {
        throw new Error("sourceMapURL could not be parsed");
      }
      if (parsed.path) {
        // Strip the last path component, but keep the "/".
        var index = parsed.path.lastIndexOf('/');
        if (index >= 0) {
          parsed.path = parsed.path.substring(0, index + 1);
        }
      }
      sourceURL = join(urlGenerate(parsed), sourceURL);
    }

    return normalize(sourceURL);
  }
  exports.computeSourceURL = computeSourceURL;
  });

  /* -*- Mode: js; js-indent-level: 2; -*- */

  /*
   * Copyright 2011 Mozilla Foundation and contributors
   * Licensed under the New BSD license. See LICENSE or:
   * http://opensource.org/licenses/BSD-3-Clause
   */


  var has$4 = Object.prototype.hasOwnProperty;
  var hasNativeMap = typeof Map !== "undefined";

  /**
   * A data structure which is a combination of an array and a set. Adding a new
   * member is O(1), testing for membership is O(1), and finding the index of an
   * element is O(1). Removing elements from the set is not supported. Only
   * strings are supported for membership.
   */
  function ArraySet$1() {
    this._array = [];
    this._set = hasNativeMap ? new Map() : Object.create(null);
  }

  /**
   * Static method for creating ArraySet instances from an existing array.
   */
  ArraySet$1.fromArray = function ArraySet_fromArray(aArray, aAllowDuplicates) {
    var set = new ArraySet$1();
    for (var i = 0, len = aArray.length; i < len; i++) {
      set.add(aArray[i], aAllowDuplicates);
    }
    return set;
  };

  /**
   * Return how many unique items are in this ArraySet. If duplicates have been
   * added, than those do not count towards the size.
   *
   * @returns Number
   */
  ArraySet$1.prototype.size = function ArraySet_size() {
    return hasNativeMap ? this._set.size : Object.getOwnPropertyNames(this._set).length;
  };

  /**
   * Add the given string to this set.
   *
   * @param String aStr
   */
  ArraySet$1.prototype.add = function ArraySet_add(aStr, aAllowDuplicates) {
    var sStr = hasNativeMap ? aStr : util.toSetString(aStr);
    var isDuplicate = hasNativeMap ? this.has(aStr) : has$4.call(this._set, sStr);
    var idx = this._array.length;
    if (!isDuplicate || aAllowDuplicates) {
      this._array.push(aStr);
    }
    if (!isDuplicate) {
      if (hasNativeMap) {
        this._set.set(aStr, idx);
      } else {
        this._set[sStr] = idx;
      }
    }
  };

  /**
   * Is the given string a member of this set?
   *
   * @param String aStr
   */
  ArraySet$1.prototype.has = function ArraySet_has(aStr) {
    if (hasNativeMap) {
      return this._set.has(aStr);
    } else {
      var sStr = util.toSetString(aStr);
      return has$4.call(this._set, sStr);
    }
  };

  /**
   * What is the index of the given string in the array?
   *
   * @param String aStr
   */
  ArraySet$1.prototype.indexOf = function ArraySet_indexOf(aStr) {
    if (hasNativeMap) {
      var idx = this._set.get(aStr);
      if (idx >= 0) {
          return idx;
      }
    } else {
      var sStr = util.toSetString(aStr);
      if (has$4.call(this._set, sStr)) {
        return this._set[sStr];
      }
    }

    throw new Error('"' + aStr + '" is not in the set.');
  };

  /**
   * What is the element at the given index?
   *
   * @param Number aIdx
   */
  ArraySet$1.prototype.at = function ArraySet_at(aIdx) {
    if (aIdx >= 0 && aIdx < this._array.length) {
      return this._array[aIdx];
    }
    throw new Error('No element indexed by ' + aIdx);
  };

  /**
   * Returns the array representation of this set (which has the proper indices
   * indicated by indexOf). Note that this is a copy of the internal array used
   * for storing the members so that no one can mess with internal state.
   */
  ArraySet$1.prototype.toArray = function ArraySet_toArray() {
    return this._array.slice();
  };

  var ArraySet_1 = ArraySet$1;

  var arraySet = {
  	ArraySet: ArraySet_1
  };

  /* -*- Mode: js; js-indent-level: 2; -*- */

  /*
   * Copyright 2014 Mozilla Foundation and contributors
   * Licensed under the New BSD license. See LICENSE or:
   * http://opensource.org/licenses/BSD-3-Clause
   */



  /**
   * Determine whether mappingB is after mappingA with respect to generated
   * position.
   */
  function generatedPositionAfter(mappingA, mappingB) {
    // Optimized for most common case
    var lineA = mappingA.generatedLine;
    var lineB = mappingB.generatedLine;
    var columnA = mappingA.generatedColumn;
    var columnB = mappingB.generatedColumn;
    return lineB > lineA || lineB == lineA && columnB >= columnA ||
           util.compareByGeneratedPositionsInflated(mappingA, mappingB) <= 0;
  }

  /**
   * A data structure to provide a sorted view of accumulated mappings in a
   * performance conscious manner. It trades a neglibable overhead in general
   * case for a large speedup in case of mappings being added in order.
   */
  function MappingList$1() {
    this._array = [];
    this._sorted = true;
    // Serves as infimum
    this._last = {generatedLine: -1, generatedColumn: 0};
  }

  /**
   * Iterate through internal items. This method takes the same arguments that
   * `Array.prototype.forEach` takes.
   *
   * NOTE: The order of the mappings is NOT guaranteed.
   */
  MappingList$1.prototype.unsortedForEach =
    function MappingList_forEach(aCallback, aThisArg) {
      this._array.forEach(aCallback, aThisArg);
    };

  /**
   * Add the given source mapping.
   *
   * @param Object aMapping
   */
  MappingList$1.prototype.add = function MappingList_add(aMapping) {
    if (generatedPositionAfter(this._last, aMapping)) {
      this._last = aMapping;
      this._array.push(aMapping);
    } else {
      this._sorted = false;
      this._array.push(aMapping);
    }
  };

  /**
   * Returns the flat, sorted array of mappings. The mappings are sorted by
   * generated position.
   *
   * WARNING: This method returns internal data without copying, for
   * performance. The return value must NOT be mutated, and should be treated as
   * an immutable borrow. If you want to take ownership, you must make your own
   * copy.
   */
  MappingList$1.prototype.toArray = function MappingList_toArray() {
    if (!this._sorted) {
      this._array.sort(util.compareByGeneratedPositionsInflated);
      this._sorted = true;
    }
    return this._array;
  };

  var MappingList_1 = MappingList$1;

  var mappingList = {
  	MappingList: MappingList_1
  };

  /* -*- Mode: js; js-indent-level: 2; -*- */

  /*
   * Copyright 2011 Mozilla Foundation and contributors
   * Licensed under the New BSD license. See LICENSE or:
   * http://opensource.org/licenses/BSD-3-Clause
   */



  var ArraySet = arraySet.ArraySet;
  var MappingList = mappingList.MappingList;

  /**
   * An instance of the SourceMapGenerator represents a source map which is
   * being built incrementally. You may pass an object with the following
   * properties:
   *
   *   - file: The filename of the generated source.
   *   - sourceRoot: A root for all relative URLs in this source map.
   */
  function SourceMapGenerator$1(aArgs) {
    if (!aArgs) {
      aArgs = {};
    }
    this._file = util.getArg(aArgs, 'file', null);
    this._sourceRoot = util.getArg(aArgs, 'sourceRoot', null);
    this._skipValidation = util.getArg(aArgs, 'skipValidation', false);
    this._sources = new ArraySet();
    this._names = new ArraySet();
    this._mappings = new MappingList();
    this._sourcesContents = null;
  }

  SourceMapGenerator$1.prototype._version = 3;

  /**
   * Creates a new SourceMapGenerator based on a SourceMapConsumer
   *
   * @param aSourceMapConsumer The SourceMap.
   */
  SourceMapGenerator$1.fromSourceMap =
    function SourceMapGenerator_fromSourceMap(aSourceMapConsumer) {
      var sourceRoot = aSourceMapConsumer.sourceRoot;
      var generator = new SourceMapGenerator$1({
        file: aSourceMapConsumer.file,
        sourceRoot: sourceRoot
      });
      aSourceMapConsumer.eachMapping(function (mapping) {
        var newMapping = {
          generated: {
            line: mapping.generatedLine,
            column: mapping.generatedColumn
          }
        };

        if (mapping.source != null) {
          newMapping.source = mapping.source;
          if (sourceRoot != null) {
            newMapping.source = util.relative(sourceRoot, newMapping.source);
          }

          newMapping.original = {
            line: mapping.originalLine,
            column: mapping.originalColumn
          };

          if (mapping.name != null) {
            newMapping.name = mapping.name;
          }
        }

        generator.addMapping(newMapping);
      });
      aSourceMapConsumer.sources.forEach(function (sourceFile) {
        var sourceRelative = sourceFile;
        if (sourceRoot !== null) {
          sourceRelative = util.relative(sourceRoot, sourceFile);
        }

        if (!generator._sources.has(sourceRelative)) {
          generator._sources.add(sourceRelative);
        }

        var content = aSourceMapConsumer.sourceContentFor(sourceFile);
        if (content != null) {
          generator.setSourceContent(sourceFile, content);
        }
      });
      return generator;
    };

  /**
   * Add a single mapping from original source line and column to the generated
   * source's line and column for this source map being created. The mapping
   * object should have the following properties:
   *
   *   - generated: An object with the generated line and column positions.
   *   - original: An object with the original line and column positions.
   *   - source: The original source file (relative to the sourceRoot).
   *   - name: An optional original token name for this mapping.
   */
  SourceMapGenerator$1.prototype.addMapping =
    function SourceMapGenerator_addMapping(aArgs) {
      var generated = util.getArg(aArgs, 'generated');
      var original = util.getArg(aArgs, 'original', null);
      var source = util.getArg(aArgs, 'source', null);
      var name = util.getArg(aArgs, 'name', null);

      if (!this._skipValidation) {
        this._validateMapping(generated, original, source, name);
      }

      if (source != null) {
        source = String(source);
        if (!this._sources.has(source)) {
          this._sources.add(source);
        }
      }

      if (name != null) {
        name = String(name);
        if (!this._names.has(name)) {
          this._names.add(name);
        }
      }

      this._mappings.add({
        generatedLine: generated.line,
        generatedColumn: generated.column,
        originalLine: original != null && original.line,
        originalColumn: original != null && original.column,
        source: source,
        name: name
      });
    };

  /**
   * Set the source content for a source file.
   */
  SourceMapGenerator$1.prototype.setSourceContent =
    function SourceMapGenerator_setSourceContent(aSourceFile, aSourceContent) {
      var source = aSourceFile;
      if (this._sourceRoot != null) {
        source = util.relative(this._sourceRoot, source);
      }

      if (aSourceContent != null) {
        // Add the source content to the _sourcesContents map.
        // Create a new _sourcesContents map if the property is null.
        if (!this._sourcesContents) {
          this._sourcesContents = Object.create(null);
        }
        this._sourcesContents[util.toSetString(source)] = aSourceContent;
      } else if (this._sourcesContents) {
        // Remove the source file from the _sourcesContents map.
        // If the _sourcesContents map is empty, set the property to null.
        delete this._sourcesContents[util.toSetString(source)];
        if (Object.keys(this._sourcesContents).length === 0) {
          this._sourcesContents = null;
        }
      }
    };

  /**
   * Applies the mappings of a sub-source-map for a specific source file to the
   * source map being generated. Each mapping to the supplied source file is
   * rewritten using the supplied source map. Note: The resolution for the
   * resulting mappings is the minimium of this map and the supplied map.
   *
   * @param aSourceMapConsumer The source map to be applied.
   * @param aSourceFile Optional. The filename of the source file.
   *        If omitted, SourceMapConsumer's file property will be used.
   * @param aSourceMapPath Optional. The dirname of the path to the source map
   *        to be applied. If relative, it is relative to the SourceMapConsumer.
   *        This parameter is needed when the two source maps aren't in the same
   *        directory, and the source map to be applied contains relative source
   *        paths. If so, those relative source paths need to be rewritten
   *        relative to the SourceMapGenerator.
   */
  SourceMapGenerator$1.prototype.applySourceMap =
    function SourceMapGenerator_applySourceMap(aSourceMapConsumer, aSourceFile, aSourceMapPath) {
      var sourceFile = aSourceFile;
      // If aSourceFile is omitted, we will use the file property of the SourceMap
      if (aSourceFile == null) {
        if (aSourceMapConsumer.file == null) {
          throw new Error(
            'SourceMapGenerator.prototype.applySourceMap requires either an explicit source file, ' +
            'or the source map\'s "file" property. Both were omitted.'
          );
        }
        sourceFile = aSourceMapConsumer.file;
      }
      var sourceRoot = this._sourceRoot;
      // Make "sourceFile" relative if an absolute Url is passed.
      if (sourceRoot != null) {
        sourceFile = util.relative(sourceRoot, sourceFile);
      }
      // Applying the SourceMap can add and remove items from the sources and
      // the names array.
      var newSources = new ArraySet();
      var newNames = new ArraySet();

      // Find mappings for the "sourceFile"
      this._mappings.unsortedForEach(function (mapping) {
        if (mapping.source === sourceFile && mapping.originalLine != null) {
          // Check if it can be mapped by the source map, then update the mapping.
          var original = aSourceMapConsumer.originalPositionFor({
            line: mapping.originalLine,
            column: mapping.originalColumn
          });
          if (original.source != null) {
            // Copy mapping
            mapping.source = original.source;
            if (aSourceMapPath != null) {
              mapping.source = util.join(aSourceMapPath, mapping.source);
            }
            if (sourceRoot != null) {
              mapping.source = util.relative(sourceRoot, mapping.source);
            }
            mapping.originalLine = original.line;
            mapping.originalColumn = original.column;
            if (original.name != null) {
              mapping.name = original.name;
            }
          }
        }

        var source = mapping.source;
        if (source != null && !newSources.has(source)) {
          newSources.add(source);
        }

        var name = mapping.name;
        if (name != null && !newNames.has(name)) {
          newNames.add(name);
        }

      }, this);
      this._sources = newSources;
      this._names = newNames;

      // Copy sourcesContents of applied map.
      aSourceMapConsumer.sources.forEach(function (sourceFile) {
        var content = aSourceMapConsumer.sourceContentFor(sourceFile);
        if (content != null) {
          if (aSourceMapPath != null) {
            sourceFile = util.join(aSourceMapPath, sourceFile);
          }
          if (sourceRoot != null) {
            sourceFile = util.relative(sourceRoot, sourceFile);
          }
          this.setSourceContent(sourceFile, content);
        }
      }, this);
    };

  /**
   * A mapping can have one of the three levels of data:
   *
   *   1. Just the generated position.
   *   2. The Generated position, original position, and original source.
   *   3. Generated and original position, original source, as well as a name
   *      token.
   *
   * To maintain consistency, we validate that any new mapping being added falls
   * in to one of these categories.
   */
  SourceMapGenerator$1.prototype._validateMapping =
    function SourceMapGenerator_validateMapping(aGenerated, aOriginal, aSource,
                                                aName) {
      // When aOriginal is truthy but has empty values for .line and .column,
      // it is most likely a programmer error. In this case we throw a very
      // specific error message to try to guide them the right way.
      // For example: https://github.com/Polymer/polymer-bundler/pull/519
      if (aOriginal && typeof aOriginal.line !== 'number' && typeof aOriginal.column !== 'number') {
          throw new Error(
              'original.line and original.column are not numbers -- you probably meant to omit ' +
              'the original mapping entirely and only map the generated position. If so, pass ' +
              'null for the original mapping instead of an object with empty or null values.'
          );
      }

      if (aGenerated && 'line' in aGenerated && 'column' in aGenerated
          && aGenerated.line > 0 && aGenerated.column >= 0
          && !aOriginal && !aSource && !aName) {
        // Case 1.
        return;
      }
      else if (aGenerated && 'line' in aGenerated && 'column' in aGenerated
               && aOriginal && 'line' in aOriginal && 'column' in aOriginal
               && aGenerated.line > 0 && aGenerated.column >= 0
               && aOriginal.line > 0 && aOriginal.column >= 0
               && aSource) {
        // Cases 2 and 3.
        return;
      }
      else {
        throw new Error('Invalid mapping: ' + JSON.stringify({
          generated: aGenerated,
          source: aSource,
          original: aOriginal,
          name: aName
        }));
      }
    };

  /**
   * Serialize the accumulated mappings in to the stream of base 64 VLQs
   * specified by the source map format.
   */
  SourceMapGenerator$1.prototype._serializeMappings =
    function SourceMapGenerator_serializeMappings() {
      var previousGeneratedColumn = 0;
      var previousGeneratedLine = 1;
      var previousOriginalColumn = 0;
      var previousOriginalLine = 0;
      var previousName = 0;
      var previousSource = 0;
      var result = '';
      var next;
      var mapping;
      var nameIdx;
      var sourceIdx;

      var mappings = this._mappings.toArray();
      for (var i = 0, len = mappings.length; i < len; i++) {
        mapping = mappings[i];
        next = '';

        if (mapping.generatedLine !== previousGeneratedLine) {
          previousGeneratedColumn = 0;
          while (mapping.generatedLine !== previousGeneratedLine) {
            next += ';';
            previousGeneratedLine++;
          }
        }
        else {
          if (i > 0) {
            if (!util.compareByGeneratedPositionsInflated(mapping, mappings[i - 1])) {
              continue;
            }
            next += ',';
          }
        }

        next += base64Vlq.encode(mapping.generatedColumn
                                   - previousGeneratedColumn);
        previousGeneratedColumn = mapping.generatedColumn;

        if (mapping.source != null) {
          sourceIdx = this._sources.indexOf(mapping.source);
          next += base64Vlq.encode(sourceIdx - previousSource);
          previousSource = sourceIdx;

          // lines are stored 0-based in SourceMap spec version 3
          next += base64Vlq.encode(mapping.originalLine - 1
                                     - previousOriginalLine);
          previousOriginalLine = mapping.originalLine - 1;

          next += base64Vlq.encode(mapping.originalColumn
                                     - previousOriginalColumn);
          previousOriginalColumn = mapping.originalColumn;

          if (mapping.name != null) {
            nameIdx = this._names.indexOf(mapping.name);
            next += base64Vlq.encode(nameIdx - previousName);
            previousName = nameIdx;
          }
        }

        result += next;
      }

      return result;
    };

  SourceMapGenerator$1.prototype._generateSourcesContent =
    function SourceMapGenerator_generateSourcesContent(aSources, aSourceRoot) {
      return aSources.map(function (source) {
        if (!this._sourcesContents) {
          return null;
        }
        if (aSourceRoot != null) {
          source = util.relative(aSourceRoot, source);
        }
        var key = util.toSetString(source);
        return Object.prototype.hasOwnProperty.call(this._sourcesContents, key)
          ? this._sourcesContents[key]
          : null;
      }, this);
    };

  /**
   * Externalize the source map.
   */
  SourceMapGenerator$1.prototype.toJSON =
    function SourceMapGenerator_toJSON() {
      var map = {
        version: this._version,
        sources: this._sources.toArray(),
        names: this._names.toArray(),
        mappings: this._serializeMappings()
      };
      if (this._file != null) {
        map.file = this._file;
      }
      if (this._sourceRoot != null) {
        map.sourceRoot = this._sourceRoot;
      }
      if (this._sourcesContents) {
        map.sourcesContent = this._generateSourcesContent(map.sources, map.sourceRoot);
      }

      return map;
    };

  /**
   * Render the source map being generated to a string.
   */
  SourceMapGenerator$1.prototype.toString =
    function SourceMapGenerator_toString() {
      return JSON.stringify(this.toJSON());
    };

  var SourceMapGenerator_1 = SourceMapGenerator$1;

  var sourceMapGenerator = {
  	SourceMapGenerator: SourceMapGenerator_1
  };

  var SourceMapGenerator = sourceMapGenerator.SourceMapGenerator;
  var trackNodes = {
      Atrule: true,
      Selector: true,
      Declaration: true
  };

  var sourceMap = function generateSourceMap(handlers) {
      var map = new SourceMapGenerator();
      var line = 1;
      var column = 0;
      var generated = {
          line: 1,
          column: 0
      };
      var original = {
          line: 0, // should be zero to add first mapping
          column: 0
      };
      var sourceMappingActive = false;
      var activatedGenerated = {
          line: 1,
          column: 0
      };
      var activatedMapping = {
          generated: activatedGenerated
      };

      var handlersNode = handlers.node;
      handlers.node = function(node) {
          if (node.loc && node.loc.start && trackNodes.hasOwnProperty(node.type)) {
              var nodeLine = node.loc.start.line;
              var nodeColumn = node.loc.start.column - 1;

              if (original.line !== nodeLine ||
                  original.column !== nodeColumn) {
                  original.line = nodeLine;
                  original.column = nodeColumn;

                  generated.line = line;
                  generated.column = column;

                  if (sourceMappingActive) {
                      sourceMappingActive = false;
                      if (generated.line !== activatedGenerated.line ||
                          generated.column !== activatedGenerated.column) {
                          map.addMapping(activatedMapping);
                      }
                  }

                  sourceMappingActive = true;
                  map.addMapping({
                      source: node.loc.source,
                      original: original,
                      generated: generated
                  });
              }
          }

          handlersNode.call(this, node);

          if (sourceMappingActive && trackNodes.hasOwnProperty(node.type)) {
              activatedGenerated.line = line;
              activatedGenerated.column = column;
          }
      };

      var handlersChunk = handlers.chunk;
      handlers.chunk = function(chunk) {
          for (var i = 0; i < chunk.length; i++) {
              if (chunk.charCodeAt(i) === 10) { // \n
                  line++;
                  column = 0;
              } else {
                  column++;
              }
          }

          handlersChunk(chunk);
      };

      var handlersResult = handlers.result;
      handlers.result = function() {
          if (sourceMappingActive) {
              map.addMapping(activatedMapping);
          }

          return {
              css: handlersResult(),
              map: map
          };
      };

      return handlers;
  };

  var hasOwnProperty$4 = Object.prototype.hasOwnProperty;

  function processChildren(node, delimeter) {
      var list = node.children;
      var prev = null;

      if (typeof delimeter !== 'function') {
          list.forEach(this.node, this);
      } else {
          list.forEach(function(node) {
              if (prev !== null) {
                  delimeter.call(this, prev);
              }

              this.node(node);
              prev = node;
          }, this);
      }
  }

  var create$3 = function createGenerator(config) {
      function processNode(node) {
          if (hasOwnProperty$4.call(types, node.type)) {
              types[node.type].call(this, node);
          } else {
              throw new Error('Unknown node type: ' + node.type);
          }
      }

      var types = {};

      if (config.node) {
          for (var name in config.node) {
              types[name] = config.node[name].generate;
          }
      }

      return function(node, options) {
          var buffer = '';
          var handlers = {
              children: processChildren,
              node: processNode,
              chunk: function(chunk) {
                  buffer += chunk;
              },
              result: function() {
                  return buffer;
              }
          };

          if (options) {
              if (typeof options.decorator === 'function') {
                  handlers = options.decorator(handlers);
              }

              if (options.sourceMap) {
                  handlers = sourceMap(handlers);
              }
          }

          handlers.node(node);

          return handlers.result();
      };
  };

  var create$2 = function createConvertors(walk) {
      return {
          fromPlainObject: function(ast) {
              walk(ast, {
                  enter: function(node) {
                      if (node.children && node.children instanceof List_1 === false) {
                          node.children = new List_1().fromArray(node.children);
                      }
                  }
              });

              return ast;
          },
          toPlainObject: function(ast) {
              walk(ast, {
                  leave: function(node) {
                      if (node.children && node.children instanceof List_1) {
                          node.children = node.children.toArray();
                      }
                  }
              });

              return ast;
          }
      };
  };

  var hasOwnProperty$3 = Object.prototype.hasOwnProperty;
  var noop = function() {};

  function ensureFunction(value) {
      return typeof value === 'function' ? value : noop;
  }

  function invokeForType(fn, type) {
      return function(node, item, list) {
          if (node.type === type) {
              fn.call(this, node, item, list);
          }
      };
  }

  function getWalkersFromStructure(name, nodeType) {
      var structure = nodeType.structure;
      var walkers = [];

      for (var key in structure) {
          if (hasOwnProperty$3.call(structure, key) === false) {
              continue;
          }

          var fieldTypes = structure[key];
          var walker = {
              name: key,
              type: false,
              nullable: false
          };

          if (!Array.isArray(structure[key])) {
              fieldTypes = [structure[key]];
          }

          for (var i = 0; i < fieldTypes.length; i++) {
              var fieldType = fieldTypes[i];
              if (fieldType === null) {
                  walker.nullable = true;
              } else if (typeof fieldType === 'string') {
                  walker.type = 'node';
              } else if (Array.isArray(fieldType)) {
                  walker.type = 'list';
              }
          }

          if (walker.type) {
              walkers.push(walker);
          }
      }

      if (walkers.length) {
          return {
              context: nodeType.walkContext,
              fields: walkers
          };
      }

      return null;
  }

  function getTypesFromConfig(config) {
      var types = {};

      for (var name in config.node) {
          if (hasOwnProperty$3.call(config.node, name)) {
              var nodeType = config.node[name];

              if (!nodeType.structure) {
                  throw new Error('Missed `structure` field in `' + name + '` node type definition');
              }

              types[name] = getWalkersFromStructure(name, nodeType);
          }
      }

      return types;
  }

  function createTypeIterator(config, reverse) {
      var fields = config.fields.slice();
      var contextName = config.context;
      var useContext = typeof contextName === 'string';

      if (reverse) {
          fields.reverse();
      }

      return function(node, context, walk, walkReducer) {
          var prevContextValue;

          if (useContext) {
              prevContextValue = context[contextName];
              context[contextName] = node;
          }

          for (var i = 0; i < fields.length; i++) {
              var field = fields[i];
              var ref = node[field.name];

              if (!field.nullable || ref) {
                  if (field.type === 'list') {
                      var breakWalk = reverse
                          ? ref.reduceRight(walkReducer, false)
                          : ref.reduce(walkReducer, false);

                      if (breakWalk) {
                          return true;
                      }
                  } else if (walk(ref)) {
                      return true;
                  }
              }
          }

          if (useContext) {
              context[contextName] = prevContextValue;
          }
      };
  }

  function createFastTraveralMap(iterators) {
      return {
          Atrule: {
              StyleSheet: iterators.StyleSheet,
              Atrule: iterators.Atrule,
              Rule: iterators.Rule,
              Block: iterators.Block
          },
          Rule: {
              StyleSheet: iterators.StyleSheet,
              Atrule: iterators.Atrule,
              Rule: iterators.Rule,
              Block: iterators.Block
          },
          Declaration: {
              StyleSheet: iterators.StyleSheet,
              Atrule: iterators.Atrule,
              Rule: iterators.Rule,
              Block: iterators.Block,
              DeclarationList: iterators.DeclarationList
          }
      };
  }

  var create$1 = function createWalker(config) {
      var types = getTypesFromConfig(config);
      var iteratorsNatural = {};
      var iteratorsReverse = {};
      var breakWalk = Symbol('break-walk');
      var skipNode = Symbol('skip-node');

      for (var name in types) {
          if (hasOwnProperty$3.call(types, name) && types[name] !== null) {
              iteratorsNatural[name] = createTypeIterator(types[name], false);
              iteratorsReverse[name] = createTypeIterator(types[name], true);
          }
      }

      var fastTraversalIteratorsNatural = createFastTraveralMap(iteratorsNatural);
      var fastTraversalIteratorsReverse = createFastTraveralMap(iteratorsReverse);

      var walk = function(root, options) {
          function walkNode(node, item, list) {
              var enterRet = enter.call(context, node, item, list);

              if (enterRet === breakWalk) {
                  debugger;
                  return true;
              }

              if (enterRet === skipNode) {
                  return false;
              }

              if (iterators.hasOwnProperty(node.type)) {
                  if (iterators[node.type](node, context, walkNode, walkReducer)) {
                      return true;
                  }
              }

              if (leave.call(context, node, item, list) === breakWalk) {
                  return true;
              }

              return false;
          }

          var walkReducer = (ret, data, item, list) => ret || walkNode(data, item, list);
          var enter = noop;
          var leave = noop;
          var iterators = iteratorsNatural;
          var context = {
              break: breakWalk,
              skip: skipNode,

              root: root,
              stylesheet: null,
              atrule: null,
              atrulePrelude: null,
              rule: null,
              selector: null,
              block: null,
              declaration: null,
              function: null
          };

          if (typeof options === 'function') {
              enter = options;
          } else if (options) {
              enter = ensureFunction(options.enter);
              leave = ensureFunction(options.leave);

              if (options.reverse) {
                  iterators = iteratorsReverse;
              }

              if (options.visit) {
                  if (fastTraversalIteratorsNatural.hasOwnProperty(options.visit)) {
                      iterators = options.reverse
                          ? fastTraversalIteratorsReverse[options.visit]
                          : fastTraversalIteratorsNatural[options.visit];
                  } else if (!types.hasOwnProperty(options.visit)) {
                      throw new Error('Bad value `' + options.visit + '` for `visit` option (should be: ' + Object.keys(types).join(', ') + ')');
                  }

                  enter = invokeForType(enter, options.visit);
                  leave = invokeForType(leave, options.visit);
              }
          }

          if (enter === noop && leave === noop) {
              throw new Error('Neither `enter` nor `leave` walker handler is set or both aren\'t a function');
          }

          walkNode(root);
      };

      walk.break = breakWalk;
      walk.skip = skipNode;

      walk.find = function(ast, fn) {
          var found = null;

          walk(ast, function(node, item, list) {
              if (fn.call(this, node, item, list)) {
                  found = node;
                  return breakWalk;
              }
          });

          return found;
      };

      walk.findLast = function(ast, fn) {
          var found = null;

          walk(ast, {
              reverse: true,
              enter: function(node, item, list) {
                  if (fn.call(this, node, item, list)) {
                      found = node;
                      return breakWalk;
                  }
              }
          });

          return found;
      };

      walk.findAll = function(ast, fn) {
          var found = [];

          walk(ast, function(node, item, list) {
              if (fn.call(this, node, item, list)) {
                  found.push(node);
              }
          });

          return found;
      };

      return walk;
  };

  var clone = function clone(node) {
      var result = {};

      for (var key in node) {
          var value = node[key];

          if (value) {
              if (Array.isArray(value) || value instanceof List_1) {
                  value = value.map(clone);
              } else if (value.constructor === Object) {
                  value = clone(value);
              }
          }

          result[key] = value;
      }

      return result;
  };

  const hasOwnProperty$2 = Object.prototype.hasOwnProperty;
  const shape$1 = {
      generic: true,
      types: appendOrAssign,
      atrules: {
          prelude: appendOrAssignOrNull,
          descriptors: appendOrAssignOrNull
      },
      properties: appendOrAssign,
      parseContext: assign,
      scope: deepAssign,
      atrule: ['parse'],
      pseudo: ['parse'],
      node: ['name', 'structure', 'parse', 'generate', 'walkContext']
  };

  function isObject(value) {
      return value && value.constructor === Object;
  }

  function copy$2(value) {
      return isObject(value)
          ? Object.assign({}, value)
          : value;
  }

  function assign(dest, src) {
      return Object.assign(dest, src);
  }

  function deepAssign(dest, src) {
      for (const key in src) {
          if (hasOwnProperty$2.call(src, key)) {
              if (isObject(dest[key])) {
                  deepAssign(dest[key], copy$2(src[key]));
              } else {
                  dest[key] = copy$2(src[key]);
              }
          }
      }

      return dest;
  }

  function append$1(a, b) {
      if (typeof b === 'string' && /^\s*\|/.test(b)) {
          return typeof a === 'string'
              ? a + b
              : b.replace(/^\s*\|\s*/, '');
      }

      return b || null;
  }

  function appendOrAssign(a, b) {
      if (typeof b === 'string') {
          return append$1(a, b);
      }

      const result = Object.assign({}, a);
      for (let key in b) {
          if (hasOwnProperty$2.call(b, key)) {
              result[key] = append$1(hasOwnProperty$2.call(a, key) ? a[key] : undefined, b[key]);
          }
      }

      return result;
  }

  function appendOrAssignOrNull(a, b) {
      const result = appendOrAssign(a, b);

      return !isObject(result) || Object.keys(result).length
          ? result
          : null;
  }

  function mix(dest, src, shape) {
      for (const key in shape) {
          if (hasOwnProperty$2.call(shape, key) === false) {
              continue;
          }

          if (shape[key] === true) {
              if (key in src) {
                  if (hasOwnProperty$2.call(src, key)) {
                      dest[key] = copy$2(src[key]);
                  }
              }
          } else if (shape[key]) {
              if (typeof shape[key] === 'function') {
                  const fn = shape[key];
                  dest[key] = fn({}, dest[key]);
                  dest[key] = fn(dest[key] || {}, src[key]);
              } else if (isObject(shape[key])) {
                  const result = {};

                  for (let name in dest[key]) {
                      result[name] = mix({}, dest[key][name], shape[key]);
                  }

                  for (let name in src[key]) {
                      result[name] = mix(result[name] || {}, src[key][name], shape[key]);
                  }

                  dest[key] = result;
              } else if (Array.isArray(shape[key])) {
                  const res = {};
                  const innerShape = shape[key].reduce(function(s, k) {
                      s[k] = true;
                      return s;
                  }, {});

                  for (const [name, value] of Object.entries(dest[key] || {})) {
                      res[name] = {};
                      if (value) {
                          mix(res[name], value, innerShape);
                      }
                  }

                  for (const name in src[key]) {
                      if (hasOwnProperty$2.call(src[key], name)) {
                          if (!res[name]) {
                              res[name] = {};
                          }

                          if (src[key] && src[key][name]) {
                              mix(res[name], src[key][name], innerShape);
                          }
                      }
                  }

                  dest[key] = res;
              }
          }
      }
      return dest;
  }

  var mix_1 = (dest, src) => mix(dest, src, shape$1);

  function createSyntax(config) {
      var parse = create$4(config);
      var walk = create$1(config);
      var generate = create$3(config);
      var convert = create$2(walk);

      var syntax = {
          List: List_1,
          SyntaxError: _SyntaxError$1,
          TokenStream: TokenStream_1,
          Lexer: Lexer_1,

          vendorPrefix: names.vendorPrefix,
          keyword: names.keyword,
          property: names.property,
          isCustomProperty: names.isCustomProperty,

          definitionSyntax: definitionSyntax,
          lexer: null,
          createLexer: function(config) {
              return new Lexer_1(config, syntax, syntax.lexer.structure);
          },

          tokenize: tokenizer$1,
          parse: parse,
          walk: walk,
          generate: generate,

          find: walk.find,
          findLast: walk.findLast,
          findAll: walk.findAll,

          clone: clone,
          fromPlainObject: convert.fromPlainObject,
          toPlainObject: convert.toPlainObject,

          createSyntax: function(config) {
              return createSyntax(mix_1({}, config));
          },
          fork: function(extension) {
              var base = mix_1({}, config); // copy of config
              return createSyntax(
                  typeof extension === 'function'
                      ? extension(base, Object.assign)
                      : mix_1(base, extension)
              );
          }
      };

      syntax.lexer = new Lexer_1({
          generic: true,
          types: config.types,
          atrules: config.atrules,
          properties: config.properties,
          node: config.node
      }, syntax);

      return syntax;
  }
  var create_1 = function(config) {
      return createSyntax(mix_1({}, config));
  };

  var create = {
  	create: create_1
  };

  var mdnAtrules = {
  	"@charset": {
  	syntax: "@charset \"<charset>\";",
  	groups: [
  		"CSS Charsets"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/@charset"
  },
  	"@counter-style": {
  	syntax: "@counter-style <counter-style-name> {\n  [ system: <counter-system>; ] ||\n  [ symbols: <counter-symbols>; ] ||\n  [ additive-symbols: <additive-symbols>; ] ||\n  [ negative: <negative-symbol>; ] ||\n  [ prefix: <prefix>; ] ||\n  [ suffix: <suffix>; ] ||\n  [ range: <range>; ] ||\n  [ pad: <padding>; ] ||\n  [ speak-as: <speak-as>; ] ||\n  [ fallback: <counter-style-name>; ]\n}",
  	interfaces: [
  		"CSSCounterStyleRule"
  	],
  	groups: [
  		"CSS Counter Styles"
  	],
  	descriptors: {
  		"additive-symbols": {
  			syntax: "[ <integer> && <symbol> ]#",
  			media: "all",
  			initial: "n/a (required)",
  			percentages: "no",
  			computed: "asSpecified",
  			order: "orderOfAppearance",
  			status: "standard"
  		},
  		fallback: {
  			syntax: "<counter-style-name>",
  			media: "all",
  			initial: "decimal",
  			percentages: "no",
  			computed: "asSpecified",
  			order: "uniqueOrder",
  			status: "standard"
  		},
  		negative: {
  			syntax: "<symbol> <symbol>?",
  			media: "all",
  			initial: "\"-\" hyphen-minus",
  			percentages: "no",
  			computed: "asSpecified",
  			order: "orderOfAppearance",
  			status: "standard"
  		},
  		pad: {
  			syntax: "<integer> && <symbol>",
  			media: "all",
  			initial: "0 \"\"",
  			percentages: "no",
  			computed: "asSpecified",
  			order: "uniqueOrder",
  			status: "standard"
  		},
  		prefix: {
  			syntax: "<symbol>",
  			media: "all",
  			initial: "\"\"",
  			percentages: "no",
  			computed: "asSpecified",
  			order: "uniqueOrder",
  			status: "standard"
  		},
  		range: {
  			syntax: "[ [ <integer> | infinite ]{2} ]# | auto",
  			media: "all",
  			initial: "auto",
  			percentages: "no",
  			computed: "asSpecified",
  			order: "orderOfAppearance",
  			status: "standard"
  		},
  		"speak-as": {
  			syntax: "auto | bullets | numbers | words | spell-out | <counter-style-name>",
  			media: "all",
  			initial: "auto",
  			percentages: "no",
  			computed: "asSpecified",
  			order: "uniqueOrder",
  			status: "standard"
  		},
  		suffix: {
  			syntax: "<symbol>",
  			media: "all",
  			initial: "\". \"",
  			percentages: "no",
  			computed: "asSpecified",
  			order: "uniqueOrder",
  			status: "standard"
  		},
  		symbols: {
  			syntax: "<symbol>+",
  			media: "all",
  			initial: "n/a (required)",
  			percentages: "no",
  			computed: "asSpecified",
  			order: "orderOfAppearance",
  			status: "standard"
  		},
  		system: {
  			syntax: "cyclic | numeric | alphabetic | symbolic | additive | [ fixed <integer>? ] | [ extends <counter-style-name> ]",
  			media: "all",
  			initial: "symbolic",
  			percentages: "no",
  			computed: "asSpecified",
  			order: "uniqueOrder",
  			status: "standard"
  		}
  	},
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/@counter-style"
  },
  	"@document": {
  	syntax: "@document [ <url> | url-prefix(<string>) | domain(<string>) | media-document(<string>) | regexp(<string>) ]# {\n  <group-rule-body>\n}",
  	interfaces: [
  		"CSSGroupingRule",
  		"CSSConditionRule"
  	],
  	groups: [
  		"CSS Conditional Rules"
  	],
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/@document"
  },
  	"@font-face": {
  	syntax: "@font-face {\n  [ font-family: <family-name>; ] ||\n  [ src: <src>; ] ||\n  [ unicode-range: <unicode-range>; ] ||\n  [ font-variant: <font-variant>; ] ||\n  [ font-feature-settings: <font-feature-settings>; ] ||\n  [ font-variation-settings: <font-variation-settings>; ] ||\n  [ font-stretch: <font-stretch>; ] ||\n  [ font-weight: <font-weight>; ] ||\n  [ font-style: <font-style>; ]\n}",
  	interfaces: [
  		"CSSFontFaceRule"
  	],
  	groups: [
  		"CSS Fonts"
  	],
  	descriptors: {
  		"font-display": {
  			syntax: "[ auto | block | swap | fallback | optional ]",
  			media: "visual",
  			percentages: "no",
  			initial: "auto",
  			computed: "asSpecified",
  			order: "uniqueOrder",
  			status: "experimental"
  		},
  		"font-family": {
  			syntax: "<family-name>",
  			media: "all",
  			initial: "n/a (required)",
  			percentages: "no",
  			computed: "asSpecified",
  			order: "uniqueOrder",
  			status: "standard"
  		},
  		"font-feature-settings": {
  			syntax: "normal | <feature-tag-value>#",
  			media: "all",
  			initial: "normal",
  			percentages: "no",
  			computed: "asSpecified",
  			order: "orderOfAppearance",
  			status: "standard"
  		},
  		"font-variation-settings": {
  			syntax: "normal | [ <string> <number> ]#",
  			media: "all",
  			initial: "normal",
  			percentages: "no",
  			computed: "asSpecified",
  			order: "orderOfAppearance",
  			status: "standard"
  		},
  		"font-stretch": {
  			syntax: "<font-stretch-absolute>{1,2}",
  			media: "all",
  			initial: "normal",
  			percentages: "no",
  			computed: "asSpecified",
  			order: "uniqueOrder",
  			status: "standard"
  		},
  		"font-style": {
  			syntax: "normal | italic | oblique <angle>{0,2}",
  			media: "all",
  			initial: "normal",
  			percentages: "no",
  			computed: "asSpecified",
  			order: "uniqueOrder",
  			status: "standard"
  		},
  		"font-weight": {
  			syntax: "<font-weight-absolute>{1,2}",
  			media: "all",
  			initial: "normal",
  			percentages: "no",
  			computed: "asSpecified",
  			order: "uniqueOrder",
  			status: "standard"
  		},
  		"font-variant": {
  			syntax: "normal | none | [ <common-lig-values> || <discretionary-lig-values> || <historical-lig-values> || <contextual-alt-values> || stylistic(<feature-value-name>) || historical-forms || styleset(<feature-value-name>#) || character-variant(<feature-value-name>#) || swash(<feature-value-name>) || ornaments(<feature-value-name>) || annotation(<feature-value-name>) || [ small-caps | all-small-caps | petite-caps | all-petite-caps | unicase | titling-caps ] || <numeric-figure-values> || <numeric-spacing-values> || <numeric-fraction-values> || ordinal || slashed-zero || <east-asian-variant-values> || <east-asian-width-values> || ruby ]",
  			media: "all",
  			initial: "normal",
  			percentages: "no",
  			computed: "asSpecified",
  			order: "orderOfAppearance",
  			status: "standard"
  		},
  		src: {
  			syntax: "[ <url> [ format( <string># ) ]? | local( <family-name> ) ]#",
  			media: "all",
  			initial: "n/a (required)",
  			percentages: "no",
  			computed: "asSpecified",
  			order: "orderOfAppearance",
  			status: "standard"
  		},
  		"unicode-range": {
  			syntax: "<unicode-range>#",
  			media: "all",
  			initial: "U+0-10FFFF",
  			percentages: "no",
  			computed: "asSpecified",
  			order: "orderOfAppearance",
  			status: "standard"
  		}
  	},
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/@font-face"
  },
  	"@font-feature-values": {
  	syntax: "@font-feature-values <family-name># {\n  <feature-value-block-list>\n}",
  	interfaces: [
  		"CSSFontFeatureValuesRule"
  	],
  	groups: [
  		"CSS Fonts"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/@font-feature-values"
  },
  	"@import": {
  	syntax: "@import [ <string> | <url> ] [ <media-query-list> ]?;",
  	groups: [
  		"Media Queries"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/@import"
  },
  	"@keyframes": {
  	syntax: "@keyframes <keyframes-name> {\n  <keyframe-block-list>\n}",
  	interfaces: [
  		"CSSKeyframeRule",
  		"CSSKeyframesRule"
  	],
  	groups: [
  		"CSS Animations"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/@keyframes"
  },
  	"@media": {
  	syntax: "@media <media-query-list> {\n  <group-rule-body>\n}",
  	interfaces: [
  		"CSSGroupingRule",
  		"CSSConditionRule",
  		"CSSMediaRule",
  		"CSSCustomMediaRule"
  	],
  	groups: [
  		"CSS Conditional Rules",
  		"Media Queries"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/@media"
  },
  	"@namespace": {
  	syntax: "@namespace <namespace-prefix>? [ <string> | <url> ];",
  	groups: [
  		"CSS Namespaces"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/@namespace"
  },
  	"@page": {
  	syntax: "@page <page-selector-list> {\n  <page-body>\n}",
  	interfaces: [
  		"CSSPageRule"
  	],
  	groups: [
  		"CSS Pages"
  	],
  	descriptors: {
  		bleed: {
  			syntax: "auto | <length>",
  			media: [
  				"visual",
  				"paged"
  			],
  			initial: "auto",
  			percentages: "no",
  			computed: "asSpecified",
  			order: "uniqueOrder",
  			status: "standard"
  		},
  		marks: {
  			syntax: "none | [ crop || cross ]",
  			media: [
  				"visual",
  				"paged"
  			],
  			initial: "none",
  			percentages: "no",
  			computed: "asSpecified",
  			order: "orderOfAppearance",
  			status: "standard"
  		},
  		size: {
  			syntax: "<length>{1,2} | auto | [ <page-size> || [ portrait | landscape ] ]",
  			media: [
  				"visual",
  				"paged"
  			],
  			initial: "auto",
  			percentages: "no",
  			computed: "asSpecifiedRelativeToAbsoluteLengths",
  			order: "orderOfAppearance",
  			status: "standard"
  		}
  	},
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/@page"
  },
  	"@property": {
  	syntax: "@property <custom-property-name> {\n  <declaration-list>\n}",
  	interfaces: [
  		"CSS",
  		"CSSPropertyRule"
  	],
  	groups: [
  		"CSS Houdini"
  	],
  	descriptors: {
  		syntax: {
  			syntax: "<string>",
  			media: "all",
  			percentages: "no",
  			initial: "n/a (required)",
  			computed: "asSpecified",
  			order: "uniqueOrder",
  			status: "experimental"
  		},
  		inherits: {
  			syntax: "true | false",
  			media: "all",
  			percentages: "no",
  			initial: "auto",
  			computed: "asSpecified",
  			order: "uniqueOrder",
  			status: "experimental"
  		},
  		"initial-value": {
  			syntax: "<string>",
  			media: "all",
  			initial: "n/a (required)",
  			percentages: "no",
  			computed: "asSpecified",
  			order: "uniqueOrder",
  			status: "experimental"
  		}
  	},
  	status: "experimental",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/@property"
  },
  	"@supports": {
  	syntax: "@supports <supports-condition> {\n  <group-rule-body>\n}",
  	interfaces: [
  		"CSSGroupingRule",
  		"CSSConditionRule",
  		"CSSSupportsRule"
  	],
  	groups: [
  		"CSS Conditional Rules"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/@supports"
  },
  	"@viewport": {
  	syntax: "@viewport {\n  <group-rule-body>\n}",
  	interfaces: [
  		"CSSViewportRule"
  	],
  	groups: [
  		"CSS Device Adaptation"
  	],
  	descriptors: {
  		height: {
  			syntax: "<viewport-length>{1,2}",
  			media: [
  				"visual",
  				"continuous"
  			],
  			initial: [
  				"min-height",
  				"max-height"
  			],
  			percentages: [
  				"min-height",
  				"max-height"
  			],
  			computed: [
  				"min-height",
  				"max-height"
  			],
  			order: "orderOfAppearance",
  			status: "standard"
  		},
  		"max-height": {
  			syntax: "<viewport-length>",
  			media: [
  				"visual",
  				"continuous"
  			],
  			initial: "auto",
  			percentages: "referToHeightOfInitialViewport",
  			computed: "lengthAbsolutePercentageAsSpecifiedOtherwiseAuto",
  			order: "uniqueOrder",
  			status: "standard"
  		},
  		"max-width": {
  			syntax: "<viewport-length>",
  			media: [
  				"visual",
  				"continuous"
  			],
  			initial: "auto",
  			percentages: "referToWidthOfInitialViewport",
  			computed: "lengthAbsolutePercentageAsSpecifiedOtherwiseAuto",
  			order: "uniqueOrder",
  			status: "standard"
  		},
  		"max-zoom": {
  			syntax: "auto | <number> | <percentage>",
  			media: [
  				"visual",
  				"continuous"
  			],
  			initial: "auto",
  			percentages: "the zoom factor itself",
  			computed: "autoNonNegativeOrPercentage",
  			order: "uniqueOrder",
  			status: "standard"
  		},
  		"min-height": {
  			syntax: "<viewport-length>",
  			media: [
  				"visual",
  				"continuous"
  			],
  			initial: "auto",
  			percentages: "referToHeightOfInitialViewport",
  			computed: "lengthAbsolutePercentageAsSpecifiedOtherwiseAuto",
  			order: "uniqueOrder",
  			status: "standard"
  		},
  		"min-width": {
  			syntax: "<viewport-length>",
  			media: [
  				"visual",
  				"continuous"
  			],
  			initial: "auto",
  			percentages: "referToWidthOfInitialViewport",
  			computed: "lengthAbsolutePercentageAsSpecifiedOtherwiseAuto",
  			order: "uniqueOrder",
  			status: "standard"
  		},
  		"min-zoom": {
  			syntax: "auto | <number> | <percentage>",
  			media: [
  				"visual",
  				"continuous"
  			],
  			initial: "auto",
  			percentages: "the zoom factor itself",
  			computed: "autoNonNegativeOrPercentage",
  			order: "uniqueOrder",
  			status: "standard"
  		},
  		orientation: {
  			syntax: "auto | portrait | landscape",
  			media: [
  				"visual",
  				"continuous"
  			],
  			initial: "auto",
  			percentages: "referToSizeOfBoundingBox",
  			computed: "asSpecified",
  			order: "uniqueOrder",
  			status: "standard"
  		},
  		"user-zoom": {
  			syntax: "zoom | fixed",
  			media: [
  				"visual",
  				"continuous"
  			],
  			initial: "zoom",
  			percentages: "referToSizeOfBoundingBox",
  			computed: "asSpecified",
  			order: "uniqueOrder",
  			status: "standard"
  		},
  		"viewport-fit": {
  			syntax: "auto | contain | cover",
  			media: [
  				"visual",
  				"continuous"
  			],
  			initial: "auto",
  			percentages: "no",
  			computed: "asSpecified",
  			order: "uniqueOrder",
  			status: "standard"
  		},
  		width: {
  			syntax: "<viewport-length>{1,2}",
  			media: [
  				"visual",
  				"continuous"
  			],
  			initial: [
  				"min-width",
  				"max-width"
  			],
  			percentages: [
  				"min-width",
  				"max-width"
  			],
  			computed: [
  				"min-width",
  				"max-width"
  			],
  			order: "orderOfAppearance",
  			status: "standard"
  		},
  		zoom: {
  			syntax: "auto | <number> | <percentage>",
  			media: [
  				"visual",
  				"continuous"
  			],
  			initial: "auto",
  			percentages: "the zoom factor itself",
  			computed: "autoNonNegativeOrPercentage",
  			order: "uniqueOrder",
  			status: "standard"
  		}
  	},
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/@viewport"
  }
  };

  var all = {
  	syntax: "initial | inherit | unset | revert",
  	media: "noPracticalMedia",
  	inherited: false,
  	animationType: "eachOfShorthandPropertiesExceptUnicodeBiDiAndDirection",
  	percentages: "no",
  	groups: [
  		"CSS Miscellaneous"
  	],
  	initial: "noPracticalInitialValue",
  	appliesto: "allElements",
  	computed: "asSpecifiedAppliesToEachProperty",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/all"
  };
  var animation = {
  	syntax: "<single-animation>#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Animations"
  	],
  	initial: [
  		"animation-name",
  		"animation-duration",
  		"animation-timing-function",
  		"animation-delay",
  		"animation-iteration-count",
  		"animation-direction",
  		"animation-fill-mode",
  		"animation-play-state"
  	],
  	appliesto: "allElementsAndPseudos",
  	computed: [
  		"animation-name",
  		"animation-duration",
  		"animation-timing-function",
  		"animation-delay",
  		"animation-direction",
  		"animation-iteration-count",
  		"animation-fill-mode",
  		"animation-play-state"
  	],
  	order: "orderOfAppearance",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/animation"
  };
  var appearance = {
  	syntax: "none | auto | textfield | menulist-button | <compat-auto>",
  	media: "all",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Basic User Interface"
  	],
  	initial: "auto",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "experimental",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/appearance"
  };
  var azimuth = {
  	syntax: "<angle> | [ [ left-side | far-left | left | center-left | center | center-right | right | far-right | right-side ] || behind ] | leftwards | rightwards",
  	media: "aural",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Speech"
  	],
  	initial: "center",
  	appliesto: "allElements",
  	computed: "normalizedAngle",
  	order: "orderOfAppearance",
  	status: "obsolete",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/azimuth"
  };
  var background = {
  	syntax: "[ <bg-layer> , ]* <final-bg-layer>",
  	media: "visual",
  	inherited: false,
  	animationType: [
  		"background-color",
  		"background-image",
  		"background-clip",
  		"background-position",
  		"background-size",
  		"background-repeat",
  		"background-attachment"
  	],
  	percentages: [
  		"background-position",
  		"background-size"
  	],
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: [
  		"background-image",
  		"background-position",
  		"background-size",
  		"background-repeat",
  		"background-origin",
  		"background-clip",
  		"background-attachment",
  		"background-color"
  	],
  	appliesto: "allElements",
  	computed: [
  		"background-image",
  		"background-position",
  		"background-size",
  		"background-repeat",
  		"background-origin",
  		"background-clip",
  		"background-attachment",
  		"background-color"
  	],
  	order: "orderOfAppearance",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/background"
  };
  var border = {
  	syntax: "<line-width> || <line-style> || <color>",
  	media: "visual",
  	inherited: false,
  	animationType: [
  		"border-color",
  		"border-style",
  		"border-width"
  	],
  	percentages: "no",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: [
  		"border-width",
  		"border-style",
  		"border-color"
  	],
  	appliesto: "allElements",
  	computed: [
  		"border-width",
  		"border-style",
  		"border-color"
  	],
  	order: "orderOfAppearance",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border"
  };
  var bottom$1 = {
  	syntax: "<length> | <percentage> | auto",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "referToContainingBlockHeight",
  	groups: [
  		"CSS Positioning"
  	],
  	initial: "auto",
  	appliesto: "positionedElements",
  	computed: "lengthAbsolutePercentageAsSpecifiedOtherwiseAuto",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/bottom"
  };
  var clear = {
  	syntax: "none | left | right | both | inline-start | inline-end",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Positioning"
  	],
  	initial: "none",
  	appliesto: "blockLevelElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/clear"
  };
  var clip = {
  	syntax: "<shape> | auto",
  	media: "visual",
  	inherited: false,
  	animationType: "rectangle",
  	percentages: "no",
  	groups: [
  		"CSS Masking"
  	],
  	initial: "auto",
  	appliesto: "absolutelyPositionedElements",
  	computed: "autoOrRectangle",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/clip"
  };
  var color$1 = {
  	syntax: "<color>",
  	media: "visual",
  	inherited: true,
  	animationType: "color",
  	percentages: "no",
  	groups: [
  		"CSS Color"
  	],
  	initial: "variesFromBrowserToBrowser",
  	appliesto: "allElements",
  	computed: "translucentValuesRGBAOtherwiseRGB",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/color"
  };
  var columns = {
  	syntax: "<'column-width'> || <'column-count'>",
  	media: "visual",
  	inherited: false,
  	animationType: [
  		"column-width",
  		"column-count"
  	],
  	percentages: "no",
  	groups: [
  		"CSS Columns"
  	],
  	initial: [
  		"column-width",
  		"column-count"
  	],
  	appliesto: "blockContainersExceptTableWrappers",
  	computed: [
  		"column-width",
  		"column-count"
  	],
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/columns"
  };
  var contain = {
  	syntax: "none | strict | content | [ size || layout || style || paint ]",
  	media: "all",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Containment"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/contain"
  };
  var content = {
  	syntax: "normal | none | [ <content-replacement> | <content-list> ] [/ <string> ]?",
  	media: "all",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Generated Content"
  	],
  	initial: "normal",
  	appliesto: "beforeAndAfterPseudos",
  	computed: "normalOnElementsForPseudosNoneAbsoluteURIStringOrAsSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/content"
  };
  var cursor = {
  	syntax: "[ [ <url> [ <x> <y> ]? , ]* [ auto | default | none | context-menu | help | pointer | progress | wait | cell | crosshair | text | vertical-text | alias | copy | move | no-drop | not-allowed | e-resize | n-resize | ne-resize | nw-resize | s-resize | se-resize | sw-resize | w-resize | ew-resize | ns-resize | nesw-resize | nwse-resize | col-resize | row-resize | all-scroll | zoom-in | zoom-out | grab | grabbing ] ]",
  	media: [
  		"visual",
  		"interactive"
  	],
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Basic User Interface"
  	],
  	initial: "auto",
  	appliesto: "allElements",
  	computed: "asSpecifiedURLsAbsolute",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/cursor"
  };
  var direction = {
  	syntax: "ltr | rtl",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Writing Modes"
  	],
  	initial: "ltr",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/direction"
  };
  var display = {
  	syntax: "[ <display-outside> || <display-inside> ] | <display-listitem> | <display-internal> | <display-box> | <display-legacy>",
  	media: "all",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Display"
  	],
  	initial: "inline",
  	appliesto: "allElements",
  	computed: "asSpecifiedExceptPositionedFloatingAndRootElementsKeywordMaybeDifferent",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/display"
  };
  var filter$1 = {
  	syntax: "none | <filter-function-list>",
  	media: "visual",
  	inherited: false,
  	animationType: "filterList",
  	percentages: "no",
  	groups: [
  		"Filter Effects"
  	],
  	initial: "none",
  	appliesto: "allElementsSVGContainerElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/filter"
  };
  var flex = {
  	syntax: "none | [ <'flex-grow'> <'flex-shrink'>? || <'flex-basis'> ]",
  	media: "visual",
  	inherited: false,
  	animationType: [
  		"flex-grow",
  		"flex-shrink",
  		"flex-basis"
  	],
  	percentages: "no",
  	groups: [
  		"CSS Flexible Box Layout"
  	],
  	initial: [
  		"flex-grow",
  		"flex-shrink",
  		"flex-basis"
  	],
  	appliesto: "flexItemsAndInFlowPseudos",
  	computed: [
  		"flex-grow",
  		"flex-shrink",
  		"flex-basis"
  	],
  	order: "orderOfAppearance",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/flex"
  };
  var float = {
  	syntax: "left | right | none | inline-start | inline-end",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Positioning"
  	],
  	initial: "none",
  	appliesto: "allElementsNoEffectIfDisplayNone",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/float"
  };
  var font = {
  	syntax: "[ [ <'font-style'> || <font-variant-css21> || <'font-weight'> || <'font-stretch'> ]? <'font-size'> [ / <'line-height'> ]? <'font-family'> ] | caption | icon | menu | message-box | small-caption | status-bar",
  	media: "visual",
  	inherited: true,
  	animationType: [
  		"font-style",
  		"font-variant",
  		"font-weight",
  		"font-stretch",
  		"font-size",
  		"line-height",
  		"font-family"
  	],
  	percentages: [
  		"font-size",
  		"line-height"
  	],
  	groups: [
  		"CSS Fonts"
  	],
  	initial: [
  		"font-style",
  		"font-variant",
  		"font-weight",
  		"font-stretch",
  		"font-size",
  		"line-height",
  		"font-family"
  	],
  	appliesto: "allElements",
  	computed: [
  		"font-style",
  		"font-variant",
  		"font-weight",
  		"font-stretch",
  		"font-size",
  		"line-height",
  		"font-family"
  	],
  	order: "orderOfAppearance",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/font"
  };
  var gap$1 = {
  	syntax: "<'row-gap'> <'column-gap'>?",
  	media: "visual",
  	inherited: false,
  	animationType: [
  		"row-gap",
  		"column-gap"
  	],
  	percentages: "no",
  	groups: [
  		"CSS Box Alignment"
  	],
  	initial: [
  		"row-gap",
  		"column-gap"
  	],
  	appliesto: "multiColumnElementsFlexContainersGridContainers",
  	computed: [
  		"row-gap",
  		"column-gap"
  	],
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/gap"
  };
  var grid = {
  	syntax: "<'grid-template'> | <'grid-template-rows'> / [ auto-flow && dense? ] <'grid-auto-columns'>? | [ auto-flow && dense? ] <'grid-auto-rows'>? / <'grid-template-columns'>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: [
  		"grid-template-rows",
  		"grid-template-columns",
  		"grid-auto-rows",
  		"grid-auto-columns"
  	],
  	groups: [
  		"CSS Grid Layout"
  	],
  	initial: [
  		"grid-template-rows",
  		"grid-template-columns",
  		"grid-template-areas",
  		"grid-auto-rows",
  		"grid-auto-columns",
  		"grid-auto-flow",
  		"grid-column-gap",
  		"grid-row-gap",
  		"column-gap",
  		"row-gap"
  	],
  	appliesto: "gridContainers",
  	computed: [
  		"grid-template-rows",
  		"grid-template-columns",
  		"grid-template-areas",
  		"grid-auto-rows",
  		"grid-auto-columns",
  		"grid-auto-flow",
  		"grid-column-gap",
  		"grid-row-gap",
  		"column-gap",
  		"row-gap"
  	],
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/grid"
  };
  var height = {
  	syntax: "auto | <length> | <percentage> | min-content | max-content | fit-content(<length-percentage>)",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "regardingHeightOfGeneratedBoxContainingBlockPercentagesRelativeToContainingBlock",
  	groups: [
  		"CSS Box Model"
  	],
  	initial: "auto",
  	appliesto: "allElementsButNonReplacedAndTableColumns",
  	computed: "percentageAutoOrAbsoluteLength",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/height"
  };
  var hyphens = {
  	syntax: "none | manual | auto",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Text"
  	],
  	initial: "manual",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/hyphens"
  };
  var inset = {
  	syntax: "<'top'>{1,4}",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "logicalHeightOfContainingBlock",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "auto",
  	appliesto: "positionedElements",
  	computed: "sameAsBoxOffsets",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/inset"
  };
  var isolation = {
  	syntax: "auto | isolate",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Compositing and Blending"
  	],
  	initial: "auto",
  	appliesto: "allElementsSVGContainerGraphicsAndGraphicsReferencingElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/isolation"
  };
  var left = {
  	syntax: "<length> | <percentage> | auto",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "referToWidthOfContainingBlock",
  	groups: [
  		"CSS Positioning"
  	],
  	initial: "auto",
  	appliesto: "positionedElements",
  	computed: "lengthAbsolutePercentageAsSpecifiedOtherwiseAuto",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/left"
  };
  var margin = {
  	syntax: "[ <length> | <percentage> | auto ]{1,4}",
  	media: "visual",
  	inherited: false,
  	animationType: "length",
  	percentages: "referToWidthOfContainingBlock",
  	groups: [
  		"CSS Box Model"
  	],
  	initial: [
  		"margin-bottom",
  		"margin-left",
  		"margin-right",
  		"margin-top"
  	],
  	appliesto: "allElementsExceptTableDisplayTypes",
  	computed: [
  		"margin-bottom",
  		"margin-left",
  		"margin-right",
  		"margin-top"
  	],
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/margin"
  };
  var mask = {
  	syntax: "<mask-layer>#",
  	media: "visual",
  	inherited: false,
  	animationType: [
  		"mask-image",
  		"mask-mode",
  		"mask-repeat",
  		"mask-position",
  		"mask-clip",
  		"mask-origin",
  		"mask-size",
  		"mask-composite"
  	],
  	percentages: [
  		"mask-position"
  	],
  	groups: [
  		"CSS Masking"
  	],
  	initial: [
  		"mask-image",
  		"mask-mode",
  		"mask-repeat",
  		"mask-position",
  		"mask-clip",
  		"mask-origin",
  		"mask-size",
  		"mask-composite"
  	],
  	appliesto: "allElementsSVGContainerElements",
  	computed: [
  		"mask-image",
  		"mask-mode",
  		"mask-repeat",
  		"mask-position",
  		"mask-clip",
  		"mask-origin",
  		"mask-size",
  		"mask-composite"
  	],
  	order: "perGrammar",
  	stacking: true,
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/mask"
  };
  var offset = {
  	syntax: "[ <'offset-position'>? [ <'offset-path'> [ <'offset-distance'> || <'offset-rotate'> ]? ]? ]! [ / <'offset-anchor'> ]?",
  	media: "visual",
  	inherited: false,
  	animationType: [
  		"offset-position",
  		"offset-path",
  		"offset-distance",
  		"offset-anchor",
  		"offset-rotate"
  	],
  	percentages: [
  		"offset-position",
  		"offset-distance",
  		"offset-anchor"
  	],
  	groups: [
  		"CSS Motion Path"
  	],
  	initial: [
  		"offset-position",
  		"offset-path",
  		"offset-distance",
  		"offset-anchor",
  		"offset-rotate"
  	],
  	appliesto: "transformableElements",
  	computed: [
  		"offset-position",
  		"offset-path",
  		"offset-distance",
  		"offset-anchor",
  		"offset-rotate"
  	],
  	order: "perGrammar",
  	stacking: true,
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/offset"
  };
  var opacity = {
  	syntax: "<alpha-value>",
  	media: "visual",
  	inherited: false,
  	animationType: "number",
  	percentages: "no",
  	groups: [
  		"CSS Color"
  	],
  	initial: "1.0",
  	appliesto: "allElements",
  	computed: "specifiedValueClipped0To1",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/opacity"
  };
  var order$1 = {
  	syntax: "<integer>",
  	media: "visual",
  	inherited: false,
  	animationType: "integer",
  	percentages: "no",
  	groups: [
  		"CSS Flexible Box Layout"
  	],
  	initial: "0",
  	appliesto: "flexItemsGridItemsAbsolutelyPositionedContainerChildren",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/order"
  };
  var orphans = {
  	syntax: "<integer>",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Fragmentation"
  	],
  	initial: "2",
  	appliesto: "blockContainerElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/orphans"
  };
  var outline = {
  	syntax: "[ <'outline-color'> || <'outline-style'> || <'outline-width'> ]",
  	media: [
  		"visual",
  		"interactive"
  	],
  	inherited: false,
  	animationType: [
  		"outline-color",
  		"outline-width",
  		"outline-style"
  	],
  	percentages: "no",
  	groups: [
  		"CSS Basic User Interface"
  	],
  	initial: [
  		"outline-color",
  		"outline-style",
  		"outline-width"
  	],
  	appliesto: "allElements",
  	computed: [
  		"outline-color",
  		"outline-width",
  		"outline-style"
  	],
  	order: "orderOfAppearance",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/outline"
  };
  var overflow = {
  	syntax: "[ visible | hidden | clip | scroll | auto ]{1,2}",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Overflow"
  	],
  	initial: "visible",
  	appliesto: "blockContainersFlexContainersGridContainers",
  	computed: [
  		"overflow-x",
  		"overflow-y"
  	],
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/overflow"
  };
  var padding = {
  	syntax: "[ <length> | <percentage> ]{1,4}",
  	media: "visual",
  	inherited: false,
  	animationType: "length",
  	percentages: "referToWidthOfContainingBlock",
  	groups: [
  		"CSS Box Model"
  	],
  	initial: [
  		"padding-bottom",
  		"padding-left",
  		"padding-right",
  		"padding-top"
  	],
  	appliesto: "allElementsExceptInternalTableDisplayTypes",
  	computed: [
  		"padding-bottom",
  		"padding-left",
  		"padding-right",
  		"padding-top"
  	],
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/padding"
  };
  var perspective = {
  	syntax: "none | <length>",
  	media: "visual",
  	inherited: false,
  	animationType: "length",
  	percentages: "no",
  	groups: [
  		"CSS Transforms"
  	],
  	initial: "none",
  	appliesto: "transformableElements",
  	computed: "absoluteLengthOrNone",
  	order: "uniqueOrder",
  	stacking: true,
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/perspective"
  };
  var position$1 = {
  	syntax: "static | relative | absolute | sticky | fixed",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Positioning"
  	],
  	initial: "static",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	stacking: true,
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/position"
  };
  var quotes$1 = {
  	syntax: "none | auto | [ <string> <string> ]+",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Generated Content"
  	],
  	initial: "dependsOnUserAgent",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/quotes"
  };
  var resize = {
  	syntax: "none | both | horizontal | vertical | block | inline",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Basic User Interface"
  	],
  	initial: "none",
  	appliesto: "elementsWithOverflowNotVisibleAndReplacedElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/resize"
  };
  var right = {
  	syntax: "<length> | <percentage> | auto",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "referToWidthOfContainingBlock",
  	groups: [
  		"CSS Positioning"
  	],
  	initial: "auto",
  	appliesto: "positionedElements",
  	computed: "lengthAbsolutePercentageAsSpecifiedOtherwiseAuto",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/right"
  };
  var rotate = {
  	syntax: "none | <angle> | [ x | y | z | <number>{3} ] && <angle>",
  	media: "visual",
  	inherited: false,
  	animationType: "transform",
  	percentages: "no",
  	groups: [
  		"CSS Transforms"
  	],
  	initial: "none",
  	appliesto: "transformableElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	stacking: true,
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/rotate"
  };
  var scale = {
  	syntax: "none | <number>{1,3}",
  	media: "visual",
  	inherited: false,
  	animationType: "transform",
  	percentages: "no",
  	groups: [
  		"CSS Transforms"
  	],
  	initial: "none",
  	appliesto: "transformableElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	stacking: true,
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scale"
  };
  var top$1 = {
  	syntax: "<length> | <percentage> | auto",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "referToContainingBlockHeight",
  	groups: [
  		"CSS Positioning"
  	],
  	initial: "auto",
  	appliesto: "positionedElements",
  	computed: "lengthAbsolutePercentageAsSpecifiedOtherwiseAuto",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/top"
  };
  var transform = {
  	syntax: "none | <transform-list>",
  	media: "visual",
  	inherited: false,
  	animationType: "transform",
  	percentages: "referToSizeOfBoundingBox",
  	groups: [
  		"CSS Transforms"
  	],
  	initial: "none",
  	appliesto: "transformableElements",
  	computed: "asSpecifiedRelativeToAbsoluteLengths",
  	order: "uniqueOrder",
  	stacking: true,
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/transform"
  };
  var transition = {
  	syntax: "<single-transition>#",
  	media: "interactive",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Transitions"
  	],
  	initial: [
  		"transition-delay",
  		"transition-duration",
  		"transition-property",
  		"transition-timing-function"
  	],
  	appliesto: "allElementsAndPseudos",
  	computed: [
  		"transition-delay",
  		"transition-duration",
  		"transition-property",
  		"transition-timing-function"
  	],
  	order: "orderOfAppearance",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/transition"
  };
  var translate = {
  	syntax: "none | <length-percentage> [ <length-percentage> <length>? ]?",
  	media: "visual",
  	inherited: false,
  	animationType: "transform",
  	percentages: "referToSizeOfBoundingBox",
  	groups: [
  		"CSS Transforms"
  	],
  	initial: "none",
  	appliesto: "transformableElements",
  	computed: "asSpecifiedRelativeToAbsoluteLengths",
  	order: "perGrammar",
  	stacking: true,
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/translate"
  };
  var visibility = {
  	syntax: "visible | hidden | collapse",
  	media: "visual",
  	inherited: true,
  	animationType: "visibility",
  	percentages: "no",
  	groups: [
  		"CSS Box Model"
  	],
  	initial: "visible",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/visibility"
  };
  var widows = {
  	syntax: "<integer>",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Fragmentation"
  	],
  	initial: "2",
  	appliesto: "blockContainerElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/widows"
  };
  var width = {
  	syntax: "auto | <length> | <percentage> | min-content | max-content | fit-content(<length-percentage>)",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "referToWidthOfContainingBlock",
  	groups: [
  		"CSS Box Model"
  	],
  	initial: "auto",
  	appliesto: "allElementsButNonReplacedAndTableRows",
  	computed: "percentageAutoOrAbsoluteLength",
  	order: "lengthOrPercentageBeforeKeywordIfBothPresent",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/width"
  };
  var zoom = {
  	syntax: "normal | reset | <number> | <percentage>",
  	media: "visual",
  	inherited: false,
  	animationType: "integer",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "normal",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/zoom"
  };
  var mdnProperties = {
  	"--*": {
  	syntax: "<declaration-value>",
  	media: "all",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Variables"
  	],
  	initial: "seeProse",
  	appliesto: "allElements",
  	computed: "asSpecifiedWithVarsSubstituted",
  	order: "perGrammar",
  	status: "experimental",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/--*"
  },
  	"-ms-accelerator": {
  	syntax: "false | true",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "false",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-accelerator"
  },
  	"-ms-block-progression": {
  	syntax: "tb | rl | bt | lr",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "tb",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-block-progression"
  },
  	"-ms-content-zoom-chaining": {
  	syntax: "none | chained",
  	media: "interactive",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "none",
  	appliesto: "nonReplacedBlockAndInlineBlockElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-content-zoom-chaining"
  },
  	"-ms-content-zooming": {
  	syntax: "none | zoom",
  	media: "interactive",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "zoomForTheTopLevelNoneForTheRest",
  	appliesto: "nonReplacedBlockAndInlineBlockElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-content-zooming"
  },
  	"-ms-content-zoom-limit": {
  	syntax: "<'-ms-content-zoom-limit-min'> <'-ms-content-zoom-limit-max'>",
  	media: "interactive",
  	inherited: false,
  	animationType: "discrete",
  	percentages: [
  		"-ms-content-zoom-limit-max",
  		"-ms-content-zoom-limit-min"
  	],
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: [
  		"-ms-content-zoom-limit-max",
  		"-ms-content-zoom-limit-min"
  	],
  	appliesto: "nonReplacedBlockAndInlineBlockElements",
  	computed: [
  		"-ms-content-zoom-limit-max",
  		"-ms-content-zoom-limit-min"
  	],
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-content-zoom-limit"
  },
  	"-ms-content-zoom-limit-max": {
  	syntax: "<percentage>",
  	media: "interactive",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "maxZoomFactor",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "400%",
  	appliesto: "nonReplacedBlockAndInlineBlockElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-content-zoom-limit-max"
  },
  	"-ms-content-zoom-limit-min": {
  	syntax: "<percentage>",
  	media: "interactive",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "minZoomFactor",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "100%",
  	appliesto: "nonReplacedBlockAndInlineBlockElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-content-zoom-limit-min"
  },
  	"-ms-content-zoom-snap": {
  	syntax: "<'-ms-content-zoom-snap-type'> || <'-ms-content-zoom-snap-points'>",
  	media: "interactive",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: [
  		"-ms-content-zoom-snap-type",
  		"-ms-content-zoom-snap-points"
  	],
  	appliesto: "nonReplacedBlockAndInlineBlockElements",
  	computed: [
  		"-ms-content-zoom-snap-type",
  		"-ms-content-zoom-snap-points"
  	],
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-content-zoom-snap"
  },
  	"-ms-content-zoom-snap-points": {
  	syntax: "snapInterval( <percentage>, <percentage> ) | snapList( <percentage># )",
  	media: "interactive",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "snapInterval(0%, 100%)",
  	appliesto: "nonReplacedBlockAndInlineBlockElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-content-zoom-snap-points"
  },
  	"-ms-content-zoom-snap-type": {
  	syntax: "none | proximity | mandatory",
  	media: "interactive",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "none",
  	appliesto: "nonReplacedBlockAndInlineBlockElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-content-zoom-snap-type"
  },
  	"-ms-filter": {
  	syntax: "<string>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "\"\"",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-filter"
  },
  	"-ms-flow-from": {
  	syntax: "[ none | <custom-ident> ]#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "none",
  	appliesto: "nonReplacedElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-flow-from"
  },
  	"-ms-flow-into": {
  	syntax: "[ none | <custom-ident> ]#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "none",
  	appliesto: "iframeElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-flow-into"
  },
  	"-ms-grid-columns": {
  	syntax: "none | <track-list> | <auto-track-list>",
  	media: "visual",
  	inherited: false,
  	animationType: "simpleListOfLpcDifferenceLpc",
  	percentages: "referToDimensionOfContentArea",
  	groups: [
  		"CSS Grid Layout"
  	],
  	initial: "none",
  	appliesto: "gridContainers",
  	computed: "asSpecifiedRelativeToAbsoluteLengths",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-grid-columns"
  },
  	"-ms-grid-rows": {
  	syntax: "none | <track-list> | <auto-track-list>",
  	media: "visual",
  	inherited: false,
  	animationType: "simpleListOfLpcDifferenceLpc",
  	percentages: "referToDimensionOfContentArea",
  	groups: [
  		"CSS Grid Layout"
  	],
  	initial: "none",
  	appliesto: "gridContainers",
  	computed: "asSpecifiedRelativeToAbsoluteLengths",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-grid-rows"
  },
  	"-ms-high-contrast-adjust": {
  	syntax: "auto | none",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "auto",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-high-contrast-adjust"
  },
  	"-ms-hyphenate-limit-chars": {
  	syntax: "auto | <integer>{1,3}",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "auto",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-hyphenate-limit-chars"
  },
  	"-ms-hyphenate-limit-lines": {
  	syntax: "no-limit | <integer>",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "no-limit",
  	appliesto: "blockContainerElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-hyphenate-limit-lines"
  },
  	"-ms-hyphenate-limit-zone": {
  	syntax: "<percentage> | <length>",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "referToLineBoxWidth",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "0",
  	appliesto: "blockContainerElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-hyphenate-limit-zone"
  },
  	"-ms-ime-align": {
  	syntax: "auto | after",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "auto",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-ime-align"
  },
  	"-ms-overflow-style": {
  	syntax: "auto | none | scrollbar | -ms-autohiding-scrollbar",
  	media: "interactive",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "auto",
  	appliesto: "nonReplacedBlockAndInlineBlockElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-overflow-style"
  },
  	"-ms-scrollbar-3dlight-color": {
  	syntax: "<color>",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "dependsOnUserAgent",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-scrollbar-3dlight-color"
  },
  	"-ms-scrollbar-arrow-color": {
  	syntax: "<color>",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "ButtonText",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-scrollbar-arrow-color"
  },
  	"-ms-scrollbar-base-color": {
  	syntax: "<color>",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "dependsOnUserAgent",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-scrollbar-base-color"
  },
  	"-ms-scrollbar-darkshadow-color": {
  	syntax: "<color>",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "ThreeDDarkShadow",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-scrollbar-darkshadow-color"
  },
  	"-ms-scrollbar-face-color": {
  	syntax: "<color>",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "ThreeDFace",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-scrollbar-face-color"
  },
  	"-ms-scrollbar-highlight-color": {
  	syntax: "<color>",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "ThreeDHighlight",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-scrollbar-highlight-color"
  },
  	"-ms-scrollbar-shadow-color": {
  	syntax: "<color>",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "ThreeDDarkShadow",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-scrollbar-shadow-color"
  },
  	"-ms-scrollbar-track-color": {
  	syntax: "<color>",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "Scrollbar",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-scrollbar-track-color"
  },
  	"-ms-scroll-chaining": {
  	syntax: "chained | none",
  	media: "interactive",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "chained",
  	appliesto: "nonReplacedBlockAndInlineBlockElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-scroll-chaining"
  },
  	"-ms-scroll-limit": {
  	syntax: "<'-ms-scroll-limit-x-min'> <'-ms-scroll-limit-y-min'> <'-ms-scroll-limit-x-max'> <'-ms-scroll-limit-y-max'>",
  	media: "interactive",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: [
  		"-ms-scroll-limit-x-min",
  		"-ms-scroll-limit-y-min",
  		"-ms-scroll-limit-x-max",
  		"-ms-scroll-limit-y-max"
  	],
  	appliesto: "nonReplacedBlockAndInlineBlockElements",
  	computed: [
  		"-ms-scroll-limit-x-min",
  		"-ms-scroll-limit-y-min",
  		"-ms-scroll-limit-x-max",
  		"-ms-scroll-limit-y-max"
  	],
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-scroll-limit"
  },
  	"-ms-scroll-limit-x-max": {
  	syntax: "auto | <length>",
  	media: "interactive",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "auto",
  	appliesto: "nonReplacedBlockAndInlineBlockElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-scroll-limit-x-max"
  },
  	"-ms-scroll-limit-x-min": {
  	syntax: "<length>",
  	media: "interactive",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "0",
  	appliesto: "nonReplacedBlockAndInlineBlockElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-scroll-limit-x-min"
  },
  	"-ms-scroll-limit-y-max": {
  	syntax: "auto | <length>",
  	media: "interactive",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "auto",
  	appliesto: "nonReplacedBlockAndInlineBlockElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-scroll-limit-y-max"
  },
  	"-ms-scroll-limit-y-min": {
  	syntax: "<length>",
  	media: "interactive",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "0",
  	appliesto: "nonReplacedBlockAndInlineBlockElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-scroll-limit-y-min"
  },
  	"-ms-scroll-rails": {
  	syntax: "none | railed",
  	media: "interactive",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "railed",
  	appliesto: "nonReplacedBlockAndInlineBlockElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-scroll-rails"
  },
  	"-ms-scroll-snap-points-x": {
  	syntax: "snapInterval( <length-percentage>, <length-percentage> ) | snapList( <length-percentage># )",
  	media: "interactive",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "snapInterval(0px, 100%)",
  	appliesto: "nonReplacedBlockAndInlineBlockElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-scroll-snap-points-x"
  },
  	"-ms-scroll-snap-points-y": {
  	syntax: "snapInterval( <length-percentage>, <length-percentage> ) | snapList( <length-percentage># )",
  	media: "interactive",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "snapInterval(0px, 100%)",
  	appliesto: "nonReplacedBlockAndInlineBlockElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-scroll-snap-points-y"
  },
  	"-ms-scroll-snap-type": {
  	syntax: "none | proximity | mandatory",
  	media: "interactive",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "none",
  	appliesto: "nonReplacedBlockAndInlineBlockElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-scroll-snap-type"
  },
  	"-ms-scroll-snap-x": {
  	syntax: "<'-ms-scroll-snap-type'> <'-ms-scroll-snap-points-x'>",
  	media: "interactive",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: [
  		"-ms-scroll-snap-type",
  		"-ms-scroll-snap-points-x"
  	],
  	appliesto: "nonReplacedBlockAndInlineBlockElements",
  	computed: [
  		"-ms-scroll-snap-type",
  		"-ms-scroll-snap-points-x"
  	],
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-scroll-snap-x"
  },
  	"-ms-scroll-snap-y": {
  	syntax: "<'-ms-scroll-snap-type'> <'-ms-scroll-snap-points-y'>",
  	media: "interactive",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: [
  		"-ms-scroll-snap-type",
  		"-ms-scroll-snap-points-y"
  	],
  	appliesto: "nonReplacedBlockAndInlineBlockElements",
  	computed: [
  		"-ms-scroll-snap-type",
  		"-ms-scroll-snap-points-y"
  	],
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-scroll-snap-y"
  },
  	"-ms-scroll-translation": {
  	syntax: "none | vertical-to-horizontal",
  	media: "interactive",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-scroll-translation"
  },
  	"-ms-text-autospace": {
  	syntax: "none | ideograph-alpha | ideograph-numeric | ideograph-parenthesis | ideograph-space",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-text-autospace"
  },
  	"-ms-touch-select": {
  	syntax: "grippers | none",
  	media: "interactive",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "grippers",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-touch-select"
  },
  	"-ms-user-select": {
  	syntax: "none | element | text",
  	media: "interactive",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "text",
  	appliesto: "nonReplacedElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-user-select"
  },
  	"-ms-wrap-flow": {
  	syntax: "auto | both | start | end | maximum | clear",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "auto",
  	appliesto: "blockLevelElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-wrap-flow"
  },
  	"-ms-wrap-margin": {
  	syntax: "<length>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "0",
  	appliesto: "exclusionElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-wrap-margin"
  },
  	"-ms-wrap-through": {
  	syntax: "wrap | none",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Microsoft Extensions"
  	],
  	initial: "wrap",
  	appliesto: "blockLevelElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-ms-wrap-through"
  },
  	"-moz-appearance": {
  	syntax: "none | button | button-arrow-down | button-arrow-next | button-arrow-previous | button-arrow-up | button-bevel | button-focus | caret | checkbox | checkbox-container | checkbox-label | checkmenuitem | dualbutton | groupbox | listbox | listitem | menuarrow | menubar | menucheckbox | menuimage | menuitem | menuitemtext | menulist | menulist-button | menulist-text | menulist-textfield | menupopup | menuradio | menuseparator | meterbar | meterchunk | progressbar | progressbar-vertical | progresschunk | progresschunk-vertical | radio | radio-container | radio-label | radiomenuitem | range | range-thumb | resizer | resizerpanel | scale-horizontal | scalethumbend | scalethumb-horizontal | scalethumbstart | scalethumbtick | scalethumb-vertical | scale-vertical | scrollbarbutton-down | scrollbarbutton-left | scrollbarbutton-right | scrollbarbutton-up | scrollbarthumb-horizontal | scrollbarthumb-vertical | scrollbartrack-horizontal | scrollbartrack-vertical | searchfield | separator | sheet | spinner | spinner-downbutton | spinner-textfield | spinner-upbutton | splitter | statusbar | statusbarpanel | tab | tabpanel | tabpanels | tab-scroll-arrow-back | tab-scroll-arrow-forward | textfield | textfield-multiline | toolbar | toolbarbutton | toolbarbutton-dropdown | toolbargripper | toolbox | tooltip | treeheader | treeheadercell | treeheadersortarrow | treeitem | treeline | treetwisty | treetwistyopen | treeview | -moz-mac-unified-toolbar | -moz-win-borderless-glass | -moz-win-browsertabbar-toolbox | -moz-win-communicationstext | -moz-win-communications-toolbox | -moz-win-exclude-glass | -moz-win-glass | -moz-win-mediatext | -moz-win-media-toolbox | -moz-window-button-box | -moz-window-button-box-maximized | -moz-window-button-close | -moz-window-button-maximize | -moz-window-button-minimize | -moz-window-button-restore | -moz-window-frame-bottom | -moz-window-frame-left | -moz-window-frame-right | -moz-window-titlebar | -moz-window-titlebar-maximized",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Mozilla Extensions",
  		"WebKit Extensions"
  	],
  	initial: "noneButOverriddenInUserAgentCSS",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/appearance"
  },
  	"-moz-binding": {
  	syntax: "<url> | none",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Mozilla Extensions"
  	],
  	initial: "none",
  	appliesto: "allElementsExceptGeneratedContentOrPseudoElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-moz-binding"
  },
  	"-moz-border-bottom-colors": {
  	syntax: "<color>+ | none",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Mozilla Extensions"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-moz-border-bottom-colors"
  },
  	"-moz-border-left-colors": {
  	syntax: "<color>+ | none",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Mozilla Extensions"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-moz-border-left-colors"
  },
  	"-moz-border-right-colors": {
  	syntax: "<color>+ | none",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Mozilla Extensions"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-moz-border-right-colors"
  },
  	"-moz-border-top-colors": {
  	syntax: "<color>+ | none",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Mozilla Extensions"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-moz-border-top-colors"
  },
  	"-moz-context-properties": {
  	syntax: "none | [ fill | fill-opacity | stroke | stroke-opacity ]#",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Mozilla Extensions"
  	],
  	initial: "none",
  	appliesto: "allElementsThatCanReferenceImages",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-moz-context-properties"
  },
  	"-moz-float-edge": {
  	syntax: "border-box | content-box | margin-box | padding-box",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Mozilla Extensions"
  	],
  	initial: "content-box",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-moz-float-edge"
  },
  	"-moz-force-broken-image-icon": {
  	syntax: "<integer [0,1]>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Mozilla Extensions"
  	],
  	initial: "0",
  	appliesto: "images",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-moz-force-broken-image-icon"
  },
  	"-moz-image-region": {
  	syntax: "<shape> | auto",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Mozilla Extensions"
  	],
  	initial: "auto",
  	appliesto: "xulImageElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-moz-image-region"
  },
  	"-moz-orient": {
  	syntax: "inline | block | horizontal | vertical",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Mozilla Extensions"
  	],
  	initial: "inline",
  	appliesto: "anyElementEffectOnProgressAndMeter",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-moz-orient"
  },
  	"-moz-outline-radius": {
  	syntax: "<outline-radius>{1,4} [ / <outline-radius>{1,4} ]?",
  	media: "visual",
  	inherited: false,
  	animationType: [
  		"-moz-outline-radius-topleft",
  		"-moz-outline-radius-topright",
  		"-moz-outline-radius-bottomright",
  		"-moz-outline-radius-bottomleft"
  	],
  	percentages: [
  		"-moz-outline-radius-topleft",
  		"-moz-outline-radius-topright",
  		"-moz-outline-radius-bottomright",
  		"-moz-outline-radius-bottomleft"
  	],
  	groups: [
  		"Mozilla Extensions"
  	],
  	initial: [
  		"-moz-outline-radius-topleft",
  		"-moz-outline-radius-topright",
  		"-moz-outline-radius-bottomright",
  		"-moz-outline-radius-bottomleft"
  	],
  	appliesto: "allElements",
  	computed: [
  		"-moz-outline-radius-topleft",
  		"-moz-outline-radius-topright",
  		"-moz-outline-radius-bottomright",
  		"-moz-outline-radius-bottomleft"
  	],
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-moz-outline-radius"
  },
  	"-moz-outline-radius-bottomleft": {
  	syntax: "<outline-radius>",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "referToDimensionOfBorderBox",
  	groups: [
  		"Mozilla Extensions"
  	],
  	initial: "0",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-moz-outline-radius-bottomleft"
  },
  	"-moz-outline-radius-bottomright": {
  	syntax: "<outline-radius>",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "referToDimensionOfBorderBox",
  	groups: [
  		"Mozilla Extensions"
  	],
  	initial: "0",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-moz-outline-radius-bottomright"
  },
  	"-moz-outline-radius-topleft": {
  	syntax: "<outline-radius>",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "referToDimensionOfBorderBox",
  	groups: [
  		"Mozilla Extensions"
  	],
  	initial: "0",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-moz-outline-radius-topleft"
  },
  	"-moz-outline-radius-topright": {
  	syntax: "<outline-radius>",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "referToDimensionOfBorderBox",
  	groups: [
  		"Mozilla Extensions"
  	],
  	initial: "0",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-moz-outline-radius-topright"
  },
  	"-moz-stack-sizing": {
  	syntax: "ignore | stretch-to-fit",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Mozilla Extensions"
  	],
  	initial: "stretch-to-fit",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-moz-stack-sizing"
  },
  	"-moz-text-blink": {
  	syntax: "none | blink",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Mozilla Extensions"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-moz-text-blink"
  },
  	"-moz-user-focus": {
  	syntax: "ignore | normal | select-after | select-before | select-menu | select-same | select-all | none",
  	media: "interactive",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Mozilla Extensions"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-moz-user-focus"
  },
  	"-moz-user-input": {
  	syntax: "auto | none | enabled | disabled",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Mozilla Extensions"
  	],
  	initial: "auto",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-moz-user-input"
  },
  	"-moz-user-modify": {
  	syntax: "read-only | read-write | write-only",
  	media: "interactive",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Mozilla Extensions"
  	],
  	initial: "read-only",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-moz-user-modify"
  },
  	"-moz-window-dragging": {
  	syntax: "drag | no-drag",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Mozilla Extensions"
  	],
  	initial: "drag",
  	appliesto: "allElementsCreatingNativeWindows",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-moz-window-dragging"
  },
  	"-moz-window-shadow": {
  	syntax: "default | menu | tooltip | sheet | none",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Mozilla Extensions"
  	],
  	initial: "default",
  	appliesto: "allElementsCreatingNativeWindows",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-moz-window-shadow"
  },
  	"-webkit-appearance": {
  	syntax: "none | button | button-bevel | caret | checkbox | default-button | inner-spin-button | listbox | listitem | media-controls-background | media-controls-fullscreen-background | media-current-time-display | media-enter-fullscreen-button | media-exit-fullscreen-button | media-fullscreen-button | media-mute-button | media-overlay-play-button | media-play-button | media-seek-back-button | media-seek-forward-button | media-slider | media-sliderthumb | media-time-remaining-display | media-toggle-closed-captions-button | media-volume-slider | media-volume-slider-container | media-volume-sliderthumb | menulist | menulist-button | menulist-text | menulist-textfield | meter | progress-bar | progress-bar-value | push-button | radio | searchfield | searchfield-cancel-button | searchfield-decoration | searchfield-results-button | searchfield-results-decoration | slider-horizontal | slider-vertical | sliderthumb-horizontal | sliderthumb-vertical | square-button | textarea | textfield | -apple-pay-button",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"WebKit Extensions"
  	],
  	initial: "noneButOverriddenInUserAgentCSS",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/appearance"
  },
  	"-webkit-border-before": {
  	syntax: "<'border-width'> || <'border-style'> || <'color'>",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: [
  		"-webkit-border-before-width"
  	],
  	groups: [
  		"WebKit Extensions"
  	],
  	initial: [
  		"border-width",
  		"border-style",
  		"color"
  	],
  	appliesto: "allElements",
  	computed: [
  		"border-width",
  		"border-style",
  		"color"
  	],
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-webkit-border-before"
  },
  	"-webkit-border-before-color": {
  	syntax: "<'color'>",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"WebKit Extensions"
  	],
  	initial: "currentcolor",
  	appliesto: "allElements",
  	computed: "computedColor",
  	order: "uniqueOrder",
  	status: "nonstandard"
  },
  	"-webkit-border-before-style": {
  	syntax: "<'border-style'>",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"WebKit Extensions"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard"
  },
  	"-webkit-border-before-width": {
  	syntax: "<'border-width'>",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "logicalWidthOfContainingBlock",
  	groups: [
  		"WebKit Extensions"
  	],
  	initial: "medium",
  	appliesto: "allElements",
  	computed: "absoluteLengthZeroIfBorderStyleNoneOrHidden",
  	order: "uniqueOrder",
  	status: "nonstandard"
  },
  	"-webkit-box-reflect": {
  	syntax: "[ above | below | right | left ]? <length>? <image>?",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"WebKit Extensions"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-webkit-box-reflect"
  },
  	"-webkit-line-clamp": {
  	syntax: "none | <integer>",
  	media: "visual",
  	inherited: false,
  	animationType: "byComputedValueType",
  	percentages: "no",
  	groups: [
  		"WebKit Extensions",
  		"CSS Overflow"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-webkit-line-clamp"
  },
  	"-webkit-mask": {
  	syntax: "[ <mask-reference> || <position> [ / <bg-size> ]? || <repeat-style> || [ <box> | border | padding | content | text ] || [ <box> | border | padding | content ] ]#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"WebKit Extensions"
  	],
  	initial: [
  		"-webkit-mask-image",
  		"-webkit-mask-repeat",
  		"-webkit-mask-attachment",
  		"-webkit-mask-position",
  		"-webkit-mask-origin",
  		"-webkit-mask-clip"
  	],
  	appliesto: "allElements",
  	computed: [
  		"-webkit-mask-image",
  		"-webkit-mask-repeat",
  		"-webkit-mask-attachment",
  		"-webkit-mask-position",
  		"-webkit-mask-origin",
  		"-webkit-mask-clip"
  	],
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/mask"
  },
  	"-webkit-mask-attachment": {
  	syntax: "<attachment>#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"WebKit Extensions"
  	],
  	initial: "scroll",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "orderOfAppearance",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-webkit-mask-attachment"
  },
  	"-webkit-mask-clip": {
  	syntax: "[ <box> | border | padding | content | text ]#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"WebKit Extensions"
  	],
  	initial: "border",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "orderOfAppearance",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/mask-clip"
  },
  	"-webkit-mask-composite": {
  	syntax: "<composite-style>#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"WebKit Extensions"
  	],
  	initial: "source-over",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "orderOfAppearance",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-webkit-mask-composite"
  },
  	"-webkit-mask-image": {
  	syntax: "<mask-reference>#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"WebKit Extensions"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "absoluteURIOrNone",
  	order: "orderOfAppearance",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/mask-image"
  },
  	"-webkit-mask-origin": {
  	syntax: "[ <box> | border | padding | content ]#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"WebKit Extensions"
  	],
  	initial: "padding",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "orderOfAppearance",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/mask-origin"
  },
  	"-webkit-mask-position": {
  	syntax: "<position>#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "referToSizeOfElement",
  	groups: [
  		"WebKit Extensions"
  	],
  	initial: "0% 0%",
  	appliesto: "allElements",
  	computed: "absoluteLengthOrPercentage",
  	order: "orderOfAppearance",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/mask-position"
  },
  	"-webkit-mask-position-x": {
  	syntax: "[ <length-percentage> | left | center | right ]#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "referToSizeOfElement",
  	groups: [
  		"WebKit Extensions"
  	],
  	initial: "0%",
  	appliesto: "allElements",
  	computed: "absoluteLengthOrPercentage",
  	order: "orderOfAppearance",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-webkit-mask-position-x"
  },
  	"-webkit-mask-position-y": {
  	syntax: "[ <length-percentage> | top | center | bottom ]#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "referToSizeOfElement",
  	groups: [
  		"WebKit Extensions"
  	],
  	initial: "0%",
  	appliesto: "allElements",
  	computed: "absoluteLengthOrPercentage",
  	order: "orderOfAppearance",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-webkit-mask-position-y"
  },
  	"-webkit-mask-repeat": {
  	syntax: "<repeat-style>#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"WebKit Extensions"
  	],
  	initial: "repeat",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "orderOfAppearance",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/mask-repeat"
  },
  	"-webkit-mask-repeat-x": {
  	syntax: "repeat | no-repeat | space | round",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"WebKit Extensions"
  	],
  	initial: "repeat",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "orderOfAppearance",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-webkit-mask-repeat-x"
  },
  	"-webkit-mask-repeat-y": {
  	syntax: "repeat | no-repeat | space | round",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"WebKit Extensions"
  	],
  	initial: "repeat",
  	appliesto: "allElements",
  	computed: "absoluteLengthOrPercentage",
  	order: "orderOfAppearance",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-webkit-mask-repeat-y"
  },
  	"-webkit-mask-size": {
  	syntax: "<bg-size>#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "relativeToBackgroundPositioningArea",
  	groups: [
  		"WebKit Extensions"
  	],
  	initial: "auto auto",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "orderOfAppearance",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/mask-size"
  },
  	"-webkit-overflow-scrolling": {
  	syntax: "auto | touch",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"WebKit Extensions"
  	],
  	initial: "auto",
  	appliesto: "scrollingBoxes",
  	computed: "asSpecified",
  	order: "orderOfAppearance",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-webkit-overflow-scrolling"
  },
  	"-webkit-tap-highlight-color": {
  	syntax: "<color>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"WebKit Extensions"
  	],
  	initial: "black",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-webkit-tap-highlight-color"
  },
  	"-webkit-text-fill-color": {
  	syntax: "<color>",
  	media: "visual",
  	inherited: true,
  	animationType: "color",
  	percentages: "no",
  	groups: [
  		"WebKit Extensions"
  	],
  	initial: "currentcolor",
  	appliesto: "allElements",
  	computed: "computedColor",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-webkit-text-fill-color"
  },
  	"-webkit-text-stroke": {
  	syntax: "<length> || <color>",
  	media: "visual",
  	inherited: true,
  	animationType: [
  		"-webkit-text-stroke-width",
  		"-webkit-text-stroke-color"
  	],
  	percentages: "no",
  	groups: [
  		"WebKit Extensions"
  	],
  	initial: [
  		"-webkit-text-stroke-width",
  		"-webkit-text-stroke-color"
  	],
  	appliesto: "allElements",
  	computed: [
  		"-webkit-text-stroke-width",
  		"-webkit-text-stroke-color"
  	],
  	order: "canonicalOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-webkit-text-stroke"
  },
  	"-webkit-text-stroke-color": {
  	syntax: "<color>",
  	media: "visual",
  	inherited: true,
  	animationType: "color",
  	percentages: "no",
  	groups: [
  		"WebKit Extensions"
  	],
  	initial: "currentcolor",
  	appliesto: "allElements",
  	computed: "computedColor",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-webkit-text-stroke-color"
  },
  	"-webkit-text-stroke-width": {
  	syntax: "<length>",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"WebKit Extensions"
  	],
  	initial: "0",
  	appliesto: "allElements",
  	computed: "absoluteLength",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-webkit-text-stroke-width"
  },
  	"-webkit-touch-callout": {
  	syntax: "default | none",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"WebKit Extensions"
  	],
  	initial: "default",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/-webkit-touch-callout"
  },
  	"-webkit-user-modify": {
  	syntax: "read-only | read-write | read-write-plaintext-only",
  	media: "interactive",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"WebKit Extensions"
  	],
  	initial: "read-only",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard"
  },
  	"align-content": {
  	syntax: "normal | <baseline-position> | <content-distribution> | <overflow-position>? <content-position>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Box Alignment"
  	],
  	initial: "normal",
  	appliesto: "multilineFlexContainers",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/align-content"
  },
  	"align-items": {
  	syntax: "normal | stretch | <baseline-position> | [ <overflow-position>? <self-position> ]",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Box Alignment"
  	],
  	initial: "normal",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/align-items"
  },
  	"align-self": {
  	syntax: "auto | normal | stretch | <baseline-position> | <overflow-position>? <self-position>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Box Alignment"
  	],
  	initial: "auto",
  	appliesto: "flexItemsGridItemsAndAbsolutelyPositionedBoxes",
  	computed: "autoOnAbsolutelyPositionedElementsValueOfAlignItemsOnParent",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/align-self"
  },
  	"align-tracks": {
  	syntax: "[ normal | <baseline-position> | <content-distribution> | <overflow-position>? <content-position> ]#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Grid Layout"
  	],
  	initial: "normal",
  	appliesto: "gridContainersWithMasonryLayoutInTheirBlockAxis",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "experimental",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/align-tracks"
  },
  	all: all,
  	animation: animation,
  	"animation-delay": {
  	syntax: "<time>#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Animations"
  	],
  	initial: "0s",
  	appliesto: "allElementsAndPseudos",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/animation-delay"
  },
  	"animation-direction": {
  	syntax: "<single-animation-direction>#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Animations"
  	],
  	initial: "normal",
  	appliesto: "allElementsAndPseudos",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/animation-direction"
  },
  	"animation-duration": {
  	syntax: "<time>#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Animations"
  	],
  	initial: "0s",
  	appliesto: "allElementsAndPseudos",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/animation-duration"
  },
  	"animation-fill-mode": {
  	syntax: "<single-animation-fill-mode>#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Animations"
  	],
  	initial: "none",
  	appliesto: "allElementsAndPseudos",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/animation-fill-mode"
  },
  	"animation-iteration-count": {
  	syntax: "<single-animation-iteration-count>#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Animations"
  	],
  	initial: "1",
  	appliesto: "allElementsAndPseudos",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/animation-iteration-count"
  },
  	"animation-name": {
  	syntax: "[ none | <keyframes-name> ]#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Animations"
  	],
  	initial: "none",
  	appliesto: "allElementsAndPseudos",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/animation-name"
  },
  	"animation-play-state": {
  	syntax: "<single-animation-play-state>#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Animations"
  	],
  	initial: "running",
  	appliesto: "allElementsAndPseudos",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/animation-play-state"
  },
  	"animation-timing-function": {
  	syntax: "<timing-function>#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Animations"
  	],
  	initial: "ease",
  	appliesto: "allElementsAndPseudos",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/animation-timing-function"
  },
  	appearance: appearance,
  	"aspect-ratio": {
  	syntax: "auto | <ratio>",
  	media: "all",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Basic User Interface"
  	],
  	initial: "auto",
  	appliesto: "allElementsExceptInlineBoxesAndInternalRubyOrTableBoxes",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "experimental",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/aspect-ratio"
  },
  	azimuth: azimuth,
  	"backdrop-filter": {
  	syntax: "none | <filter-function-list>",
  	media: "visual",
  	inherited: false,
  	animationType: "filterList",
  	percentages: "no",
  	groups: [
  		"Filter Effects"
  	],
  	initial: "none",
  	appliesto: "allElementsSVGContainerElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/backdrop-filter"
  },
  	"backface-visibility": {
  	syntax: "visible | hidden",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Transforms"
  	],
  	initial: "visible",
  	appliesto: "transformableElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/backface-visibility"
  },
  	background: background,
  	"background-attachment": {
  	syntax: "<attachment>#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: "scroll",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/background-attachment"
  },
  	"background-blend-mode": {
  	syntax: "<blend-mode>#",
  	media: "none",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Compositing and Blending"
  	],
  	initial: "normal",
  	appliesto: "allElementsSVGContainerGraphicsAndGraphicsReferencingElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/background-blend-mode"
  },
  	"background-clip": {
  	syntax: "<box>#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: "border-box",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/background-clip"
  },
  	"background-color": {
  	syntax: "<color>",
  	media: "visual",
  	inherited: false,
  	animationType: "color",
  	percentages: "no",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: "transparent",
  	appliesto: "allElements",
  	computed: "computedColor",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/background-color"
  },
  	"background-image": {
  	syntax: "<bg-image>#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecifiedURLsAbsolute",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/background-image"
  },
  	"background-origin": {
  	syntax: "<box>#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: "padding-box",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/background-origin"
  },
  	"background-position": {
  	syntax: "<bg-position>#",
  	media: "visual",
  	inherited: false,
  	animationType: "repeatableListOfSimpleListOfLpc",
  	percentages: "referToSizeOfBackgroundPositioningAreaMinusBackgroundImageSize",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: "0% 0%",
  	appliesto: "allElements",
  	computed: "listEachItemTwoKeywordsOriginOffsets",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/background-position"
  },
  	"background-position-x": {
  	syntax: "[ center | [ [ left | right | x-start | x-end ]? <length-percentage>? ]! ]#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "referToWidthOfBackgroundPositioningAreaMinusBackgroundImageHeight",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: "left",
  	appliesto: "allElements",
  	computed: "listEachItemConsistingOfAbsoluteLengthPercentageAndOrigin",
  	order: "uniqueOrder",
  	status: "experimental",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/background-position-x"
  },
  	"background-position-y": {
  	syntax: "[ center | [ [ top | bottom | y-start | y-end ]? <length-percentage>? ]! ]#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "referToHeightOfBackgroundPositioningAreaMinusBackgroundImageHeight",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: "top",
  	appliesto: "allElements",
  	computed: "listEachItemConsistingOfAbsoluteLengthPercentageAndOrigin",
  	order: "uniqueOrder",
  	status: "experimental",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/background-position-y"
  },
  	"background-repeat": {
  	syntax: "<repeat-style>#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: "repeat",
  	appliesto: "allElements",
  	computed: "listEachItemHasTwoKeywordsOnePerDimension",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/background-repeat"
  },
  	"background-size": {
  	syntax: "<bg-size>#",
  	media: "visual",
  	inherited: false,
  	animationType: "repeatableListOfSimpleListOfLpc",
  	percentages: "relativeToBackgroundPositioningArea",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: "auto auto",
  	appliesto: "allElements",
  	computed: "asSpecifiedRelativeToAbsoluteLengths",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/background-size"
  },
  	"block-overflow": {
  	syntax: "clip | ellipsis | <string>",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Overflow"
  	],
  	initial: "clip",
  	appliesto: "blockContainers",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "experimental"
  },
  	"block-size": {
  	syntax: "<'width'>",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "blockSizeOfContainingBlock",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "auto",
  	appliesto: "sameAsWidthAndHeight",
  	computed: "sameAsWidthAndHeight",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/block-size"
  },
  	border: border,
  	"border-block": {
  	syntax: "<'border-top-width'> || <'border-top-style'> || <'color'>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: [
  		"border-top-width",
  		"border-top-style",
  		"border-top-color"
  	],
  	appliesto: "allElements",
  	computed: [
  		"border-top-width",
  		"border-top-style",
  		"border-top-color"
  	],
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-block"
  },
  	"border-block-color": {
  	syntax: "<'border-top-color'>{1,2}",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "currentcolor",
  	appliesto: "allElements",
  	computed: "computedColor",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-block-color"
  },
  	"border-block-style": {
  	syntax: "<'border-top-style'>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-block-style"
  },
  	"border-block-width": {
  	syntax: "<'border-top-width'>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "logicalWidthOfContainingBlock",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "medium",
  	appliesto: "allElements",
  	computed: "absoluteLengthZeroIfBorderStyleNoneOrHidden",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-block-width"
  },
  	"border-block-end": {
  	syntax: "<'border-top-width'> || <'border-top-style'> || <'color'>",
  	media: "visual",
  	inherited: false,
  	animationType: [
  		"border-block-end-color",
  		"border-block-end-style",
  		"border-block-end-width"
  	],
  	percentages: "no",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: [
  		"border-top-width",
  		"border-top-style",
  		"border-top-color"
  	],
  	appliesto: "allElements",
  	computed: [
  		"border-top-width",
  		"border-top-style",
  		"border-top-color"
  	],
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-block-end"
  },
  	"border-block-end-color": {
  	syntax: "<'border-top-color'>",
  	media: "visual",
  	inherited: false,
  	animationType: "color",
  	percentages: "no",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "currentcolor",
  	appliesto: "allElements",
  	computed: "computedColor",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-block-end-color"
  },
  	"border-block-end-style": {
  	syntax: "<'border-top-style'>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-block-end-style"
  },
  	"border-block-end-width": {
  	syntax: "<'border-top-width'>",
  	media: "visual",
  	inherited: false,
  	animationType: "length",
  	percentages: "logicalWidthOfContainingBlock",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "medium",
  	appliesto: "allElements",
  	computed: "absoluteLengthZeroIfBorderStyleNoneOrHidden",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-block-end-width"
  },
  	"border-block-start": {
  	syntax: "<'border-top-width'> || <'border-top-style'> || <'color'>",
  	media: "visual",
  	inherited: false,
  	animationType: [
  		"border-block-start-color",
  		"border-block-start-style",
  		"border-block-start-width"
  	],
  	percentages: "no",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: [
  		"border-width",
  		"border-style",
  		"color"
  	],
  	appliesto: "allElements",
  	computed: [
  		"border-width",
  		"border-style",
  		"border-block-start-color"
  	],
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-block-start"
  },
  	"border-block-start-color": {
  	syntax: "<'border-top-color'>",
  	media: "visual",
  	inherited: false,
  	animationType: "color",
  	percentages: "no",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "currentcolor",
  	appliesto: "allElements",
  	computed: "computedColor",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-block-start-color"
  },
  	"border-block-start-style": {
  	syntax: "<'border-top-style'>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-block-start-style"
  },
  	"border-block-start-width": {
  	syntax: "<'border-top-width'>",
  	media: "visual",
  	inherited: false,
  	animationType: "length",
  	percentages: "logicalWidthOfContainingBlock",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "medium",
  	appliesto: "allElements",
  	computed: "absoluteLengthZeroIfBorderStyleNoneOrHidden",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-block-start-width"
  },
  	"border-bottom": {
  	syntax: "<line-width> || <line-style> || <color>",
  	media: "visual",
  	inherited: false,
  	animationType: [
  		"border-bottom-color",
  		"border-bottom-style",
  		"border-bottom-width"
  	],
  	percentages: "no",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: [
  		"border-bottom-width",
  		"border-bottom-style",
  		"border-bottom-color"
  	],
  	appliesto: "allElements",
  	computed: [
  		"border-bottom-width",
  		"border-bottom-style",
  		"border-bottom-color"
  	],
  	order: "orderOfAppearance",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-bottom"
  },
  	"border-bottom-color": {
  	syntax: "<'border-top-color'>",
  	media: "visual",
  	inherited: false,
  	animationType: "color",
  	percentages: "no",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: "currentcolor",
  	appliesto: "allElements",
  	computed: "computedColor",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-bottom-color"
  },
  	"border-bottom-left-radius": {
  	syntax: "<length-percentage>{1,2}",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "referToDimensionOfBorderBox",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: "0",
  	appliesto: "allElementsUAsNotRequiredWhenCollapse",
  	computed: "twoAbsoluteLengthOrPercentages",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-bottom-left-radius"
  },
  	"border-bottom-right-radius": {
  	syntax: "<length-percentage>{1,2}",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "referToDimensionOfBorderBox",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: "0",
  	appliesto: "allElementsUAsNotRequiredWhenCollapse",
  	computed: "twoAbsoluteLengthOrPercentages",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-bottom-right-radius"
  },
  	"border-bottom-style": {
  	syntax: "<line-style>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-bottom-style"
  },
  	"border-bottom-width": {
  	syntax: "<line-width>",
  	media: "visual",
  	inherited: false,
  	animationType: "length",
  	percentages: "no",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: "medium",
  	appliesto: "allElements",
  	computed: "absoluteLengthOr0IfBorderBottomStyleNoneOrHidden",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-bottom-width"
  },
  	"border-collapse": {
  	syntax: "collapse | separate",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Table"
  	],
  	initial: "separate",
  	appliesto: "tableElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-collapse"
  },
  	"border-color": {
  	syntax: "<color>{1,4}",
  	media: "visual",
  	inherited: false,
  	animationType: [
  		"border-bottom-color",
  		"border-left-color",
  		"border-right-color",
  		"border-top-color"
  	],
  	percentages: "no",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: [
  		"border-top-color",
  		"border-right-color",
  		"border-bottom-color",
  		"border-left-color"
  	],
  	appliesto: "allElements",
  	computed: [
  		"border-bottom-color",
  		"border-left-color",
  		"border-right-color",
  		"border-top-color"
  	],
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-color"
  },
  	"border-end-end-radius": {
  	syntax: "<length-percentage>{1,2}",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "referToDimensionOfBorderBox",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "0",
  	appliesto: "allElementsUAsNotRequiredWhenCollapse",
  	computed: "twoAbsoluteLengthOrPercentages",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-end-end-radius"
  },
  	"border-end-start-radius": {
  	syntax: "<length-percentage>{1,2}",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "referToDimensionOfBorderBox",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "0",
  	appliesto: "allElementsUAsNotRequiredWhenCollapse",
  	computed: "twoAbsoluteLengthOrPercentages",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-end-start-radius"
  },
  	"border-image": {
  	syntax: "<'border-image-source'> || <'border-image-slice'> [ / <'border-image-width'> | / <'border-image-width'>? / <'border-image-outset'> ]? || <'border-image-repeat'>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: [
  		"border-image-slice",
  		"border-image-width"
  	],
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: [
  		"border-image-source",
  		"border-image-slice",
  		"border-image-width",
  		"border-image-outset",
  		"border-image-repeat"
  	],
  	appliesto: "allElementsExceptTableElementsWhenCollapse",
  	computed: [
  		"border-image-outset",
  		"border-image-repeat",
  		"border-image-slice",
  		"border-image-source",
  		"border-image-width"
  	],
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-image"
  },
  	"border-image-outset": {
  	syntax: "[ <length> | <number> ]{1,4}",
  	media: "visual",
  	inherited: false,
  	animationType: "byComputedValueType",
  	percentages: "no",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: "0",
  	appliesto: "allElementsExceptTableElementsWhenCollapse",
  	computed: "asSpecifiedRelativeToAbsoluteLengths",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-image-outset"
  },
  	"border-image-repeat": {
  	syntax: "[ stretch | repeat | round | space ]{1,2}",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: "stretch",
  	appliesto: "allElementsExceptTableElementsWhenCollapse",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-image-repeat"
  },
  	"border-image-slice": {
  	syntax: "<number-percentage>{1,4} && fill?",
  	media: "visual",
  	inherited: false,
  	animationType: "byComputedValueType",
  	percentages: "referToSizeOfBorderImage",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: "100%",
  	appliesto: "allElementsExceptTableElementsWhenCollapse",
  	computed: "oneToFourPercentagesOrAbsoluteLengthsPlusFill",
  	order: "percentagesOrLengthsFollowedByFill",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-image-slice"
  },
  	"border-image-source": {
  	syntax: "none | <image>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: "none",
  	appliesto: "allElementsExceptTableElementsWhenCollapse",
  	computed: "noneOrImageWithAbsoluteURI",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-image-source"
  },
  	"border-image-width": {
  	syntax: "[ <length-percentage> | <number> | auto ]{1,4}",
  	media: "visual",
  	inherited: false,
  	animationType: "byComputedValueType",
  	percentages: "referToWidthOrHeightOfBorderImageArea",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: "1",
  	appliesto: "allElementsExceptTableElementsWhenCollapse",
  	computed: "asSpecifiedRelativeToAbsoluteLengths",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-image-width"
  },
  	"border-inline": {
  	syntax: "<'border-top-width'> || <'border-top-style'> || <'color'>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: [
  		"border-top-width",
  		"border-top-style",
  		"border-top-color"
  	],
  	appliesto: "allElements",
  	computed: [
  		"border-top-width",
  		"border-top-style",
  		"border-top-color"
  	],
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-inline"
  },
  	"border-inline-end": {
  	syntax: "<'border-top-width'> || <'border-top-style'> || <'color'>",
  	media: "visual",
  	inherited: false,
  	animationType: [
  		"border-inline-end-color",
  		"border-inline-end-style",
  		"border-inline-end-width"
  	],
  	percentages: "no",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: [
  		"border-width",
  		"border-style",
  		"color"
  	],
  	appliesto: "allElements",
  	computed: [
  		"border-width",
  		"border-style",
  		"border-inline-end-color"
  	],
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-inline-end"
  },
  	"border-inline-color": {
  	syntax: "<'border-top-color'>{1,2}",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "currentcolor",
  	appliesto: "allElements",
  	computed: "computedColor",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-inline-color"
  },
  	"border-inline-style": {
  	syntax: "<'border-top-style'>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-inline-style"
  },
  	"border-inline-width": {
  	syntax: "<'border-top-width'>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "logicalWidthOfContainingBlock",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "medium",
  	appliesto: "allElements",
  	computed: "absoluteLengthZeroIfBorderStyleNoneOrHidden",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-inline-width"
  },
  	"border-inline-end-color": {
  	syntax: "<'border-top-color'>",
  	media: "visual",
  	inherited: false,
  	animationType: "color",
  	percentages: "no",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "currentcolor",
  	appliesto: "allElements",
  	computed: "computedColor",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-inline-end-color"
  },
  	"border-inline-end-style": {
  	syntax: "<'border-top-style'>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-inline-end-style"
  },
  	"border-inline-end-width": {
  	syntax: "<'border-top-width'>",
  	media: "visual",
  	inherited: false,
  	animationType: "length",
  	percentages: "logicalWidthOfContainingBlock",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "medium",
  	appliesto: "allElements",
  	computed: "absoluteLengthZeroIfBorderStyleNoneOrHidden",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-inline-end-width"
  },
  	"border-inline-start": {
  	syntax: "<'border-top-width'> || <'border-top-style'> || <'color'>",
  	media: "visual",
  	inherited: false,
  	animationType: [
  		"border-inline-start-color",
  		"border-inline-start-style",
  		"border-inline-start-width"
  	],
  	percentages: "no",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: [
  		"border-width",
  		"border-style",
  		"color"
  	],
  	appliesto: "allElements",
  	computed: [
  		"border-width",
  		"border-style",
  		"border-inline-start-color"
  	],
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-inline-start"
  },
  	"border-inline-start-color": {
  	syntax: "<'border-top-color'>",
  	media: "visual",
  	inherited: false,
  	animationType: "color",
  	percentages: "no",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "currentcolor",
  	appliesto: "allElements",
  	computed: "computedColor",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-inline-start-color"
  },
  	"border-inline-start-style": {
  	syntax: "<'border-top-style'>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-inline-start-style"
  },
  	"border-inline-start-width": {
  	syntax: "<'border-top-width'>",
  	media: "visual",
  	inherited: false,
  	animationType: "length",
  	percentages: "logicalWidthOfContainingBlock",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "medium",
  	appliesto: "allElements",
  	computed: "absoluteLengthZeroIfBorderStyleNoneOrHidden",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-inline-start-width"
  },
  	"border-left": {
  	syntax: "<line-width> || <line-style> || <color>",
  	media: "visual",
  	inherited: false,
  	animationType: [
  		"border-left-color",
  		"border-left-style",
  		"border-left-width"
  	],
  	percentages: "no",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: [
  		"border-left-width",
  		"border-left-style",
  		"border-left-color"
  	],
  	appliesto: "allElements",
  	computed: [
  		"border-left-width",
  		"border-left-style",
  		"border-left-color"
  	],
  	order: "orderOfAppearance",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-left"
  },
  	"border-left-color": {
  	syntax: "<color>",
  	media: "visual",
  	inherited: false,
  	animationType: "color",
  	percentages: "no",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: "currentcolor",
  	appliesto: "allElements",
  	computed: "computedColor",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-left-color"
  },
  	"border-left-style": {
  	syntax: "<line-style>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-left-style"
  },
  	"border-left-width": {
  	syntax: "<line-width>",
  	media: "visual",
  	inherited: false,
  	animationType: "length",
  	percentages: "no",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: "medium",
  	appliesto: "allElements",
  	computed: "absoluteLengthOr0IfBorderLeftStyleNoneOrHidden",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-left-width"
  },
  	"border-radius": {
  	syntax: "<length-percentage>{1,4} [ / <length-percentage>{1,4} ]?",
  	media: "visual",
  	inherited: false,
  	animationType: [
  		"border-top-left-radius",
  		"border-top-right-radius",
  		"border-bottom-right-radius",
  		"border-bottom-left-radius"
  	],
  	percentages: "referToDimensionOfBorderBox",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: [
  		"border-top-left-radius",
  		"border-top-right-radius",
  		"border-bottom-right-radius",
  		"border-bottom-left-radius"
  	],
  	appliesto: "allElementsUAsNotRequiredWhenCollapse",
  	computed: [
  		"border-bottom-left-radius",
  		"border-bottom-right-radius",
  		"border-top-left-radius",
  		"border-top-right-radius"
  	],
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-radius"
  },
  	"border-right": {
  	syntax: "<line-width> || <line-style> || <color>",
  	media: "visual",
  	inherited: false,
  	animationType: [
  		"border-right-color",
  		"border-right-style",
  		"border-right-width"
  	],
  	percentages: "no",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: [
  		"border-right-width",
  		"border-right-style",
  		"border-right-color"
  	],
  	appliesto: "allElements",
  	computed: [
  		"border-right-width",
  		"border-right-style",
  		"border-right-color"
  	],
  	order: "orderOfAppearance",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-right"
  },
  	"border-right-color": {
  	syntax: "<color>",
  	media: "visual",
  	inherited: false,
  	animationType: "color",
  	percentages: "no",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: "currentcolor",
  	appliesto: "allElements",
  	computed: "computedColor",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-right-color"
  },
  	"border-right-style": {
  	syntax: "<line-style>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-right-style"
  },
  	"border-right-width": {
  	syntax: "<line-width>",
  	media: "visual",
  	inherited: false,
  	animationType: "length",
  	percentages: "no",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: "medium",
  	appliesto: "allElements",
  	computed: "absoluteLengthOr0IfBorderRightStyleNoneOrHidden",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-right-width"
  },
  	"border-spacing": {
  	syntax: "<length> <length>?",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Table"
  	],
  	initial: "0",
  	appliesto: "tableElements",
  	computed: "twoAbsoluteLengths",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-spacing"
  },
  	"border-start-end-radius": {
  	syntax: "<length-percentage>{1,2}",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "referToDimensionOfBorderBox",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "0",
  	appliesto: "allElementsUAsNotRequiredWhenCollapse",
  	computed: "twoAbsoluteLengthOrPercentages",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-start-end-radius"
  },
  	"border-start-start-radius": {
  	syntax: "<length-percentage>{1,2}",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "referToDimensionOfBorderBox",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "0",
  	appliesto: "allElementsUAsNotRequiredWhenCollapse",
  	computed: "twoAbsoluteLengthOrPercentages",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-start-start-radius"
  },
  	"border-style": {
  	syntax: "<line-style>{1,4}",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: [
  		"border-top-style",
  		"border-right-style",
  		"border-bottom-style",
  		"border-left-style"
  	],
  	appliesto: "allElements",
  	computed: [
  		"border-bottom-style",
  		"border-left-style",
  		"border-right-style",
  		"border-top-style"
  	],
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-style"
  },
  	"border-top": {
  	syntax: "<line-width> || <line-style> || <color>",
  	media: "visual",
  	inherited: false,
  	animationType: [
  		"border-top-color",
  		"border-top-style",
  		"border-top-width"
  	],
  	percentages: "no",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: [
  		"border-top-width",
  		"border-top-style",
  		"border-top-color"
  	],
  	appliesto: "allElements",
  	computed: [
  		"border-top-width",
  		"border-top-style",
  		"border-top-color"
  	],
  	order: "orderOfAppearance",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-top"
  },
  	"border-top-color": {
  	syntax: "<color>",
  	media: "visual",
  	inherited: false,
  	animationType: "color",
  	percentages: "no",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: "currentcolor",
  	appliesto: "allElements",
  	computed: "computedColor",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-top-color"
  },
  	"border-top-left-radius": {
  	syntax: "<length-percentage>{1,2}",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "referToDimensionOfBorderBox",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: "0",
  	appliesto: "allElementsUAsNotRequiredWhenCollapse",
  	computed: "twoAbsoluteLengthOrPercentages",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-top-left-radius"
  },
  	"border-top-right-radius": {
  	syntax: "<length-percentage>{1,2}",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "referToDimensionOfBorderBox",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: "0",
  	appliesto: "allElementsUAsNotRequiredWhenCollapse",
  	computed: "twoAbsoluteLengthOrPercentages",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-top-right-radius"
  },
  	"border-top-style": {
  	syntax: "<line-style>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-top-style"
  },
  	"border-top-width": {
  	syntax: "<line-width>",
  	media: "visual",
  	inherited: false,
  	animationType: "length",
  	percentages: "no",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: "medium",
  	appliesto: "allElements",
  	computed: "absoluteLengthOr0IfBorderTopStyleNoneOrHidden",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-top-width"
  },
  	"border-width": {
  	syntax: "<line-width>{1,4}",
  	media: "visual",
  	inherited: false,
  	animationType: [
  		"border-bottom-width",
  		"border-left-width",
  		"border-right-width",
  		"border-top-width"
  	],
  	percentages: "no",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: [
  		"border-top-width",
  		"border-right-width",
  		"border-bottom-width",
  		"border-left-width"
  	],
  	appliesto: "allElements",
  	computed: [
  		"border-bottom-width",
  		"border-left-width",
  		"border-right-width",
  		"border-top-width"
  	],
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/border-width"
  },
  	bottom: bottom$1,
  	"box-align": {
  	syntax: "start | center | end | baseline | stretch",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Mozilla Extensions",
  		"WebKit Extensions"
  	],
  	initial: "stretch",
  	appliesto: "elementsWithDisplayBoxOrInlineBox",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/box-align"
  },
  	"box-decoration-break": {
  	syntax: "slice | clone",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Fragmentation"
  	],
  	initial: "slice",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/box-decoration-break"
  },
  	"box-direction": {
  	syntax: "normal | reverse | inherit",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Mozilla Extensions",
  		"WebKit Extensions"
  	],
  	initial: "normal",
  	appliesto: "elementsWithDisplayBoxOrInlineBox",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/box-direction"
  },
  	"box-flex": {
  	syntax: "<number>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Mozilla Extensions",
  		"WebKit Extensions"
  	],
  	initial: "0",
  	appliesto: "directChildrenOfElementsWithDisplayMozBoxMozInlineBox",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/box-flex"
  },
  	"box-flex-group": {
  	syntax: "<integer>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Mozilla Extensions",
  		"WebKit Extensions"
  	],
  	initial: "1",
  	appliesto: "inFlowChildrenOfBoxElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/box-flex-group"
  },
  	"box-lines": {
  	syntax: "single | multiple",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Mozilla Extensions",
  		"WebKit Extensions"
  	],
  	initial: "single",
  	appliesto: "boxElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/box-lines"
  },
  	"box-ordinal-group": {
  	syntax: "<integer>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Mozilla Extensions",
  		"WebKit Extensions"
  	],
  	initial: "1",
  	appliesto: "childrenOfBoxElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/box-ordinal-group"
  },
  	"box-orient": {
  	syntax: "horizontal | vertical | inline-axis | block-axis | inherit",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Mozilla Extensions",
  		"WebKit Extensions"
  	],
  	initial: "inlineAxisHorizontalInXUL",
  	appliesto: "elementsWithDisplayBoxOrInlineBox",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/box-orient"
  },
  	"box-pack": {
  	syntax: "start | center | end | justify",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Mozilla Extensions",
  		"WebKit Extensions"
  	],
  	initial: "start",
  	appliesto: "elementsWithDisplayMozBoxMozInlineBox",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/box-pack"
  },
  	"box-shadow": {
  	syntax: "none | <shadow>#",
  	media: "visual",
  	inherited: false,
  	animationType: "shadowList",
  	percentages: "no",
  	groups: [
  		"CSS Backgrounds and Borders"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "absoluteLengthsSpecifiedColorAsSpecified",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/box-shadow"
  },
  	"box-sizing": {
  	syntax: "content-box | border-box",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Basic User Interface"
  	],
  	initial: "content-box",
  	appliesto: "allElementsAcceptingWidthOrHeight",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/box-sizing"
  },
  	"break-after": {
  	syntax: "auto | avoid | always | all | avoid-page | page | left | right | recto | verso | avoid-column | column | avoid-region | region",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Fragmentation"
  	],
  	initial: "auto",
  	appliesto: "blockLevelElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/break-after"
  },
  	"break-before": {
  	syntax: "auto | avoid | always | all | avoid-page | page | left | right | recto | verso | avoid-column | column | avoid-region | region",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Fragmentation"
  	],
  	initial: "auto",
  	appliesto: "blockLevelElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/break-before"
  },
  	"break-inside": {
  	syntax: "auto | avoid | avoid-page | avoid-column | avoid-region",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Fragmentation"
  	],
  	initial: "auto",
  	appliesto: "blockLevelElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/break-inside"
  },
  	"caption-side": {
  	syntax: "top | bottom | block-start | block-end | inline-start | inline-end",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Table"
  	],
  	initial: "top",
  	appliesto: "tableCaptionElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/caption-side"
  },
  	"caret-color": {
  	syntax: "auto | <color>",
  	media: "interactive",
  	inherited: true,
  	animationType: "color",
  	percentages: "no",
  	groups: [
  		"CSS Basic User Interface"
  	],
  	initial: "auto",
  	appliesto: "allElements",
  	computed: "asAutoOrColor",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/caret-color"
  },
  	clear: clear,
  	clip: clip,
  	"clip-path": {
  	syntax: "<clip-source> | [ <basic-shape> || <geometry-box> ] | none",
  	media: "visual",
  	inherited: false,
  	animationType: "basicShapeOtherwiseNo",
  	percentages: "referToReferenceBoxWhenSpecifiedOtherwiseBorderBox",
  	groups: [
  		"CSS Masking"
  	],
  	initial: "none",
  	appliesto: "allElementsSVGContainerElements",
  	computed: "asSpecifiedURLsAbsolute",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/clip-path"
  },
  	color: color$1,
  	"color-adjust": {
  	syntax: "economy | exact",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Color"
  	],
  	initial: "economy",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/color-adjust"
  },
  	"column-count": {
  	syntax: "<integer> | auto",
  	media: "visual",
  	inherited: false,
  	animationType: "integer",
  	percentages: "no",
  	groups: [
  		"CSS Columns"
  	],
  	initial: "auto",
  	appliesto: "blockContainersExceptTableWrappers",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/column-count"
  },
  	"column-fill": {
  	syntax: "auto | balance | balance-all",
  	media: "visualInContinuousMediaNoEffectInOverflowColumns",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Columns"
  	],
  	initial: "balance",
  	appliesto: "multicolElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/column-fill"
  },
  	"column-gap": {
  	syntax: "normal | <length-percentage>",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "referToDimensionOfContentArea",
  	groups: [
  		"CSS Box Alignment"
  	],
  	initial: "normal",
  	appliesto: "multiColumnElementsFlexContainersGridContainers",
  	computed: "asSpecifiedWithLengthsAbsoluteAndNormalComputingToZeroExceptMultiColumn",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/column-gap"
  },
  	"column-rule": {
  	syntax: "<'column-rule-width'> || <'column-rule-style'> || <'column-rule-color'>",
  	media: "visual",
  	inherited: false,
  	animationType: [
  		"column-rule-color",
  		"column-rule-style",
  		"column-rule-width"
  	],
  	percentages: "no",
  	groups: [
  		"CSS Columns"
  	],
  	initial: [
  		"column-rule-width",
  		"column-rule-style",
  		"column-rule-color"
  	],
  	appliesto: "multicolElements",
  	computed: [
  		"column-rule-color",
  		"column-rule-style",
  		"column-rule-width"
  	],
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/column-rule"
  },
  	"column-rule-color": {
  	syntax: "<color>",
  	media: "visual",
  	inherited: false,
  	animationType: "color",
  	percentages: "no",
  	groups: [
  		"CSS Columns"
  	],
  	initial: "currentcolor",
  	appliesto: "multicolElements",
  	computed: "computedColor",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/column-rule-color"
  },
  	"column-rule-style": {
  	syntax: "<'border-style'>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Columns"
  	],
  	initial: "none",
  	appliesto: "multicolElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/column-rule-style"
  },
  	"column-rule-width": {
  	syntax: "<'border-width'>",
  	media: "visual",
  	inherited: false,
  	animationType: "length",
  	percentages: "no",
  	groups: [
  		"CSS Columns"
  	],
  	initial: "medium",
  	appliesto: "multicolElements",
  	computed: "absoluteLength0IfColumnRuleStyleNoneOrHidden",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/column-rule-width"
  },
  	"column-span": {
  	syntax: "none | all",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Columns"
  	],
  	initial: "none",
  	appliesto: "inFlowBlockLevelElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/column-span"
  },
  	"column-width": {
  	syntax: "<length> | auto",
  	media: "visual",
  	inherited: false,
  	animationType: "length",
  	percentages: "no",
  	groups: [
  		"CSS Columns"
  	],
  	initial: "auto",
  	appliesto: "blockContainersExceptTableWrappers",
  	computed: "absoluteLengthZeroOrLarger",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/column-width"
  },
  	columns: columns,
  	contain: contain,
  	content: content,
  	"counter-increment": {
  	syntax: "[ <custom-ident> <integer>? ]+ | none",
  	media: "all",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Counter Styles"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/counter-increment"
  },
  	"counter-reset": {
  	syntax: "[ <custom-ident> <integer>? ]+ | none",
  	media: "all",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Counter Styles"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/counter-reset"
  },
  	"counter-set": {
  	syntax: "[ <custom-ident> <integer>? ]+ | none",
  	media: "all",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Counter Styles"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/counter-set"
  },
  	cursor: cursor,
  	direction: direction,
  	display: display,
  	"empty-cells": {
  	syntax: "show | hide",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Table"
  	],
  	initial: "show",
  	appliesto: "tableCellElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/empty-cells"
  },
  	filter: filter$1,
  	flex: flex,
  	"flex-basis": {
  	syntax: "content | <'width'>",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "referToFlexContainersInnerMainSize",
  	groups: [
  		"CSS Flexible Box Layout"
  	],
  	initial: "auto",
  	appliesto: "flexItemsAndInFlowPseudos",
  	computed: "asSpecifiedRelativeToAbsoluteLengths",
  	order: "lengthOrPercentageBeforeKeywordIfBothPresent",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/flex-basis"
  },
  	"flex-direction": {
  	syntax: "row | row-reverse | column | column-reverse",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Flexible Box Layout"
  	],
  	initial: "row",
  	appliesto: "flexContainers",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/flex-direction"
  },
  	"flex-flow": {
  	syntax: "<'flex-direction'> || <'flex-wrap'>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Flexible Box Layout"
  	],
  	initial: [
  		"flex-direction",
  		"flex-wrap"
  	],
  	appliesto: "flexContainers",
  	computed: [
  		"flex-direction",
  		"flex-wrap"
  	],
  	order: "orderOfAppearance",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/flex-flow"
  },
  	"flex-grow": {
  	syntax: "<number>",
  	media: "visual",
  	inherited: false,
  	animationType: "number",
  	percentages: "no",
  	groups: [
  		"CSS Flexible Box Layout"
  	],
  	initial: "0",
  	appliesto: "flexItemsAndInFlowPseudos",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/flex-grow"
  },
  	"flex-shrink": {
  	syntax: "<number>",
  	media: "visual",
  	inherited: false,
  	animationType: "number",
  	percentages: "no",
  	groups: [
  		"CSS Flexible Box Layout"
  	],
  	initial: "1",
  	appliesto: "flexItemsAndInFlowPseudos",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/flex-shrink"
  },
  	"flex-wrap": {
  	syntax: "nowrap | wrap | wrap-reverse",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Flexible Box Layout"
  	],
  	initial: "nowrap",
  	appliesto: "flexContainers",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/flex-wrap"
  },
  	float: float,
  	font: font,
  	"font-family": {
  	syntax: "[ <family-name> | <generic-family> ]#",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Fonts"
  	],
  	initial: "dependsOnUserAgent",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/font-family"
  },
  	"font-feature-settings": {
  	syntax: "normal | <feature-tag-value>#",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Fonts"
  	],
  	initial: "normal",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/font-feature-settings"
  },
  	"font-kerning": {
  	syntax: "auto | normal | none",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Fonts"
  	],
  	initial: "auto",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/font-kerning"
  },
  	"font-language-override": {
  	syntax: "normal | <string>",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Fonts"
  	],
  	initial: "normal",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/font-language-override"
  },
  	"font-optical-sizing": {
  	syntax: "auto | none",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Fonts"
  	],
  	initial: "auto",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/font-optical-sizing"
  },
  	"font-variation-settings": {
  	syntax: "normal | [ <string> <number> ]#",
  	media: "visual",
  	inherited: true,
  	animationType: "transform",
  	percentages: "no",
  	groups: [
  		"CSS Fonts"
  	],
  	initial: "normal",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/font-variation-settings"
  },
  	"font-size": {
  	syntax: "<absolute-size> | <relative-size> | <length-percentage>",
  	media: "visual",
  	inherited: true,
  	animationType: "length",
  	percentages: "referToParentElementsFontSize",
  	groups: [
  		"CSS Fonts"
  	],
  	initial: "medium",
  	appliesto: "allElements",
  	computed: "asSpecifiedRelativeToAbsoluteLengths",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/font-size"
  },
  	"font-size-adjust": {
  	syntax: "none | <number>",
  	media: "visual",
  	inherited: true,
  	animationType: "number",
  	percentages: "no",
  	groups: [
  		"CSS Fonts"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/font-size-adjust"
  },
  	"font-smooth": {
  	syntax: "auto | never | always | <absolute-size> | <length>",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Fonts"
  	],
  	initial: "auto",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/font-smooth"
  },
  	"font-stretch": {
  	syntax: "<font-stretch-absolute>",
  	media: "visual",
  	inherited: true,
  	animationType: "fontStretch",
  	percentages: "no",
  	groups: [
  		"CSS Fonts"
  	],
  	initial: "normal",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/font-stretch"
  },
  	"font-style": {
  	syntax: "normal | italic | oblique <angle>?",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Fonts"
  	],
  	initial: "normal",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/font-style"
  },
  	"font-synthesis": {
  	syntax: "none | [ weight || style ]",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Fonts"
  	],
  	initial: "weight style",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "orderOfAppearance",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/font-synthesis"
  },
  	"font-variant": {
  	syntax: "normal | none | [ <common-lig-values> || <discretionary-lig-values> || <historical-lig-values> || <contextual-alt-values> || stylistic( <feature-value-name> ) || historical-forms || styleset( <feature-value-name># ) || character-variant( <feature-value-name># ) || swash( <feature-value-name> ) || ornaments( <feature-value-name> ) || annotation( <feature-value-name> ) || [ small-caps | all-small-caps | petite-caps | all-petite-caps | unicase | titling-caps ] || <numeric-figure-values> || <numeric-spacing-values> || <numeric-fraction-values> || ordinal || slashed-zero || <east-asian-variant-values> || <east-asian-width-values> || ruby ]",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Fonts"
  	],
  	initial: "normal",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/font-variant"
  },
  	"font-variant-alternates": {
  	syntax: "normal | [ stylistic( <feature-value-name> ) || historical-forms || styleset( <feature-value-name># ) || character-variant( <feature-value-name># ) || swash( <feature-value-name> ) || ornaments( <feature-value-name> ) || annotation( <feature-value-name> ) ]",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Fonts"
  	],
  	initial: "normal",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "orderOfAppearance",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/font-variant-alternates"
  },
  	"font-variant-caps": {
  	syntax: "normal | small-caps | all-small-caps | petite-caps | all-petite-caps | unicase | titling-caps",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Fonts"
  	],
  	initial: "normal",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/font-variant-caps"
  },
  	"font-variant-east-asian": {
  	syntax: "normal | [ <east-asian-variant-values> || <east-asian-width-values> || ruby ]",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Fonts"
  	],
  	initial: "normal",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "orderOfAppearance",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/font-variant-east-asian"
  },
  	"font-variant-ligatures": {
  	syntax: "normal | none | [ <common-lig-values> || <discretionary-lig-values> || <historical-lig-values> || <contextual-alt-values> ]",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Fonts"
  	],
  	initial: "normal",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "orderOfAppearance",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/font-variant-ligatures"
  },
  	"font-variant-numeric": {
  	syntax: "normal | [ <numeric-figure-values> || <numeric-spacing-values> || <numeric-fraction-values> || ordinal || slashed-zero ]",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Fonts"
  	],
  	initial: "normal",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "orderOfAppearance",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/font-variant-numeric"
  },
  	"font-variant-position": {
  	syntax: "normal | sub | super",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Fonts"
  	],
  	initial: "normal",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/font-variant-position"
  },
  	"font-weight": {
  	syntax: "<font-weight-absolute> | bolder | lighter",
  	media: "visual",
  	inherited: true,
  	animationType: "fontWeight",
  	percentages: "no",
  	groups: [
  		"CSS Fonts"
  	],
  	initial: "normal",
  	appliesto: "allElements",
  	computed: "keywordOrNumericalValueBolderLighterTransformedToRealValue",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/font-weight"
  },
  	gap: gap$1,
  	grid: grid,
  	"grid-area": {
  	syntax: "<grid-line> [ / <grid-line> ]{0,3}",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Grid Layout"
  	],
  	initial: [
  		"grid-row-start",
  		"grid-column-start",
  		"grid-row-end",
  		"grid-column-end"
  	],
  	appliesto: "gridItemsAndBoxesWithinGridContainer",
  	computed: [
  		"grid-row-start",
  		"grid-column-start",
  		"grid-row-end",
  		"grid-column-end"
  	],
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/grid-area"
  },
  	"grid-auto-columns": {
  	syntax: "<track-size>+",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "referToDimensionOfContentArea",
  	groups: [
  		"CSS Grid Layout"
  	],
  	initial: "auto",
  	appliesto: "gridContainers",
  	computed: "percentageAsSpecifiedOrAbsoluteLength",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/grid-auto-columns"
  },
  	"grid-auto-flow": {
  	syntax: "[ row | column ] || dense",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Grid Layout"
  	],
  	initial: "row",
  	appliesto: "gridContainers",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/grid-auto-flow"
  },
  	"grid-auto-rows": {
  	syntax: "<track-size>+",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "referToDimensionOfContentArea",
  	groups: [
  		"CSS Grid Layout"
  	],
  	initial: "auto",
  	appliesto: "gridContainers",
  	computed: "percentageAsSpecifiedOrAbsoluteLength",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/grid-auto-rows"
  },
  	"grid-column": {
  	syntax: "<grid-line> [ / <grid-line> ]?",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Grid Layout"
  	],
  	initial: [
  		"grid-column-start",
  		"grid-column-end"
  	],
  	appliesto: "gridItemsAndBoxesWithinGridContainer",
  	computed: [
  		"grid-column-start",
  		"grid-column-end"
  	],
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/grid-column"
  },
  	"grid-column-end": {
  	syntax: "<grid-line>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Grid Layout"
  	],
  	initial: "auto",
  	appliesto: "gridItemsAndBoxesWithinGridContainer",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/grid-column-end"
  },
  	"grid-column-gap": {
  	syntax: "<length-percentage>",
  	media: "visual",
  	inherited: false,
  	animationType: "length",
  	percentages: "referToDimensionOfContentArea",
  	groups: [
  		"CSS Grid Layout"
  	],
  	initial: "0",
  	appliesto: "gridContainers",
  	computed: "percentageAsSpecifiedOrAbsoluteLength",
  	order: "uniqueOrder",
  	status: "obsolete",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/column-gap"
  },
  	"grid-column-start": {
  	syntax: "<grid-line>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Grid Layout"
  	],
  	initial: "auto",
  	appliesto: "gridItemsAndBoxesWithinGridContainer",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/grid-column-start"
  },
  	"grid-gap": {
  	syntax: "<'grid-row-gap'> <'grid-column-gap'>?",
  	media: "visual",
  	inherited: false,
  	animationType: [
  		"grid-row-gap",
  		"grid-column-gap"
  	],
  	percentages: "no",
  	groups: [
  		"CSS Grid Layout"
  	],
  	initial: [
  		"grid-row-gap",
  		"grid-column-gap"
  	],
  	appliesto: "gridContainers",
  	computed: [
  		"grid-row-gap",
  		"grid-column-gap"
  	],
  	order: "uniqueOrder",
  	status: "obsolete",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/gap"
  },
  	"grid-row": {
  	syntax: "<grid-line> [ / <grid-line> ]?",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Grid Layout"
  	],
  	initial: [
  		"grid-row-start",
  		"grid-row-end"
  	],
  	appliesto: "gridItemsAndBoxesWithinGridContainer",
  	computed: [
  		"grid-row-start",
  		"grid-row-end"
  	],
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/grid-row"
  },
  	"grid-row-end": {
  	syntax: "<grid-line>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Grid Layout"
  	],
  	initial: "auto",
  	appliesto: "gridItemsAndBoxesWithinGridContainer",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/grid-row-end"
  },
  	"grid-row-gap": {
  	syntax: "<length-percentage>",
  	media: "visual",
  	inherited: false,
  	animationType: "length",
  	percentages: "referToDimensionOfContentArea",
  	groups: [
  		"CSS Grid Layout"
  	],
  	initial: "0",
  	appliesto: "gridContainers",
  	computed: "percentageAsSpecifiedOrAbsoluteLength",
  	order: "uniqueOrder",
  	status: "obsolete",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/row-gap"
  },
  	"grid-row-start": {
  	syntax: "<grid-line>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Grid Layout"
  	],
  	initial: "auto",
  	appliesto: "gridItemsAndBoxesWithinGridContainer",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/grid-row-start"
  },
  	"grid-template": {
  	syntax: "none | [ <'grid-template-rows'> / <'grid-template-columns'> ] | [ <line-names>? <string> <track-size>? <line-names>? ]+ [ / <explicit-track-list> ]?",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: [
  		"grid-template-columns",
  		"grid-template-rows"
  	],
  	groups: [
  		"CSS Grid Layout"
  	],
  	initial: [
  		"grid-template-columns",
  		"grid-template-rows",
  		"grid-template-areas"
  	],
  	appliesto: "gridContainers",
  	computed: [
  		"grid-template-columns",
  		"grid-template-rows",
  		"grid-template-areas"
  	],
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/grid-template"
  },
  	"grid-template-areas": {
  	syntax: "none | <string>+",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Grid Layout"
  	],
  	initial: "none",
  	appliesto: "gridContainers",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/grid-template-areas"
  },
  	"grid-template-columns": {
  	syntax: "none | <track-list> | <auto-track-list> | subgrid <line-name-list>?",
  	media: "visual",
  	inherited: false,
  	animationType: "simpleListOfLpcDifferenceLpc",
  	percentages: "referToDimensionOfContentArea",
  	groups: [
  		"CSS Grid Layout"
  	],
  	initial: "none",
  	appliesto: "gridContainers",
  	computed: "asSpecifiedRelativeToAbsoluteLengths",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/grid-template-columns"
  },
  	"grid-template-rows": {
  	syntax: "none | <track-list> | <auto-track-list> | subgrid <line-name-list>?",
  	media: "visual",
  	inherited: false,
  	animationType: "simpleListOfLpcDifferenceLpc",
  	percentages: "referToDimensionOfContentArea",
  	groups: [
  		"CSS Grid Layout"
  	],
  	initial: "none",
  	appliesto: "gridContainers",
  	computed: "asSpecifiedRelativeToAbsoluteLengths",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/grid-template-rows"
  },
  	"hanging-punctuation": {
  	syntax: "none | [ first || [ force-end | allow-end ] || last ]",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Text"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/hanging-punctuation"
  },
  	height: height,
  	hyphens: hyphens,
  	"image-orientation": {
  	syntax: "from-image | <angle> | [ <angle>? flip ]",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Images"
  	],
  	initial: "from-image",
  	appliesto: "allElements",
  	computed: "angleRoundedToNextQuarter",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/image-orientation"
  },
  	"image-rendering": {
  	syntax: "auto | crisp-edges | pixelated",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Images"
  	],
  	initial: "auto",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/image-rendering"
  },
  	"image-resolution": {
  	syntax: "[ from-image || <resolution> ] && snap?",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Images"
  	],
  	initial: "1dppx",
  	appliesto: "allElements",
  	computed: "asSpecifiedWithExceptionOfResolution",
  	order: "uniqueOrder",
  	status: "experimental"
  },
  	"ime-mode": {
  	syntax: "auto | normal | active | inactive | disabled",
  	media: "interactive",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Basic User Interface"
  	],
  	initial: "auto",
  	appliesto: "textFields",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "obsolete",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/ime-mode"
  },
  	"initial-letter": {
  	syntax: "normal | [ <number> <integer>? ]",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Inline"
  	],
  	initial: "normal",
  	appliesto: "firstLetterPseudoElementsAndInlineLevelFirstChildren",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "experimental",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/initial-letter"
  },
  	"initial-letter-align": {
  	syntax: "[ auto | alphabetic | hanging | ideographic ]",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Inline"
  	],
  	initial: "auto",
  	appliesto: "firstLetterPseudoElementsAndInlineLevelFirstChildren",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "experimental",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/initial-letter-align"
  },
  	"inline-size": {
  	syntax: "<'width'>",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "inlineSizeOfContainingBlock",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "auto",
  	appliesto: "sameAsWidthAndHeight",
  	computed: "sameAsWidthAndHeight",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/inline-size"
  },
  	inset: inset,
  	"inset-block": {
  	syntax: "<'top'>{1,2}",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "logicalHeightOfContainingBlock",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "auto",
  	appliesto: "positionedElements",
  	computed: "sameAsBoxOffsets",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/inset-block"
  },
  	"inset-block-end": {
  	syntax: "<'top'>",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "logicalHeightOfContainingBlock",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "auto",
  	appliesto: "positionedElements",
  	computed: "sameAsBoxOffsets",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/inset-block-end"
  },
  	"inset-block-start": {
  	syntax: "<'top'>",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "logicalHeightOfContainingBlock",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "auto",
  	appliesto: "positionedElements",
  	computed: "sameAsBoxOffsets",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/inset-block-start"
  },
  	"inset-inline": {
  	syntax: "<'top'>{1,2}",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "logicalWidthOfContainingBlock",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "auto",
  	appliesto: "positionedElements",
  	computed: "sameAsBoxOffsets",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/inset-inline"
  },
  	"inset-inline-end": {
  	syntax: "<'top'>",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "logicalWidthOfContainingBlock",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "auto",
  	appliesto: "positionedElements",
  	computed: "sameAsBoxOffsets",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/inset-inline-end"
  },
  	"inset-inline-start": {
  	syntax: "<'top'>",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "logicalWidthOfContainingBlock",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "auto",
  	appliesto: "positionedElements",
  	computed: "sameAsBoxOffsets",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/inset-inline-start"
  },
  	isolation: isolation,
  	"justify-content": {
  	syntax: "normal | <content-distribution> | <overflow-position>? [ <content-position> | left | right ]",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Box Alignment"
  	],
  	initial: "normal",
  	appliesto: "flexContainers",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/justify-content"
  },
  	"justify-items": {
  	syntax: "normal | stretch | <baseline-position> | <overflow-position>? [ <self-position> | left | right ] | legacy | legacy && [ left | right | center ]",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Box Alignment"
  	],
  	initial: "legacy",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/justify-items"
  },
  	"justify-self": {
  	syntax: "auto | normal | stretch | <baseline-position> | <overflow-position>? [ <self-position> | left | right ]",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Box Alignment"
  	],
  	initial: "auto",
  	appliesto: "blockLevelBoxesAndAbsolutelyPositionedBoxesAndGridItems",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/justify-self"
  },
  	"justify-tracks": {
  	syntax: "[ normal | <content-distribution> | <overflow-position>? [ <content-position> | left | right ] ]#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Grid Layout"
  	],
  	initial: "normal",
  	appliesto: "gridContainersWithMasonryLayoutInTheirInlineAxis",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "experimental",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/justify-tracks"
  },
  	left: left,
  	"letter-spacing": {
  	syntax: "normal | <length>",
  	media: "visual",
  	inherited: true,
  	animationType: "length",
  	percentages: "no",
  	groups: [
  		"CSS Text"
  	],
  	initial: "normal",
  	appliesto: "allElements",
  	computed: "optimumValueOfAbsoluteLengthOrNormal",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/letter-spacing"
  },
  	"line-break": {
  	syntax: "auto | loose | normal | strict | anywhere",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Text"
  	],
  	initial: "auto",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/line-break"
  },
  	"line-clamp": {
  	syntax: "none | <integer>",
  	media: "visual",
  	inherited: false,
  	animationType: "integer",
  	percentages: "no",
  	groups: [
  		"CSS Overflow"
  	],
  	initial: "none",
  	appliesto: "blockContainersExceptMultiColumnContainers",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "experimental"
  },
  	"line-height": {
  	syntax: "normal | <number> | <length> | <percentage>",
  	media: "visual",
  	inherited: true,
  	animationType: "numberOrLength",
  	percentages: "referToElementFontSize",
  	groups: [
  		"CSS Fonts"
  	],
  	initial: "normal",
  	appliesto: "allElements",
  	computed: "absoluteLengthOrAsSpecified",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/line-height"
  },
  	"line-height-step": {
  	syntax: "<length>",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Fonts"
  	],
  	initial: "0",
  	appliesto: "blockContainers",
  	computed: "absoluteLength",
  	order: "perGrammar",
  	status: "experimental",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/line-height-step"
  },
  	"list-style": {
  	syntax: "<'list-style-type'> || <'list-style-position'> || <'list-style-image'>",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Lists and Counters"
  	],
  	initial: [
  		"list-style-type",
  		"list-style-position",
  		"list-style-image"
  	],
  	appliesto: "listItems",
  	computed: [
  		"list-style-image",
  		"list-style-position",
  		"list-style-type"
  	],
  	order: "orderOfAppearance",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/list-style"
  },
  	"list-style-image": {
  	syntax: "<url> | none",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Lists and Counters"
  	],
  	initial: "none",
  	appliesto: "listItems",
  	computed: "noneOrImageWithAbsoluteURI",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/list-style-image"
  },
  	"list-style-position": {
  	syntax: "inside | outside",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Lists and Counters"
  	],
  	initial: "outside",
  	appliesto: "listItems",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/list-style-position"
  },
  	"list-style-type": {
  	syntax: "<counter-style> | <string> | none",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Lists and Counters"
  	],
  	initial: "disc",
  	appliesto: "listItems",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/list-style-type"
  },
  	margin: margin,
  	"margin-block": {
  	syntax: "<'margin-left'>{1,2}",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "dependsOnLayoutModel",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "0",
  	appliesto: "sameAsMargin",
  	computed: "lengthAbsolutePercentageAsSpecifiedOtherwiseAuto",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/margin-block"
  },
  	"margin-block-end": {
  	syntax: "<'margin-left'>",
  	media: "visual",
  	inherited: false,
  	animationType: "length",
  	percentages: "dependsOnLayoutModel",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "0",
  	appliesto: "sameAsMargin",
  	computed: "lengthAbsolutePercentageAsSpecifiedOtherwiseAuto",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/margin-block-end"
  },
  	"margin-block-start": {
  	syntax: "<'margin-left'>",
  	media: "visual",
  	inherited: false,
  	animationType: "length",
  	percentages: "dependsOnLayoutModel",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "0",
  	appliesto: "sameAsMargin",
  	computed: "lengthAbsolutePercentageAsSpecifiedOtherwiseAuto",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/margin-block-start"
  },
  	"margin-bottom": {
  	syntax: "<length> | <percentage> | auto",
  	media: "visual",
  	inherited: false,
  	animationType: "length",
  	percentages: "referToWidthOfContainingBlock",
  	groups: [
  		"CSS Box Model"
  	],
  	initial: "0",
  	appliesto: "allElementsExceptTableDisplayTypes",
  	computed: "percentageAsSpecifiedOrAbsoluteLength",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/margin-bottom"
  },
  	"margin-inline": {
  	syntax: "<'margin-left'>{1,2}",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "dependsOnLayoutModel",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "0",
  	appliesto: "sameAsMargin",
  	computed: "lengthAbsolutePercentageAsSpecifiedOtherwiseAuto",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/margin-inline"
  },
  	"margin-inline-end": {
  	syntax: "<'margin-left'>",
  	media: "visual",
  	inherited: false,
  	animationType: "length",
  	percentages: "dependsOnLayoutModel",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "0",
  	appliesto: "sameAsMargin",
  	computed: "lengthAbsolutePercentageAsSpecifiedOtherwiseAuto",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/margin-inline-end"
  },
  	"margin-inline-start": {
  	syntax: "<'margin-left'>",
  	media: "visual",
  	inherited: false,
  	animationType: "length",
  	percentages: "dependsOnLayoutModel",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "0",
  	appliesto: "sameAsMargin",
  	computed: "lengthAbsolutePercentageAsSpecifiedOtherwiseAuto",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/margin-inline-start"
  },
  	"margin-left": {
  	syntax: "<length> | <percentage> | auto",
  	media: "visual",
  	inherited: false,
  	animationType: "length",
  	percentages: "referToWidthOfContainingBlock",
  	groups: [
  		"CSS Box Model"
  	],
  	initial: "0",
  	appliesto: "allElementsExceptTableDisplayTypes",
  	computed: "percentageAsSpecifiedOrAbsoluteLength",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/margin-left"
  },
  	"margin-right": {
  	syntax: "<length> | <percentage> | auto",
  	media: "visual",
  	inherited: false,
  	animationType: "length",
  	percentages: "referToWidthOfContainingBlock",
  	groups: [
  		"CSS Box Model"
  	],
  	initial: "0",
  	appliesto: "allElementsExceptTableDisplayTypes",
  	computed: "percentageAsSpecifiedOrAbsoluteLength",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/margin-right"
  },
  	"margin-top": {
  	syntax: "<length> | <percentage> | auto",
  	media: "visual",
  	inherited: false,
  	animationType: "length",
  	percentages: "referToWidthOfContainingBlock",
  	groups: [
  		"CSS Box Model"
  	],
  	initial: "0",
  	appliesto: "allElementsExceptTableDisplayTypes",
  	computed: "percentageAsSpecifiedOrAbsoluteLength",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/margin-top"
  },
  	"margin-trim": {
  	syntax: "none | in-flow | all",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Box Model"
  	],
  	initial: "none",
  	appliesto: "blockContainersAndMultiColumnContainers",
  	computed: "asSpecified",
  	order: "perGrammar",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line"
  	],
  	status: "experimental",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/margin-trim"
  },
  	mask: mask,
  	"mask-border": {
  	syntax: "<'mask-border-source'> || <'mask-border-slice'> [ / <'mask-border-width'>? [ / <'mask-border-outset'> ]? ]? || <'mask-border-repeat'> || <'mask-border-mode'>",
  	media: "visual",
  	inherited: false,
  	animationType: [
  		"mask-border-mode",
  		"mask-border-outset",
  		"mask-border-repeat",
  		"mask-border-slice",
  		"mask-border-source",
  		"mask-border-width"
  	],
  	percentages: [
  		"mask-border-slice",
  		"mask-border-width"
  	],
  	groups: [
  		"CSS Masking"
  	],
  	initial: [
  		"mask-border-mode",
  		"mask-border-outset",
  		"mask-border-repeat",
  		"mask-border-slice",
  		"mask-border-source",
  		"mask-border-width"
  	],
  	appliesto: "allElementsSVGContainerElements",
  	computed: [
  		"mask-border-mode",
  		"mask-border-outset",
  		"mask-border-repeat",
  		"mask-border-slice",
  		"mask-border-source",
  		"mask-border-width"
  	],
  	order: "perGrammar",
  	stacking: true,
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/mask-border"
  },
  	"mask-border-mode": {
  	syntax: "luminance | alpha",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Masking"
  	],
  	initial: "alpha",
  	appliesto: "allElementsSVGContainerElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/mask-border-mode"
  },
  	"mask-border-outset": {
  	syntax: "[ <length> | <number> ]{1,4}",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Masking"
  	],
  	initial: "0",
  	appliesto: "allElementsSVGContainerElements",
  	computed: "asSpecifiedRelativeToAbsoluteLengths",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/mask-border-outset"
  },
  	"mask-border-repeat": {
  	syntax: "[ stretch | repeat | round | space ]{1,2}",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Masking"
  	],
  	initial: "stretch",
  	appliesto: "allElementsSVGContainerElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/mask-border-repeat"
  },
  	"mask-border-slice": {
  	syntax: "<number-percentage>{1,4} fill?",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "referToSizeOfMaskBorderImage",
  	groups: [
  		"CSS Masking"
  	],
  	initial: "0",
  	appliesto: "allElementsSVGContainerElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/mask-border-slice"
  },
  	"mask-border-source": {
  	syntax: "none | <image>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Masking"
  	],
  	initial: "none",
  	appliesto: "allElementsSVGContainerElements",
  	computed: "asSpecifiedURLsAbsolute",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/mask-border-source"
  },
  	"mask-border-width": {
  	syntax: "[ <length-percentage> | <number> | auto ]{1,4}",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "relativeToMaskBorderImageArea",
  	groups: [
  		"CSS Masking"
  	],
  	initial: "auto",
  	appliesto: "allElementsSVGContainerElements",
  	computed: "asSpecifiedRelativeToAbsoluteLengths",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/mask-border-width"
  },
  	"mask-clip": {
  	syntax: "[ <geometry-box> | no-clip ]#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Masking"
  	],
  	initial: "border-box",
  	appliesto: "allElementsSVGContainerElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/mask-clip"
  },
  	"mask-composite": {
  	syntax: "<compositing-operator>#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Masking"
  	],
  	initial: "add",
  	appliesto: "allElementsSVGContainerElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/mask-composite"
  },
  	"mask-image": {
  	syntax: "<mask-reference>#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Masking"
  	],
  	initial: "none",
  	appliesto: "allElementsSVGContainerElements",
  	computed: "asSpecifiedURLsAbsolute",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/mask-image"
  },
  	"mask-mode": {
  	syntax: "<masking-mode>#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Masking"
  	],
  	initial: "match-source",
  	appliesto: "allElementsSVGContainerElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/mask-mode"
  },
  	"mask-origin": {
  	syntax: "<geometry-box>#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Masking"
  	],
  	initial: "border-box",
  	appliesto: "allElementsSVGContainerElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/mask-origin"
  },
  	"mask-position": {
  	syntax: "<position>#",
  	media: "visual",
  	inherited: false,
  	animationType: "repeatableListOfSimpleListOfLpc",
  	percentages: "referToSizeOfMaskPaintingArea",
  	groups: [
  		"CSS Masking"
  	],
  	initial: "center",
  	appliesto: "allElementsSVGContainerElements",
  	computed: "consistsOfTwoKeywordsForOriginAndOffsets",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/mask-position"
  },
  	"mask-repeat": {
  	syntax: "<repeat-style>#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Masking"
  	],
  	initial: "no-repeat",
  	appliesto: "allElementsSVGContainerElements",
  	computed: "consistsOfTwoDimensionKeywords",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/mask-repeat"
  },
  	"mask-size": {
  	syntax: "<bg-size>#",
  	media: "visual",
  	inherited: false,
  	animationType: "repeatableListOfSimpleListOfLpc",
  	percentages: "no",
  	groups: [
  		"CSS Masking"
  	],
  	initial: "auto",
  	appliesto: "allElementsSVGContainerElements",
  	computed: "asSpecifiedRelativeToAbsoluteLengths",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/mask-size"
  },
  	"mask-type": {
  	syntax: "luminance | alpha",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Masking"
  	],
  	initial: "luminance",
  	appliesto: "maskElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/mask-type"
  },
  	"masonry-auto-flow": {
  	syntax: "[ pack | next ] || [ definite-first | ordered ]",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Grid Layout"
  	],
  	initial: "pack",
  	appliesto: "gridContainersWithMasonryLayout",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "experimental",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/masonry-auto-flow"
  },
  	"math-style": {
  	syntax: "normal | compact",
  	media: "visual",
  	inherited: true,
  	animationType: "notAnimatable",
  	percentages: "no",
  	groups: [
  		"MathML"
  	],
  	initial: "normal",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/math-style"
  },
  	"max-block-size": {
  	syntax: "<'max-width'>",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "blockSizeOfContainingBlock",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "0",
  	appliesto: "sameAsWidthAndHeight",
  	computed: "sameAsMaxWidthAndMaxHeight",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/max-block-size"
  },
  	"max-height": {
  	syntax: "none | <length-percentage> | min-content | max-content | fit-content(<length-percentage>)",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "regardingHeightOfGeneratedBoxContainingBlockPercentagesNone",
  	groups: [
  		"CSS Box Model"
  	],
  	initial: "none",
  	appliesto: "allElementsButNonReplacedAndTableColumns",
  	computed: "percentageAsSpecifiedAbsoluteLengthOrNone",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/max-height"
  },
  	"max-inline-size": {
  	syntax: "<'max-width'>",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "inlineSizeOfContainingBlock",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "0",
  	appliesto: "sameAsWidthAndHeight",
  	computed: "sameAsMaxWidthAndMaxHeight",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/max-inline-size"
  },
  	"max-lines": {
  	syntax: "none | <integer>",
  	media: "visual",
  	inherited: false,
  	animationType: "integer",
  	percentages: "no",
  	groups: [
  		"CSS Overflow"
  	],
  	initial: "none",
  	appliesto: "blockContainersExceptMultiColumnContainers",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "experimental"
  },
  	"max-width": {
  	syntax: "none | <length-percentage> | min-content | max-content | fit-content(<length-percentage>)",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "referToWidthOfContainingBlock",
  	groups: [
  		"CSS Box Model"
  	],
  	initial: "none",
  	appliesto: "allElementsButNonReplacedAndTableRows",
  	computed: "percentageAsSpecifiedAbsoluteLengthOrNone",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/max-width"
  },
  	"min-block-size": {
  	syntax: "<'min-width'>",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "blockSizeOfContainingBlock",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "0",
  	appliesto: "sameAsWidthAndHeight",
  	computed: "sameAsMinWidthAndMinHeight",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/min-block-size"
  },
  	"min-height": {
  	syntax: "auto | <length> | <percentage> | min-content | max-content | fit-content(<length-percentage>)",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "regardingHeightOfGeneratedBoxContainingBlockPercentages0",
  	groups: [
  		"CSS Box Model"
  	],
  	initial: "auto",
  	appliesto: "allElementsButNonReplacedAndTableColumns",
  	computed: "percentageAsSpecifiedOrAbsoluteLength",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/min-height"
  },
  	"min-inline-size": {
  	syntax: "<'min-width'>",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "inlineSizeOfContainingBlock",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "0",
  	appliesto: "sameAsWidthAndHeight",
  	computed: "sameAsMinWidthAndMinHeight",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/min-inline-size"
  },
  	"min-width": {
  	syntax: "auto | <length> | <percentage> | min-content | max-content | fit-content(<length-percentage>)",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "referToWidthOfContainingBlock",
  	groups: [
  		"CSS Box Model"
  	],
  	initial: "auto",
  	appliesto: "allElementsButNonReplacedAndTableRows",
  	computed: "percentageAsSpecifiedOrAbsoluteLength",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/min-width"
  },
  	"mix-blend-mode": {
  	syntax: "<blend-mode>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Compositing and Blending"
  	],
  	initial: "normal",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	stacking: true,
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/mix-blend-mode"
  },
  	"object-fit": {
  	syntax: "fill | contain | cover | none | scale-down",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Images"
  	],
  	initial: "fill",
  	appliesto: "replacedElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/object-fit"
  },
  	"object-position": {
  	syntax: "<position>",
  	media: "visual",
  	inherited: true,
  	animationType: "repeatableListOfSimpleListOfLpc",
  	percentages: "referToWidthAndHeightOfElement",
  	groups: [
  		"CSS Images"
  	],
  	initial: "50% 50%",
  	appliesto: "replacedElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/object-position"
  },
  	offset: offset,
  	"offset-anchor": {
  	syntax: "auto | <position>",
  	media: "visual",
  	inherited: false,
  	animationType: "position",
  	percentages: "relativeToWidthAndHeight",
  	groups: [
  		"CSS Motion Path"
  	],
  	initial: "auto",
  	appliesto: "transformableElements",
  	computed: "forLengthAbsoluteValueOtherwisePercentage",
  	order: "perGrammar",
  	status: "standard"
  },
  	"offset-distance": {
  	syntax: "<length-percentage>",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "referToTotalPathLength",
  	groups: [
  		"CSS Motion Path"
  	],
  	initial: "0",
  	appliesto: "transformableElements",
  	computed: "forLengthAbsoluteValueOtherwisePercentage",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/offset-distance"
  },
  	"offset-path": {
  	syntax: "none | ray( [ <angle> && <size> && contain? ] ) | <path()> | <url> | [ <basic-shape> || <geometry-box> ]",
  	media: "visual",
  	inherited: false,
  	animationType: "angleOrBasicShapeOrPath",
  	percentages: "no",
  	groups: [
  		"CSS Motion Path"
  	],
  	initial: "none",
  	appliesto: "transformableElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	stacking: true,
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/offset-path"
  },
  	"offset-position": {
  	syntax: "auto | <position>",
  	media: "visual",
  	inherited: false,
  	animationType: "position",
  	percentages: "referToSizeOfContainingBlock",
  	groups: [
  		"CSS Motion Path"
  	],
  	initial: "auto",
  	appliesto: "transformableElements",
  	computed: "forLengthAbsoluteValueOtherwisePercentage",
  	order: "perGrammar",
  	status: "experimental"
  },
  	"offset-rotate": {
  	syntax: "[ auto | reverse ] || <angle>",
  	media: "visual",
  	inherited: false,
  	animationType: "angleOrBasicShapeOrPath",
  	percentages: "no",
  	groups: [
  		"CSS Motion Path"
  	],
  	initial: "auto",
  	appliesto: "transformableElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/offset-rotate"
  },
  	opacity: opacity,
  	order: order$1,
  	orphans: orphans,
  	outline: outline,
  	"outline-color": {
  	syntax: "<color> | invert",
  	media: [
  		"visual",
  		"interactive"
  	],
  	inherited: false,
  	animationType: "color",
  	percentages: "no",
  	groups: [
  		"CSS Basic User Interface"
  	],
  	initial: "invertOrCurrentColor",
  	appliesto: "allElements",
  	computed: "invertForTranslucentColorRGBAOtherwiseRGB",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/outline-color"
  },
  	"outline-offset": {
  	syntax: "<length>",
  	media: [
  		"visual",
  		"interactive"
  	],
  	inherited: false,
  	animationType: "length",
  	percentages: "no",
  	groups: [
  		"CSS Basic User Interface"
  	],
  	initial: "0",
  	appliesto: "allElements",
  	computed: "asSpecifiedRelativeToAbsoluteLengths",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/outline-offset"
  },
  	"outline-style": {
  	syntax: "auto | <'border-style'>",
  	media: [
  		"visual",
  		"interactive"
  	],
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Basic User Interface"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/outline-style"
  },
  	"outline-width": {
  	syntax: "<line-width>",
  	media: [
  		"visual",
  		"interactive"
  	],
  	inherited: false,
  	animationType: "length",
  	percentages: "no",
  	groups: [
  		"CSS Basic User Interface"
  	],
  	initial: "medium",
  	appliesto: "allElements",
  	computed: "absoluteLength0ForNone",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/outline-width"
  },
  	overflow: overflow,
  	"overflow-anchor": {
  	syntax: "auto | none",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Scroll Anchoring"
  	],
  	initial: "auto",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard"
  },
  	"overflow-block": {
  	syntax: "visible | hidden | clip | scroll | auto",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Overflow"
  	],
  	initial: "auto",
  	appliesto: "blockContainersFlexContainersGridContainers",
  	computed: "asSpecifiedButVisibleOrClipReplacedToAutoOrHiddenIfOtherValueDifferent",
  	order: "perGrammar",
  	status: "standard"
  },
  	"overflow-clip-box": {
  	syntax: "padding-box | content-box",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Mozilla Extensions"
  	],
  	initial: "padding-box",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Mozilla/CSS/overflow-clip-box"
  },
  	"overflow-inline": {
  	syntax: "visible | hidden | clip | scroll | auto",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Overflow"
  	],
  	initial: "auto",
  	appliesto: "blockContainersFlexContainersGridContainers",
  	computed: "asSpecifiedButVisibleOrClipReplacedToAutoOrHiddenIfOtherValueDifferent",
  	order: "perGrammar",
  	status: "standard"
  },
  	"overflow-wrap": {
  	syntax: "normal | break-word | anywhere",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Text"
  	],
  	initial: "normal",
  	appliesto: "nonReplacedInlineElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/overflow-wrap"
  },
  	"overflow-x": {
  	syntax: "visible | hidden | clip | scroll | auto",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Overflow"
  	],
  	initial: "visible",
  	appliesto: "blockContainersFlexContainersGridContainers",
  	computed: "asSpecifiedButVisibleOrClipReplacedToAutoOrHiddenIfOtherValueDifferent",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/overflow-x"
  },
  	"overflow-y": {
  	syntax: "visible | hidden | clip | scroll | auto",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Overflow"
  	],
  	initial: "visible",
  	appliesto: "blockContainersFlexContainersGridContainers",
  	computed: "asSpecifiedButVisibleOrClipReplacedToAutoOrHiddenIfOtherValueDifferent",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/overflow-y"
  },
  	"overscroll-behavior": {
  	syntax: "[ contain | none | auto ]{1,2}",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Box Model"
  	],
  	initial: "auto",
  	appliesto: "nonReplacedBlockAndInlineBlockElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/overscroll-behavior"
  },
  	"overscroll-behavior-block": {
  	syntax: "contain | none | auto",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Box Model"
  	],
  	initial: "auto",
  	appliesto: "nonReplacedBlockAndInlineBlockElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/overscroll-behavior-block"
  },
  	"overscroll-behavior-inline": {
  	syntax: "contain | none | auto",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Box Model"
  	],
  	initial: "auto",
  	appliesto: "nonReplacedBlockAndInlineBlockElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/overscroll-behavior-inline"
  },
  	"overscroll-behavior-x": {
  	syntax: "contain | none | auto",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Box Model"
  	],
  	initial: "auto",
  	appliesto: "nonReplacedBlockAndInlineBlockElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/overscroll-behavior-x"
  },
  	"overscroll-behavior-y": {
  	syntax: "contain | none | auto",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Box Model"
  	],
  	initial: "auto",
  	appliesto: "nonReplacedBlockAndInlineBlockElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/overscroll-behavior-y"
  },
  	padding: padding,
  	"padding-block": {
  	syntax: "<'padding-left'>{1,2}",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "logicalWidthOfContainingBlock",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "0",
  	appliesto: "allElements",
  	computed: "asLength",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/padding-block"
  },
  	"padding-block-end": {
  	syntax: "<'padding-left'>",
  	media: "visual",
  	inherited: false,
  	animationType: "length",
  	percentages: "logicalWidthOfContainingBlock",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "0",
  	appliesto: "allElements",
  	computed: "asLength",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/padding-block-end"
  },
  	"padding-block-start": {
  	syntax: "<'padding-left'>",
  	media: "visual",
  	inherited: false,
  	animationType: "length",
  	percentages: "logicalWidthOfContainingBlock",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "0",
  	appliesto: "allElements",
  	computed: "asLength",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/padding-block-start"
  },
  	"padding-bottom": {
  	syntax: "<length> | <percentage>",
  	media: "visual",
  	inherited: false,
  	animationType: "length",
  	percentages: "referToWidthOfContainingBlock",
  	groups: [
  		"CSS Box Model"
  	],
  	initial: "0",
  	appliesto: "allElementsExceptInternalTableDisplayTypes",
  	computed: "percentageAsSpecifiedOrAbsoluteLength",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/padding-bottom"
  },
  	"padding-inline": {
  	syntax: "<'padding-left'>{1,2}",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "logicalWidthOfContainingBlock",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "0",
  	appliesto: "allElements",
  	computed: "asLength",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/padding-inline"
  },
  	"padding-inline-end": {
  	syntax: "<'padding-left'>",
  	media: "visual",
  	inherited: false,
  	animationType: "length",
  	percentages: "logicalWidthOfContainingBlock",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "0",
  	appliesto: "allElements",
  	computed: "asLength",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/padding-inline-end"
  },
  	"padding-inline-start": {
  	syntax: "<'padding-left'>",
  	media: "visual",
  	inherited: false,
  	animationType: "length",
  	percentages: "logicalWidthOfContainingBlock",
  	groups: [
  		"CSS Logical Properties"
  	],
  	initial: "0",
  	appliesto: "allElements",
  	computed: "asLength",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/padding-inline-start"
  },
  	"padding-left": {
  	syntax: "<length> | <percentage>",
  	media: "visual",
  	inherited: false,
  	animationType: "length",
  	percentages: "referToWidthOfContainingBlock",
  	groups: [
  		"CSS Box Model"
  	],
  	initial: "0",
  	appliesto: "allElementsExceptInternalTableDisplayTypes",
  	computed: "percentageAsSpecifiedOrAbsoluteLength",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/padding-left"
  },
  	"padding-right": {
  	syntax: "<length> | <percentage>",
  	media: "visual",
  	inherited: false,
  	animationType: "length",
  	percentages: "referToWidthOfContainingBlock",
  	groups: [
  		"CSS Box Model"
  	],
  	initial: "0",
  	appliesto: "allElementsExceptInternalTableDisplayTypes",
  	computed: "percentageAsSpecifiedOrAbsoluteLength",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/padding-right"
  },
  	"padding-top": {
  	syntax: "<length> | <percentage>",
  	media: "visual",
  	inherited: false,
  	animationType: "length",
  	percentages: "referToWidthOfContainingBlock",
  	groups: [
  		"CSS Box Model"
  	],
  	initial: "0",
  	appliesto: "allElementsExceptInternalTableDisplayTypes",
  	computed: "percentageAsSpecifiedOrAbsoluteLength",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/padding-top"
  },
  	"page-break-after": {
  	syntax: "auto | always | avoid | left | right | recto | verso",
  	media: [
  		"visual",
  		"paged"
  	],
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Pages"
  	],
  	initial: "auto",
  	appliesto: "blockElementsInNormalFlow",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/page-break-after"
  },
  	"page-break-before": {
  	syntax: "auto | always | avoid | left | right | recto | verso",
  	media: [
  		"visual",
  		"paged"
  	],
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Pages"
  	],
  	initial: "auto",
  	appliesto: "blockElementsInNormalFlow",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/page-break-before"
  },
  	"page-break-inside": {
  	syntax: "auto | avoid",
  	media: [
  		"visual",
  		"paged"
  	],
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Pages"
  	],
  	initial: "auto",
  	appliesto: "blockElementsInNormalFlow",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/page-break-inside"
  },
  	"paint-order": {
  	syntax: "normal | [ fill || stroke || markers ]",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Text"
  	],
  	initial: "normal",
  	appliesto: "textElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/paint-order"
  },
  	perspective: perspective,
  	"perspective-origin": {
  	syntax: "<position>",
  	media: "visual",
  	inherited: false,
  	animationType: "simpleListOfLpc",
  	percentages: "referToSizeOfBoundingBox",
  	groups: [
  		"CSS Transforms"
  	],
  	initial: "50% 50%",
  	appliesto: "transformableElements",
  	computed: "forLengthAbsoluteValueOtherwisePercentage",
  	order: "oneOrTwoValuesLengthAbsoluteKeywordsPercentages",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/perspective-origin"
  },
  	"place-content": {
  	syntax: "<'align-content'> <'justify-content'>?",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Box Alignment"
  	],
  	initial: "normal",
  	appliesto: "multilineFlexContainers",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/place-content"
  },
  	"place-items": {
  	syntax: "<'align-items'> <'justify-items'>?",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Box Alignment"
  	],
  	initial: [
  		"align-items",
  		"justify-items"
  	],
  	appliesto: "allElements",
  	computed: [
  		"align-items",
  		"justify-items"
  	],
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/place-items"
  },
  	"place-self": {
  	syntax: "<'align-self'> <'justify-self'>?",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Box Alignment"
  	],
  	initial: [
  		"align-self",
  		"justify-self"
  	],
  	appliesto: "blockLevelBoxesAndAbsolutelyPositionedBoxesAndGridItems",
  	computed: [
  		"align-self",
  		"justify-self"
  	],
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/place-self"
  },
  	"pointer-events": {
  	syntax: "auto | none | visiblePainted | visibleFill | visibleStroke | visible | painted | fill | stroke | all | inherit",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Pointer Events"
  	],
  	initial: "auto",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/pointer-events"
  },
  	position: position$1,
  	quotes: quotes$1,
  	resize: resize,
  	right: right,
  	rotate: rotate,
  	"row-gap": {
  	syntax: "normal | <length-percentage>",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "referToDimensionOfContentArea",
  	groups: [
  		"CSS Box Alignment"
  	],
  	initial: "normal",
  	appliesto: "multiColumnElementsFlexContainersGridContainers",
  	computed: "asSpecifiedWithLengthsAbsoluteAndNormalComputingToZeroExceptMultiColumn",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/row-gap"
  },
  	"ruby-align": {
  	syntax: "start | center | space-between | space-around",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Ruby"
  	],
  	initial: "space-around",
  	appliesto: "rubyBasesAnnotationsBaseAnnotationContainers",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "experimental",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/ruby-align"
  },
  	"ruby-merge": {
  	syntax: "separate | collapse | auto",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Ruby"
  	],
  	initial: "separate",
  	appliesto: "rubyAnnotationsContainers",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "experimental"
  },
  	"ruby-position": {
  	syntax: "over | under | inter-character",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Ruby"
  	],
  	initial: "over",
  	appliesto: "rubyAnnotationsContainers",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "experimental",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/ruby-position"
  },
  	scale: scale,
  	"scrollbar-color": {
  	syntax: "auto | dark | light | <color>{2}",
  	media: "visual",
  	inherited: true,
  	animationType: "color",
  	percentages: "no",
  	groups: [
  		"CSS Scrollbars"
  	],
  	initial: "auto",
  	appliesto: "scrollingBoxes",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scrollbar-color"
  },
  	"scrollbar-gutter": {
  	syntax: "auto | [ stable | always ] && both? && force?",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Overflow"
  	],
  	initial: "auto",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scrollbar-gutter"
  },
  	"scrollbar-width": {
  	syntax: "auto | thin | none",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Scrollbars"
  	],
  	initial: "auto",
  	appliesto: "scrollingBoxes",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scrollbar-width"
  },
  	"scroll-behavior": {
  	syntax: "auto | smooth",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSSOM View"
  	],
  	initial: "auto",
  	appliesto: "scrollingBoxes",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scroll-behavior"
  },
  	"scroll-margin": {
  	syntax: "<length>{1,4}",
  	media: "visual",
  	inherited: false,
  	animationType: "byComputedValueType",
  	percentages: "no",
  	groups: [
  		"CSS Scroll Snap"
  	],
  	initial: "0",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scroll-margin"
  },
  	"scroll-margin-block": {
  	syntax: "<length>{1,2}",
  	media: "visual",
  	inherited: false,
  	animationType: "byComputedValueType",
  	percentages: "no",
  	groups: [
  		"CSS Scroll Snap"
  	],
  	initial: "0",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scroll-margin-block"
  },
  	"scroll-margin-block-start": {
  	syntax: "<length>",
  	media: "visual",
  	inherited: false,
  	animationType: "byComputedValueType",
  	percentages: "no",
  	groups: [
  		"CSS Scroll Snap"
  	],
  	initial: "0",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scroll-margin-block-start"
  },
  	"scroll-margin-block-end": {
  	syntax: "<length>",
  	media: "visual",
  	inherited: false,
  	animationType: "byComputedValueType",
  	percentages: "no",
  	groups: [
  		"CSS Scroll Snap"
  	],
  	initial: "0",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scroll-margin-block-end"
  },
  	"scroll-margin-bottom": {
  	syntax: "<length>",
  	media: "visual",
  	inherited: false,
  	animationType: "byComputedValueType",
  	percentages: "no",
  	groups: [
  		"CSS Scroll Snap"
  	],
  	initial: "0",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scroll-margin-bottom"
  },
  	"scroll-margin-inline": {
  	syntax: "<length>{1,2}",
  	media: "visual",
  	inherited: false,
  	animationType: "byComputedValueType",
  	percentages: "no",
  	groups: [
  		"CSS Scroll Snap"
  	],
  	initial: "0",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scroll-margin-inline"
  },
  	"scroll-margin-inline-start": {
  	syntax: "<length>",
  	media: "visual",
  	inherited: false,
  	animationType: "byComputedValueType",
  	percentages: "no",
  	groups: [
  		"CSS Scroll Snap"
  	],
  	initial: "0",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scroll-margin-inline-start"
  },
  	"scroll-margin-inline-end": {
  	syntax: "<length>",
  	media: "visual",
  	inherited: false,
  	animationType: "byComputedValueType",
  	percentages: "no",
  	groups: [
  		"CSS Scroll Snap"
  	],
  	initial: "0",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scroll-margin-inline-end"
  },
  	"scroll-margin-left": {
  	syntax: "<length>",
  	media: "visual",
  	inherited: false,
  	animationType: "byComputedValueType",
  	percentages: "no",
  	groups: [
  		"CSS Scroll Snap"
  	],
  	initial: "0",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scroll-margin-left"
  },
  	"scroll-margin-right": {
  	syntax: "<length>",
  	media: "visual",
  	inherited: false,
  	animationType: "byComputedValueType",
  	percentages: "no",
  	groups: [
  		"CSS Scroll Snap"
  	],
  	initial: "0",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scroll-margin-right"
  },
  	"scroll-margin-top": {
  	syntax: "<length>",
  	media: "visual",
  	inherited: false,
  	animationType: "byComputedValueType",
  	percentages: "no",
  	groups: [
  		"CSS Scroll Snap"
  	],
  	initial: "0",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scroll-margin-top"
  },
  	"scroll-padding": {
  	syntax: "[ auto | <length-percentage> ]{1,4}",
  	media: "visual",
  	inherited: false,
  	animationType: "byComputedValueType",
  	percentages: "relativeToTheScrollContainersScrollport",
  	groups: [
  		"CSS Scroll Snap"
  	],
  	initial: "auto",
  	appliesto: "scrollContainers",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scroll-padding"
  },
  	"scroll-padding-block": {
  	syntax: "[ auto | <length-percentage> ]{1,2}",
  	media: "visual",
  	inherited: false,
  	animationType: "byComputedValueType",
  	percentages: "relativeToTheScrollContainersScrollport",
  	groups: [
  		"CSS Scroll Snap"
  	],
  	initial: "auto",
  	appliesto: "scrollContainers",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scroll-padding-block"
  },
  	"scroll-padding-block-start": {
  	syntax: "auto | <length-percentage>",
  	media: "visual",
  	inherited: false,
  	animationType: "byComputedValueType",
  	percentages: "relativeToTheScrollContainersScrollport",
  	groups: [
  		"CSS Scroll Snap"
  	],
  	initial: "auto",
  	appliesto: "scrollContainers",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scroll-padding-block-start"
  },
  	"scroll-padding-block-end": {
  	syntax: "auto | <length-percentage>",
  	media: "visual",
  	inherited: false,
  	animationType: "byComputedValueType",
  	percentages: "relativeToTheScrollContainersScrollport",
  	groups: [
  		"CSS Scroll Snap"
  	],
  	initial: "auto",
  	appliesto: "scrollContainers",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scroll-padding-block-end"
  },
  	"scroll-padding-bottom": {
  	syntax: "auto | <length-percentage>",
  	media: "visual",
  	inherited: false,
  	animationType: "byComputedValueType",
  	percentages: "relativeToTheScrollContainersScrollport",
  	groups: [
  		"CSS Scroll Snap"
  	],
  	initial: "auto",
  	appliesto: "scrollContainers",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scroll-padding-bottom"
  },
  	"scroll-padding-inline": {
  	syntax: "[ auto | <length-percentage> ]{1,2}",
  	media: "visual",
  	inherited: false,
  	animationType: "byComputedValueType",
  	percentages: "relativeToTheScrollContainersScrollport",
  	groups: [
  		"CSS Scroll Snap"
  	],
  	initial: "auto",
  	appliesto: "scrollContainers",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scroll-padding-inline"
  },
  	"scroll-padding-inline-start": {
  	syntax: "auto | <length-percentage>",
  	media: "visual",
  	inherited: false,
  	animationType: "byComputedValueType",
  	percentages: "relativeToTheScrollContainersScrollport",
  	groups: [
  		"CSS Scroll Snap"
  	],
  	initial: "auto",
  	appliesto: "scrollContainers",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scroll-padding-inline-start"
  },
  	"scroll-padding-inline-end": {
  	syntax: "auto | <length-percentage>",
  	media: "visual",
  	inherited: false,
  	animationType: "byComputedValueType",
  	percentages: "relativeToTheScrollContainersScrollport",
  	groups: [
  		"CSS Scroll Snap"
  	],
  	initial: "auto",
  	appliesto: "scrollContainers",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scroll-padding-inline-end"
  },
  	"scroll-padding-left": {
  	syntax: "auto | <length-percentage>",
  	media: "visual",
  	inherited: false,
  	animationType: "byComputedValueType",
  	percentages: "relativeToTheScrollContainersScrollport",
  	groups: [
  		"CSS Scroll Snap"
  	],
  	initial: "auto",
  	appliesto: "scrollContainers",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scroll-padding-left"
  },
  	"scroll-padding-right": {
  	syntax: "auto | <length-percentage>",
  	media: "visual",
  	inherited: false,
  	animationType: "byComputedValueType",
  	percentages: "relativeToTheScrollContainersScrollport",
  	groups: [
  		"CSS Scroll Snap"
  	],
  	initial: "auto",
  	appliesto: "scrollContainers",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scroll-padding-right"
  },
  	"scroll-padding-top": {
  	syntax: "auto | <length-percentage>",
  	media: "visual",
  	inherited: false,
  	animationType: "byComputedValueType",
  	percentages: "relativeToTheScrollContainersScrollport",
  	groups: [
  		"CSS Scroll Snap"
  	],
  	initial: "auto",
  	appliesto: "scrollContainers",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scroll-padding-top"
  },
  	"scroll-snap-align": {
  	syntax: "[ none | start | end | center ]{1,2}",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Scroll Snap"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scroll-snap-align"
  },
  	"scroll-snap-coordinate": {
  	syntax: "none | <position>#",
  	media: "interactive",
  	inherited: false,
  	animationType: "position",
  	percentages: "referToBorderBox",
  	groups: [
  		"CSS Scroll Snap"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecifiedRelativeToAbsoluteLengths",
  	order: "uniqueOrder",
  	status: "obsolete",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scroll-snap-coordinate"
  },
  	"scroll-snap-destination": {
  	syntax: "<position>",
  	media: "interactive",
  	inherited: false,
  	animationType: "position",
  	percentages: "relativeToScrollContainerPaddingBoxAxis",
  	groups: [
  		"CSS Scroll Snap"
  	],
  	initial: "0px 0px",
  	appliesto: "scrollContainers",
  	computed: "asSpecifiedRelativeToAbsoluteLengths",
  	order: "uniqueOrder",
  	status: "obsolete",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scroll-snap-destination"
  },
  	"scroll-snap-points-x": {
  	syntax: "none | repeat( <length-percentage> )",
  	media: "interactive",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "relativeToScrollContainerPaddingBoxAxis",
  	groups: [
  		"CSS Scroll Snap"
  	],
  	initial: "none",
  	appliesto: "scrollContainers",
  	computed: "asSpecifiedRelativeToAbsoluteLengths",
  	order: "uniqueOrder",
  	status: "obsolete",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scroll-snap-points-x"
  },
  	"scroll-snap-points-y": {
  	syntax: "none | repeat( <length-percentage> )",
  	media: "interactive",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "relativeToScrollContainerPaddingBoxAxis",
  	groups: [
  		"CSS Scroll Snap"
  	],
  	initial: "none",
  	appliesto: "scrollContainers",
  	computed: "asSpecifiedRelativeToAbsoluteLengths",
  	order: "uniqueOrder",
  	status: "obsolete",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scroll-snap-points-y"
  },
  	"scroll-snap-stop": {
  	syntax: "normal | always",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Scroll Snap"
  	],
  	initial: "normal",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scroll-snap-stop"
  },
  	"scroll-snap-type": {
  	syntax: "none | [ x | y | block | inline | both ] [ mandatory | proximity ]?",
  	media: "interactive",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Scroll Snap"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scroll-snap-type"
  },
  	"scroll-snap-type-x": {
  	syntax: "none | mandatory | proximity",
  	media: "interactive",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Scroll Snap"
  	],
  	initial: "none",
  	appliesto: "scrollContainers",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "obsolete",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scroll-snap-type-x"
  },
  	"scroll-snap-type-y": {
  	syntax: "none | mandatory | proximity",
  	media: "interactive",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Scroll Snap"
  	],
  	initial: "none",
  	appliesto: "scrollContainers",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "obsolete",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/scroll-snap-type-y"
  },
  	"shape-image-threshold": {
  	syntax: "<alpha-value>",
  	media: "visual",
  	inherited: false,
  	animationType: "number",
  	percentages: "no",
  	groups: [
  		"CSS Shapes"
  	],
  	initial: "0.0",
  	appliesto: "floats",
  	computed: "specifiedValueNumberClipped0To1",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/shape-image-threshold"
  },
  	"shape-margin": {
  	syntax: "<length-percentage>",
  	media: "visual",
  	inherited: false,
  	animationType: "lpc",
  	percentages: "referToWidthOfContainingBlock",
  	groups: [
  		"CSS Shapes"
  	],
  	initial: "0",
  	appliesto: "floats",
  	computed: "asSpecifiedRelativeToAbsoluteLengths",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/shape-margin"
  },
  	"shape-outside": {
  	syntax: "none | <shape-box> || <basic-shape> | <image>",
  	media: "visual",
  	inherited: false,
  	animationType: "basicShapeOtherwiseNo",
  	percentages: "no",
  	groups: [
  		"CSS Shapes"
  	],
  	initial: "none",
  	appliesto: "floats",
  	computed: "asDefinedForBasicShapeWithAbsoluteURIOtherwiseAsSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/shape-outside"
  },
  	"tab-size": {
  	syntax: "<integer> | <length>",
  	media: "visual",
  	inherited: true,
  	animationType: "length",
  	percentages: "no",
  	groups: [
  		"CSS Text"
  	],
  	initial: "8",
  	appliesto: "blockContainers",
  	computed: "specifiedIntegerOrAbsoluteLength",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/tab-size"
  },
  	"table-layout": {
  	syntax: "auto | fixed",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Table"
  	],
  	initial: "auto",
  	appliesto: "tableElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/table-layout"
  },
  	"text-align": {
  	syntax: "start | end | left | right | center | justify | match-parent",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Text"
  	],
  	initial: "startOrNamelessValueIfLTRRightIfRTL",
  	appliesto: "blockContainers",
  	computed: "asSpecifiedExceptMatchParent",
  	order: "orderOfAppearance",
  	alsoAppliesTo: [
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/text-align"
  },
  	"text-align-last": {
  	syntax: "auto | start | end | left | right | center | justify",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Text"
  	],
  	initial: "auto",
  	appliesto: "blockContainers",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/text-align-last"
  },
  	"text-combine-upright": {
  	syntax: "none | all | [ digits <integer>? ]",
  	media: "visual",
  	inherited: true,
  	animationType: "notAnimatable",
  	percentages: "no",
  	groups: [
  		"CSS Writing Modes"
  	],
  	initial: "none",
  	appliesto: "nonReplacedInlineElements",
  	computed: "keywordPlusIntegerIfDigits",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/text-combine-upright"
  },
  	"text-decoration": {
  	syntax: "<'text-decoration-line'> || <'text-decoration-style'> || <'text-decoration-color'> || <'text-decoration-thickness'>",
  	media: "visual",
  	inherited: false,
  	animationType: [
  		"text-decoration-color",
  		"text-decoration-style",
  		"text-decoration-line",
  		"text-decoration-thickness"
  	],
  	percentages: "no",
  	groups: [
  		"CSS Text Decoration"
  	],
  	initial: [
  		"text-decoration-color",
  		"text-decoration-style",
  		"text-decoration-line"
  	],
  	appliesto: "allElements",
  	computed: [
  		"text-decoration-line",
  		"text-decoration-style",
  		"text-decoration-color",
  		"text-decoration-thickness"
  	],
  	order: "orderOfAppearance",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/text-decoration"
  },
  	"text-decoration-color": {
  	syntax: "<color>",
  	media: "visual",
  	inherited: false,
  	animationType: "color",
  	percentages: "no",
  	groups: [
  		"CSS Text Decoration"
  	],
  	initial: "currentcolor",
  	appliesto: "allElements",
  	computed: "computedColor",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/text-decoration-color"
  },
  	"text-decoration-line": {
  	syntax: "none | [ underline || overline || line-through || blink ] | spelling-error | grammar-error",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Text Decoration"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "orderOfAppearance",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/text-decoration-line"
  },
  	"text-decoration-skip": {
  	syntax: "none | [ objects || [ spaces | [ leading-spaces || trailing-spaces ] ] || edges || box-decoration ]",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Text Decoration"
  	],
  	initial: "objects",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "orderOfAppearance",
  	status: "experimental",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/text-decoration-skip"
  },
  	"text-decoration-skip-ink": {
  	syntax: "auto | all | none",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Text Decoration"
  	],
  	initial: "auto",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "orderOfAppearance",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/text-decoration-skip-ink"
  },
  	"text-decoration-style": {
  	syntax: "solid | double | dotted | dashed | wavy",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Text Decoration"
  	],
  	initial: "solid",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/text-decoration-style"
  },
  	"text-decoration-thickness": {
  	syntax: "auto | from-font | <length> | <percentage> ",
  	media: "visual",
  	inherited: false,
  	animationType: "byComputedValueType",
  	percentages: "referToElementFontSize",
  	groups: [
  		"CSS Text Decoration"
  	],
  	initial: "auto",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/text-decoration-thickness"
  },
  	"text-emphasis": {
  	syntax: "<'text-emphasis-style'> || <'text-emphasis-color'>",
  	media: "visual",
  	inherited: false,
  	animationType: [
  		"text-emphasis-color",
  		"text-emphasis-style"
  	],
  	percentages: "no",
  	groups: [
  		"CSS Text Decoration"
  	],
  	initial: [
  		"text-emphasis-style",
  		"text-emphasis-color"
  	],
  	appliesto: "allElements",
  	computed: [
  		"text-emphasis-style",
  		"text-emphasis-color"
  	],
  	order: "orderOfAppearance",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/text-emphasis"
  },
  	"text-emphasis-color": {
  	syntax: "<color>",
  	media: "visual",
  	inherited: false,
  	animationType: "color",
  	percentages: "no",
  	groups: [
  		"CSS Text Decoration"
  	],
  	initial: "currentcolor",
  	appliesto: "allElements",
  	computed: "computedColor",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/text-emphasis-color"
  },
  	"text-emphasis-position": {
  	syntax: "[ over | under ] && [ right | left ]",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Text Decoration"
  	],
  	initial: "over right",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/text-emphasis-position"
  },
  	"text-emphasis-style": {
  	syntax: "none | [ [ filled | open ] || [ dot | circle | double-circle | triangle | sesame ] ] | <string>",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Text Decoration"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/text-emphasis-style"
  },
  	"text-indent": {
  	syntax: "<length-percentage> && hanging? && each-line?",
  	media: "visual",
  	inherited: true,
  	animationType: "lpc",
  	percentages: "referToWidthOfContainingBlock",
  	groups: [
  		"CSS Text"
  	],
  	initial: "0",
  	appliesto: "blockContainers",
  	computed: "percentageOrAbsoluteLengthPlusKeywords",
  	order: "lengthOrPercentageBeforeKeywords",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/text-indent"
  },
  	"text-justify": {
  	syntax: "auto | inter-character | inter-word | none",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Text"
  	],
  	initial: "auto",
  	appliesto: "inlineLevelAndTableCellElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/text-justify"
  },
  	"text-orientation": {
  	syntax: "mixed | upright | sideways",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Writing Modes"
  	],
  	initial: "mixed",
  	appliesto: "allElementsExceptTableRowGroupsRowsColumnGroupsAndColumns",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/text-orientation"
  },
  	"text-overflow": {
  	syntax: "[ clip | ellipsis | <string> ]{1,2}",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Basic User Interface"
  	],
  	initial: "clip",
  	appliesto: "blockContainerElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/text-overflow"
  },
  	"text-rendering": {
  	syntax: "auto | optimizeSpeed | optimizeLegibility | geometricPrecision",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Miscellaneous"
  	],
  	initial: "auto",
  	appliesto: "textElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/text-rendering"
  },
  	"text-shadow": {
  	syntax: "none | <shadow-t>#",
  	media: "visual",
  	inherited: true,
  	animationType: "shadowList",
  	percentages: "no",
  	groups: [
  		"CSS Text Decoration"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "colorPlusThreeAbsoluteLengths",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/text-shadow"
  },
  	"text-size-adjust": {
  	syntax: "none | auto | <percentage>",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "referToSizeOfFont",
  	groups: [
  		"CSS Text"
  	],
  	initial: "autoForSmartphoneBrowsersSupportingInflation",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "experimental",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/text-size-adjust"
  },
  	"text-transform": {
  	syntax: "none | capitalize | uppercase | lowercase | full-width | full-size-kana",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Text"
  	],
  	initial: "none",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/text-transform"
  },
  	"text-underline-offset": {
  	syntax: "auto | <length> | <percentage> ",
  	media: "visual",
  	inherited: true,
  	animationType: "byComputedValueType",
  	percentages: "referToElementFontSize",
  	groups: [
  		"CSS Text Decoration"
  	],
  	initial: "auto",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/text-underline-offset"
  },
  	"text-underline-position": {
  	syntax: "auto | from-font | [ under || [ left | right ] ]",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Text Decoration"
  	],
  	initial: "auto",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "orderOfAppearance",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/text-underline-position"
  },
  	top: top$1,
  	"touch-action": {
  	syntax: "auto | none | [ [ pan-x | pan-left | pan-right ] || [ pan-y | pan-up | pan-down ] || pinch-zoom ] | manipulation",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"Pointer Events"
  	],
  	initial: "auto",
  	appliesto: "allElementsExceptNonReplacedInlineElementsTableRowsColumnsRowColumnGroups",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/touch-action"
  },
  	transform: transform,
  	"transform-box": {
  	syntax: "content-box | border-box | fill-box | stroke-box | view-box",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Transforms"
  	],
  	initial: "view-box",
  	appliesto: "transformableElements",
  	computed: "asSpecified",
  	order: "perGrammar",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/transform-box"
  },
  	"transform-origin": {
  	syntax: "[ <length-percentage> | left | center | right | top | bottom ] | [ [ <length-percentage> | left | center | right ] && [ <length-percentage> | top | center | bottom ] ] <length>?",
  	media: "visual",
  	inherited: false,
  	animationType: "simpleListOfLpc",
  	percentages: "referToSizeOfBoundingBox",
  	groups: [
  		"CSS Transforms"
  	],
  	initial: "50% 50% 0",
  	appliesto: "transformableElements",
  	computed: "forLengthAbsoluteValueOtherwisePercentage",
  	order: "oneOrTwoValuesLengthAbsoluteKeywordsPercentages",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/transform-origin"
  },
  	"transform-style": {
  	syntax: "flat | preserve-3d",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Transforms"
  	],
  	initial: "flat",
  	appliesto: "transformableElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	stacking: true,
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/transform-style"
  },
  	transition: transition,
  	"transition-delay": {
  	syntax: "<time>#",
  	media: "interactive",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Transitions"
  	],
  	initial: "0s",
  	appliesto: "allElementsAndPseudos",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/transition-delay"
  },
  	"transition-duration": {
  	syntax: "<time>#",
  	media: "interactive",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Transitions"
  	],
  	initial: "0s",
  	appliesto: "allElementsAndPseudos",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/transition-duration"
  },
  	"transition-property": {
  	syntax: "none | <single-transition-property>#",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Transitions"
  	],
  	initial: "all",
  	appliesto: "allElementsAndPseudos",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/transition-property"
  },
  	"transition-timing-function": {
  	syntax: "<timing-function>#",
  	media: "interactive",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Transitions"
  	],
  	initial: "ease",
  	appliesto: "allElementsAndPseudos",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/transition-timing-function"
  },
  	translate: translate,
  	"unicode-bidi": {
  	syntax: "normal | embed | isolate | bidi-override | isolate-override | plaintext",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Writing Modes"
  	],
  	initial: "normal",
  	appliesto: "allElementsSomeValuesNoEffectOnNonInlineElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/unicode-bidi"
  },
  	"user-select": {
  	syntax: "auto | text | none | contain | all",
  	media: "visual",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Basic User Interface"
  	],
  	initial: "auto",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "nonstandard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/user-select"
  },
  	"vertical-align": {
  	syntax: "baseline | sub | super | text-top | text-bottom | middle | top | bottom | <percentage> | <length>",
  	media: "visual",
  	inherited: false,
  	animationType: "length",
  	percentages: "referToLineHeight",
  	groups: [
  		"CSS Table"
  	],
  	initial: "baseline",
  	appliesto: "inlineLevelAndTableCellElements",
  	computed: "absoluteLengthOrKeyword",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/vertical-align"
  },
  	visibility: visibility,
  	"white-space": {
  	syntax: "normal | pre | nowrap | pre-wrap | pre-line | break-spaces",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Text"
  	],
  	initial: "normal",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/white-space"
  },
  	widows: widows,
  	width: width,
  	"will-change": {
  	syntax: "auto | <animateable-feature>#",
  	media: "all",
  	inherited: false,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Will Change"
  	],
  	initial: "auto",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/will-change"
  },
  	"word-break": {
  	syntax: "normal | break-all | keep-all | break-word",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Text"
  	],
  	initial: "normal",
  	appliesto: "allElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/word-break"
  },
  	"word-spacing": {
  	syntax: "normal | <length-percentage>",
  	media: "visual",
  	inherited: true,
  	animationType: "length",
  	percentages: "referToWidthOfAffectedGlyph",
  	groups: [
  		"CSS Text"
  	],
  	initial: "normal",
  	appliesto: "allElements",
  	computed: "optimumMinAndMaxValueOfAbsoluteLengthPercentageOrNormal",
  	order: "uniqueOrder",
  	alsoAppliesTo: [
  		"::first-letter",
  		"::first-line",
  		"::placeholder"
  	],
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/word-spacing"
  },
  	"word-wrap": {
  	syntax: "normal | break-word",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Text"
  	],
  	initial: "normal",
  	appliesto: "nonReplacedInlineElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/overflow-wrap"
  },
  	"writing-mode": {
  	syntax: "horizontal-tb | vertical-rl | vertical-lr | sideways-rl | sideways-lr",
  	media: "visual",
  	inherited: true,
  	animationType: "discrete",
  	percentages: "no",
  	groups: [
  		"CSS Writing Modes"
  	],
  	initial: "horizontal-tb",
  	appliesto: "allElementsExceptTableRowColumnGroupsTableRowsColumns",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/writing-mode"
  },
  	"z-index": {
  	syntax: "auto | <integer>",
  	media: "visual",
  	inherited: false,
  	animationType: "integer",
  	percentages: "no",
  	groups: [
  		"CSS Positioning"
  	],
  	initial: "auto",
  	appliesto: "positionedElements",
  	computed: "asSpecified",
  	order: "uniqueOrder",
  	stacking: true,
  	status: "standard",
  	mdn_url: "https://developer.mozilla.org/docs/Web/CSS/z-index"
  },
  	zoom: zoom
  };

  var attachment = {
  	syntax: "scroll | fixed | local"
  };
  var box = {
  	syntax: "border-box | padding-box | content-box"
  };
  var color = {
  	syntax: "<rgb()> | <rgba()> | <hsl()> | <hsla()> | <hex-color> | <named-color> | currentcolor | <deprecated-system-color>"
  };
  var combinator = {
  	syntax: "'>' | '+' | '~' | [ '||' ]"
  };
  var gradient = {
  	syntax: "<linear-gradient()> | <repeating-linear-gradient()> | <radial-gradient()> | <repeating-radial-gradient()> | <conic-gradient()>"
  };
  var hue = {
  	syntax: "<number> | <angle>"
  };
  var image$1 = {
  	syntax: "<url> | <image()> | <image-set()> | <element()> | <paint()> | <cross-fade()> | <gradient>"
  };
  var nth$1 = {
  	syntax: "<an-plus-b> | even | odd"
  };
  var position = {
  	syntax: "[ [ left | center | right ] || [ top | center | bottom ] | [ left | center | right | <length-percentage> ] [ top | center | bottom | <length-percentage> ]? | [ [ left | right ] <length-percentage> ] && [ [ top | bottom ] <length-percentage> ] ]"
  };
  var quote = {
  	syntax: "open-quote | close-quote | no-open-quote | no-close-quote"
  };
  var shadow = {
  	syntax: "inset? && <length>{2,4} && <color>?"
  };
  var shape = {
  	syntax: "rect(<top>, <right>, <bottom>, <left>)"
  };
  var size = {
  	syntax: "closest-side | farthest-side | closest-corner | farthest-corner | <length> | <length-percentage>{2}"
  };
  var symbol = {
  	syntax: "<string> | <image> | <custom-ident>"
  };
  var target$1 = {
  	syntax: "<target-counter()> | <target-counters()> | <target-text()>"
  };
  var mdnSyntaxes = {
  	"absolute-size": {
  	syntax: "xx-small | x-small | small | medium | large | x-large | xx-large | xxx-large"
  },
  	"alpha-value": {
  	syntax: "<number> | <percentage>"
  },
  	"angle-percentage": {
  	syntax: "<angle> | <percentage>"
  },
  	"angular-color-hint": {
  	syntax: "<angle-percentage>"
  },
  	"angular-color-stop": {
  	syntax: "<color> && <color-stop-angle>?"
  },
  	"angular-color-stop-list": {
  	syntax: "[ <angular-color-stop> [, <angular-color-hint>]? ]# , <angular-color-stop>"
  },
  	"animateable-feature": {
  	syntax: "scroll-position | contents | <custom-ident>"
  },
  	attachment: attachment,
  	"attr()": {
  	syntax: "attr( <attr-name> <type-or-unit>? [, <attr-fallback> ]? )"
  },
  	"attr-matcher": {
  	syntax: "[ '~' | '|' | '^' | '$' | '*' ]? '='"
  },
  	"attr-modifier": {
  	syntax: "i | s"
  },
  	"attribute-selector": {
  	syntax: "'[' <wq-name> ']' | '[' <wq-name> <attr-matcher> [ <string-token> | <ident-token> ] <attr-modifier>? ']'"
  },
  	"auto-repeat": {
  	syntax: "repeat( [ auto-fill | auto-fit ] , [ <line-names>? <fixed-size> ]+ <line-names>? )"
  },
  	"auto-track-list": {
  	syntax: "[ <line-names>? [ <fixed-size> | <fixed-repeat> ] ]* <line-names>? <auto-repeat>\n[ <line-names>? [ <fixed-size> | <fixed-repeat> ] ]* <line-names>?"
  },
  	"baseline-position": {
  	syntax: "[ first | last ]? baseline"
  },
  	"basic-shape": {
  	syntax: "<inset()> | <circle()> | <ellipse()> | <polygon()> | <path()>"
  },
  	"bg-image": {
  	syntax: "none | <image>"
  },
  	"bg-layer": {
  	syntax: "<bg-image> || <bg-position> [ / <bg-size> ]? || <repeat-style> || <attachment> || <box> || <box>"
  },
  	"bg-position": {
  	syntax: "[ [ left | center | right | top | bottom | <length-percentage> ] | [ left | center | right | <length-percentage> ] [ top | center | bottom | <length-percentage> ] | [ center | [ left | right ] <length-percentage>? ] && [ center | [ top | bottom ] <length-percentage>? ] ]"
  },
  	"bg-size": {
  	syntax: "[ <length-percentage> | auto ]{1,2} | cover | contain"
  },
  	"blur()": {
  	syntax: "blur( <length> )"
  },
  	"blend-mode": {
  	syntax: "normal | multiply | screen | overlay | darken | lighten | color-dodge | color-burn | hard-light | soft-light | difference | exclusion | hue | saturation | color | luminosity"
  },
  	box: box,
  	"brightness()": {
  	syntax: "brightness( <number-percentage> )"
  },
  	"calc()": {
  	syntax: "calc( <calc-sum> )"
  },
  	"calc-sum": {
  	syntax: "<calc-product> [ [ '+' | '-' ] <calc-product> ]*"
  },
  	"calc-product": {
  	syntax: "<calc-value> [ '*' <calc-value> | '/' <number> ]*"
  },
  	"calc-value": {
  	syntax: "<number> | <dimension> | <percentage> | ( <calc-sum> )"
  },
  	"cf-final-image": {
  	syntax: "<image> | <color>"
  },
  	"cf-mixing-image": {
  	syntax: "<percentage>? && <image>"
  },
  	"circle()": {
  	syntax: "circle( [ <shape-radius> ]? [ at <position> ]? )"
  },
  	"clamp()": {
  	syntax: "clamp( <calc-sum>#{3} )"
  },
  	"class-selector": {
  	syntax: "'.' <ident-token>"
  },
  	"clip-source": {
  	syntax: "<url>"
  },
  	color: color,
  	"color-stop": {
  	syntax: "<color-stop-length> | <color-stop-angle>"
  },
  	"color-stop-angle": {
  	syntax: "<angle-percentage>{1,2}"
  },
  	"color-stop-length": {
  	syntax: "<length-percentage>{1,2}"
  },
  	"color-stop-list": {
  	syntax: "[ <linear-color-stop> [, <linear-color-hint>]? ]# , <linear-color-stop>"
  },
  	combinator: combinator,
  	"common-lig-values": {
  	syntax: "[ common-ligatures | no-common-ligatures ]"
  },
  	"compat-auto": {
  	syntax: "searchfield | textarea | push-button | slider-horizontal | checkbox | radio | square-button | menulist | listbox | meter | progress-bar | button"
  },
  	"composite-style": {
  	syntax: "clear | copy | source-over | source-in | source-out | source-atop | destination-over | destination-in | destination-out | destination-atop | xor"
  },
  	"compositing-operator": {
  	syntax: "add | subtract | intersect | exclude"
  },
  	"compound-selector": {
  	syntax: "[ <type-selector>? <subclass-selector>* [ <pseudo-element-selector> <pseudo-class-selector>* ]* ]!"
  },
  	"compound-selector-list": {
  	syntax: "<compound-selector>#"
  },
  	"complex-selector": {
  	syntax: "<compound-selector> [ <combinator>? <compound-selector> ]*"
  },
  	"complex-selector-list": {
  	syntax: "<complex-selector>#"
  },
  	"conic-gradient()": {
  	syntax: "conic-gradient( [ from <angle> ]? [ at <position> ]?, <angular-color-stop-list> )"
  },
  	"contextual-alt-values": {
  	syntax: "[ contextual | no-contextual ]"
  },
  	"content-distribution": {
  	syntax: "space-between | space-around | space-evenly | stretch"
  },
  	"content-list": {
  	syntax: "[ <string> | contents | <image> | <quote> | <target> | <leader()> ]+"
  },
  	"content-position": {
  	syntax: "center | start | end | flex-start | flex-end"
  },
  	"content-replacement": {
  	syntax: "<image>"
  },
  	"contrast()": {
  	syntax: "contrast( [ <number-percentage> ] )"
  },
  	"counter()": {
  	syntax: "counter( <custom-ident>, <counter-style>? )"
  },
  	"counter-style": {
  	syntax: "<counter-style-name> | symbols()"
  },
  	"counter-style-name": {
  	syntax: "<custom-ident>"
  },
  	"counters()": {
  	syntax: "counters( <custom-ident>, <string>, <counter-style>? )"
  },
  	"cross-fade()": {
  	syntax: "cross-fade( <cf-mixing-image> , <cf-final-image>? )"
  },
  	"cubic-bezier-timing-function": {
  	syntax: "ease | ease-in | ease-out | ease-in-out | cubic-bezier(<number [0,1]>, <number>, <number [0,1]>, <number>)"
  },
  	"deprecated-system-color": {
  	syntax: "ActiveBorder | ActiveCaption | AppWorkspace | Background | ButtonFace | ButtonHighlight | ButtonShadow | ButtonText | CaptionText | GrayText | Highlight | HighlightText | InactiveBorder | InactiveCaption | InactiveCaptionText | InfoBackground | InfoText | Menu | MenuText | Scrollbar | ThreeDDarkShadow | ThreeDFace | ThreeDHighlight | ThreeDLightShadow | ThreeDShadow | Window | WindowFrame | WindowText"
  },
  	"discretionary-lig-values": {
  	syntax: "[ discretionary-ligatures | no-discretionary-ligatures ]"
  },
  	"display-box": {
  	syntax: "contents | none"
  },
  	"display-inside": {
  	syntax: "flow | flow-root | table | flex | grid | ruby"
  },
  	"display-internal": {
  	syntax: "table-row-group | table-header-group | table-footer-group | table-row | table-cell | table-column-group | table-column | table-caption | ruby-base | ruby-text | ruby-base-container | ruby-text-container"
  },
  	"display-legacy": {
  	syntax: "inline-block | inline-list-item | inline-table | inline-flex | inline-grid"
  },
  	"display-listitem": {
  	syntax: "<display-outside>? && [ flow | flow-root ]? && list-item"
  },
  	"display-outside": {
  	syntax: "block | inline | run-in"
  },
  	"drop-shadow()": {
  	syntax: "drop-shadow( <length>{2,3} <color>? )"
  },
  	"east-asian-variant-values": {
  	syntax: "[ jis78 | jis83 | jis90 | jis04 | simplified | traditional ]"
  },
  	"east-asian-width-values": {
  	syntax: "[ full-width | proportional-width ]"
  },
  	"element()": {
  	syntax: "element( <id-selector> )"
  },
  	"ellipse()": {
  	syntax: "ellipse( [ <shape-radius>{2} ]? [ at <position> ]? )"
  },
  	"ending-shape": {
  	syntax: "circle | ellipse"
  },
  	"env()": {
  	syntax: "env( <custom-ident> , <declaration-value>? )"
  },
  	"explicit-track-list": {
  	syntax: "[ <line-names>? <track-size> ]+ <line-names>?"
  },
  	"family-name": {
  	syntax: "<string> | <custom-ident>+"
  },
  	"feature-tag-value": {
  	syntax: "<string> [ <integer> | on | off ]?"
  },
  	"feature-type": {
  	syntax: "@stylistic | @historical-forms | @styleset | @character-variant | @swash | @ornaments | @annotation"
  },
  	"feature-value-block": {
  	syntax: "<feature-type> '{' <feature-value-declaration-list> '}'"
  },
  	"feature-value-block-list": {
  	syntax: "<feature-value-block>+"
  },
  	"feature-value-declaration": {
  	syntax: "<custom-ident>: <integer>+;"
  },
  	"feature-value-declaration-list": {
  	syntax: "<feature-value-declaration>"
  },
  	"feature-value-name": {
  	syntax: "<custom-ident>"
  },
  	"fill-rule": {
  	syntax: "nonzero | evenodd"
  },
  	"filter-function": {
  	syntax: "<blur()> | <brightness()> | <contrast()> | <drop-shadow()> | <grayscale()> | <hue-rotate()> | <invert()> | <opacity()> | <saturate()> | <sepia()>"
  },
  	"filter-function-list": {
  	syntax: "[ <filter-function> | <url> ]+"
  },
  	"final-bg-layer": {
  	syntax: "<'background-color'> || <bg-image> || <bg-position> [ / <bg-size> ]? || <repeat-style> || <attachment> || <box> || <box>"
  },
  	"fit-content()": {
  	syntax: "fit-content( [ <length> | <percentage> ] )"
  },
  	"fixed-breadth": {
  	syntax: "<length-percentage>"
  },
  	"fixed-repeat": {
  	syntax: "repeat( [ <positive-integer> ] , [ <line-names>? <fixed-size> ]+ <line-names>? )"
  },
  	"fixed-size": {
  	syntax: "<fixed-breadth> | minmax( <fixed-breadth> , <track-breadth> ) | minmax( <inflexible-breadth> , <fixed-breadth> )"
  },
  	"font-stretch-absolute": {
  	syntax: "normal | ultra-condensed | extra-condensed | condensed | semi-condensed | semi-expanded | expanded | extra-expanded | ultra-expanded | <percentage>"
  },
  	"font-variant-css21": {
  	syntax: "[ normal | small-caps ]"
  },
  	"font-weight-absolute": {
  	syntax: "normal | bold | <number [1,1000]>"
  },
  	"frequency-percentage": {
  	syntax: "<frequency> | <percentage>"
  },
  	"general-enclosed": {
  	syntax: "[ <function-token> <any-value> ) ] | ( <ident> <any-value> )"
  },
  	"generic-family": {
  	syntax: "serif | sans-serif | cursive | fantasy | monospace"
  },
  	"generic-name": {
  	syntax: "serif | sans-serif | cursive | fantasy | monospace"
  },
  	"geometry-box": {
  	syntax: "<shape-box> | fill-box | stroke-box | view-box"
  },
  	gradient: gradient,
  	"grayscale()": {
  	syntax: "grayscale( <number-percentage> )"
  },
  	"grid-line": {
  	syntax: "auto | <custom-ident> | [ <integer> && <custom-ident>? ] | [ span && [ <integer> || <custom-ident> ] ]"
  },
  	"historical-lig-values": {
  	syntax: "[ historical-ligatures | no-historical-ligatures ]"
  },
  	"hsl()": {
  	syntax: "hsl( <hue> <percentage> <percentage> [ / <alpha-value> ]? ) | hsl( <hue>, <percentage>, <percentage>, <alpha-value>? )"
  },
  	"hsla()": {
  	syntax: "hsla( <hue> <percentage> <percentage> [ / <alpha-value> ]? ) | hsla( <hue>, <percentage>, <percentage>, <alpha-value>? )"
  },
  	hue: hue,
  	"hue-rotate()": {
  	syntax: "hue-rotate( <angle> )"
  },
  	"id-selector": {
  	syntax: "<hash-token>"
  },
  	image: image$1,
  	"image()": {
  	syntax: "image( <image-tags>? [ <image-src>? , <color>? ]! )"
  },
  	"image-set()": {
  	syntax: "image-set( <image-set-option># )"
  },
  	"image-set-option": {
  	syntax: "[ <image> | <string> ] <resolution>"
  },
  	"image-src": {
  	syntax: "<url> | <string>"
  },
  	"image-tags": {
  	syntax: "ltr | rtl"
  },
  	"inflexible-breadth": {
  	syntax: "<length> | <percentage> | min-content | max-content | auto"
  },
  	"inset()": {
  	syntax: "inset( <length-percentage>{1,4} [ round <'border-radius'> ]? )"
  },
  	"invert()": {
  	syntax: "invert( <number-percentage> )"
  },
  	"keyframes-name": {
  	syntax: "<custom-ident> | <string>"
  },
  	"keyframe-block": {
  	syntax: "<keyframe-selector># {\n  <declaration-list>\n}"
  },
  	"keyframe-block-list": {
  	syntax: "<keyframe-block>+"
  },
  	"keyframe-selector": {
  	syntax: "from | to | <percentage>"
  },
  	"leader()": {
  	syntax: "leader( <leader-type> )"
  },
  	"leader-type": {
  	syntax: "dotted | solid | space | <string>"
  },
  	"length-percentage": {
  	syntax: "<length> | <percentage>"
  },
  	"line-names": {
  	syntax: "'[' <custom-ident>* ']'"
  },
  	"line-name-list": {
  	syntax: "[ <line-names> | <name-repeat> ]+"
  },
  	"line-style": {
  	syntax: "none | hidden | dotted | dashed | solid | double | groove | ridge | inset | outset"
  },
  	"line-width": {
  	syntax: "<length> | thin | medium | thick"
  },
  	"linear-color-hint": {
  	syntax: "<length-percentage>"
  },
  	"linear-color-stop": {
  	syntax: "<color> <color-stop-length>?"
  },
  	"linear-gradient()": {
  	syntax: "linear-gradient( [ <angle> | to <side-or-corner> ]? , <color-stop-list> )"
  },
  	"mask-layer": {
  	syntax: "<mask-reference> || <position> [ / <bg-size> ]? || <repeat-style> || <geometry-box> || [ <geometry-box> | no-clip ] || <compositing-operator> || <masking-mode>"
  },
  	"mask-position": {
  	syntax: "[ <length-percentage> | left | center | right ] [ <length-percentage> | top | center | bottom ]?"
  },
  	"mask-reference": {
  	syntax: "none | <image> | <mask-source>"
  },
  	"mask-source": {
  	syntax: "<url>"
  },
  	"masking-mode": {
  	syntax: "alpha | luminance | match-source"
  },
  	"matrix()": {
  	syntax: "matrix( <number>#{6} )"
  },
  	"matrix3d()": {
  	syntax: "matrix3d( <number>#{16} )"
  },
  	"max()": {
  	syntax: "max( <calc-sum># )"
  },
  	"media-and": {
  	syntax: "<media-in-parens> [ and <media-in-parens> ]+"
  },
  	"media-condition": {
  	syntax: "<media-not> | <media-and> | <media-or> | <media-in-parens>"
  },
  	"media-condition-without-or": {
  	syntax: "<media-not> | <media-and> | <media-in-parens>"
  },
  	"media-feature": {
  	syntax: "( [ <mf-plain> | <mf-boolean> | <mf-range> ] )"
  },
  	"media-in-parens": {
  	syntax: "( <media-condition> ) | <media-feature> | <general-enclosed>"
  },
  	"media-not": {
  	syntax: "not <media-in-parens>"
  },
  	"media-or": {
  	syntax: "<media-in-parens> [ or <media-in-parens> ]+"
  },
  	"media-query": {
  	syntax: "<media-condition> | [ not | only ]? <media-type> [ and <media-condition-without-or> ]?"
  },
  	"media-query-list": {
  	syntax: "<media-query>#"
  },
  	"media-type": {
  	syntax: "<ident>"
  },
  	"mf-boolean": {
  	syntax: "<mf-name>"
  },
  	"mf-name": {
  	syntax: "<ident>"
  },
  	"mf-plain": {
  	syntax: "<mf-name> : <mf-value>"
  },
  	"mf-range": {
  	syntax: "<mf-name> [ '<' | '>' ]? '='? <mf-value>\n| <mf-value> [ '<' | '>' ]? '='? <mf-name>\n| <mf-value> '<' '='? <mf-name> '<' '='? <mf-value>\n| <mf-value> '>' '='? <mf-name> '>' '='? <mf-value>"
  },
  	"mf-value": {
  	syntax: "<number> | <dimension> | <ident> | <ratio>"
  },
  	"min()": {
  	syntax: "min( <calc-sum># )"
  },
  	"minmax()": {
  	syntax: "minmax( [ <length> | <percentage> | min-content | max-content | auto ] , [ <length> | <percentage> | <flex> | min-content | max-content | auto ] )"
  },
  	"named-color": {
  	syntax: "transparent | aliceblue | antiquewhite | aqua | aquamarine | azure | beige | bisque | black | blanchedalmond | blue | blueviolet | brown | burlywood | cadetblue | chartreuse | chocolate | coral | cornflowerblue | cornsilk | crimson | cyan | darkblue | darkcyan | darkgoldenrod | darkgray | darkgreen | darkgrey | darkkhaki | darkmagenta | darkolivegreen | darkorange | darkorchid | darkred | darksalmon | darkseagreen | darkslateblue | darkslategray | darkslategrey | darkturquoise | darkviolet | deeppink | deepskyblue | dimgray | dimgrey | dodgerblue | firebrick | floralwhite | forestgreen | fuchsia | gainsboro | ghostwhite | gold | goldenrod | gray | green | greenyellow | grey | honeydew | hotpink | indianred | indigo | ivory | khaki | lavender | lavenderblush | lawngreen | lemonchiffon | lightblue | lightcoral | lightcyan | lightgoldenrodyellow | lightgray | lightgreen | lightgrey | lightpink | lightsalmon | lightseagreen | lightskyblue | lightslategray | lightslategrey | lightsteelblue | lightyellow | lime | limegreen | linen | magenta | maroon | mediumaquamarine | mediumblue | mediumorchid | mediumpurple | mediumseagreen | mediumslateblue | mediumspringgreen | mediumturquoise | mediumvioletred | midnightblue | mintcream | mistyrose | moccasin | navajowhite | navy | oldlace | olive | olivedrab | orange | orangered | orchid | palegoldenrod | palegreen | paleturquoise | palevioletred | papayawhip | peachpuff | peru | pink | plum | powderblue | purple | rebeccapurple | red | rosybrown | royalblue | saddlebrown | salmon | sandybrown | seagreen | seashell | sienna | silver | skyblue | slateblue | slategray | slategrey | snow | springgreen | steelblue | tan | teal | thistle | tomato | turquoise | violet | wheat | white | whitesmoke | yellow | yellowgreen"
  },
  	"namespace-prefix": {
  	syntax: "<ident>"
  },
  	"ns-prefix": {
  	syntax: "[ <ident-token> | '*' ]? '|'"
  },
  	"number-percentage": {
  	syntax: "<number> | <percentage>"
  },
  	"numeric-figure-values": {
  	syntax: "[ lining-nums | oldstyle-nums ]"
  },
  	"numeric-fraction-values": {
  	syntax: "[ diagonal-fractions | stacked-fractions ]"
  },
  	"numeric-spacing-values": {
  	syntax: "[ proportional-nums | tabular-nums ]"
  },
  	nth: nth$1,
  	"opacity()": {
  	syntax: "opacity( [ <number-percentage> ] )"
  },
  	"overflow-position": {
  	syntax: "unsafe | safe"
  },
  	"outline-radius": {
  	syntax: "<length> | <percentage>"
  },
  	"page-body": {
  	syntax: "<declaration>? [ ; <page-body> ]? | <page-margin-box> <page-body>"
  },
  	"page-margin-box": {
  	syntax: "<page-margin-box-type> '{' <declaration-list> '}'"
  },
  	"page-margin-box-type": {
  	syntax: "@top-left-corner | @top-left | @top-center | @top-right | @top-right-corner | @bottom-left-corner | @bottom-left | @bottom-center | @bottom-right | @bottom-right-corner | @left-top | @left-middle | @left-bottom | @right-top | @right-middle | @right-bottom"
  },
  	"page-selector-list": {
  	syntax: "[ <page-selector># ]?"
  },
  	"page-selector": {
  	syntax: "<pseudo-page>+ | <ident> <pseudo-page>*"
  },
  	"path()": {
  	syntax: "path( [ <fill-rule>, ]? <string> )"
  },
  	"paint()": {
  	syntax: "paint( <ident>, <declaration-value>? )"
  },
  	"perspective()": {
  	syntax: "perspective( <length> )"
  },
  	"polygon()": {
  	syntax: "polygon( <fill-rule>? , [ <length-percentage> <length-percentage> ]# )"
  },
  	position: position,
  	"pseudo-class-selector": {
  	syntax: "':' <ident-token> | ':' <function-token> <any-value> ')'"
  },
  	"pseudo-element-selector": {
  	syntax: "':' <pseudo-class-selector>"
  },
  	"pseudo-page": {
  	syntax: ": [ left | right | first | blank ]"
  },
  	quote: quote,
  	"radial-gradient()": {
  	syntax: "radial-gradient( [ <ending-shape> || <size> ]? [ at <position> ]? , <color-stop-list> )"
  },
  	"relative-selector": {
  	syntax: "<combinator>? <complex-selector>"
  },
  	"relative-selector-list": {
  	syntax: "<relative-selector>#"
  },
  	"relative-size": {
  	syntax: "larger | smaller"
  },
  	"repeat-style": {
  	syntax: "repeat-x | repeat-y | [ repeat | space | round | no-repeat ]{1,2}"
  },
  	"repeating-linear-gradient()": {
  	syntax: "repeating-linear-gradient( [ <angle> | to <side-or-corner> ]? , <color-stop-list> )"
  },
  	"repeating-radial-gradient()": {
  	syntax: "repeating-radial-gradient( [ <ending-shape> || <size> ]? [ at <position> ]? , <color-stop-list> )"
  },
  	"rgb()": {
  	syntax: "rgb( <percentage>{3} [ / <alpha-value> ]? ) | rgb( <number>{3} [ / <alpha-value> ]? ) | rgb( <percentage>#{3} , <alpha-value>? ) | rgb( <number>#{3} , <alpha-value>? )"
  },
  	"rgba()": {
  	syntax: "rgba( <percentage>{3} [ / <alpha-value> ]? ) | rgba( <number>{3} [ / <alpha-value> ]? ) | rgba( <percentage>#{3} , <alpha-value>? ) | rgba( <number>#{3} , <alpha-value>? )"
  },
  	"rotate()": {
  	syntax: "rotate( [ <angle> | <zero> ] )"
  },
  	"rotate3d()": {
  	syntax: "rotate3d( <number> , <number> , <number> , [ <angle> | <zero> ] )"
  },
  	"rotateX()": {
  	syntax: "rotateX( [ <angle> | <zero> ] )"
  },
  	"rotateY()": {
  	syntax: "rotateY( [ <angle> | <zero> ] )"
  },
  	"rotateZ()": {
  	syntax: "rotateZ( [ <angle> | <zero> ] )"
  },
  	"saturate()": {
  	syntax: "saturate( <number-percentage> )"
  },
  	"scale()": {
  	syntax: "scale( <number> , <number>? )"
  },
  	"scale3d()": {
  	syntax: "scale3d( <number> , <number> , <number> )"
  },
  	"scaleX()": {
  	syntax: "scaleX( <number> )"
  },
  	"scaleY()": {
  	syntax: "scaleY( <number> )"
  },
  	"scaleZ()": {
  	syntax: "scaleZ( <number> )"
  },
  	"self-position": {
  	syntax: "center | start | end | self-start | self-end | flex-start | flex-end"
  },
  	"shape-radius": {
  	syntax: "<length-percentage> | closest-side | farthest-side"
  },
  	"skew()": {
  	syntax: "skew( [ <angle> | <zero> ] , [ <angle> | <zero> ]? )"
  },
  	"skewX()": {
  	syntax: "skewX( [ <angle> | <zero> ] )"
  },
  	"skewY()": {
  	syntax: "skewY( [ <angle> | <zero> ] )"
  },
  	"sepia()": {
  	syntax: "sepia( <number-percentage> )"
  },
  	shadow: shadow,
  	"shadow-t": {
  	syntax: "[ <length>{2,3} && <color>? ]"
  },
  	shape: shape,
  	"shape-box": {
  	syntax: "<box> | margin-box"
  },
  	"side-or-corner": {
  	syntax: "[ left | right ] || [ top | bottom ]"
  },
  	"single-animation": {
  	syntax: "<time> || <timing-function> || <time> || <single-animation-iteration-count> || <single-animation-direction> || <single-animation-fill-mode> || <single-animation-play-state> || [ none | <keyframes-name> ]"
  },
  	"single-animation-direction": {
  	syntax: "normal | reverse | alternate | alternate-reverse"
  },
  	"single-animation-fill-mode": {
  	syntax: "none | forwards | backwards | both"
  },
  	"single-animation-iteration-count": {
  	syntax: "infinite | <number>"
  },
  	"single-animation-play-state": {
  	syntax: "running | paused"
  },
  	"single-transition": {
  	syntax: "[ none | <single-transition-property> ] || <time> || <timing-function> || <time>"
  },
  	"single-transition-property": {
  	syntax: "all | <custom-ident>"
  },
  	size: size,
  	"step-position": {
  	syntax: "jump-start | jump-end | jump-none | jump-both | start | end"
  },
  	"step-timing-function": {
  	syntax: "step-start | step-end | steps(<integer>[, <step-position>]?)"
  },
  	"subclass-selector": {
  	syntax: "<id-selector> | <class-selector> | <attribute-selector> | <pseudo-class-selector>"
  },
  	"supports-condition": {
  	syntax: "not <supports-in-parens> | <supports-in-parens> [ and <supports-in-parens> ]* | <supports-in-parens> [ or <supports-in-parens> ]*"
  },
  	"supports-in-parens": {
  	syntax: "( <supports-condition> ) | <supports-feature> | <general-enclosed>"
  },
  	"supports-feature": {
  	syntax: "<supports-decl> | <supports-selector-fn>"
  },
  	"supports-decl": {
  	syntax: "( <declaration> )"
  },
  	"supports-selector-fn": {
  	syntax: "selector( <complex-selector> )"
  },
  	symbol: symbol,
  	target: target$1,
  	"target-counter()": {
  	syntax: "target-counter( [ <string> | <url> ] , <custom-ident> , <counter-style>? )"
  },
  	"target-counters()": {
  	syntax: "target-counters( [ <string> | <url> ] , <custom-ident> , <string> , <counter-style>? )"
  },
  	"target-text()": {
  	syntax: "target-text( [ <string> | <url> ] , [ content | before | after | first-letter ]? )"
  },
  	"time-percentage": {
  	syntax: "<time> | <percentage>"
  },
  	"timing-function": {
  	syntax: "linear | <cubic-bezier-timing-function> | <step-timing-function>"
  },
  	"track-breadth": {
  	syntax: "<length-percentage> | <flex> | min-content | max-content | auto"
  },
  	"track-list": {
  	syntax: "[ <line-names>? [ <track-size> | <track-repeat> ] ]+ <line-names>?"
  },
  	"track-repeat": {
  	syntax: "repeat( [ <positive-integer> ] , [ <line-names>? <track-size> ]+ <line-names>? )"
  },
  	"track-size": {
  	syntax: "<track-breadth> | minmax( <inflexible-breadth> , <track-breadth> ) | fit-content( [ <length> | <percentage> ] )"
  },
  	"transform-function": {
  	syntax: "<matrix()> | <translate()> | <translateX()> | <translateY()> | <scale()> | <scaleX()> | <scaleY()> | <rotate()> | <skew()> | <skewX()> | <skewY()> | <matrix3d()> | <translate3d()> | <translateZ()> | <scale3d()> | <scaleZ()> | <rotate3d()> | <rotateX()> | <rotateY()> | <rotateZ()> | <perspective()>"
  },
  	"transform-list": {
  	syntax: "<transform-function>+"
  },
  	"translate()": {
  	syntax: "translate( <length-percentage> , <length-percentage>? )"
  },
  	"translate3d()": {
  	syntax: "translate3d( <length-percentage> , <length-percentage> , <length> )"
  },
  	"translateX()": {
  	syntax: "translateX( <length-percentage> )"
  },
  	"translateY()": {
  	syntax: "translateY( <length-percentage> )"
  },
  	"translateZ()": {
  	syntax: "translateZ( <length> )"
  },
  	"type-or-unit": {
  	syntax: "string | color | url | integer | number | length | angle | time | frequency | cap | ch | em | ex | ic | lh | rlh | rem | vb | vi | vw | vh | vmin | vmax | mm | Q | cm | in | pt | pc | px | deg | grad | rad | turn | ms | s | Hz | kHz | %"
  },
  	"type-selector": {
  	syntax: "<wq-name> | <ns-prefix>? '*'"
  },
  	"var()": {
  	syntax: "var( <custom-property-name> , <declaration-value>? )"
  },
  	"viewport-length": {
  	syntax: "auto | <length-percentage>"
  },
  	"wq-name": {
  	syntax: "<ns-prefix>? <ident-token>"
  }
  };

  var atrules = {
  	charset: {
  		prelude: "<string>"
  	},
  	"font-face": {
  		descriptors: {
  			"unicode-range": {
  				comment: "replaces <unicode-range>, an old production name",
  				syntax: "<urange>#"
  			}
  		}
  	}
  };
  var properties = {
  	"-moz-background-clip": {
  		comment: "deprecated syntax in old Firefox, https://developer.mozilla.org/en/docs/Web/CSS/background-clip",
  		syntax: "padding | border"
  	},
  	"-moz-border-radius-bottomleft": {
  		comment: "https://developer.mozilla.org/en-US/docs/Web/CSS/border-bottom-left-radius",
  		syntax: "<'border-bottom-left-radius'>"
  	},
  	"-moz-border-radius-bottomright": {
  		comment: "https://developer.mozilla.org/en-US/docs/Web/CSS/border-bottom-right-radius",
  		syntax: "<'border-bottom-right-radius'>"
  	},
  	"-moz-border-radius-topleft": {
  		comment: "https://developer.mozilla.org/en-US/docs/Web/CSS/border-top-left-radius",
  		syntax: "<'border-top-left-radius'>"
  	},
  	"-moz-border-radius-topright": {
  		comment: "https://developer.mozilla.org/en-US/docs/Web/CSS/border-bottom-right-radius",
  		syntax: "<'border-bottom-right-radius'>"
  	},
  	"-moz-control-character-visibility": {
  		comment: "firefox specific keywords, https://bugzilla.mozilla.org/show_bug.cgi?id=947588",
  		syntax: "visible | hidden"
  	},
  	"-moz-osx-font-smoothing": {
  		comment: "misssed old syntax https://developer.mozilla.org/en-US/docs/Web/CSS/font-smooth",
  		syntax: "auto | grayscale"
  	},
  	"-moz-user-select": {
  		comment: "https://developer.mozilla.org/en-US/docs/Web/CSS/user-select",
  		syntax: "none | text | all | -moz-none"
  	},
  	"-ms-flex-align": {
  		comment: "misssed old syntax implemented in IE, https://www.w3.org/TR/2012/WD-css3-flexbox-20120322/#flex-align",
  		syntax: "start | end | center | baseline | stretch"
  	},
  	"-ms-flex-item-align": {
  		comment: "misssed old syntax implemented in IE, https://www.w3.org/TR/2012/WD-css3-flexbox-20120322/#flex-align",
  		syntax: "auto | start | end | center | baseline | stretch"
  	},
  	"-ms-flex-line-pack": {
  		comment: "misssed old syntax implemented in IE, https://www.w3.org/TR/2012/WD-css3-flexbox-20120322/#flex-line-pack",
  		syntax: "start | end | center | justify | distribute | stretch"
  	},
  	"-ms-flex-negative": {
  		comment: "misssed old syntax implemented in IE; TODO: find references for comfirmation",
  		syntax: "<'flex-shrink'>"
  	},
  	"-ms-flex-pack": {
  		comment: "misssed old syntax implemented in IE, https://www.w3.org/TR/2012/WD-css3-flexbox-20120322/#flex-pack",
  		syntax: "start | end | center | justify | distribute"
  	},
  	"-ms-flex-order": {
  		comment: "misssed old syntax implemented in IE; https://msdn.microsoft.com/en-us/library/jj127303(v=vs.85).aspx",
  		syntax: "<integer>"
  	},
  	"-ms-flex-positive": {
  		comment: "misssed old syntax implemented in IE; TODO: find references for comfirmation",
  		syntax: "<'flex-grow'>"
  	},
  	"-ms-flex-preferred-size": {
  		comment: "misssed old syntax implemented in IE; TODO: find references for comfirmation",
  		syntax: "<'flex-basis'>"
  	},
  	"-ms-interpolation-mode": {
  		comment: "https://msdn.microsoft.com/en-us/library/ff521095(v=vs.85).aspx",
  		syntax: "nearest-neighbor | bicubic"
  	},
  	"-ms-grid-column-align": {
  		comment: "add this property first since it uses as fallback for flexbox, https://msdn.microsoft.com/en-us/library/windows/apps/hh466338.aspx",
  		syntax: "start | end | center | stretch"
  	},
  	"-ms-grid-row-align": {
  		comment: "add this property first since it uses as fallback for flexbox, https://msdn.microsoft.com/en-us/library/windows/apps/hh466348.aspx",
  		syntax: "start | end | center | stretch"
  	},
  	"-ms-hyphenate-limit-last": {
  		comment: "misssed old syntax implemented in IE; https://www.w3.org/TR/css-text-4/#hyphenate-line-limits",
  		syntax: "none | always | column | page | spread"
  	},
  	"-webkit-appearance": {
  		comment: "webkit specific keywords",
  		references: [
  			"http://css-infos.net/property/-webkit-appearance"
  		],
  		syntax: "none | button | button-bevel | caps-lock-indicator | caret | checkbox | default-button | inner-spin-button | listbox | listitem | media-controls-background | media-controls-fullscreen-background | media-current-time-display | media-enter-fullscreen-button | media-exit-fullscreen-button | media-fullscreen-button | media-mute-button | media-overlay-play-button | media-play-button | media-seek-back-button | media-seek-forward-button | media-slider | media-sliderthumb | media-time-remaining-display | media-toggle-closed-captions-button | media-volume-slider | media-volume-slider-container | media-volume-sliderthumb | menulist | menulist-button | menulist-text | menulist-textfield | meter | progress-bar | progress-bar-value | push-button | radio | scrollbarbutton-down | scrollbarbutton-left | scrollbarbutton-right | scrollbarbutton-up | scrollbargripper-horizontal | scrollbargripper-vertical | scrollbarthumb-horizontal | scrollbarthumb-vertical | scrollbartrack-horizontal | scrollbartrack-vertical | searchfield | searchfield-cancel-button | searchfield-decoration | searchfield-results-button | searchfield-results-decoration | slider-horizontal | slider-vertical | sliderthumb-horizontal | sliderthumb-vertical | square-button | textarea | textfield | -apple-pay-button"
  	},
  	"-webkit-background-clip": {
  		comment: "https://developer.mozilla.org/en/docs/Web/CSS/background-clip",
  		syntax: "[ <box> | border | padding | content | text ]#"
  	},
  	"-webkit-column-break-after": {
  		comment: "added, http://help.dottoro.com/lcrthhhv.php",
  		syntax: "always | auto | avoid"
  	},
  	"-webkit-column-break-before": {
  		comment: "added, http://help.dottoro.com/lcxquvkf.php",
  		syntax: "always | auto | avoid"
  	},
  	"-webkit-column-break-inside": {
  		comment: "added, http://help.dottoro.com/lclhnthl.php",
  		syntax: "always | auto | avoid"
  	},
  	"-webkit-font-smoothing": {
  		comment: "https://developer.mozilla.org/en-US/docs/Web/CSS/font-smooth",
  		syntax: "auto | none | antialiased | subpixel-antialiased"
  	},
  	"-webkit-mask-box-image": {
  		comment: "missed; https://developer.mozilla.org/en-US/docs/Web/CSS/-webkit-mask-box-image",
  		syntax: "[ <url> | <gradient> | none ] [ <length-percentage>{4} <-webkit-mask-box-repeat>{2} ]?"
  	},
  	"-webkit-print-color-adjust": {
  		comment: "missed",
  		references: [
  			"https://developer.mozilla.org/en/docs/Web/CSS/-webkit-print-color-adjust"
  		],
  		syntax: "economy | exact"
  	},
  	"-webkit-text-security": {
  		comment: "missed; http://help.dottoro.com/lcbkewgt.php",
  		syntax: "none | circle | disc | square"
  	},
  	"-webkit-user-drag": {
  		comment: "missed; http://help.dottoro.com/lcbixvwm.php",
  		syntax: "none | element | auto"
  	},
  	"-webkit-user-select": {
  		comment: "auto is supported by old webkit, https://developer.mozilla.org/en-US/docs/Web/CSS/user-select",
  		syntax: "auto | none | text | all"
  	},
  	"alignment-baseline": {
  		comment: "added SVG property",
  		references: [
  			"https://www.w3.org/TR/SVG/text.html#AlignmentBaselineProperty"
  		],
  		syntax: "auto | baseline | before-edge | text-before-edge | middle | central | after-edge | text-after-edge | ideographic | alphabetic | hanging | mathematical"
  	},
  	"baseline-shift": {
  		comment: "added SVG property",
  		references: [
  			"https://www.w3.org/TR/SVG/text.html#BaselineShiftProperty"
  		],
  		syntax: "baseline | sub | super | <svg-length>"
  	},
  	behavior: {
  		comment: "added old IE property https://msdn.microsoft.com/en-us/library/ms530723(v=vs.85).aspx",
  		syntax: "<url>+"
  	},
  	"clip-rule": {
  		comment: "added SVG property",
  		references: [
  			"https://www.w3.org/TR/SVG/masking.html#ClipRuleProperty"
  		],
  		syntax: "nonzero | evenodd"
  	},
  	cue: {
  		comment: "https://www.w3.org/TR/css3-speech/#property-index",
  		syntax: "<'cue-before'> <'cue-after'>?"
  	},
  	"cue-after": {
  		comment: "https://www.w3.org/TR/css3-speech/#property-index",
  		syntax: "<url> <decibel>? | none"
  	},
  	"cue-before": {
  		comment: "https://www.w3.org/TR/css3-speech/#property-index",
  		syntax: "<url> <decibel>? | none"
  	},
  	cursor: {
  		comment: "added legacy keywords: hand, -webkit-grab. -webkit-grabbing, -webkit-zoom-in, -webkit-zoom-out, -moz-grab, -moz-grabbing, -moz-zoom-in, -moz-zoom-out",
  		references: [
  			"https://www.sitepoint.com/css3-cursor-styles/"
  		],
  		syntax: "[ [ <url> [ <x> <y> ]? , ]* [ auto | default | none | context-menu | help | pointer | progress | wait | cell | crosshair | text | vertical-text | alias | copy | move | no-drop | not-allowed | e-resize | n-resize | ne-resize | nw-resize | s-resize | se-resize | sw-resize | w-resize | ew-resize | ns-resize | nesw-resize | nwse-resize | col-resize | row-resize | all-scroll | zoom-in | zoom-out | grab | grabbing | hand | -webkit-grab | -webkit-grabbing | -webkit-zoom-in | -webkit-zoom-out | -moz-grab | -moz-grabbing | -moz-zoom-in | -moz-zoom-out ] ]"
  	},
  	display: {
  		comment: "extended with -ms-flexbox",
  		syntax: "| <-non-standard-display>"
  	},
  	position: {
  		comment: "extended with -webkit-sticky",
  		syntax: "| -webkit-sticky"
  	},
  	"dominant-baseline": {
  		comment: "added SVG property",
  		references: [
  			"https://www.w3.org/TR/SVG/text.html#DominantBaselineProperty"
  		],
  		syntax: "auto | use-script | no-change | reset-size | ideographic | alphabetic | hanging | mathematical | central | middle | text-after-edge | text-before-edge"
  	},
  	"image-rendering": {
  		comment: "extended with <-non-standard-image-rendering>, added SVG keywords optimizeSpeed and optimizeQuality",
  		references: [
  			"https://developer.mozilla.org/en/docs/Web/CSS/image-rendering",
  			"https://www.w3.org/TR/SVG/painting.html#ImageRenderingProperty"
  		],
  		syntax: "| optimizeSpeed | optimizeQuality | <-non-standard-image-rendering>"
  	},
  	fill: {
  		comment: "added SVG property",
  		references: [
  			"https://www.w3.org/TR/SVG/painting.html#FillProperty"
  		],
  		syntax: "<paint>"
  	},
  	"fill-opacity": {
  		comment: "added SVG property",
  		references: [
  			"https://www.w3.org/TR/SVG/painting.html#FillProperty"
  		],
  		syntax: "<number-zero-one>"
  	},
  	"fill-rule": {
  		comment: "added SVG property",
  		references: [
  			"https://www.w3.org/TR/SVG/painting.html#FillProperty"
  		],
  		syntax: "nonzero | evenodd"
  	},
  	filter: {
  		comment: "extend with IE legacy syntaxes",
  		syntax: "| <-ms-filter-function-list>"
  	},
  	"glyph-orientation-horizontal": {
  		comment: "added SVG property",
  		references: [
  			"https://www.w3.org/TR/SVG/text.html#GlyphOrientationHorizontalProperty"
  		],
  		syntax: "<angle>"
  	},
  	"glyph-orientation-vertical": {
  		comment: "added SVG property",
  		references: [
  			"https://www.w3.org/TR/SVG/text.html#GlyphOrientationVerticalProperty"
  		],
  		syntax: "<angle>"
  	},
  	kerning: {
  		comment: "added SVG property",
  		references: [
  			"https://www.w3.org/TR/SVG/text.html#KerningProperty"
  		],
  		syntax: "auto | <svg-length>"
  	},
  	"letter-spacing": {
  		comment: "fix syntax <length> -> <length-percentage>",
  		references: [
  			"https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/letter-spacing"
  		],
  		syntax: "normal | <length-percentage>"
  	},
  	marker: {
  		comment: "added SVG property",
  		references: [
  			"https://www.w3.org/TR/SVG/painting.html#MarkerProperties"
  		],
  		syntax: "none | <url>"
  	},
  	"marker-end": {
  		comment: "added SVG property",
  		references: [
  			"https://www.w3.org/TR/SVG/painting.html#MarkerProperties"
  		],
  		syntax: "none | <url>"
  	},
  	"marker-mid": {
  		comment: "added SVG property",
  		references: [
  			"https://www.w3.org/TR/SVG/painting.html#MarkerProperties"
  		],
  		syntax: "none | <url>"
  	},
  	"marker-start": {
  		comment: "added SVG property",
  		references: [
  			"https://www.w3.org/TR/SVG/painting.html#MarkerProperties"
  		],
  		syntax: "none | <url>"
  	},
  	"max-width": {
  		comment: "fix auto -> none (https://github.com/mdn/data/pull/431); extend by non-standard width keywords https://developer.mozilla.org/en-US/docs/Web/CSS/max-width",
  		syntax: "none | <length-percentage> | min-content | max-content | fit-content(<length-percentage>) | <-non-standard-width>"
  	},
  	width: {
  		comment: "per spec fit-content should be a function, however browsers are supporting it as a keyword (https://github.com/csstree/stylelint-validator/issues/29)",
  		syntax: "| fit-content | -moz-fit-content | -webkit-fit-content"
  	},
  	"min-width": {
  		comment: "extend by non-standard width keywords https://developer.mozilla.org/en-US/docs/Web/CSS/width",
  		syntax: "auto | <length-percentage> | min-content | max-content | fit-content(<length-percentage>) | <-non-standard-width>"
  	},
  	overflow: {
  		comment: "extend by vendor keywords https://developer.mozilla.org/en-US/docs/Web/CSS/overflow",
  		syntax: "| <-non-standard-overflow>"
  	},
  	pause: {
  		comment: "https://www.w3.org/TR/css3-speech/#property-index",
  		syntax: "<'pause-before'> <'pause-after'>?"
  	},
  	"pause-after": {
  		comment: "https://www.w3.org/TR/css3-speech/#property-index",
  		syntax: "<time> | none | x-weak | weak | medium | strong | x-strong"
  	},
  	"pause-before": {
  		comment: "https://www.w3.org/TR/css3-speech/#property-index",
  		syntax: "<time> | none | x-weak | weak | medium | strong | x-strong"
  	},
  	rest: {
  		comment: "https://www.w3.org/TR/css3-speech/#property-index",
  		syntax: "<'rest-before'> <'rest-after'>?"
  	},
  	"rest-after": {
  		comment: "https://www.w3.org/TR/css3-speech/#property-index",
  		syntax: "<time> | none | x-weak | weak | medium | strong | x-strong"
  	},
  	"rest-before": {
  		comment: "https://www.w3.org/TR/css3-speech/#property-index",
  		syntax: "<time> | none | x-weak | weak | medium | strong | x-strong"
  	},
  	"shape-rendering": {
  		comment: "added SVG property",
  		references: [
  			"https://www.w3.org/TR/SVG/painting.html#ShapeRenderingPropert"
  		],
  		syntax: "auto | optimizeSpeed | crispEdges | geometricPrecision"
  	},
  	src: {
  		comment: "added @font-face's src property https://developer.mozilla.org/en-US/docs/Web/CSS/@font-face/src",
  		syntax: "[ <url> [ format( <string># ) ]? | local( <family-name> ) ]#"
  	},
  	speak: {
  		comment: "https://www.w3.org/TR/css3-speech/#property-index",
  		syntax: "auto | none | normal"
  	},
  	"speak-as": {
  		comment: "https://www.w3.org/TR/css3-speech/#property-index",
  		syntax: "normal | spell-out || digits || [ literal-punctuation | no-punctuation ]"
  	},
  	stroke: {
  		comment: "added SVG property",
  		references: [
  			"https://www.w3.org/TR/SVG/painting.html#StrokeProperties"
  		],
  		syntax: "<paint>"
  	},
  	"stroke-dasharray": {
  		comment: "added SVG property; a list of comma and/or white space separated <length>s and <percentage>s",
  		references: [
  			"https://www.w3.org/TR/SVG/painting.html#StrokeProperties"
  		],
  		syntax: "none | [ <svg-length>+ ]#"
  	},
  	"stroke-dashoffset": {
  		comment: "added SVG property",
  		references: [
  			"https://www.w3.org/TR/SVG/painting.html#StrokeProperties"
  		],
  		syntax: "<svg-length>"
  	},
  	"stroke-linecap": {
  		comment: "added SVG property",
  		references: [
  			"https://www.w3.org/TR/SVG/painting.html#StrokeProperties"
  		],
  		syntax: "butt | round | square"
  	},
  	"stroke-linejoin": {
  		comment: "added SVG property",
  		references: [
  			"https://www.w3.org/TR/SVG/painting.html#StrokeProperties"
  		],
  		syntax: "miter | round | bevel"
  	},
  	"stroke-miterlimit": {
  		comment: "added SVG property (<miterlimit> = <number-one-or-greater>) ",
  		references: [
  			"https://www.w3.org/TR/SVG/painting.html#StrokeProperties"
  		],
  		syntax: "<number-one-or-greater>"
  	},
  	"stroke-opacity": {
  		comment: "added SVG property",
  		references: [
  			"https://www.w3.org/TR/SVG/painting.html#StrokeProperties"
  		],
  		syntax: "<number-zero-one>"
  	},
  	"stroke-width": {
  		comment: "added SVG property",
  		references: [
  			"https://www.w3.org/TR/SVG/painting.html#StrokeProperties"
  		],
  		syntax: "<svg-length>"
  	},
  	"text-anchor": {
  		comment: "added SVG property",
  		references: [
  			"https://www.w3.org/TR/SVG/text.html#TextAlignmentProperties"
  		],
  		syntax: "start | middle | end"
  	},
  	"unicode-bidi": {
  		comment: "added prefixed keywords https://developer.mozilla.org/en-US/docs/Web/CSS/unicode-bidi",
  		syntax: "| -moz-isolate | -moz-isolate-override | -moz-plaintext | -webkit-isolate | -webkit-isolate-override | -webkit-plaintext"
  	},
  	"unicode-range": {
  		comment: "added missed property https://developer.mozilla.org/en-US/docs/Web/CSS/%40font-face/unicode-range",
  		syntax: "<urange>#"
  	},
  	"voice-balance": {
  		comment: "https://www.w3.org/TR/css3-speech/#property-index",
  		syntax: "<number> | left | center | right | leftwards | rightwards"
  	},
  	"voice-duration": {
  		comment: "https://www.w3.org/TR/css3-speech/#property-index",
  		syntax: "auto | <time>"
  	},
  	"voice-family": {
  		comment: "<name> -> <family-name>, https://www.w3.org/TR/css3-speech/#property-index",
  		syntax: "[ [ <family-name> | <generic-voice> ] , ]* [ <family-name> | <generic-voice> ] | preserve"
  	},
  	"voice-pitch": {
  		comment: "https://www.w3.org/TR/css3-speech/#property-index",
  		syntax: "<frequency> && absolute | [ [ x-low | low | medium | high | x-high ] || [ <frequency> | <semitones> | <percentage> ] ]"
  	},
  	"voice-range": {
  		comment: "https://www.w3.org/TR/css3-speech/#property-index",
  		syntax: "<frequency> && absolute | [ [ x-low | low | medium | high | x-high ] || [ <frequency> | <semitones> | <percentage> ] ]"
  	},
  	"voice-rate": {
  		comment: "https://www.w3.org/TR/css3-speech/#property-index",
  		syntax: "[ normal | x-slow | slow | medium | fast | x-fast ] || <percentage>"
  	},
  	"voice-stress": {
  		comment: "https://www.w3.org/TR/css3-speech/#property-index",
  		syntax: "normal | strong | moderate | none | reduced"
  	},
  	"voice-volume": {
  		comment: "https://www.w3.org/TR/css3-speech/#property-index",
  		syntax: "silent | [ [ x-soft | soft | medium | loud | x-loud ] || <decibel> ]"
  	},
  	"writing-mode": {
  		comment: "extend with SVG keywords",
  		syntax: "| <svg-writing-mode>"
  	}
  };
  var syntaxes = {
  	"-legacy-gradient": {
  		comment: "added collection of legacy gradient syntaxes",
  		syntax: "<-webkit-gradient()> | <-legacy-linear-gradient> | <-legacy-repeating-linear-gradient> | <-legacy-radial-gradient> | <-legacy-repeating-radial-gradient>"
  	},
  	"-legacy-linear-gradient": {
  		comment: "like standard syntax but w/o `to` keyword https://developer.mozilla.org/en-US/docs/Web/CSS/linear-gradient",
  		syntax: "-moz-linear-gradient( <-legacy-linear-gradient-arguments> ) | -webkit-linear-gradient( <-legacy-linear-gradient-arguments> ) | -o-linear-gradient( <-legacy-linear-gradient-arguments> )"
  	},
  	"-legacy-repeating-linear-gradient": {
  		comment: "like standard syntax but w/o `to` keyword https://developer.mozilla.org/en-US/docs/Web/CSS/linear-gradient",
  		syntax: "-moz-repeating-linear-gradient( <-legacy-linear-gradient-arguments> ) | -webkit-repeating-linear-gradient( <-legacy-linear-gradient-arguments> ) | -o-repeating-linear-gradient( <-legacy-linear-gradient-arguments> )"
  	},
  	"-legacy-linear-gradient-arguments": {
  		comment: "like standard syntax but w/o `to` keyword https://developer.mozilla.org/en-US/docs/Web/CSS/linear-gradient",
  		syntax: "[ <angle> | <side-or-corner> ]? , <color-stop-list>"
  	},
  	"-legacy-radial-gradient": {
  		comment: "deprecated syntax that implemented by some browsers https://www.w3.org/TR/2011/WD-css3-images-20110908/#radial-gradients",
  		syntax: "-moz-radial-gradient( <-legacy-radial-gradient-arguments> ) | -webkit-radial-gradient( <-legacy-radial-gradient-arguments> ) | -o-radial-gradient( <-legacy-radial-gradient-arguments> )"
  	},
  	"-legacy-repeating-radial-gradient": {
  		comment: "deprecated syntax that implemented by some browsers https://www.w3.org/TR/2011/WD-css3-images-20110908/#radial-gradients",
  		syntax: "-moz-repeating-radial-gradient( <-legacy-radial-gradient-arguments> ) | -webkit-repeating-radial-gradient( <-legacy-radial-gradient-arguments> ) | -o-repeating-radial-gradient( <-legacy-radial-gradient-arguments> )"
  	},
  	"-legacy-radial-gradient-arguments": {
  		comment: "deprecated syntax that implemented by some browsers https://www.w3.org/TR/2011/WD-css3-images-20110908/#radial-gradients",
  		syntax: "[ <position> , ]? [ [ [ <-legacy-radial-gradient-shape> || <-legacy-radial-gradient-size> ] | [ <length> | <percentage> ]{2} ] , ]? <color-stop-list>"
  	},
  	"-legacy-radial-gradient-size": {
  		comment: "before a standard it contains 2 extra keywords (`contain` and `cover`) https://www.w3.org/TR/2011/WD-css3-images-20110908/#ltsize",
  		syntax: "closest-side | closest-corner | farthest-side | farthest-corner | contain | cover"
  	},
  	"-legacy-radial-gradient-shape": {
  		comment: "define to double sure it doesn't extends in future https://www.w3.org/TR/2011/WD-css3-images-20110908/#ltshape",
  		syntax: "circle | ellipse"
  	},
  	"-non-standard-font": {
  		comment: "non standard fonts",
  		references: [
  			"https://webkit.org/blog/3709/using-the-system-font-in-web-content/"
  		],
  		syntax: "-apple-system-body | -apple-system-headline | -apple-system-subheadline | -apple-system-caption1 | -apple-system-caption2 | -apple-system-footnote | -apple-system-short-body | -apple-system-short-headline | -apple-system-short-subheadline | -apple-system-short-caption1 | -apple-system-short-footnote | -apple-system-tall-body"
  	},
  	"-non-standard-color": {
  		comment: "non standard colors",
  		references: [
  			"http://cssdot.ru/%D0%A1%D0%BF%D1%80%D0%B0%D0%B2%D0%BE%D1%87%D0%BD%D0%B8%D0%BA_CSS/color-i305.html",
  			"https://developer.mozilla.org/en-US/docs/Web/CSS/color_value#Mozilla_Color_Preference_Extensions"
  		],
  		syntax: "-moz-ButtonDefault | -moz-ButtonHoverFace | -moz-ButtonHoverText | -moz-CellHighlight | -moz-CellHighlightText | -moz-Combobox | -moz-ComboboxText | -moz-Dialog | -moz-DialogText | -moz-dragtargetzone | -moz-EvenTreeRow | -moz-Field | -moz-FieldText | -moz-html-CellHighlight | -moz-html-CellHighlightText | -moz-mac-accentdarkestshadow | -moz-mac-accentdarkshadow | -moz-mac-accentface | -moz-mac-accentlightesthighlight | -moz-mac-accentlightshadow | -moz-mac-accentregularhighlight | -moz-mac-accentregularshadow | -moz-mac-chrome-active | -moz-mac-chrome-inactive | -moz-mac-focusring | -moz-mac-menuselect | -moz-mac-menushadow | -moz-mac-menutextselect | -moz-MenuHover | -moz-MenuHoverText | -moz-MenuBarText | -moz-MenuBarHoverText | -moz-nativehyperlinktext | -moz-OddTreeRow | -moz-win-communicationstext | -moz-win-mediatext | -moz-activehyperlinktext | -moz-default-background-color | -moz-default-color | -moz-hyperlinktext | -moz-visitedhyperlinktext | -webkit-activelink | -webkit-focus-ring-color | -webkit-link | -webkit-text"
  	},
  	"-non-standard-image-rendering": {
  		comment: "non-standard keywords http://phrogz.net/tmp/canvas_image_zoom.html",
  		syntax: "optimize-contrast | -moz-crisp-edges | -o-crisp-edges | -webkit-optimize-contrast"
  	},
  	"-non-standard-overflow": {
  		comment: "non-standard keywords https://developer.mozilla.org/en-US/docs/Web/CSS/overflow",
  		syntax: "-moz-scrollbars-none | -moz-scrollbars-horizontal | -moz-scrollbars-vertical | -moz-hidden-unscrollable"
  	},
  	"-non-standard-width": {
  		comment: "non-standard keywords https://developer.mozilla.org/en-US/docs/Web/CSS/width",
  		syntax: "fill-available | min-intrinsic | intrinsic | -moz-available | -moz-fit-content | -moz-min-content | -moz-max-content | -webkit-min-content | -webkit-max-content"
  	},
  	"-webkit-gradient()": {
  		comment: "first Apple proposal gradient syntax https://webkit.org/blog/175/introducing-css-gradients/ - TODO: simplify when after match algorithm improvement ( [, point, radius | , point] -> [, radius]? , point )",
  		syntax: "-webkit-gradient( <-webkit-gradient-type>, <-webkit-gradient-point> [, <-webkit-gradient-point> | , <-webkit-gradient-radius>, <-webkit-gradient-point> ] [, <-webkit-gradient-radius>]? [, <-webkit-gradient-color-stop>]* )"
  	},
  	"-webkit-gradient-color-stop": {
  		comment: "first Apple proposal gradient syntax https://webkit.org/blog/175/introducing-css-gradients/",
  		syntax: "from( <color> ) | color-stop( [ <number-zero-one> | <percentage> ] , <color> ) | to( <color> )"
  	},
  	"-webkit-gradient-point": {
  		comment: "first Apple proposal gradient syntax https://webkit.org/blog/175/introducing-css-gradients/",
  		syntax: "[ left | center | right | <length-percentage> ] [ top | center | bottom | <length-percentage> ]"
  	},
  	"-webkit-gradient-radius": {
  		comment: "first Apple proposal gradient syntax https://webkit.org/blog/175/introducing-css-gradients/",
  		syntax: "<length> | <percentage>"
  	},
  	"-webkit-gradient-type": {
  		comment: "first Apple proposal gradient syntax https://webkit.org/blog/175/introducing-css-gradients/",
  		syntax: "linear | radial"
  	},
  	"-webkit-mask-box-repeat": {
  		comment: "missed; https://developer.mozilla.org/en-US/docs/Web/CSS/-webkit-mask-box-image",
  		syntax: "repeat | stretch | round"
  	},
  	"-webkit-mask-clip-style": {
  		comment: "missed; there is no enough information about `-webkit-mask-clip` property, but looks like all those keywords are working",
  		syntax: "border | border-box | padding | padding-box | content | content-box | text"
  	},
  	"-ms-filter-function-list": {
  		comment: "https://developer.mozilla.org/en-US/docs/Web/CSS/-ms-filter",
  		syntax: "<-ms-filter-function>+"
  	},
  	"-ms-filter-function": {
  		comment: "https://developer.mozilla.org/en-US/docs/Web/CSS/-ms-filter",
  		syntax: "<-ms-filter-function-progid> | <-ms-filter-function-legacy>"
  	},
  	"-ms-filter-function-progid": {
  		comment: "https://developer.mozilla.org/en-US/docs/Web/CSS/-ms-filter",
  		syntax: "'progid:' [ <ident-token> '.' ]* [ <ident-token> | <function-token> <any-value>? ) ]"
  	},
  	"-ms-filter-function-legacy": {
  		comment: "https://developer.mozilla.org/en-US/docs/Web/CSS/-ms-filter",
  		syntax: "<ident-token> | <function-token> <any-value>? )"
  	},
  	"-ms-filter": {
  		syntax: "<string>"
  	},
  	age: {
  		comment: "https://www.w3.org/TR/css3-speech/#voice-family",
  		syntax: "child | young | old"
  	},
  	"attr-name": {
  		syntax: "<wq-name>"
  	},
  	"attr-fallback": {
  		syntax: "<any-value>"
  	},
  	"border-radius": {
  		comment: "missed, https://drafts.csswg.org/css-backgrounds-3/#the-border-radius",
  		syntax: "<length-percentage>{1,2}"
  	},
  	bottom: {
  		comment: "missed; not sure we should add it, but no others except `shape` is using it so it's ok for now; https://drafts.fxtf.org/css-masking-1/#funcdef-clip-rect",
  		syntax: "<length> | auto"
  	},
  	"content-list": {
  		comment: "missed -> https://drafts.csswg.org/css-content/#typedef-content-list (document-url, <target> and leader() is omitted util stabilization)",
  		syntax: "[ <string> | contents | <image> | <quote> | <target> | <leader()> | <attr()> | counter( <ident>, <'list-style-type'>? ) ]+"
  	},
  	"element()": {
  		comment: "https://drafts.csswg.org/css-gcpm/#element-syntax & https://drafts.csswg.org/css-images-4/#element-notation",
  		syntax: "element( <custom-ident> , [ first | start | last | first-except ]? ) | element( <id-selector> )"
  	},
  	"generic-voice": {
  		comment: "https://www.w3.org/TR/css3-speech/#voice-family",
  		syntax: "[ <age>? <gender> <integer>? ]"
  	},
  	gender: {
  		comment: "https://www.w3.org/TR/css3-speech/#voice-family",
  		syntax: "male | female | neutral"
  	},
  	"generic-family": {
  		comment: "added -apple-system",
  		references: [
  			"https://webkit.org/blog/3709/using-the-system-font-in-web-content/"
  		],
  		syntax: "| -apple-system"
  	},
  	gradient: {
  		comment: "added legacy syntaxes support",
  		syntax: "| <-legacy-gradient>"
  	},
  	left: {
  		comment: "missed; not sure we should add it, but no others except `shape` is using it so it's ok for now; https://drafts.fxtf.org/css-masking-1/#funcdef-clip-rect",
  		syntax: "<length> | auto"
  	},
  	"mask-image": {
  		comment: "missed; https://drafts.fxtf.org/css-masking-1/#the-mask-image",
  		syntax: "<mask-reference>#"
  	},
  	"name-repeat": {
  		comment: "missed, and looks like obsolete, keep it as is since other property syntaxes should be changed too; https://www.w3.org/TR/2015/WD-css-grid-1-20150917/#typedef-name-repeat",
  		syntax: "repeat( [ <positive-integer> | auto-fill ], <line-names>+)"
  	},
  	"named-color": {
  		comment: "added non standard color names",
  		syntax: "| <-non-standard-color>"
  	},
  	paint: {
  		comment: "used by SVG https://www.w3.org/TR/SVG/painting.html#SpecifyingPaint",
  		syntax: "none | <color> | <url> [ none | <color> ]? | context-fill | context-stroke"
  	},
  	"page-size": {
  		comment: "https://www.w3.org/TR/css-page-3/#typedef-page-size-page-size",
  		syntax: "A5 | A4 | A3 | B5 | B4 | JIS-B5 | JIS-B4 | letter | legal | ledger"
  	},
  	ratio: {
  		comment: "missed, https://drafts.csswg.org/mediaqueries-4/#typedef-ratio",
  		syntax: "<integer> / <integer>"
  	},
  	right: {
  		comment: "missed; not sure we should add it, but no others except `shape` is using it so it's ok for now; https://drafts.fxtf.org/css-masking-1/#funcdef-clip-rect",
  		syntax: "<length> | auto"
  	},
  	shape: {
  		comment: "missed spaces in function body and add backwards compatible syntax",
  		syntax: "rect( <top>, <right>, <bottom>, <left> ) | rect( <top> <right> <bottom> <left> )"
  	},
  	"svg-length": {
  		comment: "All coordinates and lengths in SVG can be specified with or without a unit identifier",
  		references: [
  			"https://www.w3.org/TR/SVG11/coords.html#Units"
  		],
  		syntax: "<percentage> | <length> | <number>"
  	},
  	"svg-writing-mode": {
  		comment: "SVG specific keywords (deprecated for CSS)",
  		references: [
  			"https://developer.mozilla.org/en/docs/Web/CSS/writing-mode",
  			"https://www.w3.org/TR/SVG/text.html#WritingModeProperty"
  		],
  		syntax: "lr-tb | rl-tb | tb-rl | lr | rl | tb"
  	},
  	top: {
  		comment: "missed; not sure we should add it, but no others except `shape` is using it so it's ok for now; https://drafts.fxtf.org/css-masking-1/#funcdef-clip-rect",
  		syntax: "<length> | auto"
  	},
  	"track-group": {
  		comment: "used by old grid-columns and grid-rows syntax v0",
  		syntax: "'(' [ <string>* <track-minmax> <string>* ]+ ')' [ '[' <positive-integer> ']' ]? | <track-minmax>"
  	},
  	"track-list-v0": {
  		comment: "used by old grid-columns and grid-rows syntax v0",
  		syntax: "[ <string>* <track-group> <string>* ]+ | none"
  	},
  	"track-minmax": {
  		comment: "used by old grid-columns and grid-rows syntax v0",
  		syntax: "minmax( <track-breadth> , <track-breadth> ) | auto | <track-breadth> | fit-content"
  	},
  	x: {
  		comment: "missed; not sure we should add it, but no others except `cursor` is using it so it's ok for now; https://drafts.csswg.org/css-ui-3/#cursor",
  		syntax: "<number>"
  	},
  	y: {
  		comment: "missed; not sure we should add it, but no others except `cursor` is using so it's ok for now; https://drafts.csswg.org/css-ui-3/#cursor",
  		syntax: "<number>"
  	},
  	declaration: {
  		comment: "missed, restored by https://drafts.csswg.org/css-syntax",
  		syntax: "<ident-token> : <declaration-value>? [ '!' important ]?"
  	},
  	"declaration-list": {
  		comment: "missed, restored by https://drafts.csswg.org/css-syntax",
  		syntax: "[ <declaration>? ';' ]* <declaration>?"
  	},
  	url: {
  		comment: "https://drafts.csswg.org/css-values-4/#urls",
  		syntax: "url( <string> <url-modifier>* ) | <url-token>"
  	},
  	"url-modifier": {
  		comment: "https://drafts.csswg.org/css-values-4/#typedef-url-modifier",
  		syntax: "<ident> | <function-token> <any-value> )"
  	},
  	"number-zero-one": {
  		syntax: "<number [0,1]>"
  	},
  	"number-one-or-greater": {
  		syntax: "<number [1,∞]>"
  	},
  	"positive-integer": {
  		syntax: "<integer [0,∞]>"
  	},
  	"-non-standard-display": {
  		syntax: "-ms-inline-flexbox | -ms-grid | -ms-inline-grid | -webkit-flex | -webkit-inline-flex | -webkit-box | -webkit-inline-box | -moz-inline-stack | -moz-box | -moz-inline-box"
  	}
  };
  var patch = {
  	atrules: atrules,
  	properties: properties,
  	syntaxes: syntaxes
  };

  const extendSyntax = /^\s*\|\s*/;

  function preprocessAtrules(dict) {
      const result = Object.create(null);

      for (const atruleName in dict) {
          const atrule = dict[atruleName];
          let descriptors = null;

          if (atrule.descriptors) {
              descriptors = Object.create(null);

              for (const descriptor in atrule.descriptors) {
                  descriptors[descriptor] = atrule.descriptors[descriptor].syntax;
              }
          }

          result[atruleName.substr(1)] = {
              prelude: atrule.syntax.trim().match(/^@\S+\s+([^;\{]*)/)[1].trim() || null,
              descriptors
          };
      }

      return result;
  }

  function patchDictionary(dict, patchDict) {
      const result = {};

      // copy all syntaxes for an original dict
      for (const key in dict) {
          result[key] = dict[key].syntax || dict[key];
      }

      // apply a patch
      for (const key in patchDict) {
          if (key in dict) {
              if (patchDict[key].syntax) {
                  result[key] = extendSyntax.test(patchDict[key].syntax)
                      ? result[key] + ' ' + patchDict[key].syntax.trim()
                      : patchDict[key].syntax;
              } else {
                  delete result[key];
              }
          } else {
              if (patchDict[key].syntax) {
                  result[key] = patchDict[key].syntax.replace(extendSyntax, '');
              }
          }
      }

      return result;
  }

  function unpackSyntaxes(dict) {
      const result = {};

      for (const key in dict) {
          result[key] = dict[key].syntax;
      }

      return result;
  }

  function patchAtrules(dict, patchDict) {
      const result = {};

      // copy all syntaxes for an original dict
      for (const key in dict) {
          const patchDescriptors = (patchDict[key] && patchDict[key].descriptors) || null;

          result[key] = {
              prelude: key in patchDict && 'prelude' in patchDict[key]
                  ? patchDict[key].prelude
                  : dict[key].prelude || null,
              descriptors: dict[key].descriptors
                  ? patchDictionary(dict[key].descriptors, patchDescriptors || {})
                  : patchDescriptors && unpackSyntaxes(patchDescriptors)
          };
      }

      // apply a patch
      for (const key in patchDict) {
          if (!hasOwnProperty.call(dict, key)) {
              result[key] = {
                  prelude: patchDict[key].prelude || null,
                  descriptors: patchDict[key].descriptors && unpackSyntaxes(patchDict[key].descriptors)
              };
          }
      }

      return result;
  }

  var data = {
      types: patchDictionary(mdnSyntaxes, patch.syntaxes),
      atrules: patchAtrules(preprocessAtrules(mdnAtrules), patch.atrules),
      properties: patchDictionary(mdnProperties, patch.properties)
  };

  var cmpChar$2 = tokenizer$1.cmpChar;
  var isDigit$1 = tokenizer$1.isDigit;
  var TYPE$y = tokenizer$1.TYPE;

  var WHITESPACE$8 = TYPE$y.WhiteSpace;
  var COMMENT$6 = TYPE$y.Comment;
  var IDENT$f = TYPE$y.Ident;
  var NUMBER$6 = TYPE$y.Number;
  var DIMENSION$5 = TYPE$y.Dimension;
  var PLUSSIGN$5 = 0x002B;    // U+002B PLUS SIGN (+)
  var HYPHENMINUS$2 = 0x002D; // U+002D HYPHEN-MINUS (-)
  var N = 0x006E;           // U+006E LATIN SMALL LETTER N (n)
  var DISALLOW_SIGN = true;
  var ALLOW_SIGN = false;

  function checkInteger(offset, disallowSign) {
      var pos = this.scanner.tokenStart + offset;
      var code = this.scanner.source.charCodeAt(pos);

      if (code === PLUSSIGN$5 || code === HYPHENMINUS$2) {
          if (disallowSign) {
              this.error('Number sign is not allowed');
          }
          pos++;
      }

      for (; pos < this.scanner.tokenEnd; pos++) {
          if (!isDigit$1(this.scanner.source.charCodeAt(pos))) {
              this.error('Integer is expected', pos);
          }
      }
  }

  function checkTokenIsInteger(disallowSign) {
      return checkInteger.call(this, 0, disallowSign);
  }

  function expectCharCode(offset, code) {
      if (!cmpChar$2(this.scanner.source, this.scanner.tokenStart + offset, code)) {
          var msg = '';

          switch (code) {
              case N:
                  msg = 'N is expected';
                  break;
              case HYPHENMINUS$2:
                  msg = 'HyphenMinus is expected';
                  break;
          }

          this.error(msg, this.scanner.tokenStart + offset);
      }
  }

  // ... <signed-integer>
  // ... ['+' | '-'] <signless-integer>
  function consumeB() {
      var offset = 0;
      var sign = 0;
      var type = this.scanner.tokenType;

      while (type === WHITESPACE$8 || type === COMMENT$6) {
          type = this.scanner.lookupType(++offset);
      }

      if (type !== NUMBER$6) {
          if (this.scanner.isDelim(PLUSSIGN$5, offset) ||
              this.scanner.isDelim(HYPHENMINUS$2, offset)) {
              sign = this.scanner.isDelim(PLUSSIGN$5, offset) ? PLUSSIGN$5 : HYPHENMINUS$2;

              do {
                  type = this.scanner.lookupType(++offset);
              } while (type === WHITESPACE$8 || type === COMMENT$6);

              if (type !== NUMBER$6) {
                  this.scanner.skip(offset);
                  checkTokenIsInteger.call(this, DISALLOW_SIGN);
              }
          } else {
              return null;
          }
      }

      if (offset > 0) {
          this.scanner.skip(offset);
      }

      if (sign === 0) {
          type = this.scanner.source.charCodeAt(this.scanner.tokenStart);
          if (type !== PLUSSIGN$5 && type !== HYPHENMINUS$2) {
              this.error('Number sign is expected');
          }
      }

      checkTokenIsInteger.call(this, sign !== 0);
      return sign === HYPHENMINUS$2 ? '-' + this.consume(NUMBER$6) : this.consume(NUMBER$6);
  }

  // An+B microsyntax https://www.w3.org/TR/css-syntax-3/#anb
  var AnPlusB = {
      name: 'AnPlusB',
      structure: {
          a: [String, null],
          b: [String, null]
      },
      parse: function() {
          /* eslint-disable brace-style*/
          var start = this.scanner.tokenStart;
          var a = null;
          var b = null;

          // <integer>
          if (this.scanner.tokenType === NUMBER$6) {
              checkTokenIsInteger.call(this, ALLOW_SIGN);
              b = this.consume(NUMBER$6);
          }

          // -n
          // -n <signed-integer>
          // -n ['+' | '-'] <signless-integer>
          // -n- <signless-integer>
          // <dashndashdigit-ident>
          else if (this.scanner.tokenType === IDENT$f && cmpChar$2(this.scanner.source, this.scanner.tokenStart, HYPHENMINUS$2)) {
              a = '-1';

              expectCharCode.call(this, 1, N);

              switch (this.scanner.getTokenLength()) {
                  // -n
                  // -n <signed-integer>
                  // -n ['+' | '-'] <signless-integer>
                  case 2:
                      this.scanner.next();
                      b = consumeB.call(this);
                      break;

                  // -n- <signless-integer>
                  case 3:
                      expectCharCode.call(this, 2, HYPHENMINUS$2);

                      this.scanner.next();
                      this.scanner.skipSC();

                      checkTokenIsInteger.call(this, DISALLOW_SIGN);

                      b = '-' + this.consume(NUMBER$6);
                      break;

                  // <dashndashdigit-ident>
                  default:
                      expectCharCode.call(this, 2, HYPHENMINUS$2);
                      checkInteger.call(this, 3, DISALLOW_SIGN);
                      this.scanner.next();

                      b = this.scanner.substrToCursor(start + 2);
              }
          }

          // '+'? n
          // '+'? n <signed-integer>
          // '+'? n ['+' | '-'] <signless-integer>
          // '+'? n- <signless-integer>
          // '+'? <ndashdigit-ident>
          else if (this.scanner.tokenType === IDENT$f || (this.scanner.isDelim(PLUSSIGN$5) && this.scanner.lookupType(1) === IDENT$f)) {
              var sign = 0;
              a = '1';

              // just ignore a plus
              if (this.scanner.isDelim(PLUSSIGN$5)) {
                  sign = 1;
                  this.scanner.next();
              }

              expectCharCode.call(this, 0, N);

              switch (this.scanner.getTokenLength()) {
                  // '+'? n
                  // '+'? n <signed-integer>
                  // '+'? n ['+' | '-'] <signless-integer>
                  case 1:
                      this.scanner.next();
                      b = consumeB.call(this);
                      break;

                  // '+'? n- <signless-integer>
                  case 2:
                      expectCharCode.call(this, 1, HYPHENMINUS$2);

                      this.scanner.next();
                      this.scanner.skipSC();

                      checkTokenIsInteger.call(this, DISALLOW_SIGN);

                      b = '-' + this.consume(NUMBER$6);
                      break;

                  // '+'? <ndashdigit-ident>
                  default:
                      expectCharCode.call(this, 1, HYPHENMINUS$2);
                      checkInteger.call(this, 2, DISALLOW_SIGN);
                      this.scanner.next();

                      b = this.scanner.substrToCursor(start + sign + 1);
              }
          }

          // <ndashdigit-dimension>
          // <ndash-dimension> <signless-integer>
          // <n-dimension>
          // <n-dimension> <signed-integer>
          // <n-dimension> ['+' | '-'] <signless-integer>
          else if (this.scanner.tokenType === DIMENSION$5) {
              var code = this.scanner.source.charCodeAt(this.scanner.tokenStart);
              var sign = code === PLUSSIGN$5 || code === HYPHENMINUS$2;

              for (var i = this.scanner.tokenStart + sign; i < this.scanner.tokenEnd; i++) {
                  if (!isDigit$1(this.scanner.source.charCodeAt(i))) {
                      break;
                  }
              }

              if (i === this.scanner.tokenStart + sign) {
                  this.error('Integer is expected', this.scanner.tokenStart + sign);
              }

              expectCharCode.call(this, i - this.scanner.tokenStart, N);
              a = this.scanner.source.substring(start, i);

              // <n-dimension>
              // <n-dimension> <signed-integer>
              // <n-dimension> ['+' | '-'] <signless-integer>
              if (i + 1 === this.scanner.tokenEnd) {
                  this.scanner.next();
                  b = consumeB.call(this);
              } else {
                  expectCharCode.call(this, i - this.scanner.tokenStart + 1, HYPHENMINUS$2);

                  // <ndash-dimension> <signless-integer>
                  if (i + 2 === this.scanner.tokenEnd) {
                      this.scanner.next();
                      this.scanner.skipSC();
                      checkTokenIsInteger.call(this, DISALLOW_SIGN);
                      b = '-' + this.consume(NUMBER$6);
                  }
                  // <ndashdigit-dimension>
                  else {
                      checkInteger.call(this, i - this.scanner.tokenStart + 2, DISALLOW_SIGN);
                      this.scanner.next();
                      b = this.scanner.substrToCursor(i + 1);
                  }
              }
          } else {
              this.error();
          }

          if (a !== null && a.charCodeAt(0) === PLUSSIGN$5) {
              a = a.substr(1);
          }

          if (b !== null && b.charCodeAt(0) === PLUSSIGN$5) {
              b = b.substr(1);
          }

          return {
              type: 'AnPlusB',
              loc: this.getLocation(start, this.scanner.tokenStart),
              a: a,
              b: b
          };
      },
      generate: function(node) {
          var a = node.a !== null && node.a !== undefined;
          var b = node.b !== null && node.b !== undefined;

          if (a) {
              this.chunk(
                  node.a === '+1' ? '+n' : // eslint-disable-line operator-linebreak, indent
                  node.a ===  '1' ?  'n' : // eslint-disable-line operator-linebreak, indent
                  node.a === '-1' ? '-n' : // eslint-disable-line operator-linebreak, indent
                  node.a + 'n'             // eslint-disable-line operator-linebreak, indent
              );

              if (b) {
                  b = String(node.b);
                  if (b.charAt(0) === '-' || b.charAt(0) === '+') {
                      this.chunk(b.charAt(0));
                      this.chunk(b.substr(1));
                  } else {
                      this.chunk('+');
                      this.chunk(b);
                  }
              }
          } else {
              this.chunk(String(node.b));
          }
      }
  };

  var TYPE$x = tokenizer$1.TYPE;

  var WhiteSpace$1 = TYPE$x.WhiteSpace;
  var Semicolon = TYPE$x.Semicolon;
  var LeftCurlyBracket = TYPE$x.LeftCurlyBracket;
  var Delim = TYPE$x.Delim;
  var EXCLAMATIONMARK$2 = 0x0021; // U+0021 EXCLAMATION MARK (!)

  function getOffsetExcludeWS() {
      if (this.scanner.tokenIndex > 0) {
          if (this.scanner.lookupType(-1) === WhiteSpace$1) {
              return this.scanner.tokenIndex > 1
                  ? this.scanner.getTokenStart(this.scanner.tokenIndex - 1)
                  : this.scanner.firstCharOffset;
          }
      }

      return this.scanner.tokenStart;
  }

  // 0, 0, false
  function balanceEnd() {
      return 0;
  }

  // LEFTCURLYBRACKET, 0, false
  function leftCurlyBracket(tokenType) {
      return tokenType === LeftCurlyBracket ? 1 : 0;
  }

  // LEFTCURLYBRACKET, SEMICOLON, false
  function leftCurlyBracketOrSemicolon(tokenType) {
      return tokenType === LeftCurlyBracket || tokenType === Semicolon ? 1 : 0;
  }

  // EXCLAMATIONMARK, SEMICOLON, false
  function exclamationMarkOrSemicolon(tokenType, source, offset) {
      if (tokenType === Delim && source.charCodeAt(offset) === EXCLAMATIONMARK$2) {
          return 1;
      }

      return tokenType === Semicolon ? 1 : 0;
  }

  // 0, SEMICOLON, true
  function semicolonIncluded(tokenType) {
      return tokenType === Semicolon ? 2 : 0;
  }

  var Raw = {
      name: 'Raw',
      structure: {
          value: String
      },
      parse: function(startToken, mode, excludeWhiteSpace) {
          var startOffset = this.scanner.getTokenStart(startToken);
          var endOffset;

          this.scanner.skip(
              this.scanner.getRawLength(startToken, mode || balanceEnd)
          );

          if (excludeWhiteSpace && this.scanner.tokenStart > startOffset) {
              endOffset = getOffsetExcludeWS.call(this);
          } else {
              endOffset = this.scanner.tokenStart;
          }

          return {
              type: 'Raw',
              loc: this.getLocation(startOffset, endOffset),
              value: this.scanner.source.substring(startOffset, endOffset)
          };
      },
      generate: function(node) {
          this.chunk(node.value);
      },

      mode: {
          default: balanceEnd,
          leftCurlyBracket: leftCurlyBracket,
          leftCurlyBracketOrSemicolon: leftCurlyBracketOrSemicolon,
          exclamationMarkOrSemicolon: exclamationMarkOrSemicolon,
          semicolonIncluded: semicolonIncluded
      }
  };

  var TYPE$w = tokenizer$1.TYPE;
  var rawMode$5 = Raw.mode;

  var ATKEYWORD$2 = TYPE$w.AtKeyword;
  var SEMICOLON$4 = TYPE$w.Semicolon;
  var LEFTCURLYBRACKET$3 = TYPE$w.LeftCurlyBracket;
  var RIGHTCURLYBRACKET$1 = TYPE$w.RightCurlyBracket;

  function consumeRaw$5(startToken) {
      return this.Raw(startToken, rawMode$5.leftCurlyBracketOrSemicolon, true);
  }

  function isDeclarationBlockAtrule() {
      for (var offset = 1, type; type = this.scanner.lookupType(offset); offset++) {
          if (type === RIGHTCURLYBRACKET$1) {
              return true;
          }

          if (type === LEFTCURLYBRACKET$3 ||
              type === ATKEYWORD$2) {
              return false;
          }
      }

      return false;
  }

  var Atrule = {
      name: 'Atrule',
      structure: {
          name: String,
          prelude: ['AtrulePrelude', 'Raw', null],
          block: ['Block', null]
      },
      parse: function() {
          var start = this.scanner.tokenStart;
          var name;
          var nameLowerCase;
          var prelude = null;
          var block = null;

          this.eat(ATKEYWORD$2);

          name = this.scanner.substrToCursor(start + 1);
          nameLowerCase = name.toLowerCase();
          this.scanner.skipSC();

          // parse prelude
          if (this.scanner.eof === false &&
              this.scanner.tokenType !== LEFTCURLYBRACKET$3 &&
              this.scanner.tokenType !== SEMICOLON$4) {
              if (this.parseAtrulePrelude) {
                  prelude = this.parseWithFallback(this.AtrulePrelude.bind(this, name), consumeRaw$5);

                  // turn empty AtrulePrelude into null
                  if (prelude.type === 'AtrulePrelude' && prelude.children.head === null) {
                      prelude = null;
                  }
              } else {
                  prelude = consumeRaw$5.call(this, this.scanner.tokenIndex);
              }

              this.scanner.skipSC();
          }

          switch (this.scanner.tokenType) {
              case SEMICOLON$4:
                  this.scanner.next();
                  break;

              case LEFTCURLYBRACKET$3:
                  if (this.atrule.hasOwnProperty(nameLowerCase) &&
                      typeof this.atrule[nameLowerCase].block === 'function') {
                      block = this.atrule[nameLowerCase].block.call(this);
                  } else {
                      // TODO: should consume block content as Raw?
                      block = this.Block(isDeclarationBlockAtrule.call(this));
                  }

                  break;
          }

          return {
              type: 'Atrule',
              loc: this.getLocation(start, this.scanner.tokenStart),
              name: name,
              prelude: prelude,
              block: block
          };
      },
      generate: function(node) {
          this.chunk('@');
          this.chunk(node.name);

          if (node.prelude !== null) {
              this.chunk(' ');
              this.node(node.prelude);
          }

          if (node.block) {
              this.node(node.block);
          } else {
              this.chunk(';');
          }
      },
      walkContext: 'atrule'
  };

  var TYPE$v = tokenizer$1.TYPE;

  var SEMICOLON$3 = TYPE$v.Semicolon;
  var LEFTCURLYBRACKET$2 = TYPE$v.LeftCurlyBracket;

  var AtrulePrelude = {
      name: 'AtrulePrelude',
      structure: {
          children: [[]]
      },
      parse: function(name) {
          var children = null;

          if (name !== null) {
              name = name.toLowerCase();
          }

          this.scanner.skipSC();

          if (this.atrule.hasOwnProperty(name) &&
              typeof this.atrule[name].prelude === 'function') {
              // custom consumer
              children = this.atrule[name].prelude.call(this);
          } else {
              // default consumer
              children = this.readSequence(this.scope.AtrulePrelude);
          }

          this.scanner.skipSC();

          if (this.scanner.eof !== true &&
              this.scanner.tokenType !== LEFTCURLYBRACKET$2 &&
              this.scanner.tokenType !== SEMICOLON$3) {
              this.error('Semicolon or block is expected');
          }

          if (children === null) {
              children = this.createList();
          }

          return {
              type: 'AtrulePrelude',
              loc: this.getLocationFromList(children),
              children: children
          };
      },
      generate: function(node) {
          this.children(node);
      },
      walkContext: 'atrulePrelude'
  };

  var TYPE$u = tokenizer$1.TYPE;

  var IDENT$e = TYPE$u.Ident;
  var STRING$3 = TYPE$u.String;
  var COLON$6 = TYPE$u.Colon;
  var LEFTSQUAREBRACKET$3 = TYPE$u.LeftSquareBracket;
  var RIGHTSQUAREBRACKET$1 = TYPE$u.RightSquareBracket;
  var DOLLARSIGN$1 = 0x0024;       // U+0024 DOLLAR SIGN ($)
  var ASTERISK$5 = 0x002A;         // U+002A ASTERISK (*)
  var EQUALSSIGN = 0x003D;       // U+003D EQUALS SIGN (=)
  var CIRCUMFLEXACCENT = 0x005E; // U+005E (^)
  var VERTICALLINE$2 = 0x007C;     // U+007C VERTICAL LINE (|)
  var TILDE$2 = 0x007E;            // U+007E TILDE (~)

  function getAttributeName() {
      if (this.scanner.eof) {
          this.error('Unexpected end of input');
      }

      var start = this.scanner.tokenStart;
      var expectIdent = false;
      var checkColon = true;

      if (this.scanner.isDelim(ASTERISK$5)) {
          expectIdent = true;
          checkColon = false;
          this.scanner.next();
      } else if (!this.scanner.isDelim(VERTICALLINE$2)) {
          this.eat(IDENT$e);
      }

      if (this.scanner.isDelim(VERTICALLINE$2)) {
          if (this.scanner.source.charCodeAt(this.scanner.tokenStart + 1) !== EQUALSSIGN) {
              this.scanner.next();
              this.eat(IDENT$e);
          } else if (expectIdent) {
              this.error('Identifier is expected', this.scanner.tokenEnd);
          }
      } else if (expectIdent) {
          this.error('Vertical line is expected');
      }

      if (checkColon && this.scanner.tokenType === COLON$6) {
          this.scanner.next();
          this.eat(IDENT$e);
      }

      return {
          type: 'Identifier',
          loc: this.getLocation(start, this.scanner.tokenStart),
          name: this.scanner.substrToCursor(start)
      };
  }

  function getOperator() {
      var start = this.scanner.tokenStart;
      var code = this.scanner.source.charCodeAt(start);

      if (code !== EQUALSSIGN &&        // =
          code !== TILDE$2 &&             // ~=
          code !== CIRCUMFLEXACCENT &&  // ^=
          code !== DOLLARSIGN$1 &&        // $=
          code !== ASTERISK$5 &&          // *=
          code !== VERTICALLINE$2         // |=
      ) {
          this.error('Attribute selector (=, ~=, ^=, $=, *=, |=) is expected');
      }

      this.scanner.next();

      if (code !== EQUALSSIGN) {
          if (!this.scanner.isDelim(EQUALSSIGN)) {
              this.error('Equal sign is expected');
          }

          this.scanner.next();
      }

      return this.scanner.substrToCursor(start);
  }

  // '[' <wq-name> ']'
  // '[' <wq-name> <attr-matcher> [ <string-token> | <ident-token> ] <attr-modifier>? ']'
  var AttributeSelector = {
      name: 'AttributeSelector',
      structure: {
          name: 'Identifier',
          matcher: [String, null],
          value: ['String', 'Identifier', null],
          flags: [String, null]
      },
      parse: function() {
          var start = this.scanner.tokenStart;
          var name;
          var matcher = null;
          var value = null;
          var flags = null;

          this.eat(LEFTSQUAREBRACKET$3);
          this.scanner.skipSC();

          name = getAttributeName.call(this);
          this.scanner.skipSC();

          if (this.scanner.tokenType !== RIGHTSQUAREBRACKET$1) {
              // avoid case `[name i]`
              if (this.scanner.tokenType !== IDENT$e) {
                  matcher = getOperator.call(this);

                  this.scanner.skipSC();

                  value = this.scanner.tokenType === STRING$3
                      ? this.String()
                      : this.Identifier();

                  this.scanner.skipSC();
              }

              // attribute flags
              if (this.scanner.tokenType === IDENT$e) {
                  flags = this.scanner.getTokenValue();
                  this.scanner.next();

                  this.scanner.skipSC();
              }
          }

          this.eat(RIGHTSQUAREBRACKET$1);

          return {
              type: 'AttributeSelector',
              loc: this.getLocation(start, this.scanner.tokenStart),
              name: name,
              matcher: matcher,
              value: value,
              flags: flags
          };
      },
      generate: function(node) {
          var flagsPrefix = ' ';

          this.chunk('[');
          this.node(node.name);

          if (node.matcher !== null) {
              this.chunk(node.matcher);

              if (node.value !== null) {
                  this.node(node.value);

                  // space between string and flags is not required
                  if (node.value.type === 'String') {
                      flagsPrefix = '';
                  }
              }
          }

          if (node.flags !== null) {
              this.chunk(flagsPrefix);
              this.chunk(node.flags);
          }

          this.chunk(']');
      }
  };

  var TYPE$t = tokenizer$1.TYPE;
  var rawMode$4 = Raw.mode;

  var WHITESPACE$7 = TYPE$t.WhiteSpace;
  var COMMENT$5 = TYPE$t.Comment;
  var SEMICOLON$2 = TYPE$t.Semicolon;
  var ATKEYWORD$1 = TYPE$t.AtKeyword;
  var LEFTCURLYBRACKET$1 = TYPE$t.LeftCurlyBracket;
  var RIGHTCURLYBRACKET = TYPE$t.RightCurlyBracket;

  function consumeRaw$4(startToken) {
      return this.Raw(startToken, null, true);
  }
  function consumeRule() {
      return this.parseWithFallback(this.Rule, consumeRaw$4);
  }
  function consumeRawDeclaration(startToken) {
      return this.Raw(startToken, rawMode$4.semicolonIncluded, true);
  }
  function consumeDeclaration() {
      if (this.scanner.tokenType === SEMICOLON$2) {
          return consumeRawDeclaration.call(this, this.scanner.tokenIndex);
      }

      var node = this.parseWithFallback(this.Declaration, consumeRawDeclaration);

      if (this.scanner.tokenType === SEMICOLON$2) {
          this.scanner.next();
      }

      return node;
  }

  var Block = {
      name: 'Block',
      structure: {
          children: [[
              'Atrule',
              'Rule',
              'Declaration'
          ]]
      },
      parse: function(isDeclaration) {
          var consumer = isDeclaration ? consumeDeclaration : consumeRule;

          var start = this.scanner.tokenStart;
          var children = this.createList();

          this.eat(LEFTCURLYBRACKET$1);

          scan:
          while (!this.scanner.eof) {
              switch (this.scanner.tokenType) {
                  case RIGHTCURLYBRACKET:
                      break scan;

                  case WHITESPACE$7:
                  case COMMENT$5:
                      this.scanner.next();
                      break;

                  case ATKEYWORD$1:
                      children.push(this.parseWithFallback(this.Atrule, consumeRaw$4));
                      break;

                  default:
                      children.push(consumer.call(this));
              }
          }

          if (!this.scanner.eof) {
              this.eat(RIGHTCURLYBRACKET);
          }

          return {
              type: 'Block',
              loc: this.getLocation(start, this.scanner.tokenStart),
              children: children
          };
      },
      generate: function(node) {
          this.chunk('{');
          this.children(node, function(prev) {
              if (prev.type === 'Declaration') {
                  this.chunk(';');
              }
          });
          this.chunk('}');
      },
      walkContext: 'block'
  };

  var TYPE$s = tokenizer$1.TYPE;

  var LEFTSQUAREBRACKET$2 = TYPE$s.LeftSquareBracket;
  var RIGHTSQUAREBRACKET = TYPE$s.RightSquareBracket;

  var Brackets = {
      name: 'Brackets',
      structure: {
          children: [[]]
      },
      parse: function(readSequence, recognizer) {
          var start = this.scanner.tokenStart;
          var children = null;

          this.eat(LEFTSQUAREBRACKET$2);

          children = readSequence.call(this, recognizer);

          if (!this.scanner.eof) {
              this.eat(RIGHTSQUAREBRACKET);
          }

          return {
              type: 'Brackets',
              loc: this.getLocation(start, this.scanner.tokenStart),
              children: children
          };
      },
      generate: function(node) {
          this.chunk('[');
          this.children(node);
          this.chunk(']');
      }
  };

  var CDC$1 = tokenizer$1.TYPE.CDC;

  var CDC_1 = {
      name: 'CDC',
      structure: [],
      parse: function() {
          var start = this.scanner.tokenStart;

          this.eat(CDC$1); // -->

          return {
              type: 'CDC',
              loc: this.getLocation(start, this.scanner.tokenStart)
          };
      },
      generate: function() {
          this.chunk('-->');
      }
  };

  var CDO$1 = tokenizer$1.TYPE.CDO;

  var CDO_1 = {
      name: 'CDO',
      structure: [],
      parse: function() {
          var start = this.scanner.tokenStart;

          this.eat(CDO$1); // <!--

          return {
              type: 'CDO',
              loc: this.getLocation(start, this.scanner.tokenStart)
          };
      },
      generate: function() {
          this.chunk('<!--');
      }
  };

  var TYPE$r = tokenizer$1.TYPE;

  var IDENT$d = TYPE$r.Ident;
  var FULLSTOP$2 = 0x002E; // U+002E FULL STOP (.)

  // '.' ident
  var ClassSelector = {
      name: 'ClassSelector',
      structure: {
          name: String
      },
      parse: function() {
          if (!this.scanner.isDelim(FULLSTOP$2)) {
              this.error('Full stop is expected');
          }

          this.scanner.next();

          return {
              type: 'ClassSelector',
              loc: this.getLocation(this.scanner.tokenStart - 1, this.scanner.tokenEnd),
              name: this.consume(IDENT$d)
          };
      },
      generate: function(node) {
          this.chunk('.');
          this.chunk(node.name);
      }
  };

  var TYPE$q = tokenizer$1.TYPE;

  var IDENT$c = TYPE$q.Ident;
  var PLUSSIGN$4 = 0x002B;        // U+002B PLUS SIGN (+)
  var SOLIDUS$5 = 0x002F;         // U+002F SOLIDUS (/)
  var GREATERTHANSIGN$1 = 0x003E; // U+003E GREATER-THAN SIGN (>)
  var TILDE$1 = 0x007E;           // U+007E TILDE (~)

  // + | > | ~ | /deep/
  var Combinator = {
      name: 'Combinator',
      structure: {
          name: String
      },
      parse: function() {
          var start = this.scanner.tokenStart;
          var code = this.scanner.source.charCodeAt(this.scanner.tokenStart);

          switch (code) {
              case GREATERTHANSIGN$1:
              case PLUSSIGN$4:
              case TILDE$1:
                  this.scanner.next();
                  break;

              case SOLIDUS$5:
                  this.scanner.next();

                  if (this.scanner.tokenType !== IDENT$c || this.scanner.lookupValue(0, 'deep') === false) {
                      this.error('Identifier `deep` is expected');
                  }

                  this.scanner.next();

                  if (!this.scanner.isDelim(SOLIDUS$5)) {
                      this.error('Solidus is expected');
                  }

                  this.scanner.next();
                  break;

              default:
                  this.error('Combinator is expected');
          }

          return {
              type: 'Combinator',
              loc: this.getLocation(start, this.scanner.tokenStart),
              name: this.scanner.substrToCursor(start)
          };
      },
      generate: function(node) {
          this.chunk(node.name);
      }
  };

  var TYPE$p = tokenizer$1.TYPE;

  var COMMENT$4 = TYPE$p.Comment;
  var ASTERISK$4 = 0x002A;        // U+002A ASTERISK (*)
  var SOLIDUS$4 = 0x002F;         // U+002F SOLIDUS (/)

  // '/*' .* '*/'
  var Comment = {
      name: 'Comment',
      structure: {
          value: String
      },
      parse: function() {
          var start = this.scanner.tokenStart;
          var end = this.scanner.tokenEnd;

          this.eat(COMMENT$4);

          if ((end - start + 2) >= 2 &&
              this.scanner.source.charCodeAt(end - 2) === ASTERISK$4 &&
              this.scanner.source.charCodeAt(end - 1) === SOLIDUS$4) {
              end -= 2;
          }

          return {
              type: 'Comment',
              loc: this.getLocation(start, this.scanner.tokenStart),
              value: this.scanner.source.substring(start + 2, end)
          };
      },
      generate: function(node) {
          this.chunk('/*');
          this.chunk(node.value);
          this.chunk('*/');
      }
  };

  var isCustomProperty = names.isCustomProperty;
  var TYPE$o = tokenizer$1.TYPE;
  var rawMode$3 = Raw.mode;

  var IDENT$b = TYPE$o.Ident;
  var HASH$4 = TYPE$o.Hash;
  var COLON$5 = TYPE$o.Colon;
  var SEMICOLON$1 = TYPE$o.Semicolon;
  var DELIM$4 = TYPE$o.Delim;
  var WHITESPACE$6 = TYPE$o.WhiteSpace;
  var EXCLAMATIONMARK$1 = 0x0021; // U+0021 EXCLAMATION MARK (!)
  var NUMBERSIGN$2 = 0x0023;      // U+0023 NUMBER SIGN (#)
  var DOLLARSIGN = 0x0024;      // U+0024 DOLLAR SIGN ($)
  var AMPERSAND = 0x0026;       // U+0026 ANPERSAND (&)
  var ASTERISK$3 = 0x002A;        // U+002A ASTERISK (*)
  var PLUSSIGN$3 = 0x002B;        // U+002B PLUS SIGN (+)
  var SOLIDUS$3 = 0x002F;         // U+002F SOLIDUS (/)

  function consumeValueRaw(startToken) {
      return this.Raw(startToken, rawMode$3.exclamationMarkOrSemicolon, true);
  }

  function consumeCustomPropertyRaw(startToken) {
      return this.Raw(startToken, rawMode$3.exclamationMarkOrSemicolon, false);
  }

  function consumeValue() {
      var startValueToken = this.scanner.tokenIndex;
      var value = this.Value();

      if (value.type !== 'Raw' &&
          this.scanner.eof === false &&
          this.scanner.tokenType !== SEMICOLON$1 &&
          this.scanner.isDelim(EXCLAMATIONMARK$1) === false &&
          this.scanner.isBalanceEdge(startValueToken) === false) {
          this.error();
      }

      return value;
  }

  var Declaration = {
      name: 'Declaration',
      structure: {
          important: [Boolean, String],
          property: String,
          value: ['Value', 'Raw']
      },
      parse: function() {
          var start = this.scanner.tokenStart;
          var startToken = this.scanner.tokenIndex;
          var property = readProperty.call(this);
          var customProperty = isCustomProperty(property);
          var parseValue = customProperty ? this.parseCustomProperty : this.parseValue;
          var consumeRaw = customProperty ? consumeCustomPropertyRaw : consumeValueRaw;
          var important = false;
          var value;

          this.scanner.skipSC();
          this.eat(COLON$5);

          const valueStart = this.scanner.tokenIndex;

          if (!customProperty) {
              this.scanner.skipSC();
          }

          if (parseValue) {
              value = this.parseWithFallback(consumeValue, consumeRaw);
          } else {
              value = consumeRaw.call(this, this.scanner.tokenIndex);
          }

          if (customProperty && value.type === 'Value' && value.children.isEmpty()) {
              for (let offset = valueStart - this.scanner.tokenIndex; offset <= 0; offset++) {
                  if (this.scanner.lookupType(offset) === WHITESPACE$6) {
                      value.children.appendData({
                          type: 'WhiteSpace',
                          loc: null,
                          value: ' '
                      });
                      break;
                  }
              }
          }

          if (this.scanner.isDelim(EXCLAMATIONMARK$1)) {
              important = getImportant.call(this);
              this.scanner.skipSC();
          }

          // Do not include semicolon to range per spec
          // https://drafts.csswg.org/css-syntax/#declaration-diagram

          if (this.scanner.eof === false &&
              this.scanner.tokenType !== SEMICOLON$1 &&
              this.scanner.isBalanceEdge(startToken) === false) {
              this.error();
          }

          return {
              type: 'Declaration',
              loc: this.getLocation(start, this.scanner.tokenStart),
              important: important,
              property: property,
              value: value
          };
      },
      generate: function(node) {
          this.chunk(node.property);
          this.chunk(':');
          this.node(node.value);

          if (node.important) {
              this.chunk(node.important === true ? '!important' : '!' + node.important);
          }
      },
      walkContext: 'declaration'
  };

  function readProperty() {
      var start = this.scanner.tokenStart;

      // hacks
      if (this.scanner.tokenType === DELIM$4) {
          switch (this.scanner.source.charCodeAt(this.scanner.tokenStart)) {
              case ASTERISK$3:
              case DOLLARSIGN:
              case PLUSSIGN$3:
              case NUMBERSIGN$2:
              case AMPERSAND:
                  this.scanner.next();
                  break;

              // TODO: not sure we should support this hack
              case SOLIDUS$3:
                  this.scanner.next();
                  if (this.scanner.isDelim(SOLIDUS$3)) {
                      this.scanner.next();
                  }
                  break;
          }
      }

      if (this.scanner.tokenType === HASH$4) {
          this.eat(HASH$4);
      } else {
          this.eat(IDENT$b);
      }

      return this.scanner.substrToCursor(start);
  }

  // ! ws* important
  function getImportant() {
      this.eat(DELIM$4);
      this.scanner.skipSC();

      var important = this.consume(IDENT$b);

      // store original value in case it differ from `important`
      // for better original source restoring and hacks like `!ie` support
      return important === 'important' ? true : important;
  }

  var TYPE$n = tokenizer$1.TYPE;
  var rawMode$2 = Raw.mode;

  var WHITESPACE$5 = TYPE$n.WhiteSpace;
  var COMMENT$3 = TYPE$n.Comment;
  var SEMICOLON = TYPE$n.Semicolon;

  function consumeRaw$3(startToken) {
      return this.Raw(startToken, rawMode$2.semicolonIncluded, true);
  }

  var DeclarationList = {
      name: 'DeclarationList',
      structure: {
          children: [[
              'Declaration'
          ]]
      },
      parse: function() {
          var children = this.createList();

          while (!this.scanner.eof) {
              switch (this.scanner.tokenType) {
                  case WHITESPACE$5:
                  case COMMENT$3:
                  case SEMICOLON:
                      this.scanner.next();
                      break;

                  default:
                      children.push(this.parseWithFallback(this.Declaration, consumeRaw$3));
              }
          }

          return {
              type: 'DeclarationList',
              loc: this.getLocationFromList(children),
              children: children
          };
      },
      generate: function(node) {
          this.children(node, function(prev) {
              if (prev.type === 'Declaration') {
                  this.chunk(';');
              }
          });
      }
  };

  var consumeNumber$2 = utils.consumeNumber;
  var TYPE$m = tokenizer$1.TYPE;

  var DIMENSION$4 = TYPE$m.Dimension;

  var Dimension = {
      name: 'Dimension',
      structure: {
          value: String,
          unit: String
      },
      parse: function() {
          var start = this.scanner.tokenStart;
          var numberEnd = consumeNumber$2(this.scanner.source, start);

          this.eat(DIMENSION$4);

          return {
              type: 'Dimension',
              loc: this.getLocation(start, this.scanner.tokenStart),
              value: this.scanner.source.substring(start, numberEnd),
              unit: this.scanner.source.substring(numberEnd, this.scanner.tokenStart)
          };
      },
      generate: function(node) {
          this.chunk(node.value);
          this.chunk(node.unit);
      }
  };

  var TYPE$l = tokenizer$1.TYPE;

  var RIGHTPARENTHESIS$5 = TYPE$l.RightParenthesis;

  // <function-token> <sequence> )
  var _Function = {
      name: 'Function',
      structure: {
          name: String,
          children: [[]]
      },
      parse: function(readSequence, recognizer) {
          var start = this.scanner.tokenStart;
          var name = this.consumeFunctionName();
          var nameLowerCase = name.toLowerCase();
          var children;

          children = recognizer.hasOwnProperty(nameLowerCase)
              ? recognizer[nameLowerCase].call(this, recognizer)
              : readSequence.call(this, recognizer);

          if (!this.scanner.eof) {
              this.eat(RIGHTPARENTHESIS$5);
          }

          return {
              type: 'Function',
              loc: this.getLocation(start, this.scanner.tokenStart),
              name: name,
              children: children
          };
      },
      generate: function(node) {
          this.chunk(node.name);
          this.chunk('(');
          this.children(node);
          this.chunk(')');
      },
      walkContext: 'function'
  };

  var TYPE$k = tokenizer$1.TYPE;

  var HASH$3 = TYPE$k.Hash;

  // '#' ident
  var Hash = {
      name: 'Hash',
      structure: {
          value: String
      },
      parse: function() {
          var start = this.scanner.tokenStart;

          this.eat(HASH$3);

          return {
              type: 'Hash',
              loc: this.getLocation(start, this.scanner.tokenStart),
              value: this.scanner.substrToCursor(start + 1)
          };
      },
      generate: function(node) {
          this.chunk('#');
          this.chunk(node.value);
      }
  };

  var TYPE$j = tokenizer$1.TYPE;

  var IDENT$a = TYPE$j.Ident;

  var Identifier = {
      name: 'Identifier',
      structure: {
          name: String
      },
      parse: function() {
          return {
              type: 'Identifier',
              loc: this.getLocation(this.scanner.tokenStart, this.scanner.tokenEnd),
              name: this.consume(IDENT$a)
          };
      },
      generate: function(node) {
          this.chunk(node.name);
      }
  };

  var TYPE$i = tokenizer$1.TYPE;

  var HASH$2 = TYPE$i.Hash;

  // <hash-token>
  var IdSelector = {
      name: 'IdSelector',
      structure: {
          name: String
      },
      parse: function() {
          var start = this.scanner.tokenStart;

          // TODO: check value is an ident
          this.eat(HASH$2);

          return {
              type: 'IdSelector',
              loc: this.getLocation(start, this.scanner.tokenStart),
              name: this.scanner.substrToCursor(start + 1)
          };
      },
      generate: function(node) {
          this.chunk('#');
          this.chunk(node.name);
      }
  };

  var TYPE$h = tokenizer$1.TYPE;

  var IDENT$9 = TYPE$h.Ident;
  var NUMBER$5 = TYPE$h.Number;
  var DIMENSION$3 = TYPE$h.Dimension;
  var LEFTPARENTHESIS$5 = TYPE$h.LeftParenthesis;
  var RIGHTPARENTHESIS$4 = TYPE$h.RightParenthesis;
  var COLON$4 = TYPE$h.Colon;
  var DELIM$3 = TYPE$h.Delim;

  var MediaFeature = {
      name: 'MediaFeature',
      structure: {
          name: String,
          value: ['Identifier', 'Number', 'Dimension', 'Ratio', null]
      },
      parse: function() {
          var start = this.scanner.tokenStart;
          var name;
          var value = null;

          this.eat(LEFTPARENTHESIS$5);
          this.scanner.skipSC();

          name = this.consume(IDENT$9);
          this.scanner.skipSC();

          if (this.scanner.tokenType !== RIGHTPARENTHESIS$4) {
              this.eat(COLON$4);
              this.scanner.skipSC();

              switch (this.scanner.tokenType) {
                  case NUMBER$5:
                      if (this.lookupNonWSType(1) === DELIM$3) {
                          value = this.Ratio();
                      } else {
                          value = this.Number();
                      }

                      break;

                  case DIMENSION$3:
                      value = this.Dimension();
                      break;

                  case IDENT$9:
                      value = this.Identifier();

                      break;

                  default:
                      this.error('Number, dimension, ratio or identifier is expected');
              }

              this.scanner.skipSC();
          }

          this.eat(RIGHTPARENTHESIS$4);

          return {
              type: 'MediaFeature',
              loc: this.getLocation(start, this.scanner.tokenStart),
              name: name,
              value: value
          };
      },
      generate: function(node) {
          this.chunk('(');
          this.chunk(node.name);
          if (node.value !== null) {
              this.chunk(':');
              this.node(node.value);
          }
          this.chunk(')');
      }
  };

  var TYPE$g = tokenizer$1.TYPE;

  var WHITESPACE$4 = TYPE$g.WhiteSpace;
  var COMMENT$2 = TYPE$g.Comment;
  var IDENT$8 = TYPE$g.Ident;
  var LEFTPARENTHESIS$4 = TYPE$g.LeftParenthesis;

  var MediaQuery = {
      name: 'MediaQuery',
      structure: {
          children: [[
              'Identifier',
              'MediaFeature',
              'WhiteSpace'
          ]]
      },
      parse: function() {
          this.scanner.skipSC();

          var children = this.createList();
          var child = null;
          var space = null;

          scan:
          while (!this.scanner.eof) {
              switch (this.scanner.tokenType) {
                  case COMMENT$2:
                      this.scanner.next();
                      continue;

                  case WHITESPACE$4:
                      space = this.WhiteSpace();
                      continue;

                  case IDENT$8:
                      child = this.Identifier();
                      break;

                  case LEFTPARENTHESIS$4:
                      child = this.MediaFeature();
                      break;

                  default:
                      break scan;
              }

              if (space !== null) {
                  children.push(space);
                  space = null;
              }

              children.push(child);
          }

          if (child === null) {
              this.error('Identifier or parenthesis is expected');
          }

          return {
              type: 'MediaQuery',
              loc: this.getLocationFromList(children),
              children: children
          };
      },
      generate: function(node) {
          this.children(node);
      }
  };

  var COMMA$3 = tokenizer$1.TYPE.Comma;

  var MediaQueryList = {
      name: 'MediaQueryList',
      structure: {
          children: [[
              'MediaQuery'
          ]]
      },
      parse: function(relative) {
          var children = this.createList();

          this.scanner.skipSC();

          while (!this.scanner.eof) {
              children.push(this.MediaQuery(relative));

              if (this.scanner.tokenType !== COMMA$3) {
                  break;
              }

              this.scanner.next();
          }

          return {
              type: 'MediaQueryList',
              loc: this.getLocationFromList(children),
              children: children
          };
      },
      generate: function(node) {
          this.children(node, function() {
              this.chunk(',');
          });
      }
  };

  var Nth = {
      name: 'Nth',
      structure: {
          nth: ['AnPlusB', 'Identifier'],
          selector: ['SelectorList', null]
      },
      parse: function(allowOfClause) {
          this.scanner.skipSC();

          var start = this.scanner.tokenStart;
          var end = start;
          var selector = null;
          var query;

          if (this.scanner.lookupValue(0, 'odd') || this.scanner.lookupValue(0, 'even')) {
              query = this.Identifier();
          } else {
              query = this.AnPlusB();
          }

          this.scanner.skipSC();

          if (allowOfClause && this.scanner.lookupValue(0, 'of')) {
              this.scanner.next();

              selector = this.SelectorList();

              if (this.needPositions) {
                  end = this.getLastListNode(selector.children).loc.end.offset;
              }
          } else {
              if (this.needPositions) {
                  end = query.loc.end.offset;
              }
          }

          return {
              type: 'Nth',
              loc: this.getLocation(start, end),
              nth: query,
              selector: selector
          };
      },
      generate: function(node) {
          this.node(node.nth);
          if (node.selector !== null) {
              this.chunk(' of ');
              this.node(node.selector);
          }
      }
  };

  var NUMBER$4 = tokenizer$1.TYPE.Number;

  var _Number = {
      name: 'Number',
      structure: {
          value: String
      },
      parse: function() {
          return {
              type: 'Number',
              loc: this.getLocation(this.scanner.tokenStart, this.scanner.tokenEnd),
              value: this.consume(NUMBER$4)
          };
      },
      generate: function(node) {
          this.chunk(node.value);
      }
  };

  // '/' | '*' | ',' | ':' | '+' | '-'
  var Operator = {
      name: 'Operator',
      structure: {
          value: String
      },
      parse: function() {
          var start = this.scanner.tokenStart;

          this.scanner.next();

          return {
              type: 'Operator',
              loc: this.getLocation(start, this.scanner.tokenStart),
              value: this.scanner.substrToCursor(start)
          };
      },
      generate: function(node) {
          this.chunk(node.value);
      }
  };

  var TYPE$f = tokenizer$1.TYPE;

  var LEFTPARENTHESIS$3 = TYPE$f.LeftParenthesis;
  var RIGHTPARENTHESIS$3 = TYPE$f.RightParenthesis;

  var Parentheses = {
      name: 'Parentheses',
      structure: {
          children: [[]]
      },
      parse: function(readSequence, recognizer) {
          var start = this.scanner.tokenStart;
          var children = null;

          this.eat(LEFTPARENTHESIS$3);

          children = readSequence.call(this, recognizer);

          if (!this.scanner.eof) {
              this.eat(RIGHTPARENTHESIS$3);
          }

          return {
              type: 'Parentheses',
              loc: this.getLocation(start, this.scanner.tokenStart),
              children: children
          };
      },
      generate: function(node) {
          this.chunk('(');
          this.children(node);
          this.chunk(')');
      }
  };

  var consumeNumber$1 = utils.consumeNumber;
  var TYPE$e = tokenizer$1.TYPE;

  var PERCENTAGE$2 = TYPE$e.Percentage;

  var Percentage = {
      name: 'Percentage',
      structure: {
          value: String
      },
      parse: function() {
          var start = this.scanner.tokenStart;
          var numberEnd = consumeNumber$1(this.scanner.source, start);

          this.eat(PERCENTAGE$2);

          return {
              type: 'Percentage',
              loc: this.getLocation(start, this.scanner.tokenStart),
              value: this.scanner.source.substring(start, numberEnd)
          };
      },
      generate: function(node) {
          this.chunk(node.value);
          this.chunk('%');
      }
  };

  var TYPE$d = tokenizer$1.TYPE;

  var IDENT$7 = TYPE$d.Ident;
  var FUNCTION$5 = TYPE$d.Function;
  var COLON$3 = TYPE$d.Colon;
  var RIGHTPARENTHESIS$2 = TYPE$d.RightParenthesis;

  // : [ <ident> | <function-token> <any-value>? ) ]
  var PseudoClassSelector = {
      name: 'PseudoClassSelector',
      structure: {
          name: String,
          children: [['Raw'], null]
      },
      parse: function() {
          var start = this.scanner.tokenStart;
          var children = null;
          var name;
          var nameLowerCase;

          this.eat(COLON$3);

          if (this.scanner.tokenType === FUNCTION$5) {
              name = this.consumeFunctionName();
              nameLowerCase = name.toLowerCase();

              if (this.pseudo.hasOwnProperty(nameLowerCase)) {
                  this.scanner.skipSC();
                  children = this.pseudo[nameLowerCase].call(this);
                  this.scanner.skipSC();
              } else {
                  children = this.createList();
                  children.push(
                      this.Raw(this.scanner.tokenIndex, null, false)
                  );
              }

              this.eat(RIGHTPARENTHESIS$2);
          } else {
              name = this.consume(IDENT$7);
          }

          return {
              type: 'PseudoClassSelector',
              loc: this.getLocation(start, this.scanner.tokenStart),
              name: name,
              children: children
          };
      },
      generate: function(node) {
          this.chunk(':');
          this.chunk(node.name);

          if (node.children !== null) {
              this.chunk('(');
              this.children(node);
              this.chunk(')');
          }
      },
      walkContext: 'function'
  };

  var TYPE$c = tokenizer$1.TYPE;

  var IDENT$6 = TYPE$c.Ident;
  var FUNCTION$4 = TYPE$c.Function;
  var COLON$2 = TYPE$c.Colon;
  var RIGHTPARENTHESIS$1 = TYPE$c.RightParenthesis;

  // :: [ <ident> | <function-token> <any-value>? ) ]
  var PseudoElementSelector = {
      name: 'PseudoElementSelector',
      structure: {
          name: String,
          children: [['Raw'], null]
      },
      parse: function() {
          var start = this.scanner.tokenStart;
          var children = null;
          var name;
          var nameLowerCase;

          this.eat(COLON$2);
          this.eat(COLON$2);

          if (this.scanner.tokenType === FUNCTION$4) {
              name = this.consumeFunctionName();
              nameLowerCase = name.toLowerCase();

              if (this.pseudo.hasOwnProperty(nameLowerCase)) {
                  this.scanner.skipSC();
                  children = this.pseudo[nameLowerCase].call(this);
                  this.scanner.skipSC();
              } else {
                  children = this.createList();
                  children.push(
                      this.Raw(this.scanner.tokenIndex, null, false)
                  );
              }

              this.eat(RIGHTPARENTHESIS$1);
          } else {
              name = this.consume(IDENT$6);
          }

          return {
              type: 'PseudoElementSelector',
              loc: this.getLocation(start, this.scanner.tokenStart),
              name: name,
              children: children
          };
      },
      generate: function(node) {
          this.chunk('::');
          this.chunk(node.name);

          if (node.children !== null) {
              this.chunk('(');
              this.children(node);
              this.chunk(')');
          }
      },
      walkContext: 'function'
  };

  var isDigit = tokenizer$1.isDigit;
  var TYPE$b = tokenizer$1.TYPE;

  var NUMBER$3 = TYPE$b.Number;
  var DELIM$2 = TYPE$b.Delim;
  var SOLIDUS$2 = 0x002F;  // U+002F SOLIDUS (/)
  var FULLSTOP$1 = 0x002E; // U+002E FULL STOP (.)

  // Terms of <ratio> should be a positive numbers (not zero or negative)
  // (see https://drafts.csswg.org/mediaqueries-3/#values)
  // However, -o-min-device-pixel-ratio takes fractional values as a ratio's term
  // and this is using by various sites. Therefore we relax checking on parse
  // to test a term is unsigned number without an exponent part.
  // Additional checking may be applied on lexer validation.
  function consumeNumber() {
      this.scanner.skipWS();

      var value = this.consume(NUMBER$3);

      for (var i = 0; i < value.length; i++) {
          var code = value.charCodeAt(i);
          if (!isDigit(code) && code !== FULLSTOP$1) {
              this.error('Unsigned number is expected', this.scanner.tokenStart - value.length + i);
          }
      }

      if (Number(value) === 0) {
          this.error('Zero number is not allowed', this.scanner.tokenStart - value.length);
      }

      return value;
  }

  // <positive-integer> S* '/' S* <positive-integer>
  var Ratio = {
      name: 'Ratio',
      structure: {
          left: String,
          right: String
      },
      parse: function() {
          var start = this.scanner.tokenStart;
          var left = consumeNumber.call(this);
          var right;

          this.scanner.skipWS();

          if (!this.scanner.isDelim(SOLIDUS$2)) {
              this.error('Solidus is expected');
          }
          this.eat(DELIM$2);
          right = consumeNumber.call(this);

          return {
              type: 'Ratio',
              loc: this.getLocation(start, this.scanner.tokenStart),
              left: left,
              right: right
          };
      },
      generate: function(node) {
          this.chunk(node.left);
          this.chunk('/');
          this.chunk(node.right);
      }
  };

  var TYPE$a = tokenizer$1.TYPE;
  var rawMode$1 = Raw.mode;

  var LEFTCURLYBRACKET = TYPE$a.LeftCurlyBracket;

  function consumeRaw$2(startToken) {
      return this.Raw(startToken, rawMode$1.leftCurlyBracket, true);
  }

  function consumePrelude() {
      var prelude = this.SelectorList();

      if (prelude.type !== 'Raw' &&
          this.scanner.eof === false &&
          this.scanner.tokenType !== LEFTCURLYBRACKET) {
          this.error();
      }

      return prelude;
  }

  var Rule = {
      name: 'Rule',
      structure: {
          prelude: ['SelectorList', 'Raw'],
          block: ['Block']
      },
      parse: function() {
          var startToken = this.scanner.tokenIndex;
          var startOffset = this.scanner.tokenStart;
          var prelude;
          var block;

          if (this.parseRulePrelude) {
              prelude = this.parseWithFallback(consumePrelude, consumeRaw$2);
          } else {
              prelude = consumeRaw$2.call(this, startToken);
          }

          block = this.Block(true);

          return {
              type: 'Rule',
              loc: this.getLocation(startOffset, this.scanner.tokenStart),
              prelude: prelude,
              block: block
          };
      },
      generate: function(node) {
          this.node(node.prelude);
          this.node(node.block);
      },
      walkContext: 'rule'
  };

  var Selector = {
      name: 'Selector',
      structure: {
          children: [[
              'TypeSelector',
              'IdSelector',
              'ClassSelector',
              'AttributeSelector',
              'PseudoClassSelector',
              'PseudoElementSelector',
              'Combinator',
              'WhiteSpace'
          ]]
      },
      parse: function() {
          var children = this.readSequence(this.scope.Selector);

          // nothing were consumed
          if (this.getFirstListNode(children) === null) {
              this.error('Selector is expected');
          }

          return {
              type: 'Selector',
              loc: this.getLocationFromList(children),
              children: children
          };
      },
      generate: function(node) {
          this.children(node);
      }
  };

  var TYPE$9 = tokenizer$1.TYPE;

  var COMMA$2 = TYPE$9.Comma;

  var SelectorList = {
      name: 'SelectorList',
      structure: {
          children: [[
              'Selector',
              'Raw'
          ]]
      },
      parse: function() {
          var children = this.createList();

          while (!this.scanner.eof) {
              children.push(this.Selector());

              if (this.scanner.tokenType === COMMA$2) {
                  this.scanner.next();
                  continue;
              }

              break;
          }

          return {
              type: 'SelectorList',
              loc: this.getLocationFromList(children),
              children: children
          };
      },
      generate: function(node) {
          this.children(node, function() {
              this.chunk(',');
          });
      },
      walkContext: 'selector'
  };

  var STRING$2 = tokenizer$1.TYPE.String;

  var _String = {
      name: 'String',
      structure: {
          value: String
      },
      parse: function() {
          return {
              type: 'String',
              loc: this.getLocation(this.scanner.tokenStart, this.scanner.tokenEnd),
              value: this.consume(STRING$2)
          };
      },
      generate: function(node) {
          this.chunk(node.value);
      }
  };

  var TYPE$8 = tokenizer$1.TYPE;

  var WHITESPACE$3 = TYPE$8.WhiteSpace;
  var COMMENT$1 = TYPE$8.Comment;
  var ATKEYWORD = TYPE$8.AtKeyword;
  var CDO = TYPE$8.CDO;
  var CDC = TYPE$8.CDC;
  var EXCLAMATIONMARK = 0x0021; // U+0021 EXCLAMATION MARK (!)

  function consumeRaw$1(startToken) {
      return this.Raw(startToken, null, false);
  }

  var StyleSheet$1 = {
      name: 'StyleSheet',
      structure: {
          children: [[
              'Comment',
              'CDO',
              'CDC',
              'Atrule',
              'Rule',
              'Raw'
          ]]
      },
      parse: function() {
          var start = this.scanner.tokenStart;
          var children = this.createList();
          var child;

          while (!this.scanner.eof) {
              switch (this.scanner.tokenType) {
                  case WHITESPACE$3:
                      this.scanner.next();
                      continue;

                  case COMMENT$1:
                      // ignore comments except exclamation comments (i.e. /*! .. */) on top level
                      if (this.scanner.source.charCodeAt(this.scanner.tokenStart + 2) !== EXCLAMATIONMARK) {
                          this.scanner.next();
                          continue;
                      }

                      child = this.Comment();
                      break;

                  case CDO: // <!--
                      child = this.CDO();
                      break;

                  case CDC: // -->
                      child = this.CDC();
                      break;

                  // CSS Syntax Module Level 3
                  // §2.2 Error handling
                  // At the "top level" of a stylesheet, an <at-keyword-token> starts an at-rule.
                  case ATKEYWORD:
                      child = this.parseWithFallback(this.Atrule, consumeRaw$1);
                      break;

                  // Anything else starts a qualified rule ...
                  default:
                      child = this.parseWithFallback(this.Rule, consumeRaw$1);
              }

              children.push(child);
          }

          return {
              type: 'StyleSheet',
              loc: this.getLocation(start, this.scanner.tokenStart),
              children: children
          };
      },
      generate: function(node) {
          this.children(node);
      },
      walkContext: 'stylesheet'
  };

  var TYPE$7 = tokenizer$1.TYPE;

  var IDENT$5 = TYPE$7.Ident;
  var ASTERISK$2 = 0x002A;     // U+002A ASTERISK (*)
  var VERTICALLINE$1 = 0x007C; // U+007C VERTICAL LINE (|)

  function eatIdentifierOrAsterisk() {
      if (this.scanner.tokenType !== IDENT$5 &&
          this.scanner.isDelim(ASTERISK$2) === false) {
          this.error('Identifier or asterisk is expected');
      }

      this.scanner.next();
  }

  // ident
  // ident|ident
  // ident|*
  // *
  // *|ident
  // *|*
  // |ident
  // |*
  var TypeSelector = {
      name: 'TypeSelector',
      structure: {
          name: String
      },
      parse: function() {
          var start = this.scanner.tokenStart;

          if (this.scanner.isDelim(VERTICALLINE$1)) {
              this.scanner.next();
              eatIdentifierOrAsterisk.call(this);
          } else {
              eatIdentifierOrAsterisk.call(this);

              if (this.scanner.isDelim(VERTICALLINE$1)) {
                  this.scanner.next();
                  eatIdentifierOrAsterisk.call(this);
              }
          }

          return {
              type: 'TypeSelector',
              loc: this.getLocation(start, this.scanner.tokenStart),
              name: this.scanner.substrToCursor(start)
          };
      },
      generate: function(node) {
          this.chunk(node.name);
      }
  };

  var isHexDigit = tokenizer$1.isHexDigit;
  var cmpChar$1 = tokenizer$1.cmpChar;
  var TYPE$6 = tokenizer$1.TYPE;
  var NAME = tokenizer$1.NAME;

  var IDENT$4 = TYPE$6.Ident;
  var NUMBER$2 = TYPE$6.Number;
  var DIMENSION$2 = TYPE$6.Dimension;
  var PLUSSIGN$2 = 0x002B;     // U+002B PLUS SIGN (+)
  var HYPHENMINUS$1 = 0x002D;  // U+002D HYPHEN-MINUS (-)
  var QUESTIONMARK = 0x003F; // U+003F QUESTION MARK (?)
  var U$1 = 0x0075;            // U+0075 LATIN SMALL LETTER U (u)

  function eatHexSequence(offset, allowDash) {
      for (var pos = this.scanner.tokenStart + offset, len = 0; pos < this.scanner.tokenEnd; pos++) {
          var code = this.scanner.source.charCodeAt(pos);

          if (code === HYPHENMINUS$1 && allowDash && len !== 0) {
              if (eatHexSequence.call(this, offset + len + 1, false) === 0) {
                  this.error();
              }

              return -1;
          }

          if (!isHexDigit(code)) {
              this.error(
                  allowDash && len !== 0
                      ? 'HyphenMinus' + (len < 6 ? ' or hex digit' : '') + ' is expected'
                      : (len < 6 ? 'Hex digit is expected' : 'Unexpected input'),
                  pos
              );
          }

          if (++len > 6) {
              this.error('Too many hex digits', pos);
          }    }

      this.scanner.next();
      return len;
  }

  function eatQuestionMarkSequence(max) {
      var count = 0;

      while (this.scanner.isDelim(QUESTIONMARK)) {
          if (++count > max) {
              this.error('Too many question marks');
          }

          this.scanner.next();
      }
  }

  function startsWith(code) {
      if (this.scanner.source.charCodeAt(this.scanner.tokenStart) !== code) {
          this.error(NAME[code] + ' is expected');
      }
  }

  // https://drafts.csswg.org/css-syntax/#urange
  // Informally, the <urange> production has three forms:
  // U+0001
  //      Defines a range consisting of a single code point, in this case the code point "1".
  // U+0001-00ff
  //      Defines a range of codepoints between the first and the second value, in this case
  //      the range between "1" and "ff" (255 in decimal) inclusive.
  // U+00??
  //      Defines a range of codepoints where the "?" characters range over all hex digits,
  //      in this case defining the same as the value U+0000-00ff.
  // In each form, a maximum of 6 digits is allowed for each hexadecimal number (if you treat "?" as a hexadecimal digit).
  //
  // <urange> =
  //   u '+' <ident-token> '?'* |
  //   u <dimension-token> '?'* |
  //   u <number-token> '?'* |
  //   u <number-token> <dimension-token> |
  //   u <number-token> <number-token> |
  //   u '+' '?'+
  function scanUnicodeRange() {
      var hexLength = 0;

      // u '+' <ident-token> '?'*
      // u '+' '?'+
      if (this.scanner.isDelim(PLUSSIGN$2)) {
          this.scanner.next();

          if (this.scanner.tokenType === IDENT$4) {
              hexLength = eatHexSequence.call(this, 0, true);
              if (hexLength > 0) {
                  eatQuestionMarkSequence.call(this, 6 - hexLength);
              }
              return;
          }

          if (this.scanner.isDelim(QUESTIONMARK)) {
              this.scanner.next();
              eatQuestionMarkSequence.call(this, 5);
              return;
          }

          this.error('Hex digit or question mark is expected');
          return;
      }

      // u <number-token> '?'*
      // u <number-token> <dimension-token>
      // u <number-token> <number-token>
      if (this.scanner.tokenType === NUMBER$2) {
          startsWith.call(this, PLUSSIGN$2);
          hexLength = eatHexSequence.call(this, 1, true);

          if (this.scanner.isDelim(QUESTIONMARK)) {
              eatQuestionMarkSequence.call(this, 6 - hexLength);
              return;
          }

          if (this.scanner.tokenType === DIMENSION$2 ||
              this.scanner.tokenType === NUMBER$2) {
              startsWith.call(this, HYPHENMINUS$1);
              eatHexSequence.call(this, 1, false);
              return;
          }

          return;
      }

      // u <dimension-token> '?'*
      if (this.scanner.tokenType === DIMENSION$2) {
          startsWith.call(this, PLUSSIGN$2);
          hexLength = eatHexSequence.call(this, 1, true);

          if (hexLength > 0) {
              eatQuestionMarkSequence.call(this, 6 - hexLength);
          }

          return;
      }

      this.error();
  }

  var UnicodeRange = {
      name: 'UnicodeRange',
      structure: {
          value: String
      },
      parse: function() {
          var start = this.scanner.tokenStart;

          // U or u
          if (!cmpChar$1(this.scanner.source, start, U$1)) {
              this.error('U is expected');
          }

          if (!cmpChar$1(this.scanner.source, start + 1, PLUSSIGN$2)) {
              this.error('Plus sign is expected');
          }

          this.scanner.next();
          scanUnicodeRange.call(this);

          return {
              type: 'UnicodeRange',
              loc: this.getLocation(start, this.scanner.tokenStart),
              value: this.scanner.substrToCursor(start)
          };
      },
      generate: function(node) {
          this.chunk(node.value);
      }
  };

  var isWhiteSpace = tokenizer$1.isWhiteSpace;
  var cmpStr$1 = tokenizer$1.cmpStr;
  var TYPE$5 = tokenizer$1.TYPE;

  var FUNCTION$3 = TYPE$5.Function;
  var URL$2 = TYPE$5.Url;
  var RIGHTPARENTHESIS = TYPE$5.RightParenthesis;

  // <url-token> | <function-token> <string> )
  var Url = {
      name: 'Url',
      structure: {
          value: ['String', 'Raw']
      },
      parse: function() {
          var start = this.scanner.tokenStart;
          var value;

          switch (this.scanner.tokenType) {
              case URL$2:
                  var rawStart = start + 4;
                  var rawEnd = this.scanner.tokenEnd - 1;

                  while (rawStart < rawEnd && isWhiteSpace(this.scanner.source.charCodeAt(rawStart))) {
                      rawStart++;
                  }

                  while (rawStart < rawEnd && isWhiteSpace(this.scanner.source.charCodeAt(rawEnd - 1))) {
                      rawEnd--;
                  }

                  value = {
                      type: 'Raw',
                      loc: this.getLocation(rawStart, rawEnd),
                      value: this.scanner.source.substring(rawStart, rawEnd)
                  };

                  this.eat(URL$2);
                  break;

              case FUNCTION$3:
                  if (!cmpStr$1(this.scanner.source, this.scanner.tokenStart, this.scanner.tokenEnd, 'url(')) {
                      this.error('Function name must be `url`');
                  }

                  this.eat(FUNCTION$3);
                  this.scanner.skipSC();
                  value = this.String();
                  this.scanner.skipSC();
                  this.eat(RIGHTPARENTHESIS);
                  break;

              default:
                  this.error('Url or Function is expected');
          }

          return {
              type: 'Url',
              loc: this.getLocation(start, this.scanner.tokenStart),
              value: value
          };
      },
      generate: function(node) {
          this.chunk('url');
          this.chunk('(');
          this.node(node.value);
          this.chunk(')');
      }
  };

  var Value = {
      name: 'Value',
      structure: {
          children: [[]]
      },
      parse: function() {
          var start = this.scanner.tokenStart;
          var children = this.readSequence(this.scope.Value);

          return {
              type: 'Value',
              loc: this.getLocation(start, this.scanner.tokenStart),
              children: children
          };
      },
      generate: function(node) {
          this.children(node);
      }
  };

  var WHITESPACE$2 = tokenizer$1.TYPE.WhiteSpace;
  var SPACE = Object.freeze({
      type: 'WhiteSpace',
      loc: null,
      value: ' '
  });

  var WhiteSpace = {
      name: 'WhiteSpace',
      structure: {
          value: String
      },
      parse: function() {
          this.eat(WHITESPACE$2);
          return SPACE;

          // return {
          //     type: 'WhiteSpace',
          //     loc: this.getLocation(this.scanner.tokenStart, this.scanner.tokenEnd),
          //     value: this.consume(WHITESPACE)
          // };
      },
      generate: function(node) {
          this.chunk(node.value);
      }
  };

  var node = {
      AnPlusB: AnPlusB,
      Atrule: Atrule,
      AtrulePrelude: AtrulePrelude,
      AttributeSelector: AttributeSelector,
      Block: Block,
      Brackets: Brackets,
      CDC: CDC_1,
      CDO: CDO_1,
      ClassSelector: ClassSelector,
      Combinator: Combinator,
      Comment: Comment,
      Declaration: Declaration,
      DeclarationList: DeclarationList,
      Dimension: Dimension,
      Function: _Function,
      Hash: Hash,
      Identifier: Identifier,
      IdSelector: IdSelector,
      MediaFeature: MediaFeature,
      MediaQuery: MediaQuery,
      MediaQueryList: MediaQueryList,
      Nth: Nth,
      Number: _Number,
      Operator: Operator,
      Parentheses: Parentheses,
      Percentage: Percentage,
      PseudoClassSelector: PseudoClassSelector,
      PseudoElementSelector: PseudoElementSelector,
      Ratio: Ratio,
      Raw: Raw,
      Rule: Rule,
      Selector: Selector,
      SelectorList: SelectorList,
      String: _String,
      StyleSheet: StyleSheet$1,
      TypeSelector: TypeSelector,
      UnicodeRange: UnicodeRange,
      Url: Url,
      Value: Value,
      WhiteSpace: WhiteSpace
  };

  var lexer = {
      generic: true,
      types: data.types,
      atrules: data.atrules,
      properties: data.properties,
      node: node
  };

  var cmpChar = tokenizer$1.cmpChar;
  var cmpStr = tokenizer$1.cmpStr;
  var TYPE$4 = tokenizer$1.TYPE;

  var IDENT$3 = TYPE$4.Ident;
  var STRING$1 = TYPE$4.String;
  var NUMBER$1 = TYPE$4.Number;
  var FUNCTION$2 = TYPE$4.Function;
  var URL$1 = TYPE$4.Url;
  var HASH$1 = TYPE$4.Hash;
  var DIMENSION$1 = TYPE$4.Dimension;
  var PERCENTAGE$1 = TYPE$4.Percentage;
  var LEFTPARENTHESIS$2 = TYPE$4.LeftParenthesis;
  var LEFTSQUAREBRACKET$1 = TYPE$4.LeftSquareBracket;
  var COMMA$1 = TYPE$4.Comma;
  var DELIM$1 = TYPE$4.Delim;
  var NUMBERSIGN$1 = 0x0023;  // U+0023 NUMBER SIGN (#)
  var ASTERISK$1 = 0x002A;    // U+002A ASTERISK (*)
  var PLUSSIGN$1 = 0x002B;    // U+002B PLUS SIGN (+)
  var HYPHENMINUS = 0x002D; // U+002D HYPHEN-MINUS (-)
  var SOLIDUS$1 = 0x002F;     // U+002F SOLIDUS (/)
  var U = 0x0075;           // U+0075 LATIN SMALL LETTER U (u)

  var _default$3 = function defaultRecognizer(context) {
      switch (this.scanner.tokenType) {
          case HASH$1:
              return this.Hash();

          case COMMA$1:
              context.space = null;
              context.ignoreWSAfter = true;
              return this.Operator();

          case LEFTPARENTHESIS$2:
              return this.Parentheses(this.readSequence, context.recognizer);

          case LEFTSQUAREBRACKET$1:
              return this.Brackets(this.readSequence, context.recognizer);

          case STRING$1:
              return this.String();

          case DIMENSION$1:
              return this.Dimension();

          case PERCENTAGE$1:
              return this.Percentage();

          case NUMBER$1:
              return this.Number();

          case FUNCTION$2:
              return cmpStr(this.scanner.source, this.scanner.tokenStart, this.scanner.tokenEnd, 'url(')
                  ? this.Url()
                  : this.Function(this.readSequence, context.recognizer);

          case URL$1:
              return this.Url();

          case IDENT$3:
              // check for unicode range, it should start with u+ or U+
              if (cmpChar(this.scanner.source, this.scanner.tokenStart, U) &&
                  cmpChar(this.scanner.source, this.scanner.tokenStart + 1, PLUSSIGN$1)) {
                  return this.UnicodeRange();
              } else {
                  return this.Identifier();
              }

          case DELIM$1:
              var code = this.scanner.source.charCodeAt(this.scanner.tokenStart);

              if (code === SOLIDUS$1 ||
                  code === ASTERISK$1 ||
                  code === PLUSSIGN$1 ||
                  code === HYPHENMINUS) {
                  return this.Operator(); // TODO: replace with Delim
              }

              // TODO: produce a node with Delim node type

              if (code === NUMBERSIGN$1) {
                  this.error('Hex or identifier is expected', this.scanner.tokenStart + 1);
              }

              break;
      }
  };

  var atrulePrelude = {
      getNode: _default$3
  };

  var TYPE$3 = tokenizer$1.TYPE;

  var DELIM = TYPE$3.Delim;
  var IDENT$2 = TYPE$3.Ident;
  var DIMENSION = TYPE$3.Dimension;
  var PERCENTAGE = TYPE$3.Percentage;
  var NUMBER = TYPE$3.Number;
  var HASH = TYPE$3.Hash;
  var COLON$1 = TYPE$3.Colon;
  var LEFTSQUAREBRACKET = TYPE$3.LeftSquareBracket;
  var NUMBERSIGN = 0x0023;      // U+0023 NUMBER SIGN (#)
  var ASTERISK = 0x002A;        // U+002A ASTERISK (*)
  var PLUSSIGN = 0x002B;        // U+002B PLUS SIGN (+)
  var SOLIDUS = 0x002F;         // U+002F SOLIDUS (/)
  var FULLSTOP = 0x002E;        // U+002E FULL STOP (.)
  var GREATERTHANSIGN = 0x003E; // U+003E GREATER-THAN SIGN (>)
  var VERTICALLINE = 0x007C;    // U+007C VERTICAL LINE (|)
  var TILDE = 0x007E;           // U+007E TILDE (~)

  function getNode(context) {
      switch (this.scanner.tokenType) {
          case LEFTSQUAREBRACKET:
              return this.AttributeSelector();

          case HASH:
              return this.IdSelector();

          case COLON$1:
              if (this.scanner.lookupType(1) === COLON$1) {
                  return this.PseudoElementSelector();
              } else {
                  return this.PseudoClassSelector();
              }

          case IDENT$2:
              return this.TypeSelector();

          case NUMBER:
          case PERCENTAGE:
              return this.Percentage();

          case DIMENSION:
              // throws when .123ident
              if (this.scanner.source.charCodeAt(this.scanner.tokenStart) === FULLSTOP) {
                  this.error('Identifier is expected', this.scanner.tokenStart + 1);
              }
              break;

          case DELIM:
              var code = this.scanner.source.charCodeAt(this.scanner.tokenStart);

              switch (code) {
                  case PLUSSIGN:
                  case GREATERTHANSIGN:
                  case TILDE:
                      context.space = null;
                      context.ignoreWSAfter = true;
                      return this.Combinator();

                  case SOLIDUS:  // /deep/
                      return this.Combinator();

                  case FULLSTOP:
                      return this.ClassSelector();

                  case ASTERISK:
                  case VERTICALLINE:
                      return this.TypeSelector();

                  case NUMBERSIGN:
                      return this.IdSelector();
              }

              break;
      }
  }
  var selector = {
      getNode: getNode
  };

  // legacy IE function
  // expression( <any-value> )
  var expression = function() {
      return this.createSingleNodeList(
          this.Raw(this.scanner.tokenIndex, null, false)
      );
  };

  var TYPE$2 = tokenizer$1.TYPE;
  var rawMode = Raw.mode;

  var COMMA = TYPE$2.Comma;
  var WHITESPACE$1 = TYPE$2.WhiteSpace;

  // var( <ident> , <value>? )
  var _var = function() {
      var children = this.createList();

      this.scanner.skipSC();

      // NOTE: Don't check more than a first argument is an ident, rest checks are for lexer
      children.push(this.Identifier());

      this.scanner.skipSC();

      if (this.scanner.tokenType === COMMA) {
          children.push(this.Operator());

          const startIndex = this.scanner.tokenIndex;
          const value = this.parseCustomProperty
              ? this.Value(null)
              : this.Raw(this.scanner.tokenIndex, rawMode.exclamationMarkOrSemicolon, false);

          if (value.type === 'Value' && value.children.isEmpty()) {
              for (let offset = startIndex - this.scanner.tokenIndex; offset <= 0; offset++) {
                  if (this.scanner.lookupType(offset) === WHITESPACE$1) {
                      value.children.appendData({
                          type: 'WhiteSpace',
                          loc: null,
                          value: ' '
                      });
                      break;
                  }
              }
          }

          children.push(value);
      }

      return children;
  };

  var value = {
      getNode: _default$3,
      'expression': expression,
      'var': _var
  };

  var scope = {
      AtrulePrelude: atrulePrelude,
      Selector: selector,
      Value: value
  };

  var fontFace = {
      parse: {
          prelude: null,
          block: function() {
              return this.Block(true);
          }
      }
  };

  var TYPE$1 = tokenizer$1.TYPE;

  var STRING = TYPE$1.String;
  var IDENT$1 = TYPE$1.Ident;
  var URL = TYPE$1.Url;
  var FUNCTION$1 = TYPE$1.Function;
  var LEFTPARENTHESIS$1 = TYPE$1.LeftParenthesis;

  var _import = {
      parse: {
          prelude: function() {
              var children = this.createList();

              this.scanner.skipSC();

              switch (this.scanner.tokenType) {
                  case STRING:
                      children.push(this.String());
                      break;

                  case URL:
                  case FUNCTION$1:
                      children.push(this.Url());
                      break;

                  default:
                      this.error('String or url() is expected');
              }

              if (this.lookupNonWSType(0) === IDENT$1 ||
                  this.lookupNonWSType(0) === LEFTPARENTHESIS$1) {
                  children.push(this.WhiteSpace());
                  children.push(this.MediaQueryList());
              }

              return children;
          },
          block: null
      }
  };

  var media = {
      parse: {
          prelude: function() {
              return this.createSingleNodeList(
                  this.MediaQueryList()
              );
          },
          block: function() {
              return this.Block(false);
          }
      }
  };

  var page = {
      parse: {
          prelude: function() {
              return this.createSingleNodeList(
                  this.SelectorList()
              );
          },
          block: function() {
              return this.Block(true);
          }
      }
  };

  var TYPE = tokenizer$1.TYPE;

  var WHITESPACE = TYPE.WhiteSpace;
  var COMMENT = TYPE.Comment;
  var IDENT = TYPE.Ident;
  var FUNCTION = TYPE.Function;
  var COLON = TYPE.Colon;
  var LEFTPARENTHESIS = TYPE.LeftParenthesis;

  function consumeRaw() {
      return this.createSingleNodeList(
          this.Raw(this.scanner.tokenIndex, null, false)
      );
  }

  function parentheses() {
      this.scanner.skipSC();

      if (this.scanner.tokenType === IDENT &&
          this.lookupNonWSType(1) === COLON) {
          return this.createSingleNodeList(
              this.Declaration()
          );
      }

      return readSequence.call(this);
  }

  function readSequence() {
      var children = this.createList();
      var space = null;
      var child;

      this.scanner.skipSC();

      scan:
      while (!this.scanner.eof) {
          switch (this.scanner.tokenType) {
              case WHITESPACE:
                  space = this.WhiteSpace();
                  continue;

              case COMMENT:
                  this.scanner.next();
                  continue;

              case FUNCTION:
                  child = this.Function(consumeRaw, this.scope.AtrulePrelude);
                  break;

              case IDENT:
                  child = this.Identifier();
                  break;

              case LEFTPARENTHESIS:
                  child = this.Parentheses(parentheses, this.scope.AtrulePrelude);
                  break;

              default:
                  break scan;
          }

          if (space !== null) {
              children.push(space);
              space = null;
          }

          children.push(child);
      }

      return children;
  }

  var supports = {
      parse: {
          prelude: function() {
              var children = readSequence.call(this);

              if (this.getFirstListNode(children) === null) {
                  this.error('Condition is expected');
              }

              return children;
          },
          block: function() {
              return this.Block(false);
          }
      }
  };

  var atrule = {
      'font-face': fontFace,
      'import': _import,
      'media': media,
      'page': page,
      'supports': supports
  };

  var dir = {
      parse: function() {
          return this.createSingleNodeList(
              this.Identifier()
          );
      }
  };

  var has$3 = {
      parse: function() {
          return this.createSingleNodeList(
              this.SelectorList()
          );
      }
  };

  var lang$1 = {
      parse: function() {
          return this.createSingleNodeList(
              this.Identifier()
          );
      }
  };

  var selectorList = {
      parse: function selectorList() {
          return this.createSingleNodeList(
              this.SelectorList()
          );
      }
  };

  var matches = selectorList;

  var not$2 = selectorList;

  var ALLOW_OF_CLAUSE = true;

  var nthWithOfClause = {
      parse: function nthWithOfClause() {
          return this.createSingleNodeList(
              this.Nth(ALLOW_OF_CLAUSE)
          );
      }
  };

  var nthChild = nthWithOfClause;

  var nthLastChild = nthWithOfClause;

  var DISALLOW_OF_CLAUSE = false;

  var nth = {
      parse: function nth() {
          return this.createSingleNodeList(
              this.Nth(DISALLOW_OF_CLAUSE)
          );
      }
  };

  var nthLastOfType = nth;

  var nthOfType = nth;

  var slotted = {
      parse: function compoundSelector() {
          return this.createSingleNodeList(
              this.Selector()
          );
      }
  };

  var pseudo$1 = {
      'dir': dir,
      'has': has$3,
      'lang': lang$1,
      'matches': matches,
      'not': not$2,
      'nth-child': nthChild,
      'nth-last-child': nthLastChild,
      'nth-last-of-type': nthLastOfType,
      'nth-of-type': nthOfType,
      'slotted': slotted
  };

  var parser = {
      parseContext: {
          default: 'StyleSheet',
          stylesheet: 'StyleSheet',
          atrule: 'Atrule',
          atrulePrelude: function(options) {
              return this.AtrulePrelude(options.atrule ? String(options.atrule) : null);
          },
          mediaQueryList: 'MediaQueryList',
          mediaQuery: 'MediaQuery',
          rule: 'Rule',
          selectorList: 'SelectorList',
          selector: 'Selector',
          block: function() {
              return this.Block(true);
          },
          declarationList: 'DeclarationList',
          declaration: 'Declaration',
          value: 'Value'
      },
      scope: scope,
      atrule: atrule,
      pseudo: pseudo$1,
      node: node
  };

  var walker = {
      node: node
  };

  var name = "css-tree";
  var version$1 = "1.1.3";
  var description = "A tool set for CSS: fast detailed parser (CSS → AST), walker (AST traversal), generator (AST → CSS) and lexer (validation and matching) based on specs and browser implementations";
  var author = "Roman Dvornov <rdvornov@gmail.com> (https://github.com/lahmatiy)";
  var license = "MIT";
  var repository = "csstree/csstree";
  var keywords = [
  	"css",
  	"ast",
  	"tokenizer",
  	"parser",
  	"walker",
  	"lexer",
  	"generator",
  	"utils",
  	"syntax",
  	"validation"
  ];
  var main = "lib/index.js";
  var unpkg = "dist/csstree.min.js";
  var jsdelivr = "dist/csstree.min.js";
  var scripts = {
  	build: "rollup --config",
  	lint: "eslint data lib scripts test && node scripts/review-syntax-patch --lint && node scripts/update-docs --lint",
  	"lint-and-test": "npm run lint && npm test",
  	"update:docs": "node scripts/update-docs",
  	"review:syntax-patch": "node scripts/review-syntax-patch",
  	test: "mocha --reporter progress",
  	coverage: "nyc npm test",
  	travis: "nyc npm run lint-and-test && npm run coveralls",
  	coveralls: "nyc report --reporter=text-lcov | coveralls",
  	prepublishOnly: "npm run build",
  	hydrogen: "node --trace-hydrogen --trace-phase=Z --trace-deopt --code-comments --hydrogen-track-positions --redirect-code-traces --redirect-code-traces-to=code.asm --trace_hydrogen_file=code.cfg --print-opt-code bin/parse --stat -o /dev/null"
  };
  var dependencies = {
  	"mdn-data": "2.0.14",
  	"source-map": "^0.6.1"
  };
  var devDependencies = {
  	"@rollup/plugin-commonjs": "^11.0.2",
  	"@rollup/plugin-json": "^4.0.2",
  	"@rollup/plugin-node-resolve": "^7.1.1",
  	coveralls: "^3.0.9",
  	eslint: "^6.8.0",
  	"json-to-ast": "^2.1.0",
  	mocha: "^6.2.3",
  	nyc: "^14.1.1",
  	rollup: "^1.32.1",
  	"rollup-plugin-terser": "^5.3.0"
  };
  var engines = {
  	node: ">=8.0.0"
  };
  var files = [
  	"data",
  	"dist",
  	"lib"
  ];
  var require$$4 = {
  	name: name,
  	version: version$1,
  	description: description,
  	author: author,
  	license: license,
  	repository: repository,
  	keywords: keywords,
  	main: main,
  	unpkg: unpkg,
  	jsdelivr: jsdelivr,
  	scripts: scripts,
  	dependencies: dependencies,
  	devDependencies: devDependencies,
  	engines: engines,
  	files: files
  };

  function merge() {
      var dest = {};

      for (var i = 0; i < arguments.length; i++) {
          var src = arguments[i];
          for (var key in src) {
              dest[key] = src[key];
          }
      }

      return dest;
  }

  var syntax = create.create(
      merge(
          lexer,
          parser,
          walker
      )
  );
  var version = require$$4.version;
  syntax.version = version;

  var lib$3 = syntax;

  //Types of elements found in the DOM
  var domelementtype = {
  	Text: "text", //Text
  	Directive: "directive", //<? ... ?>
  	Comment: "comment", //<!-- ... -->
  	Script: "script", //<script> tags
  	Style: "style", //<style> tags
  	Tag: "tag", //Any tag
  	CDATA: "cdata", //<![CDATA[ ... ]]>
  	Doctype: "doctype",

  	isTag: function(elem){
  		return elem.type === "tag" || elem.type === "script" || elem.type === "style";
  	}
  };

  var lib$2 = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports, "__esModule", { value: true });
  exports.Doctype = exports.CDATA = exports.Tag = exports.Style = exports.Script = exports.Comment = exports.Directive = exports.Text = exports.Root = exports.isTag = exports.ElementType = void 0;
  /** Types of elements found in htmlparser2's DOM */
  var ElementType;
  (function (ElementType) {
      /** Type for the root element of a document */
      ElementType["Root"] = "root";
      /** Type for Text */
      ElementType["Text"] = "text";
      /** Type for <? ... ?> */
      ElementType["Directive"] = "directive";
      /** Type for <!-- ... --> */
      ElementType["Comment"] = "comment";
      /** Type for <script> tags */
      ElementType["Script"] = "script";
      /** Type for <style> tags */
      ElementType["Style"] = "style";
      /** Type for Any tag */
      ElementType["Tag"] = "tag";
      /** Type for <![CDATA[ ... ]]> */
      ElementType["CDATA"] = "cdata";
      /** Type for <!doctype ...> */
      ElementType["Doctype"] = "doctype";
  })(ElementType = exports.ElementType || (exports.ElementType = {}));
  /**
   * Tests whether an element is a tag or not.
   *
   * @param elem Element to test
   */
  function isTag(elem) {
      return (elem.type === ElementType.Tag ||
          elem.type === ElementType.Script ||
          elem.type === ElementType.Style);
  }
  exports.isTag = isTag;
  // Exports for backwards compatibility
  /** Type for the root element of a document */
  exports.Root = ElementType.Root;
  /** Type for Text */
  exports.Text = ElementType.Text;
  /** Type for <? ... ?> */
  exports.Directive = ElementType.Directive;
  /** Type for <!-- ... --> */
  exports.Comment = ElementType.Comment;
  /** Type for <script> tags */
  exports.Script = ElementType.Script;
  /** Type for <style> tags */
  exports.Style = ElementType.Style;
  /** Type for Any tag */
  exports.Tag = ElementType.Tag;
  /** Type for <![CDATA[ ... ]]> */
  exports.CDATA = ElementType.CDATA;
  /** Type for <!doctype ...> */
  exports.Doctype = ElementType.Doctype;
  });

  var Aacute$1 = "Á";
  var aacute$1 = "á";
  var Abreve = "Ă";
  var abreve = "ă";
  var ac = "∾";
  var acd = "∿";
  var acE = "∾̳";
  var Acirc$1 = "Â";
  var acirc$1 = "â";
  var acute$1 = "´";
  var Acy = "А";
  var acy = "а";
  var AElig$1 = "Æ";
  var aelig$1 = "æ";
  var af = "⁡";
  var Afr = "𝔄";
  var afr = "𝔞";
  var Agrave$1 = "À";
  var agrave$1 = "à";
  var alefsym = "ℵ";
  var aleph = "ℵ";
  var Alpha = "Α";
  var alpha = "α";
  var Amacr = "Ā";
  var amacr = "ā";
  var amalg = "⨿";
  var amp$2 = "&";
  var AMP$1 = "&";
  var andand = "⩕";
  var And = "⩓";
  var and = "∧";
  var andd = "⩜";
  var andslope = "⩘";
  var andv = "⩚";
  var ang = "∠";
  var ange = "⦤";
  var angle = "∠";
  var angmsdaa = "⦨";
  var angmsdab = "⦩";
  var angmsdac = "⦪";
  var angmsdad = "⦫";
  var angmsdae = "⦬";
  var angmsdaf = "⦭";
  var angmsdag = "⦮";
  var angmsdah = "⦯";
  var angmsd = "∡";
  var angrt = "∟";
  var angrtvb = "⊾";
  var angrtvbd = "⦝";
  var angsph = "∢";
  var angst = "Å";
  var angzarr = "⍼";
  var Aogon = "Ą";
  var aogon = "ą";
  var Aopf = "𝔸";
  var aopf = "𝕒";
  var apacir = "⩯";
  var ap = "≈";
  var apE = "⩰";
  var ape = "≊";
  var apid = "≋";
  var apos$1 = "'";
  var ApplyFunction = "⁡";
  var approx = "≈";
  var approxeq = "≊";
  var Aring$1 = "Å";
  var aring$1 = "å";
  var Ascr = "𝒜";
  var ascr = "𝒶";
  var Assign = "≔";
  var ast = "*";
  var asymp = "≈";
  var asympeq = "≍";
  var Atilde$1 = "Ã";
  var atilde$1 = "ã";
  var Auml$1 = "Ä";
  var auml$1 = "ä";
  var awconint = "∳";
  var awint = "⨑";
  var backcong = "≌";
  var backepsilon = "϶";
  var backprime = "‵";
  var backsim = "∽";
  var backsimeq = "⋍";
  var Backslash = "∖";
  var Barv = "⫧";
  var barvee = "⊽";
  var barwed = "⌅";
  var Barwed = "⌆";
  var barwedge = "⌅";
  var bbrk = "⎵";
  var bbrktbrk = "⎶";
  var bcong = "≌";
  var Bcy = "Б";
  var bcy = "б";
  var bdquo = "„";
  var becaus = "∵";
  var because = "∵";
  var Because = "∵";
  var bemptyv = "⦰";
  var bepsi = "϶";
  var bernou = "ℬ";
  var Bernoullis = "ℬ";
  var Beta = "Β";
  var beta = "β";
  var beth = "ℶ";
  var between = "≬";
  var Bfr = "𝔅";
  var bfr = "𝔟";
  var bigcap = "⋂";
  var bigcirc = "◯";
  var bigcup = "⋃";
  var bigodot = "⨀";
  var bigoplus = "⨁";
  var bigotimes = "⨂";
  var bigsqcup = "⨆";
  var bigstar = "★";
  var bigtriangledown = "▽";
  var bigtriangleup = "△";
  var biguplus = "⨄";
  var bigvee = "⋁";
  var bigwedge = "⋀";
  var bkarow = "⤍";
  var blacklozenge = "⧫";
  var blacksquare = "▪";
  var blacktriangle = "▴";
  var blacktriangledown = "▾";
  var blacktriangleleft = "◂";
  var blacktriangleright = "▸";
  var blank = "␣";
  var blk12 = "▒";
  var blk14 = "░";
  var blk34 = "▓";
  var block = "█";
  var bne = "=⃥";
  var bnequiv = "≡⃥";
  var bNot = "⫭";
  var bnot = "⌐";
  var Bopf = "𝔹";
  var bopf = "𝕓";
  var bot = "⊥";
  var bottom = "⊥";
  var bowtie = "⋈";
  var boxbox = "⧉";
  var boxdl = "┐";
  var boxdL = "╕";
  var boxDl = "╖";
  var boxDL = "╗";
  var boxdr = "┌";
  var boxdR = "╒";
  var boxDr = "╓";
  var boxDR = "╔";
  var boxh = "─";
  var boxH = "═";
  var boxhd = "┬";
  var boxHd = "╤";
  var boxhD = "╥";
  var boxHD = "╦";
  var boxhu = "┴";
  var boxHu = "╧";
  var boxhU = "╨";
  var boxHU = "╩";
  var boxminus = "⊟";
  var boxplus = "⊞";
  var boxtimes = "⊠";
  var boxul = "┘";
  var boxuL = "╛";
  var boxUl = "╜";
  var boxUL = "╝";
  var boxur = "└";
  var boxuR = "╘";
  var boxUr = "╙";
  var boxUR = "╚";
  var boxv = "│";
  var boxV = "║";
  var boxvh = "┼";
  var boxvH = "╪";
  var boxVh = "╫";
  var boxVH = "╬";
  var boxvl = "┤";
  var boxvL = "╡";
  var boxVl = "╢";
  var boxVL = "╣";
  var boxvr = "├";
  var boxvR = "╞";
  var boxVr = "╟";
  var boxVR = "╠";
  var bprime = "‵";
  var breve = "˘";
  var Breve = "˘";
  var brvbar$1 = "¦";
  var bscr = "𝒷";
  var Bscr = "ℬ";
  var bsemi = "⁏";
  var bsim = "∽";
  var bsime = "⋍";
  var bsolb = "⧅";
  var bsol = "\\";
  var bsolhsub = "⟈";
  var bull = "•";
  var bullet = "•";
  var bump = "≎";
  var bumpE = "⪮";
  var bumpe = "≏";
  var Bumpeq = "≎";
  var bumpeq = "≏";
  var Cacute = "Ć";
  var cacute = "ć";
  var capand = "⩄";
  var capbrcup = "⩉";
  var capcap = "⩋";
  var cap = "∩";
  var Cap = "⋒";
  var capcup = "⩇";
  var capdot = "⩀";
  var CapitalDifferentialD = "ⅅ";
  var caps = "∩︀";
  var caret = "⁁";
  var caron = "ˇ";
  var Cayleys = "ℭ";
  var ccaps = "⩍";
  var Ccaron = "Č";
  var ccaron = "č";
  var Ccedil$1 = "Ç";
  var ccedil$1 = "ç";
  var Ccirc = "Ĉ";
  var ccirc = "ĉ";
  var Cconint = "∰";
  var ccups = "⩌";
  var ccupssm = "⩐";
  var Cdot = "Ċ";
  var cdot = "ċ";
  var cedil$1 = "¸";
  var Cedilla = "¸";
  var cemptyv = "⦲";
  var cent$1 = "¢";
  var centerdot = "·";
  var CenterDot = "·";
  var cfr = "𝔠";
  var Cfr = "ℭ";
  var CHcy = "Ч";
  var chcy = "ч";
  var check = "✓";
  var checkmark = "✓";
  var Chi = "Χ";
  var chi = "χ";
  var circ = "ˆ";
  var circeq = "≗";
  var circlearrowleft = "↺";
  var circlearrowright = "↻";
  var circledast = "⊛";
  var circledcirc = "⊚";
  var circleddash = "⊝";
  var CircleDot = "⊙";
  var circledR = "®";
  var circledS = "Ⓢ";
  var CircleMinus = "⊖";
  var CirclePlus = "⊕";
  var CircleTimes = "⊗";
  var cir = "○";
  var cirE = "⧃";
  var cire = "≗";
  var cirfnint = "⨐";
  var cirmid = "⫯";
  var cirscir = "⧂";
  var ClockwiseContourIntegral = "∲";
  var CloseCurlyDoubleQuote = "”";
  var CloseCurlyQuote = "’";
  var clubs = "♣";
  var clubsuit = "♣";
  var colon = ":";
  var Colon = "∷";
  var Colone = "⩴";
  var colone = "≔";
  var coloneq = "≔";
  var comma = ",";
  var commat = "@";
  var comp = "∁";
  var compfn = "∘";
  var complement = "∁";
  var complexes = "ℂ";
  var cong = "≅";
  var congdot = "⩭";
  var Congruent = "≡";
  var conint = "∮";
  var Conint = "∯";
  var ContourIntegral = "∮";
  var copf = "𝕔";
  var Copf = "ℂ";
  var coprod = "∐";
  var Coproduct = "∐";
  var copy$1 = "©";
  var COPY$1 = "©";
  var copysr = "℗";
  var CounterClockwiseContourIntegral = "∳";
  var crarr = "↵";
  var cross = "✗";
  var Cross = "⨯";
  var Cscr = "𝒞";
  var cscr = "𝒸";
  var csub = "⫏";
  var csube = "⫑";
  var csup = "⫐";
  var csupe = "⫒";
  var ctdot = "⋯";
  var cudarrl = "⤸";
  var cudarrr = "⤵";
  var cuepr = "⋞";
  var cuesc = "⋟";
  var cularr = "↶";
  var cularrp = "⤽";
  var cupbrcap = "⩈";
  var cupcap = "⩆";
  var CupCap = "≍";
  var cup = "∪";
  var Cup = "⋓";
  var cupcup = "⩊";
  var cupdot = "⊍";
  var cupor = "⩅";
  var cups = "∪︀";
  var curarr = "↷";
  var curarrm = "⤼";
  var curlyeqprec = "⋞";
  var curlyeqsucc = "⋟";
  var curlyvee = "⋎";
  var curlywedge = "⋏";
  var curren$1 = "¤";
  var curvearrowleft = "↶";
  var curvearrowright = "↷";
  var cuvee = "⋎";
  var cuwed = "⋏";
  var cwconint = "∲";
  var cwint = "∱";
  var cylcty = "⌭";
  var dagger = "†";
  var Dagger = "‡";
  var daleth = "ℸ";
  var darr = "↓";
  var Darr = "↡";
  var dArr = "⇓";
  var dash = "‐";
  var Dashv = "⫤";
  var dashv = "⊣";
  var dbkarow = "⤏";
  var dblac = "˝";
  var Dcaron = "Ď";
  var dcaron = "ď";
  var Dcy = "Д";
  var dcy = "д";
  var ddagger = "‡";
  var ddarr = "⇊";
  var DD = "ⅅ";
  var dd = "ⅆ";
  var DDotrahd = "⤑";
  var ddotseq = "⩷";
  var deg$1 = "°";
  var Del = "∇";
  var Delta = "Δ";
  var delta = "δ";
  var demptyv = "⦱";
  var dfisht = "⥿";
  var Dfr = "𝔇";
  var dfr = "𝔡";
  var dHar = "⥥";
  var dharl = "⇃";
  var dharr = "⇂";
  var DiacriticalAcute = "´";
  var DiacriticalDot = "˙";
  var DiacriticalDoubleAcute = "˝";
  var DiacriticalGrave = "`";
  var DiacriticalTilde = "˜";
  var diam = "⋄";
  var diamond = "⋄";
  var Diamond = "⋄";
  var diamondsuit = "♦";
  var diams = "♦";
  var die = "¨";
  var DifferentialD = "ⅆ";
  var digamma = "ϝ";
  var disin = "⋲";
  var div = "÷";
  var divide$2 = "÷";
  var divideontimes = "⋇";
  var divonx = "⋇";
  var DJcy = "Ђ";
  var djcy = "ђ";
  var dlcorn = "⌞";
  var dlcrop = "⌍";
  var dollar = "$";
  var Dopf = "𝔻";
  var dopf = "𝕕";
  var Dot = "¨";
  var dot = "˙";
  var DotDot = "⃜";
  var doteq = "≐";
  var doteqdot = "≑";
  var DotEqual = "≐";
  var dotminus = "∸";
  var dotplus = "∔";
  var dotsquare = "⊡";
  var doublebarwedge = "⌆";
  var DoubleContourIntegral = "∯";
  var DoubleDot = "¨";
  var DoubleDownArrow = "⇓";
  var DoubleLeftArrow = "⇐";
  var DoubleLeftRightArrow = "⇔";
  var DoubleLeftTee = "⫤";
  var DoubleLongLeftArrow = "⟸";
  var DoubleLongLeftRightArrow = "⟺";
  var DoubleLongRightArrow = "⟹";
  var DoubleRightArrow = "⇒";
  var DoubleRightTee = "⊨";
  var DoubleUpArrow = "⇑";
  var DoubleUpDownArrow = "⇕";
  var DoubleVerticalBar = "∥";
  var DownArrowBar = "⤓";
  var downarrow = "↓";
  var DownArrow = "↓";
  var Downarrow = "⇓";
  var DownArrowUpArrow = "⇵";
  var DownBreve = "̑";
  var downdownarrows = "⇊";
  var downharpoonleft = "⇃";
  var downharpoonright = "⇂";
  var DownLeftRightVector = "⥐";
  var DownLeftTeeVector = "⥞";
  var DownLeftVectorBar = "⥖";
  var DownLeftVector = "↽";
  var DownRightTeeVector = "⥟";
  var DownRightVectorBar = "⥗";
  var DownRightVector = "⇁";
  var DownTeeArrow = "↧";
  var DownTee = "⊤";
  var drbkarow = "⤐";
  var drcorn = "⌟";
  var drcrop = "⌌";
  var Dscr = "𝒟";
  var dscr = "𝒹";
  var DScy = "Ѕ";
  var dscy = "ѕ";
  var dsol = "⧶";
  var Dstrok = "Đ";
  var dstrok = "đ";
  var dtdot = "⋱";
  var dtri = "▿";
  var dtrif = "▾";
  var duarr = "⇵";
  var duhar = "⥯";
  var dwangle = "⦦";
  var DZcy = "Џ";
  var dzcy = "џ";
  var dzigrarr = "⟿";
  var Eacute$1 = "É";
  var eacute$1 = "é";
  var easter = "⩮";
  var Ecaron = "Ě";
  var ecaron = "ě";
  var Ecirc$1 = "Ê";
  var ecirc$1 = "ê";
  var ecir = "≖";
  var ecolon = "≕";
  var Ecy = "Э";
  var ecy = "э";
  var eDDot = "⩷";
  var Edot = "Ė";
  var edot = "ė";
  var eDot = "≑";
  var ee = "ⅇ";
  var efDot = "≒";
  var Efr = "𝔈";
  var efr = "𝔢";
  var eg = "⪚";
  var Egrave$1 = "È";
  var egrave$1 = "è";
  var egs = "⪖";
  var egsdot = "⪘";
  var el = "⪙";
  var Element = "∈";
  var elinters = "⏧";
  var ell = "ℓ";
  var els = "⪕";
  var elsdot = "⪗";
  var Emacr = "Ē";
  var emacr = "ē";
  var empty = "∅";
  var emptyset = "∅";
  var EmptySmallSquare = "◻";
  var emptyv = "∅";
  var EmptyVerySmallSquare = "▫";
  var emsp13 = " ";
  var emsp14 = " ";
  var emsp = " ";
  var ENG = "Ŋ";
  var eng = "ŋ";
  var ensp = " ";
  var Eogon = "Ę";
  var eogon = "ę";
  var Eopf = "𝔼";
  var eopf = "𝕖";
  var epar = "⋕";
  var eparsl = "⧣";
  var eplus = "⩱";
  var epsi = "ε";
  var Epsilon = "Ε";
  var epsilon = "ε";
  var epsiv = "ϵ";
  var eqcirc = "≖";
  var eqcolon = "≕";
  var eqsim = "≂";
  var eqslantgtr = "⪖";
  var eqslantless = "⪕";
  var Equal = "⩵";
  var equals = "=";
  var EqualTilde = "≂";
  var equest = "≟";
  var Equilibrium = "⇌";
  var equiv = "≡";
  var equivDD = "⩸";
  var eqvparsl = "⧥";
  var erarr = "⥱";
  var erDot = "≓";
  var escr = "ℯ";
  var Escr = "ℰ";
  var esdot = "≐";
  var Esim = "⩳";
  var esim = "≂";
  var Eta = "Η";
  var eta = "η";
  var ETH$1 = "Ð";
  var eth$1 = "ð";
  var Euml$1 = "Ë";
  var euml$1 = "ë";
  var euro = "€";
  var excl = "!";
  var exist = "∃";
  var Exists = "∃";
  var expectation = "ℰ";
  var exponentiale = "ⅇ";
  var ExponentialE = "ⅇ";
  var fallingdotseq = "≒";
  var Fcy = "Ф";
  var fcy = "ф";
  var female = "♀";
  var ffilig = "ﬃ";
  var fflig = "ﬀ";
  var ffllig = "ﬄ";
  var Ffr = "𝔉";
  var ffr = "𝔣";
  var filig = "ﬁ";
  var FilledSmallSquare = "◼";
  var FilledVerySmallSquare = "▪";
  var fjlig = "fj";
  var flat = "♭";
  var fllig = "ﬂ";
  var fltns = "▱";
  var fnof = "ƒ";
  var Fopf = "𝔽";
  var fopf = "𝕗";
  var forall = "∀";
  var ForAll = "∀";
  var fork = "⋔";
  var forkv = "⫙";
  var Fouriertrf = "ℱ";
  var fpartint = "⨍";
  var frac12$1 = "½";
  var frac13 = "⅓";
  var frac14$1 = "¼";
  var frac15 = "⅕";
  var frac16 = "⅙";
  var frac18 = "⅛";
  var frac23 = "⅔";
  var frac25 = "⅖";
  var frac34$1 = "¾";
  var frac35 = "⅗";
  var frac38 = "⅜";
  var frac45 = "⅘";
  var frac56 = "⅚";
  var frac58 = "⅝";
  var frac78 = "⅞";
  var frasl = "⁄";
  var frown = "⌢";
  var fscr = "𝒻";
  var Fscr = "ℱ";
  var gacute = "ǵ";
  var Gamma = "Γ";
  var gamma = "γ";
  var Gammad = "Ϝ";
  var gammad = "ϝ";
  var gap = "⪆";
  var Gbreve = "Ğ";
  var gbreve = "ğ";
  var Gcedil = "Ģ";
  var Gcirc = "Ĝ";
  var gcirc = "ĝ";
  var Gcy = "Г";
  var gcy = "г";
  var Gdot = "Ġ";
  var gdot = "ġ";
  var ge = "≥";
  var gE = "≧";
  var gEl = "⪌";
  var gel = "⋛";
  var geq = "≥";
  var geqq = "≧";
  var geqslant = "⩾";
  var gescc = "⪩";
  var ges = "⩾";
  var gesdot = "⪀";
  var gesdoto = "⪂";
  var gesdotol = "⪄";
  var gesl = "⋛︀";
  var gesles = "⪔";
  var Gfr = "𝔊";
  var gfr = "𝔤";
  var gg = "≫";
  var Gg = "⋙";
  var ggg = "⋙";
  var gimel = "ℷ";
  var GJcy = "Ѓ";
  var gjcy = "ѓ";
  var gla = "⪥";
  var gl = "≷";
  var glE = "⪒";
  var glj = "⪤";
  var gnap = "⪊";
  var gnapprox = "⪊";
  var gne = "⪈";
  var gnE = "≩";
  var gneq = "⪈";
  var gneqq = "≩";
  var gnsim = "⋧";
  var Gopf = "𝔾";
  var gopf = "𝕘";
  var grave = "`";
  var GreaterEqual = "≥";
  var GreaterEqualLess = "⋛";
  var GreaterFullEqual = "≧";
  var GreaterGreater = "⪢";
  var GreaterLess = "≷";
  var GreaterSlantEqual = "⩾";
  var GreaterTilde = "≳";
  var Gscr = "𝒢";
  var gscr = "ℊ";
  var gsim = "≳";
  var gsime = "⪎";
  var gsiml = "⪐";
  var gtcc = "⪧";
  var gtcir = "⩺";
  var gt$2 = ">";
  var GT$1 = ">";
  var Gt = "≫";
  var gtdot = "⋗";
  var gtlPar = "⦕";
  var gtquest = "⩼";
  var gtrapprox = "⪆";
  var gtrarr = "⥸";
  var gtrdot = "⋗";
  var gtreqless = "⋛";
  var gtreqqless = "⪌";
  var gtrless = "≷";
  var gtrsim = "≳";
  var gvertneqq = "≩︀";
  var gvnE = "≩︀";
  var Hacek = "ˇ";
  var hairsp = " ";
  var half = "½";
  var hamilt = "ℋ";
  var HARDcy = "Ъ";
  var hardcy = "ъ";
  var harrcir = "⥈";
  var harr = "↔";
  var hArr = "⇔";
  var harrw = "↭";
  var Hat = "^";
  var hbar = "ℏ";
  var Hcirc = "Ĥ";
  var hcirc = "ĥ";
  var hearts = "♥";
  var heartsuit = "♥";
  var hellip = "…";
  var hercon = "⊹";
  var hfr = "𝔥";
  var Hfr = "ℌ";
  var HilbertSpace = "ℋ";
  var hksearow = "⤥";
  var hkswarow = "⤦";
  var hoarr = "⇿";
  var homtht = "∻";
  var hookleftarrow = "↩";
  var hookrightarrow = "↪";
  var hopf = "𝕙";
  var Hopf = "ℍ";
  var horbar = "―";
  var HorizontalLine = "─";
  var hscr = "𝒽";
  var Hscr = "ℋ";
  var hslash = "ℏ";
  var Hstrok = "Ħ";
  var hstrok = "ħ";
  var HumpDownHump = "≎";
  var HumpEqual = "≏";
  var hybull = "⁃";
  var hyphen = "‐";
  var Iacute$1 = "Í";
  var iacute$1 = "í";
  var ic = "⁣";
  var Icirc$1 = "Î";
  var icirc$1 = "î";
  var Icy = "И";
  var icy = "и";
  var Idot = "İ";
  var IEcy = "Е";
  var iecy = "е";
  var iexcl$1 = "¡";
  var iff = "⇔";
  var ifr = "𝔦";
  var Ifr = "ℑ";
  var Igrave$1 = "Ì";
  var igrave$1 = "ì";
  var ii = "ⅈ";
  var iiiint = "⨌";
  var iiint = "∭";
  var iinfin = "⧜";
  var iiota = "℩";
  var IJlig = "Ĳ";
  var ijlig = "ĳ";
  var Imacr = "Ī";
  var imacr = "ī";
  var image = "ℑ";
  var ImaginaryI = "ⅈ";
  var imagline = "ℐ";
  var imagpart = "ℑ";
  var imath = "ı";
  var Im = "ℑ";
  var imof = "⊷";
  var imped = "Ƶ";
  var Implies = "⇒";
  var incare = "℅";
  var infin = "∞";
  var infintie = "⧝";
  var inodot = "ı";
  var intcal = "⊺";
  var int = "∫";
  var Int = "∬";
  var integers = "ℤ";
  var Integral = "∫";
  var intercal = "⊺";
  var Intersection = "⋂";
  var intlarhk = "⨗";
  var intprod = "⨼";
  var InvisibleComma = "⁣";
  var InvisibleTimes = "⁢";
  var IOcy = "Ё";
  var iocy = "ё";
  var Iogon = "Į";
  var iogon = "į";
  var Iopf = "𝕀";
  var iopf = "𝕚";
  var Iota = "Ι";
  var iota = "ι";
  var iprod = "⨼";
  var iquest$1 = "¿";
  var iscr = "𝒾";
  var Iscr = "ℐ";
  var isin = "∈";
  var isindot = "⋵";
  var isinE = "⋹";
  var isins = "⋴";
  var isinsv = "⋳";
  var isinv = "∈";
  var it = "⁢";
  var Itilde = "Ĩ";
  var itilde = "ĩ";
  var Iukcy = "І";
  var iukcy = "і";
  var Iuml$1 = "Ï";
  var iuml$1 = "ï";
  var Jcirc = "Ĵ";
  var jcirc = "ĵ";
  var Jcy = "Й";
  var jcy = "й";
  var Jfr = "𝔍";
  var jfr = "𝔧";
  var jmath = "ȷ";
  var Jopf = "𝕁";
  var jopf = "𝕛";
  var Jscr = "𝒥";
  var jscr = "𝒿";
  var Jsercy = "Ј";
  var jsercy = "ј";
  var Jukcy = "Є";
  var jukcy = "є";
  var Kappa = "Κ";
  var kappa = "κ";
  var kappav = "ϰ";
  var Kcedil = "Ķ";
  var kcedil = "ķ";
  var Kcy = "К";
  var kcy = "к";
  var Kfr = "𝔎";
  var kfr = "𝔨";
  var kgreen = "ĸ";
  var KHcy = "Х";
  var khcy = "х";
  var KJcy = "Ќ";
  var kjcy = "ќ";
  var Kopf = "𝕂";
  var kopf = "𝕜";
  var Kscr = "𝒦";
  var kscr = "𝓀";
  var lAarr = "⇚";
  var Lacute = "Ĺ";
  var lacute = "ĺ";
  var laemptyv = "⦴";
  var lagran = "ℒ";
  var Lambda = "Λ";
  var lambda = "λ";
  var lang = "⟨";
  var Lang = "⟪";
  var langd = "⦑";
  var langle = "⟨";
  var lap = "⪅";
  var Laplacetrf = "ℒ";
  var laquo$1 = "«";
  var larrb = "⇤";
  var larrbfs = "⤟";
  var larr = "←";
  var Larr = "↞";
  var lArr = "⇐";
  var larrfs = "⤝";
  var larrhk = "↩";
  var larrlp = "↫";
  var larrpl = "⤹";
  var larrsim = "⥳";
  var larrtl = "↢";
  var latail = "⤙";
  var lAtail = "⤛";
  var lat = "⪫";
  var late = "⪭";
  var lates = "⪭︀";
  var lbarr = "⤌";
  var lBarr = "⤎";
  var lbbrk = "❲";
  var lbrace = "{";
  var lbrack = "[";
  var lbrke = "⦋";
  var lbrksld = "⦏";
  var lbrkslu = "⦍";
  var Lcaron = "Ľ";
  var lcaron = "ľ";
  var Lcedil = "Ļ";
  var lcedil = "ļ";
  var lceil = "⌈";
  var lcub = "{";
  var Lcy = "Л";
  var lcy = "л";
  var ldca = "⤶";
  var ldquo = "“";
  var ldquor = "„";
  var ldrdhar = "⥧";
  var ldrushar = "⥋";
  var ldsh = "↲";
  var le = "≤";
  var lE = "≦";
  var LeftAngleBracket = "⟨";
  var LeftArrowBar = "⇤";
  var leftarrow = "←";
  var LeftArrow = "←";
  var Leftarrow = "⇐";
  var LeftArrowRightArrow = "⇆";
  var leftarrowtail = "↢";
  var LeftCeiling = "⌈";
  var LeftDoubleBracket = "⟦";
  var LeftDownTeeVector = "⥡";
  var LeftDownVectorBar = "⥙";
  var LeftDownVector = "⇃";
  var LeftFloor = "⌊";
  var leftharpoondown = "↽";
  var leftharpoonup = "↼";
  var leftleftarrows = "⇇";
  var leftrightarrow = "↔";
  var LeftRightArrow = "↔";
  var Leftrightarrow = "⇔";
  var leftrightarrows = "⇆";
  var leftrightharpoons = "⇋";
  var leftrightsquigarrow = "↭";
  var LeftRightVector = "⥎";
  var LeftTeeArrow = "↤";
  var LeftTee = "⊣";
  var LeftTeeVector = "⥚";
  var leftthreetimes = "⋋";
  var LeftTriangleBar = "⧏";
  var LeftTriangle = "⊲";
  var LeftTriangleEqual = "⊴";
  var LeftUpDownVector = "⥑";
  var LeftUpTeeVector = "⥠";
  var LeftUpVectorBar = "⥘";
  var LeftUpVector = "↿";
  var LeftVectorBar = "⥒";
  var LeftVector = "↼";
  var lEg = "⪋";
  var leg = "⋚";
  var leq = "≤";
  var leqq = "≦";
  var leqslant = "⩽";
  var lescc = "⪨";
  var les = "⩽";
  var lesdot = "⩿";
  var lesdoto = "⪁";
  var lesdotor = "⪃";
  var lesg = "⋚︀";
  var lesges = "⪓";
  var lessapprox = "⪅";
  var lessdot = "⋖";
  var lesseqgtr = "⋚";
  var lesseqqgtr = "⪋";
  var LessEqualGreater = "⋚";
  var LessFullEqual = "≦";
  var LessGreater = "≶";
  var lessgtr = "≶";
  var LessLess = "⪡";
  var lesssim = "≲";
  var LessSlantEqual = "⩽";
  var LessTilde = "≲";
  var lfisht = "⥼";
  var lfloor = "⌊";
  var Lfr = "𝔏";
  var lfr = "𝔩";
  var lg = "≶";
  var lgE = "⪑";
  var lHar = "⥢";
  var lhard = "↽";
  var lharu = "↼";
  var lharul = "⥪";
  var lhblk = "▄";
  var LJcy = "Љ";
  var ljcy = "љ";
  var llarr = "⇇";
  var ll = "≪";
  var Ll = "⋘";
  var llcorner = "⌞";
  var Lleftarrow = "⇚";
  var llhard = "⥫";
  var lltri = "◺";
  var Lmidot = "Ŀ";
  var lmidot = "ŀ";
  var lmoustache = "⎰";
  var lmoust = "⎰";
  var lnap = "⪉";
  var lnapprox = "⪉";
  var lne = "⪇";
  var lnE = "≨";
  var lneq = "⪇";
  var lneqq = "≨";
  var lnsim = "⋦";
  var loang = "⟬";
  var loarr = "⇽";
  var lobrk = "⟦";
  var longleftarrow = "⟵";
  var LongLeftArrow = "⟵";
  var Longleftarrow = "⟸";
  var longleftrightarrow = "⟷";
  var LongLeftRightArrow = "⟷";
  var Longleftrightarrow = "⟺";
  var longmapsto = "⟼";
  var longrightarrow = "⟶";
  var LongRightArrow = "⟶";
  var Longrightarrow = "⟹";
  var looparrowleft = "↫";
  var looparrowright = "↬";
  var lopar = "⦅";
  var Lopf = "𝕃";
  var lopf = "𝕝";
  var loplus = "⨭";
  var lotimes = "⨴";
  var lowast = "∗";
  var lowbar = "_";
  var LowerLeftArrow = "↙";
  var LowerRightArrow = "↘";
  var loz = "◊";
  var lozenge = "◊";
  var lozf = "⧫";
  var lpar = "(";
  var lparlt = "⦓";
  var lrarr = "⇆";
  var lrcorner = "⌟";
  var lrhar = "⇋";
  var lrhard = "⥭";
  var lrm = "‎";
  var lrtri = "⊿";
  var lsaquo = "‹";
  var lscr = "𝓁";
  var Lscr = "ℒ";
  var lsh = "↰";
  var Lsh = "↰";
  var lsim = "≲";
  var lsime = "⪍";
  var lsimg = "⪏";
  var lsqb = "[";
  var lsquo = "‘";
  var lsquor = "‚";
  var Lstrok = "Ł";
  var lstrok = "ł";
  var ltcc = "⪦";
  var ltcir = "⩹";
  var lt$2 = "<";
  var LT$1 = "<";
  var Lt = "≪";
  var ltdot = "⋖";
  var lthree = "⋋";
  var ltimes = "⋉";
  var ltlarr = "⥶";
  var ltquest = "⩻";
  var ltri = "◃";
  var ltrie = "⊴";
  var ltrif = "◂";
  var ltrPar = "⦖";
  var lurdshar = "⥊";
  var luruhar = "⥦";
  var lvertneqq = "≨︀";
  var lvnE = "≨︀";
  var macr$1 = "¯";
  var male = "♂";
  var malt = "✠";
  var maltese = "✠";
  var map = "↦";
  var mapsto = "↦";
  var mapstodown = "↧";
  var mapstoleft = "↤";
  var mapstoup = "↥";
  var marker = "▮";
  var mcomma = "⨩";
  var Mcy = "М";
  var mcy = "м";
  var mdash = "—";
  var mDDot = "∺";
  var measuredangle = "∡";
  var MediumSpace = " ";
  var Mellintrf = "ℳ";
  var Mfr = "𝔐";
  var mfr = "𝔪";
  var mho = "℧";
  var micro$1 = "µ";
  var midast = "*";
  var midcir = "⫰";
  var mid = "∣";
  var middot$1 = "·";
  var minusb = "⊟";
  var minus = "−";
  var minusd = "∸";
  var minusdu = "⨪";
  var MinusPlus = "∓";
  var mlcp = "⫛";
  var mldr = "…";
  var mnplus = "∓";
  var models = "⊧";
  var Mopf = "𝕄";
  var mopf = "𝕞";
  var mp = "∓";
  var mscr = "𝓂";
  var Mscr = "ℳ";
  var mstpos = "∾";
  var Mu = "Μ";
  var mu = "μ";
  var multimap = "⊸";
  var mumap = "⊸";
  var nabla = "∇";
  var Nacute = "Ń";
  var nacute = "ń";
  var nang = "∠⃒";
  var nap = "≉";
  var napE = "⩰̸";
  var napid = "≋̸";
  var napos = "ŉ";
  var napprox = "≉";
  var natural = "♮";
  var naturals = "ℕ";
  var natur = "♮";
  var nbsp$1 = " ";
  var nbump = "≎̸";
  var nbumpe = "≏̸";
  var ncap = "⩃";
  var Ncaron = "Ň";
  var ncaron = "ň";
  var Ncedil = "Ņ";
  var ncedil = "ņ";
  var ncong = "≇";
  var ncongdot = "⩭̸";
  var ncup = "⩂";
  var Ncy = "Н";
  var ncy = "н";
  var ndash = "–";
  var nearhk = "⤤";
  var nearr = "↗";
  var neArr = "⇗";
  var nearrow = "↗";
  var ne = "≠";
  var nedot = "≐̸";
  var NegativeMediumSpace = "​";
  var NegativeThickSpace = "​";
  var NegativeThinSpace = "​";
  var NegativeVeryThinSpace = "​";
  var nequiv = "≢";
  var nesear = "⤨";
  var nesim = "≂̸";
  var NestedGreaterGreater = "≫";
  var NestedLessLess = "≪";
  var NewLine = "\n";
  var nexist = "∄";
  var nexists = "∄";
  var Nfr = "𝔑";
  var nfr = "𝔫";
  var ngE = "≧̸";
  var nge = "≱";
  var ngeq = "≱";
  var ngeqq = "≧̸";
  var ngeqslant = "⩾̸";
  var nges = "⩾̸";
  var nGg = "⋙̸";
  var ngsim = "≵";
  var nGt = "≫⃒";
  var ngt = "≯";
  var ngtr = "≯";
  var nGtv = "≫̸";
  var nharr = "↮";
  var nhArr = "⇎";
  var nhpar = "⫲";
  var ni = "∋";
  var nis = "⋼";
  var nisd = "⋺";
  var niv = "∋";
  var NJcy = "Њ";
  var njcy = "њ";
  var nlarr = "↚";
  var nlArr = "⇍";
  var nldr = "‥";
  var nlE = "≦̸";
  var nle = "≰";
  var nleftarrow = "↚";
  var nLeftarrow = "⇍";
  var nleftrightarrow = "↮";
  var nLeftrightarrow = "⇎";
  var nleq = "≰";
  var nleqq = "≦̸";
  var nleqslant = "⩽̸";
  var nles = "⩽̸";
  var nless = "≮";
  var nLl = "⋘̸";
  var nlsim = "≴";
  var nLt = "≪⃒";
  var nlt = "≮";
  var nltri = "⋪";
  var nltrie = "⋬";
  var nLtv = "≪̸";
  var nmid = "∤";
  var NoBreak = "⁠";
  var NonBreakingSpace = " ";
  var nopf = "𝕟";
  var Nopf = "ℕ";
  var Not = "⫬";
  var not$1 = "¬";
  var NotCongruent = "≢";
  var NotCupCap = "≭";
  var NotDoubleVerticalBar = "∦";
  var NotElement = "∉";
  var NotEqual = "≠";
  var NotEqualTilde = "≂̸";
  var NotExists = "∄";
  var NotGreater = "≯";
  var NotGreaterEqual = "≱";
  var NotGreaterFullEqual = "≧̸";
  var NotGreaterGreater = "≫̸";
  var NotGreaterLess = "≹";
  var NotGreaterSlantEqual = "⩾̸";
  var NotGreaterTilde = "≵";
  var NotHumpDownHump = "≎̸";
  var NotHumpEqual = "≏̸";
  var notin = "∉";
  var notindot = "⋵̸";
  var notinE = "⋹̸";
  var notinva = "∉";
  var notinvb = "⋷";
  var notinvc = "⋶";
  var NotLeftTriangleBar = "⧏̸";
  var NotLeftTriangle = "⋪";
  var NotLeftTriangleEqual = "⋬";
  var NotLess = "≮";
  var NotLessEqual = "≰";
  var NotLessGreater = "≸";
  var NotLessLess = "≪̸";
  var NotLessSlantEqual = "⩽̸";
  var NotLessTilde = "≴";
  var NotNestedGreaterGreater = "⪢̸";
  var NotNestedLessLess = "⪡̸";
  var notni = "∌";
  var notniva = "∌";
  var notnivb = "⋾";
  var notnivc = "⋽";
  var NotPrecedes = "⊀";
  var NotPrecedesEqual = "⪯̸";
  var NotPrecedesSlantEqual = "⋠";
  var NotReverseElement = "∌";
  var NotRightTriangleBar = "⧐̸";
  var NotRightTriangle = "⋫";
  var NotRightTriangleEqual = "⋭";
  var NotSquareSubset = "⊏̸";
  var NotSquareSubsetEqual = "⋢";
  var NotSquareSuperset = "⊐̸";
  var NotSquareSupersetEqual = "⋣";
  var NotSubset = "⊂⃒";
  var NotSubsetEqual = "⊈";
  var NotSucceeds = "⊁";
  var NotSucceedsEqual = "⪰̸";
  var NotSucceedsSlantEqual = "⋡";
  var NotSucceedsTilde = "≿̸";
  var NotSuperset = "⊃⃒";
  var NotSupersetEqual = "⊉";
  var NotTilde = "≁";
  var NotTildeEqual = "≄";
  var NotTildeFullEqual = "≇";
  var NotTildeTilde = "≉";
  var NotVerticalBar = "∤";
  var nparallel = "∦";
  var npar = "∦";
  var nparsl = "⫽⃥";
  var npart = "∂̸";
  var npolint = "⨔";
  var npr = "⊀";
  var nprcue = "⋠";
  var nprec = "⊀";
  var npreceq = "⪯̸";
  var npre = "⪯̸";
  var nrarrc = "⤳̸";
  var nrarr = "↛";
  var nrArr = "⇏";
  var nrarrw = "↝̸";
  var nrightarrow = "↛";
  var nRightarrow = "⇏";
  var nrtri = "⋫";
  var nrtrie = "⋭";
  var nsc = "⊁";
  var nsccue = "⋡";
  var nsce = "⪰̸";
  var Nscr = "𝒩";
  var nscr = "𝓃";
  var nshortmid = "∤";
  var nshortparallel = "∦";
  var nsim = "≁";
  var nsime = "≄";
  var nsimeq = "≄";
  var nsmid = "∤";
  var nspar = "∦";
  var nsqsube = "⋢";
  var nsqsupe = "⋣";
  var nsub = "⊄";
  var nsubE = "⫅̸";
  var nsube = "⊈";
  var nsubset = "⊂⃒";
  var nsubseteq = "⊈";
  var nsubseteqq = "⫅̸";
  var nsucc = "⊁";
  var nsucceq = "⪰̸";
  var nsup = "⊅";
  var nsupE = "⫆̸";
  var nsupe = "⊉";
  var nsupset = "⊃⃒";
  var nsupseteq = "⊉";
  var nsupseteqq = "⫆̸";
  var ntgl = "≹";
  var Ntilde$1 = "Ñ";
  var ntilde$1 = "ñ";
  var ntlg = "≸";
  var ntriangleleft = "⋪";
  var ntrianglelefteq = "⋬";
  var ntriangleright = "⋫";
  var ntrianglerighteq = "⋭";
  var Nu = "Ν";
  var nu = "ν";
  var num = "#";
  var numero = "№";
  var numsp = " ";
  var nvap = "≍⃒";
  var nvdash = "⊬";
  var nvDash = "⊭";
  var nVdash = "⊮";
  var nVDash = "⊯";
  var nvge = "≥⃒";
  var nvgt = ">⃒";
  var nvHarr = "⤄";
  var nvinfin = "⧞";
  var nvlArr = "⤂";
  var nvle = "≤⃒";
  var nvlt = "<⃒";
  var nvltrie = "⊴⃒";
  var nvrArr = "⤃";
  var nvrtrie = "⊵⃒";
  var nvsim = "∼⃒";
  var nwarhk = "⤣";
  var nwarr = "↖";
  var nwArr = "⇖";
  var nwarrow = "↖";
  var nwnear = "⤧";
  var Oacute$1 = "Ó";
  var oacute$1 = "ó";
  var oast = "⊛";
  var Ocirc$1 = "Ô";
  var ocirc$1 = "ô";
  var ocir = "⊚";
  var Ocy = "О";
  var ocy = "о";
  var odash = "⊝";
  var Odblac = "Ő";
  var odblac = "ő";
  var odiv = "⨸";
  var odot = "⊙";
  var odsold = "⦼";
  var OElig = "Œ";
  var oelig = "œ";
  var ofcir = "⦿";
  var Ofr = "𝔒";
  var ofr = "𝔬";
  var ogon = "˛";
  var Ograve$1 = "Ò";
  var ograve$1 = "ò";
  var ogt = "⧁";
  var ohbar = "⦵";
  var ohm = "Ω";
  var oint = "∮";
  var olarr = "↺";
  var olcir = "⦾";
  var olcross = "⦻";
  var oline = "‾";
  var olt = "⧀";
  var Omacr = "Ō";
  var omacr = "ō";
  var Omega = "Ω";
  var omega = "ω";
  var Omicron = "Ο";
  var omicron = "ο";
  var omid = "⦶";
  var ominus = "⊖";
  var Oopf = "𝕆";
  var oopf = "𝕠";
  var opar = "⦷";
  var OpenCurlyDoubleQuote = "“";
  var OpenCurlyQuote = "‘";
  var operp = "⦹";
  var oplus = "⊕";
  var orarr = "↻";
  var Or = "⩔";
  var or = "∨";
  var ord = "⩝";
  var order = "ℴ";
  var orderof = "ℴ";
  var ordf$1 = "ª";
  var ordm$1 = "º";
  var origof = "⊶";
  var oror = "⩖";
  var orslope = "⩗";
  var orv = "⩛";
  var oS = "Ⓢ";
  var Oscr = "𝒪";
  var oscr = "ℴ";
  var Oslash$1 = "Ø";
  var oslash$1 = "ø";
  var osol = "⊘";
  var Otilde$1 = "Õ";
  var otilde$1 = "õ";
  var otimesas = "⨶";
  var Otimes = "⨷";
  var otimes = "⊗";
  var Ouml$1 = "Ö";
  var ouml$1 = "ö";
  var ovbar = "⌽";
  var OverBar = "‾";
  var OverBrace = "⏞";
  var OverBracket = "⎴";
  var OverParenthesis = "⏜";
  var para$1 = "¶";
  var parallel = "∥";
  var par = "∥";
  var parsim = "⫳";
  var parsl = "⫽";
  var part = "∂";
  var PartialD = "∂";
  var Pcy = "П";
  var pcy = "п";
  var percnt = "%";
  var period = ".";
  var permil = "‰";
  var perp = "⊥";
  var pertenk = "‱";
  var Pfr = "𝔓";
  var pfr = "𝔭";
  var Phi = "Φ";
  var phi = "φ";
  var phiv = "ϕ";
  var phmmat = "ℳ";
  var phone = "☎";
  var Pi = "Π";
  var pi = "π";
  var pitchfork = "⋔";
  var piv = "ϖ";
  var planck = "ℏ";
  var planckh = "ℎ";
  var plankv = "ℏ";
  var plusacir = "⨣";
  var plusb = "⊞";
  var pluscir = "⨢";
  var plus = "+";
  var plusdo = "∔";
  var plusdu = "⨥";
  var pluse = "⩲";
  var PlusMinus = "±";
  var plusmn$1 = "±";
  var plussim = "⨦";
  var plustwo = "⨧";
  var pm = "±";
  var Poincareplane = "ℌ";
  var pointint = "⨕";
  var popf = "𝕡";
  var Popf = "ℙ";
  var pound$1 = "£";
  var prap = "⪷";
  var Pr = "⪻";
  var pr = "≺";
  var prcue = "≼";
  var precapprox = "⪷";
  var prec = "≺";
  var preccurlyeq = "≼";
  var Precedes = "≺";
  var PrecedesEqual = "⪯";
  var PrecedesSlantEqual = "≼";
  var PrecedesTilde = "≾";
  var preceq = "⪯";
  var precnapprox = "⪹";
  var precneqq = "⪵";
  var precnsim = "⋨";
  var pre = "⪯";
  var prE = "⪳";
  var precsim = "≾";
  var prime = "′";
  var Prime = "″";
  var primes = "ℙ";
  var prnap = "⪹";
  var prnE = "⪵";
  var prnsim = "⋨";
  var prod = "∏";
  var Product = "∏";
  var profalar = "⌮";
  var profline = "⌒";
  var profsurf = "⌓";
  var prop = "∝";
  var Proportional = "∝";
  var Proportion = "∷";
  var propto = "∝";
  var prsim = "≾";
  var prurel = "⊰";
  var Pscr = "𝒫";
  var pscr = "𝓅";
  var Psi = "Ψ";
  var psi = "ψ";
  var puncsp = " ";
  var Qfr = "𝔔";
  var qfr = "𝔮";
  var qint = "⨌";
  var qopf = "𝕢";
  var Qopf = "ℚ";
  var qprime = "⁗";
  var Qscr = "𝒬";
  var qscr = "𝓆";
  var quaternions = "ℍ";
  var quatint = "⨖";
  var quest = "?";
  var questeq = "≟";
  var quot$2 = "\"";
  var QUOT$1 = "\"";
  var rAarr = "⇛";
  var race = "∽̱";
  var Racute = "Ŕ";
  var racute = "ŕ";
  var radic = "√";
  var raemptyv = "⦳";
  var rang = "⟩";
  var Rang = "⟫";
  var rangd = "⦒";
  var range = "⦥";
  var rangle = "⟩";
  var raquo$1 = "»";
  var rarrap = "⥵";
  var rarrb = "⇥";
  var rarrbfs = "⤠";
  var rarrc = "⤳";
  var rarr = "→";
  var Rarr = "↠";
  var rArr = "⇒";
  var rarrfs = "⤞";
  var rarrhk = "↪";
  var rarrlp = "↬";
  var rarrpl = "⥅";
  var rarrsim = "⥴";
  var Rarrtl = "⤖";
  var rarrtl = "↣";
  var rarrw = "↝";
  var ratail = "⤚";
  var rAtail = "⤜";
  var ratio = "∶";
  var rationals = "ℚ";
  var rbarr = "⤍";
  var rBarr = "⤏";
  var RBarr = "⤐";
  var rbbrk = "❳";
  var rbrace = "}";
  var rbrack = "]";
  var rbrke = "⦌";
  var rbrksld = "⦎";
  var rbrkslu = "⦐";
  var Rcaron = "Ř";
  var rcaron = "ř";
  var Rcedil = "Ŗ";
  var rcedil = "ŗ";
  var rceil = "⌉";
  var rcub = "}";
  var Rcy = "Р";
  var rcy = "р";
  var rdca = "⤷";
  var rdldhar = "⥩";
  var rdquo = "”";
  var rdquor = "”";
  var rdsh = "↳";
  var real = "ℜ";
  var realine = "ℛ";
  var realpart = "ℜ";
  var reals = "ℝ";
  var Re = "ℜ";
  var rect = "▭";
  var reg$1 = "®";
  var REG$1 = "®";
  var ReverseElement = "∋";
  var ReverseEquilibrium = "⇋";
  var ReverseUpEquilibrium = "⥯";
  var rfisht = "⥽";
  var rfloor = "⌋";
  var rfr = "𝔯";
  var Rfr = "ℜ";
  var rHar = "⥤";
  var rhard = "⇁";
  var rharu = "⇀";
  var rharul = "⥬";
  var Rho = "Ρ";
  var rho = "ρ";
  var rhov = "ϱ";
  var RightAngleBracket = "⟩";
  var RightArrowBar = "⇥";
  var rightarrow = "→";
  var RightArrow = "→";
  var Rightarrow = "⇒";
  var RightArrowLeftArrow = "⇄";
  var rightarrowtail = "↣";
  var RightCeiling = "⌉";
  var RightDoubleBracket = "⟧";
  var RightDownTeeVector = "⥝";
  var RightDownVectorBar = "⥕";
  var RightDownVector = "⇂";
  var RightFloor = "⌋";
  var rightharpoondown = "⇁";
  var rightharpoonup = "⇀";
  var rightleftarrows = "⇄";
  var rightleftharpoons = "⇌";
  var rightrightarrows = "⇉";
  var rightsquigarrow = "↝";
  var RightTeeArrow = "↦";
  var RightTee = "⊢";
  var RightTeeVector = "⥛";
  var rightthreetimes = "⋌";
  var RightTriangleBar = "⧐";
  var RightTriangle = "⊳";
  var RightTriangleEqual = "⊵";
  var RightUpDownVector = "⥏";
  var RightUpTeeVector = "⥜";
  var RightUpVectorBar = "⥔";
  var RightUpVector = "↾";
  var RightVectorBar = "⥓";
  var RightVector = "⇀";
  var ring = "˚";
  var risingdotseq = "≓";
  var rlarr = "⇄";
  var rlhar = "⇌";
  var rlm = "‏";
  var rmoustache = "⎱";
  var rmoust = "⎱";
  var rnmid = "⫮";
  var roang = "⟭";
  var roarr = "⇾";
  var robrk = "⟧";
  var ropar = "⦆";
  var ropf = "𝕣";
  var Ropf = "ℝ";
  var roplus = "⨮";
  var rotimes = "⨵";
  var RoundImplies = "⥰";
  var rpar = ")";
  var rpargt = "⦔";
  var rppolint = "⨒";
  var rrarr = "⇉";
  var Rrightarrow = "⇛";
  var rsaquo = "›";
  var rscr = "𝓇";
  var Rscr = "ℛ";
  var rsh = "↱";
  var Rsh = "↱";
  var rsqb = "]";
  var rsquo = "’";
  var rsquor = "’";
  var rthree = "⋌";
  var rtimes = "⋊";
  var rtri = "▹";
  var rtrie = "⊵";
  var rtrif = "▸";
  var rtriltri = "⧎";
  var RuleDelayed = "⧴";
  var ruluhar = "⥨";
  var rx = "℞";
  var Sacute = "Ś";
  var sacute = "ś";
  var sbquo = "‚";
  var scap = "⪸";
  var Scaron = "Š";
  var scaron = "š";
  var Sc = "⪼";
  var sc = "≻";
  var sccue = "≽";
  var sce = "⪰";
  var scE = "⪴";
  var Scedil = "Ş";
  var scedil = "ş";
  var Scirc = "Ŝ";
  var scirc = "ŝ";
  var scnap = "⪺";
  var scnE = "⪶";
  var scnsim = "⋩";
  var scpolint = "⨓";
  var scsim = "≿";
  var Scy = "С";
  var scy = "с";
  var sdotb = "⊡";
  var sdot = "⋅";
  var sdote = "⩦";
  var searhk = "⤥";
  var searr = "↘";
  var seArr = "⇘";
  var searrow = "↘";
  var sect$1 = "§";
  var semi = ";";
  var seswar = "⤩";
  var setminus = "∖";
  var setmn = "∖";
  var sext = "✶";
  var Sfr = "𝔖";
  var sfr = "𝔰";
  var sfrown = "⌢";
  var sharp = "♯";
  var SHCHcy = "Щ";
  var shchcy = "щ";
  var SHcy = "Ш";
  var shcy = "ш";
  var ShortDownArrow = "↓";
  var ShortLeftArrow = "←";
  var shortmid = "∣";
  var shortparallel = "∥";
  var ShortRightArrow = "→";
  var ShortUpArrow = "↑";
  var shy$1 = "­";
  var Sigma = "Σ";
  var sigma = "σ";
  var sigmaf = "ς";
  var sigmav = "ς";
  var sim = "∼";
  var simdot = "⩪";
  var sime = "≃";
  var simeq = "≃";
  var simg = "⪞";
  var simgE = "⪠";
  var siml = "⪝";
  var simlE = "⪟";
  var simne = "≆";
  var simplus = "⨤";
  var simrarr = "⥲";
  var slarr = "←";
  var SmallCircle = "∘";
  var smallsetminus = "∖";
  var smashp = "⨳";
  var smeparsl = "⧤";
  var smid = "∣";
  var smile = "⌣";
  var smt = "⪪";
  var smte = "⪬";
  var smtes = "⪬︀";
  var SOFTcy = "Ь";
  var softcy = "ь";
  var solbar = "⌿";
  var solb = "⧄";
  var sol = "/";
  var Sopf = "𝕊";
  var sopf = "𝕤";
  var spades = "♠";
  var spadesuit = "♠";
  var spar = "∥";
  var sqcap = "⊓";
  var sqcaps = "⊓︀";
  var sqcup = "⊔";
  var sqcups = "⊔︀";
  var Sqrt = "√";
  var sqsub = "⊏";
  var sqsube = "⊑";
  var sqsubset = "⊏";
  var sqsubseteq = "⊑";
  var sqsup = "⊐";
  var sqsupe = "⊒";
  var sqsupset = "⊐";
  var sqsupseteq = "⊒";
  var square = "□";
  var Square = "□";
  var SquareIntersection = "⊓";
  var SquareSubset = "⊏";
  var SquareSubsetEqual = "⊑";
  var SquareSuperset = "⊐";
  var SquareSupersetEqual = "⊒";
  var SquareUnion = "⊔";
  var squarf = "▪";
  var squ = "□";
  var squf = "▪";
  var srarr = "→";
  var Sscr = "𝒮";
  var sscr = "𝓈";
  var ssetmn = "∖";
  var ssmile = "⌣";
  var sstarf = "⋆";
  var Star = "⋆";
  var star = "☆";
  var starf = "★";
  var straightepsilon = "ϵ";
  var straightphi = "ϕ";
  var strns = "¯";
  var sub = "⊂";
  var Sub = "⋐";
  var subdot = "⪽";
  var subE = "⫅";
  var sube = "⊆";
  var subedot = "⫃";
  var submult = "⫁";
  var subnE = "⫋";
  var subne = "⊊";
  var subplus = "⪿";
  var subrarr = "⥹";
  var subset = "⊂";
  var Subset = "⋐";
  var subseteq = "⊆";
  var subseteqq = "⫅";
  var SubsetEqual = "⊆";
  var subsetneq = "⊊";
  var subsetneqq = "⫋";
  var subsim = "⫇";
  var subsub = "⫕";
  var subsup = "⫓";
  var succapprox = "⪸";
  var succ = "≻";
  var succcurlyeq = "≽";
  var Succeeds = "≻";
  var SucceedsEqual = "⪰";
  var SucceedsSlantEqual = "≽";
  var SucceedsTilde = "≿";
  var succeq = "⪰";
  var succnapprox = "⪺";
  var succneqq = "⪶";
  var succnsim = "⋩";
  var succsim = "≿";
  var SuchThat = "∋";
  var sum = "∑";
  var Sum = "∑";
  var sung = "♪";
  var sup1$1 = "¹";
  var sup2$1 = "²";
  var sup3$1 = "³";
  var sup = "⊃";
  var Sup = "⋑";
  var supdot = "⪾";
  var supdsub = "⫘";
  var supE = "⫆";
  var supe = "⊇";
  var supedot = "⫄";
  var Superset = "⊃";
  var SupersetEqual = "⊇";
  var suphsol = "⟉";
  var suphsub = "⫗";
  var suplarr = "⥻";
  var supmult = "⫂";
  var supnE = "⫌";
  var supne = "⊋";
  var supplus = "⫀";
  var supset = "⊃";
  var Supset = "⋑";
  var supseteq = "⊇";
  var supseteqq = "⫆";
  var supsetneq = "⊋";
  var supsetneqq = "⫌";
  var supsim = "⫈";
  var supsub = "⫔";
  var supsup = "⫖";
  var swarhk = "⤦";
  var swarr = "↙";
  var swArr = "⇙";
  var swarrow = "↙";
  var swnwar = "⤪";
  var szlig$1 = "ß";
  var Tab$1 = "\t";
  var target = "⌖";
  var Tau = "Τ";
  var tau = "τ";
  var tbrk = "⎴";
  var Tcaron = "Ť";
  var tcaron = "ť";
  var Tcedil = "Ţ";
  var tcedil = "ţ";
  var Tcy = "Т";
  var tcy = "т";
  var tdot = "⃛";
  var telrec = "⌕";
  var Tfr = "𝔗";
  var tfr = "𝔱";
  var there4 = "∴";
  var therefore = "∴";
  var Therefore = "∴";
  var Theta = "Θ";
  var theta = "θ";
  var thetasym = "ϑ";
  var thetav = "ϑ";
  var thickapprox = "≈";
  var thicksim = "∼";
  var ThickSpace = "  ";
  var ThinSpace = " ";
  var thinsp = " ";
  var thkap = "≈";
  var thksim = "∼";
  var THORN$1 = "Þ";
  var thorn$1 = "þ";
  var tilde = "˜";
  var Tilde = "∼";
  var TildeEqual = "≃";
  var TildeFullEqual = "≅";
  var TildeTilde = "≈";
  var timesbar = "⨱";
  var timesb = "⊠";
  var times$1 = "×";
  var timesd = "⨰";
  var tint = "∭";
  var toea = "⤨";
  var topbot = "⌶";
  var topcir = "⫱";
  var top = "⊤";
  var Topf = "𝕋";
  var topf = "𝕥";
  var topfork = "⫚";
  var tosa = "⤩";
  var tprime = "‴";
  var trade = "™";
  var TRADE = "™";
  var triangle = "▵";
  var triangledown = "▿";
  var triangleleft = "◃";
  var trianglelefteq = "⊴";
  var triangleq = "≜";
  var triangleright = "▹";
  var trianglerighteq = "⊵";
  var tridot = "◬";
  var trie = "≜";
  var triminus = "⨺";
  var TripleDot = "⃛";
  var triplus = "⨹";
  var trisb = "⧍";
  var tritime = "⨻";
  var trpezium = "⏢";
  var Tscr = "𝒯";
  var tscr = "𝓉";
  var TScy = "Ц";
  var tscy = "ц";
  var TSHcy = "Ћ";
  var tshcy = "ћ";
  var Tstrok = "Ŧ";
  var tstrok = "ŧ";
  var twixt = "≬";
  var twoheadleftarrow = "↞";
  var twoheadrightarrow = "↠";
  var Uacute$1 = "Ú";
  var uacute$1 = "ú";
  var uarr = "↑";
  var Uarr = "↟";
  var uArr = "⇑";
  var Uarrocir = "⥉";
  var Ubrcy = "Ў";
  var ubrcy = "ў";
  var Ubreve = "Ŭ";
  var ubreve = "ŭ";
  var Ucirc$1 = "Û";
  var ucirc$1 = "û";
  var Ucy = "У";
  var ucy = "у";
  var udarr = "⇅";
  var Udblac = "Ű";
  var udblac = "ű";
  var udhar = "⥮";
  var ufisht = "⥾";
  var Ufr = "𝔘";
  var ufr = "𝔲";
  var Ugrave$1 = "Ù";
  var ugrave$1 = "ù";
  var uHar = "⥣";
  var uharl = "↿";
  var uharr = "↾";
  var uhblk = "▀";
  var ulcorn = "⌜";
  var ulcorner = "⌜";
  var ulcrop = "⌏";
  var ultri = "◸";
  var Umacr = "Ū";
  var umacr = "ū";
  var uml$1 = "¨";
  var UnderBar = "_";
  var UnderBrace = "⏟";
  var UnderBracket = "⎵";
  var UnderParenthesis = "⏝";
  var Union = "⋃";
  var UnionPlus = "⊎";
  var Uogon = "Ų";
  var uogon = "ų";
  var Uopf = "𝕌";
  var uopf = "𝕦";
  var UpArrowBar = "⤒";
  var uparrow = "↑";
  var UpArrow = "↑";
  var Uparrow = "⇑";
  var UpArrowDownArrow = "⇅";
  var updownarrow = "↕";
  var UpDownArrow = "↕";
  var Updownarrow = "⇕";
  var UpEquilibrium = "⥮";
  var upharpoonleft = "↿";
  var upharpoonright = "↾";
  var uplus = "⊎";
  var UpperLeftArrow = "↖";
  var UpperRightArrow = "↗";
  var upsi = "υ";
  var Upsi = "ϒ";
  var upsih = "ϒ";
  var Upsilon = "Υ";
  var upsilon = "υ";
  var UpTeeArrow = "↥";
  var UpTee = "⊥";
  var upuparrows = "⇈";
  var urcorn = "⌝";
  var urcorner = "⌝";
  var urcrop = "⌎";
  var Uring = "Ů";
  var uring = "ů";
  var urtri = "◹";
  var Uscr = "𝒰";
  var uscr = "𝓊";
  var utdot = "⋰";
  var Utilde = "Ũ";
  var utilde = "ũ";
  var utri = "▵";
  var utrif = "▴";
  var uuarr = "⇈";
  var Uuml$1 = "Ü";
  var uuml$1 = "ü";
  var uwangle = "⦧";
  var vangrt = "⦜";
  var varepsilon = "ϵ";
  var varkappa = "ϰ";
  var varnothing = "∅";
  var varphi = "ϕ";
  var varpi = "ϖ";
  var varpropto = "∝";
  var varr = "↕";
  var vArr = "⇕";
  var varrho = "ϱ";
  var varsigma = "ς";
  var varsubsetneq = "⊊︀";
  var varsubsetneqq = "⫋︀";
  var varsupsetneq = "⊋︀";
  var varsupsetneqq = "⫌︀";
  var vartheta = "ϑ";
  var vartriangleleft = "⊲";
  var vartriangleright = "⊳";
  var vBar = "⫨";
  var Vbar = "⫫";
  var vBarv = "⫩";
  var Vcy = "В";
  var vcy = "в";
  var vdash = "⊢";
  var vDash = "⊨";
  var Vdash = "⊩";
  var VDash = "⊫";
  var Vdashl = "⫦";
  var veebar = "⊻";
  var vee = "∨";
  var Vee = "⋁";
  var veeeq = "≚";
  var vellip = "⋮";
  var verbar = "|";
  var Verbar = "‖";
  var vert = "|";
  var Vert = "‖";
  var VerticalBar = "∣";
  var VerticalLine = "|";
  var VerticalSeparator = "❘";
  var VerticalTilde = "≀";
  var VeryThinSpace = " ";
  var Vfr = "𝔙";
  var vfr = "𝔳";
  var vltri = "⊲";
  var vnsub = "⊂⃒";
  var vnsup = "⊃⃒";
  var Vopf = "𝕍";
  var vopf = "𝕧";
  var vprop = "∝";
  var vrtri = "⊳";
  var Vscr = "𝒱";
  var vscr = "𝓋";
  var vsubnE = "⫋︀";
  var vsubne = "⊊︀";
  var vsupnE = "⫌︀";
  var vsupne = "⊋︀";
  var Vvdash = "⊪";
  var vzigzag = "⦚";
  var Wcirc = "Ŵ";
  var wcirc = "ŵ";
  var wedbar = "⩟";
  var wedge = "∧";
  var Wedge = "⋀";
  var wedgeq = "≙";
  var weierp = "℘";
  var Wfr = "𝔚";
  var wfr = "𝔴";
  var Wopf = "𝕎";
  var wopf = "𝕨";
  var wp = "℘";
  var wr = "≀";
  var wreath = "≀";
  var Wscr = "𝒲";
  var wscr = "𝓌";
  var xcap = "⋂";
  var xcirc = "◯";
  var xcup = "⋃";
  var xdtri = "▽";
  var Xfr = "𝔛";
  var xfr = "𝔵";
  var xharr = "⟷";
  var xhArr = "⟺";
  var Xi = "Ξ";
  var xi = "ξ";
  var xlarr = "⟵";
  var xlArr = "⟸";
  var xmap = "⟼";
  var xnis = "⋻";
  var xodot = "⨀";
  var Xopf = "𝕏";
  var xopf = "𝕩";
  var xoplus = "⨁";
  var xotime = "⨂";
  var xrarr = "⟶";
  var xrArr = "⟹";
  var Xscr = "𝒳";
  var xscr = "𝓍";
  var xsqcup = "⨆";
  var xuplus = "⨄";
  var xutri = "△";
  var xvee = "⋁";
  var xwedge = "⋀";
  var Yacute$1 = "Ý";
  var yacute$1 = "ý";
  var YAcy = "Я";
  var yacy = "я";
  var Ycirc = "Ŷ";
  var ycirc = "ŷ";
  var Ycy = "Ы";
  var ycy = "ы";
  var yen$1 = "¥";
  var Yfr = "𝔜";
  var yfr = "𝔶";
  var YIcy = "Ї";
  var yicy = "ї";
  var Yopf = "𝕐";
  var yopf = "𝕪";
  var Yscr = "𝒴";
  var yscr = "𝓎";
  var YUcy = "Ю";
  var yucy = "ю";
  var yuml$1 = "ÿ";
  var Yuml = "Ÿ";
  var Zacute = "Ź";
  var zacute = "ź";
  var Zcaron = "Ž";
  var zcaron = "ž";
  var Zcy = "З";
  var zcy = "з";
  var Zdot = "Ż";
  var zdot = "ż";
  var zeetrf = "ℨ";
  var ZeroWidthSpace = "​";
  var Zeta = "Ζ";
  var zeta = "ζ";
  var zfr = "𝔷";
  var Zfr = "ℨ";
  var ZHcy = "Ж";
  var zhcy = "ж";
  var zigrarr = "⇝";
  var zopf = "𝕫";
  var Zopf = "ℤ";
  var Zscr = "𝒵";
  var zscr = "𝓏";
  var zwj = "‍";
  var zwnj = "‌";
  var require$$1$2 = {
  	Aacute: Aacute$1,
  	aacute: aacute$1,
  	Abreve: Abreve,
  	abreve: abreve,
  	ac: ac,
  	acd: acd,
  	acE: acE,
  	Acirc: Acirc$1,
  	acirc: acirc$1,
  	acute: acute$1,
  	Acy: Acy,
  	acy: acy,
  	AElig: AElig$1,
  	aelig: aelig$1,
  	af: af,
  	Afr: Afr,
  	afr: afr,
  	Agrave: Agrave$1,
  	agrave: agrave$1,
  	alefsym: alefsym,
  	aleph: aleph,
  	Alpha: Alpha,
  	alpha: alpha,
  	Amacr: Amacr,
  	amacr: amacr,
  	amalg: amalg,
  	amp: amp$2,
  	AMP: AMP$1,
  	andand: andand,
  	And: And,
  	and: and,
  	andd: andd,
  	andslope: andslope,
  	andv: andv,
  	ang: ang,
  	ange: ange,
  	angle: angle,
  	angmsdaa: angmsdaa,
  	angmsdab: angmsdab,
  	angmsdac: angmsdac,
  	angmsdad: angmsdad,
  	angmsdae: angmsdae,
  	angmsdaf: angmsdaf,
  	angmsdag: angmsdag,
  	angmsdah: angmsdah,
  	angmsd: angmsd,
  	angrt: angrt,
  	angrtvb: angrtvb,
  	angrtvbd: angrtvbd,
  	angsph: angsph,
  	angst: angst,
  	angzarr: angzarr,
  	Aogon: Aogon,
  	aogon: aogon,
  	Aopf: Aopf,
  	aopf: aopf,
  	apacir: apacir,
  	ap: ap,
  	apE: apE,
  	ape: ape,
  	apid: apid,
  	apos: apos$1,
  	ApplyFunction: ApplyFunction,
  	approx: approx,
  	approxeq: approxeq,
  	Aring: Aring$1,
  	aring: aring$1,
  	Ascr: Ascr,
  	ascr: ascr,
  	Assign: Assign,
  	ast: ast,
  	asymp: asymp,
  	asympeq: asympeq,
  	Atilde: Atilde$1,
  	atilde: atilde$1,
  	Auml: Auml$1,
  	auml: auml$1,
  	awconint: awconint,
  	awint: awint,
  	backcong: backcong,
  	backepsilon: backepsilon,
  	backprime: backprime,
  	backsim: backsim,
  	backsimeq: backsimeq,
  	Backslash: Backslash,
  	Barv: Barv,
  	barvee: barvee,
  	barwed: barwed,
  	Barwed: Barwed,
  	barwedge: barwedge,
  	bbrk: bbrk,
  	bbrktbrk: bbrktbrk,
  	bcong: bcong,
  	Bcy: Bcy,
  	bcy: bcy,
  	bdquo: bdquo,
  	becaus: becaus,
  	because: because,
  	Because: Because,
  	bemptyv: bemptyv,
  	bepsi: bepsi,
  	bernou: bernou,
  	Bernoullis: Bernoullis,
  	Beta: Beta,
  	beta: beta,
  	beth: beth,
  	between: between,
  	Bfr: Bfr,
  	bfr: bfr,
  	bigcap: bigcap,
  	bigcirc: bigcirc,
  	bigcup: bigcup,
  	bigodot: bigodot,
  	bigoplus: bigoplus,
  	bigotimes: bigotimes,
  	bigsqcup: bigsqcup,
  	bigstar: bigstar,
  	bigtriangledown: bigtriangledown,
  	bigtriangleup: bigtriangleup,
  	biguplus: biguplus,
  	bigvee: bigvee,
  	bigwedge: bigwedge,
  	bkarow: bkarow,
  	blacklozenge: blacklozenge,
  	blacksquare: blacksquare,
  	blacktriangle: blacktriangle,
  	blacktriangledown: blacktriangledown,
  	blacktriangleleft: blacktriangleleft,
  	blacktriangleright: blacktriangleright,
  	blank: blank,
  	blk12: blk12,
  	blk14: blk14,
  	blk34: blk34,
  	block: block,
  	bne: bne,
  	bnequiv: bnequiv,
  	bNot: bNot,
  	bnot: bnot,
  	Bopf: Bopf,
  	bopf: bopf,
  	bot: bot,
  	bottom: bottom,
  	bowtie: bowtie,
  	boxbox: boxbox,
  	boxdl: boxdl,
  	boxdL: boxdL,
  	boxDl: boxDl,
  	boxDL: boxDL,
  	boxdr: boxdr,
  	boxdR: boxdR,
  	boxDr: boxDr,
  	boxDR: boxDR,
  	boxh: boxh,
  	boxH: boxH,
  	boxhd: boxhd,
  	boxHd: boxHd,
  	boxhD: boxhD,
  	boxHD: boxHD,
  	boxhu: boxhu,
  	boxHu: boxHu,
  	boxhU: boxhU,
  	boxHU: boxHU,
  	boxminus: boxminus,
  	boxplus: boxplus,
  	boxtimes: boxtimes,
  	boxul: boxul,
  	boxuL: boxuL,
  	boxUl: boxUl,
  	boxUL: boxUL,
  	boxur: boxur,
  	boxuR: boxuR,
  	boxUr: boxUr,
  	boxUR: boxUR,
  	boxv: boxv,
  	boxV: boxV,
  	boxvh: boxvh,
  	boxvH: boxvH,
  	boxVh: boxVh,
  	boxVH: boxVH,
  	boxvl: boxvl,
  	boxvL: boxvL,
  	boxVl: boxVl,
  	boxVL: boxVL,
  	boxvr: boxvr,
  	boxvR: boxvR,
  	boxVr: boxVr,
  	boxVR: boxVR,
  	bprime: bprime,
  	breve: breve,
  	Breve: Breve,
  	brvbar: brvbar$1,
  	bscr: bscr,
  	Bscr: Bscr,
  	bsemi: bsemi,
  	bsim: bsim,
  	bsime: bsime,
  	bsolb: bsolb,
  	bsol: bsol,
  	bsolhsub: bsolhsub,
  	bull: bull,
  	bullet: bullet,
  	bump: bump,
  	bumpE: bumpE,
  	bumpe: bumpe,
  	Bumpeq: Bumpeq,
  	bumpeq: bumpeq,
  	Cacute: Cacute,
  	cacute: cacute,
  	capand: capand,
  	capbrcup: capbrcup,
  	capcap: capcap,
  	cap: cap,
  	Cap: Cap,
  	capcup: capcup,
  	capdot: capdot,
  	CapitalDifferentialD: CapitalDifferentialD,
  	caps: caps,
  	caret: caret,
  	caron: caron,
  	Cayleys: Cayleys,
  	ccaps: ccaps,
  	Ccaron: Ccaron,
  	ccaron: ccaron,
  	Ccedil: Ccedil$1,
  	ccedil: ccedil$1,
  	Ccirc: Ccirc,
  	ccirc: ccirc,
  	Cconint: Cconint,
  	ccups: ccups,
  	ccupssm: ccupssm,
  	Cdot: Cdot,
  	cdot: cdot,
  	cedil: cedil$1,
  	Cedilla: Cedilla,
  	cemptyv: cemptyv,
  	cent: cent$1,
  	centerdot: centerdot,
  	CenterDot: CenterDot,
  	cfr: cfr,
  	Cfr: Cfr,
  	CHcy: CHcy,
  	chcy: chcy,
  	check: check,
  	checkmark: checkmark,
  	Chi: Chi,
  	chi: chi,
  	circ: circ,
  	circeq: circeq,
  	circlearrowleft: circlearrowleft,
  	circlearrowright: circlearrowright,
  	circledast: circledast,
  	circledcirc: circledcirc,
  	circleddash: circleddash,
  	CircleDot: CircleDot,
  	circledR: circledR,
  	circledS: circledS,
  	CircleMinus: CircleMinus,
  	CirclePlus: CirclePlus,
  	CircleTimes: CircleTimes,
  	cir: cir,
  	cirE: cirE,
  	cire: cire,
  	cirfnint: cirfnint,
  	cirmid: cirmid,
  	cirscir: cirscir,
  	ClockwiseContourIntegral: ClockwiseContourIntegral,
  	CloseCurlyDoubleQuote: CloseCurlyDoubleQuote,
  	CloseCurlyQuote: CloseCurlyQuote,
  	clubs: clubs,
  	clubsuit: clubsuit,
  	colon: colon,
  	Colon: Colon,
  	Colone: Colone,
  	colone: colone,
  	coloneq: coloneq,
  	comma: comma,
  	commat: commat,
  	comp: comp,
  	compfn: compfn,
  	complement: complement,
  	complexes: complexes,
  	cong: cong,
  	congdot: congdot,
  	Congruent: Congruent,
  	conint: conint,
  	Conint: Conint,
  	ContourIntegral: ContourIntegral,
  	copf: copf,
  	Copf: Copf,
  	coprod: coprod,
  	Coproduct: Coproduct,
  	copy: copy$1,
  	COPY: COPY$1,
  	copysr: copysr,
  	CounterClockwiseContourIntegral: CounterClockwiseContourIntegral,
  	crarr: crarr,
  	cross: cross,
  	Cross: Cross,
  	Cscr: Cscr,
  	cscr: cscr,
  	csub: csub,
  	csube: csube,
  	csup: csup,
  	csupe: csupe,
  	ctdot: ctdot,
  	cudarrl: cudarrl,
  	cudarrr: cudarrr,
  	cuepr: cuepr,
  	cuesc: cuesc,
  	cularr: cularr,
  	cularrp: cularrp,
  	cupbrcap: cupbrcap,
  	cupcap: cupcap,
  	CupCap: CupCap,
  	cup: cup,
  	Cup: Cup,
  	cupcup: cupcup,
  	cupdot: cupdot,
  	cupor: cupor,
  	cups: cups,
  	curarr: curarr,
  	curarrm: curarrm,
  	curlyeqprec: curlyeqprec,
  	curlyeqsucc: curlyeqsucc,
  	curlyvee: curlyvee,
  	curlywedge: curlywedge,
  	curren: curren$1,
  	curvearrowleft: curvearrowleft,
  	curvearrowright: curvearrowright,
  	cuvee: cuvee,
  	cuwed: cuwed,
  	cwconint: cwconint,
  	cwint: cwint,
  	cylcty: cylcty,
  	dagger: dagger,
  	Dagger: Dagger,
  	daleth: daleth,
  	darr: darr,
  	Darr: Darr,
  	dArr: dArr,
  	dash: dash,
  	Dashv: Dashv,
  	dashv: dashv,
  	dbkarow: dbkarow,
  	dblac: dblac,
  	Dcaron: Dcaron,
  	dcaron: dcaron,
  	Dcy: Dcy,
  	dcy: dcy,
  	ddagger: ddagger,
  	ddarr: ddarr,
  	DD: DD,
  	dd: dd,
  	DDotrahd: DDotrahd,
  	ddotseq: ddotseq,
  	deg: deg$1,
  	Del: Del,
  	Delta: Delta,
  	delta: delta,
  	demptyv: demptyv,
  	dfisht: dfisht,
  	Dfr: Dfr,
  	dfr: dfr,
  	dHar: dHar,
  	dharl: dharl,
  	dharr: dharr,
  	DiacriticalAcute: DiacriticalAcute,
  	DiacriticalDot: DiacriticalDot,
  	DiacriticalDoubleAcute: DiacriticalDoubleAcute,
  	DiacriticalGrave: DiacriticalGrave,
  	DiacriticalTilde: DiacriticalTilde,
  	diam: diam,
  	diamond: diamond,
  	Diamond: Diamond,
  	diamondsuit: diamondsuit,
  	diams: diams,
  	die: die,
  	DifferentialD: DifferentialD,
  	digamma: digamma,
  	disin: disin,
  	div: div,
  	divide: divide$2,
  	divideontimes: divideontimes,
  	divonx: divonx,
  	DJcy: DJcy,
  	djcy: djcy,
  	dlcorn: dlcorn,
  	dlcrop: dlcrop,
  	dollar: dollar,
  	Dopf: Dopf,
  	dopf: dopf,
  	Dot: Dot,
  	dot: dot,
  	DotDot: DotDot,
  	doteq: doteq,
  	doteqdot: doteqdot,
  	DotEqual: DotEqual,
  	dotminus: dotminus,
  	dotplus: dotplus,
  	dotsquare: dotsquare,
  	doublebarwedge: doublebarwedge,
  	DoubleContourIntegral: DoubleContourIntegral,
  	DoubleDot: DoubleDot,
  	DoubleDownArrow: DoubleDownArrow,
  	DoubleLeftArrow: DoubleLeftArrow,
  	DoubleLeftRightArrow: DoubleLeftRightArrow,
  	DoubleLeftTee: DoubleLeftTee,
  	DoubleLongLeftArrow: DoubleLongLeftArrow,
  	DoubleLongLeftRightArrow: DoubleLongLeftRightArrow,
  	DoubleLongRightArrow: DoubleLongRightArrow,
  	DoubleRightArrow: DoubleRightArrow,
  	DoubleRightTee: DoubleRightTee,
  	DoubleUpArrow: DoubleUpArrow,
  	DoubleUpDownArrow: DoubleUpDownArrow,
  	DoubleVerticalBar: DoubleVerticalBar,
  	DownArrowBar: DownArrowBar,
  	downarrow: downarrow,
  	DownArrow: DownArrow,
  	Downarrow: Downarrow,
  	DownArrowUpArrow: DownArrowUpArrow,
  	DownBreve: DownBreve,
  	downdownarrows: downdownarrows,
  	downharpoonleft: downharpoonleft,
  	downharpoonright: downharpoonright,
  	DownLeftRightVector: DownLeftRightVector,
  	DownLeftTeeVector: DownLeftTeeVector,
  	DownLeftVectorBar: DownLeftVectorBar,
  	DownLeftVector: DownLeftVector,
  	DownRightTeeVector: DownRightTeeVector,
  	DownRightVectorBar: DownRightVectorBar,
  	DownRightVector: DownRightVector,
  	DownTeeArrow: DownTeeArrow,
  	DownTee: DownTee,
  	drbkarow: drbkarow,
  	drcorn: drcorn,
  	drcrop: drcrop,
  	Dscr: Dscr,
  	dscr: dscr,
  	DScy: DScy,
  	dscy: dscy,
  	dsol: dsol,
  	Dstrok: Dstrok,
  	dstrok: dstrok,
  	dtdot: dtdot,
  	dtri: dtri,
  	dtrif: dtrif,
  	duarr: duarr,
  	duhar: duhar,
  	dwangle: dwangle,
  	DZcy: DZcy,
  	dzcy: dzcy,
  	dzigrarr: dzigrarr,
  	Eacute: Eacute$1,
  	eacute: eacute$1,
  	easter: easter,
  	Ecaron: Ecaron,
  	ecaron: ecaron,
  	Ecirc: Ecirc$1,
  	ecirc: ecirc$1,
  	ecir: ecir,
  	ecolon: ecolon,
  	Ecy: Ecy,
  	ecy: ecy,
  	eDDot: eDDot,
  	Edot: Edot,
  	edot: edot,
  	eDot: eDot,
  	ee: ee,
  	efDot: efDot,
  	Efr: Efr,
  	efr: efr,
  	eg: eg,
  	Egrave: Egrave$1,
  	egrave: egrave$1,
  	egs: egs,
  	egsdot: egsdot,
  	el: el,
  	Element: Element,
  	elinters: elinters,
  	ell: ell,
  	els: els,
  	elsdot: elsdot,
  	Emacr: Emacr,
  	emacr: emacr,
  	empty: empty,
  	emptyset: emptyset,
  	EmptySmallSquare: EmptySmallSquare,
  	emptyv: emptyv,
  	EmptyVerySmallSquare: EmptyVerySmallSquare,
  	emsp13: emsp13,
  	emsp14: emsp14,
  	emsp: emsp,
  	ENG: ENG,
  	eng: eng,
  	ensp: ensp,
  	Eogon: Eogon,
  	eogon: eogon,
  	Eopf: Eopf,
  	eopf: eopf,
  	epar: epar,
  	eparsl: eparsl,
  	eplus: eplus,
  	epsi: epsi,
  	Epsilon: Epsilon,
  	epsilon: epsilon,
  	epsiv: epsiv,
  	eqcirc: eqcirc,
  	eqcolon: eqcolon,
  	eqsim: eqsim,
  	eqslantgtr: eqslantgtr,
  	eqslantless: eqslantless,
  	Equal: Equal,
  	equals: equals,
  	EqualTilde: EqualTilde,
  	equest: equest,
  	Equilibrium: Equilibrium,
  	equiv: equiv,
  	equivDD: equivDD,
  	eqvparsl: eqvparsl,
  	erarr: erarr,
  	erDot: erDot,
  	escr: escr,
  	Escr: Escr,
  	esdot: esdot,
  	Esim: Esim,
  	esim: esim,
  	Eta: Eta,
  	eta: eta,
  	ETH: ETH$1,
  	eth: eth$1,
  	Euml: Euml$1,
  	euml: euml$1,
  	euro: euro,
  	excl: excl,
  	exist: exist,
  	Exists: Exists,
  	expectation: expectation,
  	exponentiale: exponentiale,
  	ExponentialE: ExponentialE,
  	fallingdotseq: fallingdotseq,
  	Fcy: Fcy,
  	fcy: fcy,
  	female: female,
  	ffilig: ffilig,
  	fflig: fflig,
  	ffllig: ffllig,
  	Ffr: Ffr,
  	ffr: ffr,
  	filig: filig,
  	FilledSmallSquare: FilledSmallSquare,
  	FilledVerySmallSquare: FilledVerySmallSquare,
  	fjlig: fjlig,
  	flat: flat,
  	fllig: fllig,
  	fltns: fltns,
  	fnof: fnof,
  	Fopf: Fopf,
  	fopf: fopf,
  	forall: forall,
  	ForAll: ForAll,
  	fork: fork,
  	forkv: forkv,
  	Fouriertrf: Fouriertrf,
  	fpartint: fpartint,
  	frac12: frac12$1,
  	frac13: frac13,
  	frac14: frac14$1,
  	frac15: frac15,
  	frac16: frac16,
  	frac18: frac18,
  	frac23: frac23,
  	frac25: frac25,
  	frac34: frac34$1,
  	frac35: frac35,
  	frac38: frac38,
  	frac45: frac45,
  	frac56: frac56,
  	frac58: frac58,
  	frac78: frac78,
  	frasl: frasl,
  	frown: frown,
  	fscr: fscr,
  	Fscr: Fscr,
  	gacute: gacute,
  	Gamma: Gamma,
  	gamma: gamma,
  	Gammad: Gammad,
  	gammad: gammad,
  	gap: gap,
  	Gbreve: Gbreve,
  	gbreve: gbreve,
  	Gcedil: Gcedil,
  	Gcirc: Gcirc,
  	gcirc: gcirc,
  	Gcy: Gcy,
  	gcy: gcy,
  	Gdot: Gdot,
  	gdot: gdot,
  	ge: ge,
  	gE: gE,
  	gEl: gEl,
  	gel: gel,
  	geq: geq,
  	geqq: geqq,
  	geqslant: geqslant,
  	gescc: gescc,
  	ges: ges,
  	gesdot: gesdot,
  	gesdoto: gesdoto,
  	gesdotol: gesdotol,
  	gesl: gesl,
  	gesles: gesles,
  	Gfr: Gfr,
  	gfr: gfr,
  	gg: gg,
  	Gg: Gg,
  	ggg: ggg,
  	gimel: gimel,
  	GJcy: GJcy,
  	gjcy: gjcy,
  	gla: gla,
  	gl: gl,
  	glE: glE,
  	glj: glj,
  	gnap: gnap,
  	gnapprox: gnapprox,
  	gne: gne,
  	gnE: gnE,
  	gneq: gneq,
  	gneqq: gneqq,
  	gnsim: gnsim,
  	Gopf: Gopf,
  	gopf: gopf,
  	grave: grave,
  	GreaterEqual: GreaterEqual,
  	GreaterEqualLess: GreaterEqualLess,
  	GreaterFullEqual: GreaterFullEqual,
  	GreaterGreater: GreaterGreater,
  	GreaterLess: GreaterLess,
  	GreaterSlantEqual: GreaterSlantEqual,
  	GreaterTilde: GreaterTilde,
  	Gscr: Gscr,
  	gscr: gscr,
  	gsim: gsim,
  	gsime: gsime,
  	gsiml: gsiml,
  	gtcc: gtcc,
  	gtcir: gtcir,
  	gt: gt$2,
  	GT: GT$1,
  	Gt: Gt,
  	gtdot: gtdot,
  	gtlPar: gtlPar,
  	gtquest: gtquest,
  	gtrapprox: gtrapprox,
  	gtrarr: gtrarr,
  	gtrdot: gtrdot,
  	gtreqless: gtreqless,
  	gtreqqless: gtreqqless,
  	gtrless: gtrless,
  	gtrsim: gtrsim,
  	gvertneqq: gvertneqq,
  	gvnE: gvnE,
  	Hacek: Hacek,
  	hairsp: hairsp,
  	half: half,
  	hamilt: hamilt,
  	HARDcy: HARDcy,
  	hardcy: hardcy,
  	harrcir: harrcir,
  	harr: harr,
  	hArr: hArr,
  	harrw: harrw,
  	Hat: Hat,
  	hbar: hbar,
  	Hcirc: Hcirc,
  	hcirc: hcirc,
  	hearts: hearts,
  	heartsuit: heartsuit,
  	hellip: hellip,
  	hercon: hercon,
  	hfr: hfr,
  	Hfr: Hfr,
  	HilbertSpace: HilbertSpace,
  	hksearow: hksearow,
  	hkswarow: hkswarow,
  	hoarr: hoarr,
  	homtht: homtht,
  	hookleftarrow: hookleftarrow,
  	hookrightarrow: hookrightarrow,
  	hopf: hopf,
  	Hopf: Hopf,
  	horbar: horbar,
  	HorizontalLine: HorizontalLine,
  	hscr: hscr,
  	Hscr: Hscr,
  	hslash: hslash,
  	Hstrok: Hstrok,
  	hstrok: hstrok,
  	HumpDownHump: HumpDownHump,
  	HumpEqual: HumpEqual,
  	hybull: hybull,
  	hyphen: hyphen,
  	Iacute: Iacute$1,
  	iacute: iacute$1,
  	ic: ic,
  	Icirc: Icirc$1,
  	icirc: icirc$1,
  	Icy: Icy,
  	icy: icy,
  	Idot: Idot,
  	IEcy: IEcy,
  	iecy: iecy,
  	iexcl: iexcl$1,
  	iff: iff,
  	ifr: ifr,
  	Ifr: Ifr,
  	Igrave: Igrave$1,
  	igrave: igrave$1,
  	ii: ii,
  	iiiint: iiiint,
  	iiint: iiint,
  	iinfin: iinfin,
  	iiota: iiota,
  	IJlig: IJlig,
  	ijlig: ijlig,
  	Imacr: Imacr,
  	imacr: imacr,
  	image: image,
  	ImaginaryI: ImaginaryI,
  	imagline: imagline,
  	imagpart: imagpart,
  	imath: imath,
  	Im: Im,
  	imof: imof,
  	imped: imped,
  	Implies: Implies,
  	incare: incare,
  	"in": "∈",
  	infin: infin,
  	infintie: infintie,
  	inodot: inodot,
  	intcal: intcal,
  	int: int,
  	Int: Int,
  	integers: integers,
  	Integral: Integral,
  	intercal: intercal,
  	Intersection: Intersection,
  	intlarhk: intlarhk,
  	intprod: intprod,
  	InvisibleComma: InvisibleComma,
  	InvisibleTimes: InvisibleTimes,
  	IOcy: IOcy,
  	iocy: iocy,
  	Iogon: Iogon,
  	iogon: iogon,
  	Iopf: Iopf,
  	iopf: iopf,
  	Iota: Iota,
  	iota: iota,
  	iprod: iprod,
  	iquest: iquest$1,
  	iscr: iscr,
  	Iscr: Iscr,
  	isin: isin,
  	isindot: isindot,
  	isinE: isinE,
  	isins: isins,
  	isinsv: isinsv,
  	isinv: isinv,
  	it: it,
  	Itilde: Itilde,
  	itilde: itilde,
  	Iukcy: Iukcy,
  	iukcy: iukcy,
  	Iuml: Iuml$1,
  	iuml: iuml$1,
  	Jcirc: Jcirc,
  	jcirc: jcirc,
  	Jcy: Jcy,
  	jcy: jcy,
  	Jfr: Jfr,
  	jfr: jfr,
  	jmath: jmath,
  	Jopf: Jopf,
  	jopf: jopf,
  	Jscr: Jscr,
  	jscr: jscr,
  	Jsercy: Jsercy,
  	jsercy: jsercy,
  	Jukcy: Jukcy,
  	jukcy: jukcy,
  	Kappa: Kappa,
  	kappa: kappa,
  	kappav: kappav,
  	Kcedil: Kcedil,
  	kcedil: kcedil,
  	Kcy: Kcy,
  	kcy: kcy,
  	Kfr: Kfr,
  	kfr: kfr,
  	kgreen: kgreen,
  	KHcy: KHcy,
  	khcy: khcy,
  	KJcy: KJcy,
  	kjcy: kjcy,
  	Kopf: Kopf,
  	kopf: kopf,
  	Kscr: Kscr,
  	kscr: kscr,
  	lAarr: lAarr,
  	Lacute: Lacute,
  	lacute: lacute,
  	laemptyv: laemptyv,
  	lagran: lagran,
  	Lambda: Lambda,
  	lambda: lambda,
  	lang: lang,
  	Lang: Lang,
  	langd: langd,
  	langle: langle,
  	lap: lap,
  	Laplacetrf: Laplacetrf,
  	laquo: laquo$1,
  	larrb: larrb,
  	larrbfs: larrbfs,
  	larr: larr,
  	Larr: Larr,
  	lArr: lArr,
  	larrfs: larrfs,
  	larrhk: larrhk,
  	larrlp: larrlp,
  	larrpl: larrpl,
  	larrsim: larrsim,
  	larrtl: larrtl,
  	latail: latail,
  	lAtail: lAtail,
  	lat: lat,
  	late: late,
  	lates: lates,
  	lbarr: lbarr,
  	lBarr: lBarr,
  	lbbrk: lbbrk,
  	lbrace: lbrace,
  	lbrack: lbrack,
  	lbrke: lbrke,
  	lbrksld: lbrksld,
  	lbrkslu: lbrkslu,
  	Lcaron: Lcaron,
  	lcaron: lcaron,
  	Lcedil: Lcedil,
  	lcedil: lcedil,
  	lceil: lceil,
  	lcub: lcub,
  	Lcy: Lcy,
  	lcy: lcy,
  	ldca: ldca,
  	ldquo: ldquo,
  	ldquor: ldquor,
  	ldrdhar: ldrdhar,
  	ldrushar: ldrushar,
  	ldsh: ldsh,
  	le: le,
  	lE: lE,
  	LeftAngleBracket: LeftAngleBracket,
  	LeftArrowBar: LeftArrowBar,
  	leftarrow: leftarrow,
  	LeftArrow: LeftArrow,
  	Leftarrow: Leftarrow,
  	LeftArrowRightArrow: LeftArrowRightArrow,
  	leftarrowtail: leftarrowtail,
  	LeftCeiling: LeftCeiling,
  	LeftDoubleBracket: LeftDoubleBracket,
  	LeftDownTeeVector: LeftDownTeeVector,
  	LeftDownVectorBar: LeftDownVectorBar,
  	LeftDownVector: LeftDownVector,
  	LeftFloor: LeftFloor,
  	leftharpoondown: leftharpoondown,
  	leftharpoonup: leftharpoonup,
  	leftleftarrows: leftleftarrows,
  	leftrightarrow: leftrightarrow,
  	LeftRightArrow: LeftRightArrow,
  	Leftrightarrow: Leftrightarrow,
  	leftrightarrows: leftrightarrows,
  	leftrightharpoons: leftrightharpoons,
  	leftrightsquigarrow: leftrightsquigarrow,
  	LeftRightVector: LeftRightVector,
  	LeftTeeArrow: LeftTeeArrow,
  	LeftTee: LeftTee,
  	LeftTeeVector: LeftTeeVector,
  	leftthreetimes: leftthreetimes,
  	LeftTriangleBar: LeftTriangleBar,
  	LeftTriangle: LeftTriangle,
  	LeftTriangleEqual: LeftTriangleEqual,
  	LeftUpDownVector: LeftUpDownVector,
  	LeftUpTeeVector: LeftUpTeeVector,
  	LeftUpVectorBar: LeftUpVectorBar,
  	LeftUpVector: LeftUpVector,
  	LeftVectorBar: LeftVectorBar,
  	LeftVector: LeftVector,
  	lEg: lEg,
  	leg: leg,
  	leq: leq,
  	leqq: leqq,
  	leqslant: leqslant,
  	lescc: lescc,
  	les: les,
  	lesdot: lesdot,
  	lesdoto: lesdoto,
  	lesdotor: lesdotor,
  	lesg: lesg,
  	lesges: lesges,
  	lessapprox: lessapprox,
  	lessdot: lessdot,
  	lesseqgtr: lesseqgtr,
  	lesseqqgtr: lesseqqgtr,
  	LessEqualGreater: LessEqualGreater,
  	LessFullEqual: LessFullEqual,
  	LessGreater: LessGreater,
  	lessgtr: lessgtr,
  	LessLess: LessLess,
  	lesssim: lesssim,
  	LessSlantEqual: LessSlantEqual,
  	LessTilde: LessTilde,
  	lfisht: lfisht,
  	lfloor: lfloor,
  	Lfr: Lfr,
  	lfr: lfr,
  	lg: lg,
  	lgE: lgE,
  	lHar: lHar,
  	lhard: lhard,
  	lharu: lharu,
  	lharul: lharul,
  	lhblk: lhblk,
  	LJcy: LJcy,
  	ljcy: ljcy,
  	llarr: llarr,
  	ll: ll,
  	Ll: Ll,
  	llcorner: llcorner,
  	Lleftarrow: Lleftarrow,
  	llhard: llhard,
  	lltri: lltri,
  	Lmidot: Lmidot,
  	lmidot: lmidot,
  	lmoustache: lmoustache,
  	lmoust: lmoust,
  	lnap: lnap,
  	lnapprox: lnapprox,
  	lne: lne,
  	lnE: lnE,
  	lneq: lneq,
  	lneqq: lneqq,
  	lnsim: lnsim,
  	loang: loang,
  	loarr: loarr,
  	lobrk: lobrk,
  	longleftarrow: longleftarrow,
  	LongLeftArrow: LongLeftArrow,
  	Longleftarrow: Longleftarrow,
  	longleftrightarrow: longleftrightarrow,
  	LongLeftRightArrow: LongLeftRightArrow,
  	Longleftrightarrow: Longleftrightarrow,
  	longmapsto: longmapsto,
  	longrightarrow: longrightarrow,
  	LongRightArrow: LongRightArrow,
  	Longrightarrow: Longrightarrow,
  	looparrowleft: looparrowleft,
  	looparrowright: looparrowright,
  	lopar: lopar,
  	Lopf: Lopf,
  	lopf: lopf,
  	loplus: loplus,
  	lotimes: lotimes,
  	lowast: lowast,
  	lowbar: lowbar,
  	LowerLeftArrow: LowerLeftArrow,
  	LowerRightArrow: LowerRightArrow,
  	loz: loz,
  	lozenge: lozenge,
  	lozf: lozf,
  	lpar: lpar,
  	lparlt: lparlt,
  	lrarr: lrarr,
  	lrcorner: lrcorner,
  	lrhar: lrhar,
  	lrhard: lrhard,
  	lrm: lrm,
  	lrtri: lrtri,
  	lsaquo: lsaquo,
  	lscr: lscr,
  	Lscr: Lscr,
  	lsh: lsh,
  	Lsh: Lsh,
  	lsim: lsim,
  	lsime: lsime,
  	lsimg: lsimg,
  	lsqb: lsqb,
  	lsquo: lsquo,
  	lsquor: lsquor,
  	Lstrok: Lstrok,
  	lstrok: lstrok,
  	ltcc: ltcc,
  	ltcir: ltcir,
  	lt: lt$2,
  	LT: LT$1,
  	Lt: Lt,
  	ltdot: ltdot,
  	lthree: lthree,
  	ltimes: ltimes,
  	ltlarr: ltlarr,
  	ltquest: ltquest,
  	ltri: ltri,
  	ltrie: ltrie,
  	ltrif: ltrif,
  	ltrPar: ltrPar,
  	lurdshar: lurdshar,
  	luruhar: luruhar,
  	lvertneqq: lvertneqq,
  	lvnE: lvnE,
  	macr: macr$1,
  	male: male,
  	malt: malt,
  	maltese: maltese,
  	"Map": "⤅",
  	map: map,
  	mapsto: mapsto,
  	mapstodown: mapstodown,
  	mapstoleft: mapstoleft,
  	mapstoup: mapstoup,
  	marker: marker,
  	mcomma: mcomma,
  	Mcy: Mcy,
  	mcy: mcy,
  	mdash: mdash,
  	mDDot: mDDot,
  	measuredangle: measuredangle,
  	MediumSpace: MediumSpace,
  	Mellintrf: Mellintrf,
  	Mfr: Mfr,
  	mfr: mfr,
  	mho: mho,
  	micro: micro$1,
  	midast: midast,
  	midcir: midcir,
  	mid: mid,
  	middot: middot$1,
  	minusb: minusb,
  	minus: minus,
  	minusd: minusd,
  	minusdu: minusdu,
  	MinusPlus: MinusPlus,
  	mlcp: mlcp,
  	mldr: mldr,
  	mnplus: mnplus,
  	models: models,
  	Mopf: Mopf,
  	mopf: mopf,
  	mp: mp,
  	mscr: mscr,
  	Mscr: Mscr,
  	mstpos: mstpos,
  	Mu: Mu,
  	mu: mu,
  	multimap: multimap,
  	mumap: mumap,
  	nabla: nabla,
  	Nacute: Nacute,
  	nacute: nacute,
  	nang: nang,
  	nap: nap,
  	napE: napE,
  	napid: napid,
  	napos: napos,
  	napprox: napprox,
  	natural: natural,
  	naturals: naturals,
  	natur: natur,
  	nbsp: nbsp$1,
  	nbump: nbump,
  	nbumpe: nbumpe,
  	ncap: ncap,
  	Ncaron: Ncaron,
  	ncaron: ncaron,
  	Ncedil: Ncedil,
  	ncedil: ncedil,
  	ncong: ncong,
  	ncongdot: ncongdot,
  	ncup: ncup,
  	Ncy: Ncy,
  	ncy: ncy,
  	ndash: ndash,
  	nearhk: nearhk,
  	nearr: nearr,
  	neArr: neArr,
  	nearrow: nearrow,
  	ne: ne,
  	nedot: nedot,
  	NegativeMediumSpace: NegativeMediumSpace,
  	NegativeThickSpace: NegativeThickSpace,
  	NegativeThinSpace: NegativeThinSpace,
  	NegativeVeryThinSpace: NegativeVeryThinSpace,
  	nequiv: nequiv,
  	nesear: nesear,
  	nesim: nesim,
  	NestedGreaterGreater: NestedGreaterGreater,
  	NestedLessLess: NestedLessLess,
  	NewLine: NewLine,
  	nexist: nexist,
  	nexists: nexists,
  	Nfr: Nfr,
  	nfr: nfr,
  	ngE: ngE,
  	nge: nge,
  	ngeq: ngeq,
  	ngeqq: ngeqq,
  	ngeqslant: ngeqslant,
  	nges: nges,
  	nGg: nGg,
  	ngsim: ngsim,
  	nGt: nGt,
  	ngt: ngt,
  	ngtr: ngtr,
  	nGtv: nGtv,
  	nharr: nharr,
  	nhArr: nhArr,
  	nhpar: nhpar,
  	ni: ni,
  	nis: nis,
  	nisd: nisd,
  	niv: niv,
  	NJcy: NJcy,
  	njcy: njcy,
  	nlarr: nlarr,
  	nlArr: nlArr,
  	nldr: nldr,
  	nlE: nlE,
  	nle: nle,
  	nleftarrow: nleftarrow,
  	nLeftarrow: nLeftarrow,
  	nleftrightarrow: nleftrightarrow,
  	nLeftrightarrow: nLeftrightarrow,
  	nleq: nleq,
  	nleqq: nleqq,
  	nleqslant: nleqslant,
  	nles: nles,
  	nless: nless,
  	nLl: nLl,
  	nlsim: nlsim,
  	nLt: nLt,
  	nlt: nlt,
  	nltri: nltri,
  	nltrie: nltrie,
  	nLtv: nLtv,
  	nmid: nmid,
  	NoBreak: NoBreak,
  	NonBreakingSpace: NonBreakingSpace,
  	nopf: nopf,
  	Nopf: Nopf,
  	Not: Not,
  	not: not$1,
  	NotCongruent: NotCongruent,
  	NotCupCap: NotCupCap,
  	NotDoubleVerticalBar: NotDoubleVerticalBar,
  	NotElement: NotElement,
  	NotEqual: NotEqual,
  	NotEqualTilde: NotEqualTilde,
  	NotExists: NotExists,
  	NotGreater: NotGreater,
  	NotGreaterEqual: NotGreaterEqual,
  	NotGreaterFullEqual: NotGreaterFullEqual,
  	NotGreaterGreater: NotGreaterGreater,
  	NotGreaterLess: NotGreaterLess,
  	NotGreaterSlantEqual: NotGreaterSlantEqual,
  	NotGreaterTilde: NotGreaterTilde,
  	NotHumpDownHump: NotHumpDownHump,
  	NotHumpEqual: NotHumpEqual,
  	notin: notin,
  	notindot: notindot,
  	notinE: notinE,
  	notinva: notinva,
  	notinvb: notinvb,
  	notinvc: notinvc,
  	NotLeftTriangleBar: NotLeftTriangleBar,
  	NotLeftTriangle: NotLeftTriangle,
  	NotLeftTriangleEqual: NotLeftTriangleEqual,
  	NotLess: NotLess,
  	NotLessEqual: NotLessEqual,
  	NotLessGreater: NotLessGreater,
  	NotLessLess: NotLessLess,
  	NotLessSlantEqual: NotLessSlantEqual,
  	NotLessTilde: NotLessTilde,
  	NotNestedGreaterGreater: NotNestedGreaterGreater,
  	NotNestedLessLess: NotNestedLessLess,
  	notni: notni,
  	notniva: notniva,
  	notnivb: notnivb,
  	notnivc: notnivc,
  	NotPrecedes: NotPrecedes,
  	NotPrecedesEqual: NotPrecedesEqual,
  	NotPrecedesSlantEqual: NotPrecedesSlantEqual,
  	NotReverseElement: NotReverseElement,
  	NotRightTriangleBar: NotRightTriangleBar,
  	NotRightTriangle: NotRightTriangle,
  	NotRightTriangleEqual: NotRightTriangleEqual,
  	NotSquareSubset: NotSquareSubset,
  	NotSquareSubsetEqual: NotSquareSubsetEqual,
  	NotSquareSuperset: NotSquareSuperset,
  	NotSquareSupersetEqual: NotSquareSupersetEqual,
  	NotSubset: NotSubset,
  	NotSubsetEqual: NotSubsetEqual,
  	NotSucceeds: NotSucceeds,
  	NotSucceedsEqual: NotSucceedsEqual,
  	NotSucceedsSlantEqual: NotSucceedsSlantEqual,
  	NotSucceedsTilde: NotSucceedsTilde,
  	NotSuperset: NotSuperset,
  	NotSupersetEqual: NotSupersetEqual,
  	NotTilde: NotTilde,
  	NotTildeEqual: NotTildeEqual,
  	NotTildeFullEqual: NotTildeFullEqual,
  	NotTildeTilde: NotTildeTilde,
  	NotVerticalBar: NotVerticalBar,
  	nparallel: nparallel,
  	npar: npar,
  	nparsl: nparsl,
  	npart: npart,
  	npolint: npolint,
  	npr: npr,
  	nprcue: nprcue,
  	nprec: nprec,
  	npreceq: npreceq,
  	npre: npre,
  	nrarrc: nrarrc,
  	nrarr: nrarr,
  	nrArr: nrArr,
  	nrarrw: nrarrw,
  	nrightarrow: nrightarrow,
  	nRightarrow: nRightarrow,
  	nrtri: nrtri,
  	nrtrie: nrtrie,
  	nsc: nsc,
  	nsccue: nsccue,
  	nsce: nsce,
  	Nscr: Nscr,
  	nscr: nscr,
  	nshortmid: nshortmid,
  	nshortparallel: nshortparallel,
  	nsim: nsim,
  	nsime: nsime,
  	nsimeq: nsimeq,
  	nsmid: nsmid,
  	nspar: nspar,
  	nsqsube: nsqsube,
  	nsqsupe: nsqsupe,
  	nsub: nsub,
  	nsubE: nsubE,
  	nsube: nsube,
  	nsubset: nsubset,
  	nsubseteq: nsubseteq,
  	nsubseteqq: nsubseteqq,
  	nsucc: nsucc,
  	nsucceq: nsucceq,
  	nsup: nsup,
  	nsupE: nsupE,
  	nsupe: nsupe,
  	nsupset: nsupset,
  	nsupseteq: nsupseteq,
  	nsupseteqq: nsupseteqq,
  	ntgl: ntgl,
  	Ntilde: Ntilde$1,
  	ntilde: ntilde$1,
  	ntlg: ntlg,
  	ntriangleleft: ntriangleleft,
  	ntrianglelefteq: ntrianglelefteq,
  	ntriangleright: ntriangleright,
  	ntrianglerighteq: ntrianglerighteq,
  	Nu: Nu,
  	nu: nu,
  	num: num,
  	numero: numero,
  	numsp: numsp,
  	nvap: nvap,
  	nvdash: nvdash,
  	nvDash: nvDash,
  	nVdash: nVdash,
  	nVDash: nVDash,
  	nvge: nvge,
  	nvgt: nvgt,
  	nvHarr: nvHarr,
  	nvinfin: nvinfin,
  	nvlArr: nvlArr,
  	nvle: nvle,
  	nvlt: nvlt,
  	nvltrie: nvltrie,
  	nvrArr: nvrArr,
  	nvrtrie: nvrtrie,
  	nvsim: nvsim,
  	nwarhk: nwarhk,
  	nwarr: nwarr,
  	nwArr: nwArr,
  	nwarrow: nwarrow,
  	nwnear: nwnear,
  	Oacute: Oacute$1,
  	oacute: oacute$1,
  	oast: oast,
  	Ocirc: Ocirc$1,
  	ocirc: ocirc$1,
  	ocir: ocir,
  	Ocy: Ocy,
  	ocy: ocy,
  	odash: odash,
  	Odblac: Odblac,
  	odblac: odblac,
  	odiv: odiv,
  	odot: odot,
  	odsold: odsold,
  	OElig: OElig,
  	oelig: oelig,
  	ofcir: ofcir,
  	Ofr: Ofr,
  	ofr: ofr,
  	ogon: ogon,
  	Ograve: Ograve$1,
  	ograve: ograve$1,
  	ogt: ogt,
  	ohbar: ohbar,
  	ohm: ohm,
  	oint: oint,
  	olarr: olarr,
  	olcir: olcir,
  	olcross: olcross,
  	oline: oline,
  	olt: olt,
  	Omacr: Omacr,
  	omacr: omacr,
  	Omega: Omega,
  	omega: omega,
  	Omicron: Omicron,
  	omicron: omicron,
  	omid: omid,
  	ominus: ominus,
  	Oopf: Oopf,
  	oopf: oopf,
  	opar: opar,
  	OpenCurlyDoubleQuote: OpenCurlyDoubleQuote,
  	OpenCurlyQuote: OpenCurlyQuote,
  	operp: operp,
  	oplus: oplus,
  	orarr: orarr,
  	Or: Or,
  	or: or,
  	ord: ord,
  	order: order,
  	orderof: orderof,
  	ordf: ordf$1,
  	ordm: ordm$1,
  	origof: origof,
  	oror: oror,
  	orslope: orslope,
  	orv: orv,
  	oS: oS,
  	Oscr: Oscr,
  	oscr: oscr,
  	Oslash: Oslash$1,
  	oslash: oslash$1,
  	osol: osol,
  	Otilde: Otilde$1,
  	otilde: otilde$1,
  	otimesas: otimesas,
  	Otimes: Otimes,
  	otimes: otimes,
  	Ouml: Ouml$1,
  	ouml: ouml$1,
  	ovbar: ovbar,
  	OverBar: OverBar,
  	OverBrace: OverBrace,
  	OverBracket: OverBracket,
  	OverParenthesis: OverParenthesis,
  	para: para$1,
  	parallel: parallel,
  	par: par,
  	parsim: parsim,
  	parsl: parsl,
  	part: part,
  	PartialD: PartialD,
  	Pcy: Pcy,
  	pcy: pcy,
  	percnt: percnt,
  	period: period,
  	permil: permil,
  	perp: perp,
  	pertenk: pertenk,
  	Pfr: Pfr,
  	pfr: pfr,
  	Phi: Phi,
  	phi: phi,
  	phiv: phiv,
  	phmmat: phmmat,
  	phone: phone,
  	Pi: Pi,
  	pi: pi,
  	pitchfork: pitchfork,
  	piv: piv,
  	planck: planck,
  	planckh: planckh,
  	plankv: plankv,
  	plusacir: plusacir,
  	plusb: plusb,
  	pluscir: pluscir,
  	plus: plus,
  	plusdo: plusdo,
  	plusdu: plusdu,
  	pluse: pluse,
  	PlusMinus: PlusMinus,
  	plusmn: plusmn$1,
  	plussim: plussim,
  	plustwo: plustwo,
  	pm: pm,
  	Poincareplane: Poincareplane,
  	pointint: pointint,
  	popf: popf,
  	Popf: Popf,
  	pound: pound$1,
  	prap: prap,
  	Pr: Pr,
  	pr: pr,
  	prcue: prcue,
  	precapprox: precapprox,
  	prec: prec,
  	preccurlyeq: preccurlyeq,
  	Precedes: Precedes,
  	PrecedesEqual: PrecedesEqual,
  	PrecedesSlantEqual: PrecedesSlantEqual,
  	PrecedesTilde: PrecedesTilde,
  	preceq: preceq,
  	precnapprox: precnapprox,
  	precneqq: precneqq,
  	precnsim: precnsim,
  	pre: pre,
  	prE: prE,
  	precsim: precsim,
  	prime: prime,
  	Prime: Prime,
  	primes: primes,
  	prnap: prnap,
  	prnE: prnE,
  	prnsim: prnsim,
  	prod: prod,
  	Product: Product,
  	profalar: profalar,
  	profline: profline,
  	profsurf: profsurf,
  	prop: prop,
  	Proportional: Proportional,
  	Proportion: Proportion,
  	propto: propto,
  	prsim: prsim,
  	prurel: prurel,
  	Pscr: Pscr,
  	pscr: pscr,
  	Psi: Psi,
  	psi: psi,
  	puncsp: puncsp,
  	Qfr: Qfr,
  	qfr: qfr,
  	qint: qint,
  	qopf: qopf,
  	Qopf: Qopf,
  	qprime: qprime,
  	Qscr: Qscr,
  	qscr: qscr,
  	quaternions: quaternions,
  	quatint: quatint,
  	quest: quest,
  	questeq: questeq,
  	quot: quot$2,
  	QUOT: QUOT$1,
  	rAarr: rAarr,
  	race: race,
  	Racute: Racute,
  	racute: racute,
  	radic: radic,
  	raemptyv: raemptyv,
  	rang: rang,
  	Rang: Rang,
  	rangd: rangd,
  	range: range,
  	rangle: rangle,
  	raquo: raquo$1,
  	rarrap: rarrap,
  	rarrb: rarrb,
  	rarrbfs: rarrbfs,
  	rarrc: rarrc,
  	rarr: rarr,
  	Rarr: Rarr,
  	rArr: rArr,
  	rarrfs: rarrfs,
  	rarrhk: rarrhk,
  	rarrlp: rarrlp,
  	rarrpl: rarrpl,
  	rarrsim: rarrsim,
  	Rarrtl: Rarrtl,
  	rarrtl: rarrtl,
  	rarrw: rarrw,
  	ratail: ratail,
  	rAtail: rAtail,
  	ratio: ratio,
  	rationals: rationals,
  	rbarr: rbarr,
  	rBarr: rBarr,
  	RBarr: RBarr,
  	rbbrk: rbbrk,
  	rbrace: rbrace,
  	rbrack: rbrack,
  	rbrke: rbrke,
  	rbrksld: rbrksld,
  	rbrkslu: rbrkslu,
  	Rcaron: Rcaron,
  	rcaron: rcaron,
  	Rcedil: Rcedil,
  	rcedil: rcedil,
  	rceil: rceil,
  	rcub: rcub,
  	Rcy: Rcy,
  	rcy: rcy,
  	rdca: rdca,
  	rdldhar: rdldhar,
  	rdquo: rdquo,
  	rdquor: rdquor,
  	rdsh: rdsh,
  	real: real,
  	realine: realine,
  	realpart: realpart,
  	reals: reals,
  	Re: Re,
  	rect: rect,
  	reg: reg$1,
  	REG: REG$1,
  	ReverseElement: ReverseElement,
  	ReverseEquilibrium: ReverseEquilibrium,
  	ReverseUpEquilibrium: ReverseUpEquilibrium,
  	rfisht: rfisht,
  	rfloor: rfloor,
  	rfr: rfr,
  	Rfr: Rfr,
  	rHar: rHar,
  	rhard: rhard,
  	rharu: rharu,
  	rharul: rharul,
  	Rho: Rho,
  	rho: rho,
  	rhov: rhov,
  	RightAngleBracket: RightAngleBracket,
  	RightArrowBar: RightArrowBar,
  	rightarrow: rightarrow,
  	RightArrow: RightArrow,
  	Rightarrow: Rightarrow,
  	RightArrowLeftArrow: RightArrowLeftArrow,
  	rightarrowtail: rightarrowtail,
  	RightCeiling: RightCeiling,
  	RightDoubleBracket: RightDoubleBracket,
  	RightDownTeeVector: RightDownTeeVector,
  	RightDownVectorBar: RightDownVectorBar,
  	RightDownVector: RightDownVector,
  	RightFloor: RightFloor,
  	rightharpoondown: rightharpoondown,
  	rightharpoonup: rightharpoonup,
  	rightleftarrows: rightleftarrows,
  	rightleftharpoons: rightleftharpoons,
  	rightrightarrows: rightrightarrows,
  	rightsquigarrow: rightsquigarrow,
  	RightTeeArrow: RightTeeArrow,
  	RightTee: RightTee,
  	RightTeeVector: RightTeeVector,
  	rightthreetimes: rightthreetimes,
  	RightTriangleBar: RightTriangleBar,
  	RightTriangle: RightTriangle,
  	RightTriangleEqual: RightTriangleEqual,
  	RightUpDownVector: RightUpDownVector,
  	RightUpTeeVector: RightUpTeeVector,
  	RightUpVectorBar: RightUpVectorBar,
  	RightUpVector: RightUpVector,
  	RightVectorBar: RightVectorBar,
  	RightVector: RightVector,
  	ring: ring,
  	risingdotseq: risingdotseq,
  	rlarr: rlarr,
  	rlhar: rlhar,
  	rlm: rlm,
  	rmoustache: rmoustache,
  	rmoust: rmoust,
  	rnmid: rnmid,
  	roang: roang,
  	roarr: roarr,
  	robrk: robrk,
  	ropar: ropar,
  	ropf: ropf,
  	Ropf: Ropf,
  	roplus: roplus,
  	rotimes: rotimes,
  	RoundImplies: RoundImplies,
  	rpar: rpar,
  	rpargt: rpargt,
  	rppolint: rppolint,
  	rrarr: rrarr,
  	Rrightarrow: Rrightarrow,
  	rsaquo: rsaquo,
  	rscr: rscr,
  	Rscr: Rscr,
  	rsh: rsh,
  	Rsh: Rsh,
  	rsqb: rsqb,
  	rsquo: rsquo,
  	rsquor: rsquor,
  	rthree: rthree,
  	rtimes: rtimes,
  	rtri: rtri,
  	rtrie: rtrie,
  	rtrif: rtrif,
  	rtriltri: rtriltri,
  	RuleDelayed: RuleDelayed,
  	ruluhar: ruluhar,
  	rx: rx,
  	Sacute: Sacute,
  	sacute: sacute,
  	sbquo: sbquo,
  	scap: scap,
  	Scaron: Scaron,
  	scaron: scaron,
  	Sc: Sc,
  	sc: sc,
  	sccue: sccue,
  	sce: sce,
  	scE: scE,
  	Scedil: Scedil,
  	scedil: scedil,
  	Scirc: Scirc,
  	scirc: scirc,
  	scnap: scnap,
  	scnE: scnE,
  	scnsim: scnsim,
  	scpolint: scpolint,
  	scsim: scsim,
  	Scy: Scy,
  	scy: scy,
  	sdotb: sdotb,
  	sdot: sdot,
  	sdote: sdote,
  	searhk: searhk,
  	searr: searr,
  	seArr: seArr,
  	searrow: searrow,
  	sect: sect$1,
  	semi: semi,
  	seswar: seswar,
  	setminus: setminus,
  	setmn: setmn,
  	sext: sext,
  	Sfr: Sfr,
  	sfr: sfr,
  	sfrown: sfrown,
  	sharp: sharp,
  	SHCHcy: SHCHcy,
  	shchcy: shchcy,
  	SHcy: SHcy,
  	shcy: shcy,
  	ShortDownArrow: ShortDownArrow,
  	ShortLeftArrow: ShortLeftArrow,
  	shortmid: shortmid,
  	shortparallel: shortparallel,
  	ShortRightArrow: ShortRightArrow,
  	ShortUpArrow: ShortUpArrow,
  	shy: shy$1,
  	Sigma: Sigma,
  	sigma: sigma,
  	sigmaf: sigmaf,
  	sigmav: sigmav,
  	sim: sim,
  	simdot: simdot,
  	sime: sime,
  	simeq: simeq,
  	simg: simg,
  	simgE: simgE,
  	siml: siml,
  	simlE: simlE,
  	simne: simne,
  	simplus: simplus,
  	simrarr: simrarr,
  	slarr: slarr,
  	SmallCircle: SmallCircle,
  	smallsetminus: smallsetminus,
  	smashp: smashp,
  	smeparsl: smeparsl,
  	smid: smid,
  	smile: smile,
  	smt: smt,
  	smte: smte,
  	smtes: smtes,
  	SOFTcy: SOFTcy,
  	softcy: softcy,
  	solbar: solbar,
  	solb: solb,
  	sol: sol,
  	Sopf: Sopf,
  	sopf: sopf,
  	spades: spades,
  	spadesuit: spadesuit,
  	spar: spar,
  	sqcap: sqcap,
  	sqcaps: sqcaps,
  	sqcup: sqcup,
  	sqcups: sqcups,
  	Sqrt: Sqrt,
  	sqsub: sqsub,
  	sqsube: sqsube,
  	sqsubset: sqsubset,
  	sqsubseteq: sqsubseteq,
  	sqsup: sqsup,
  	sqsupe: sqsupe,
  	sqsupset: sqsupset,
  	sqsupseteq: sqsupseteq,
  	square: square,
  	Square: Square,
  	SquareIntersection: SquareIntersection,
  	SquareSubset: SquareSubset,
  	SquareSubsetEqual: SquareSubsetEqual,
  	SquareSuperset: SquareSuperset,
  	SquareSupersetEqual: SquareSupersetEqual,
  	SquareUnion: SquareUnion,
  	squarf: squarf,
  	squ: squ,
  	squf: squf,
  	srarr: srarr,
  	Sscr: Sscr,
  	sscr: sscr,
  	ssetmn: ssetmn,
  	ssmile: ssmile,
  	sstarf: sstarf,
  	Star: Star,
  	star: star,
  	starf: starf,
  	straightepsilon: straightepsilon,
  	straightphi: straightphi,
  	strns: strns,
  	sub: sub,
  	Sub: Sub,
  	subdot: subdot,
  	subE: subE,
  	sube: sube,
  	subedot: subedot,
  	submult: submult,
  	subnE: subnE,
  	subne: subne,
  	subplus: subplus,
  	subrarr: subrarr,
  	subset: subset,
  	Subset: Subset,
  	subseteq: subseteq,
  	subseteqq: subseteqq,
  	SubsetEqual: SubsetEqual,
  	subsetneq: subsetneq,
  	subsetneqq: subsetneqq,
  	subsim: subsim,
  	subsub: subsub,
  	subsup: subsup,
  	succapprox: succapprox,
  	succ: succ,
  	succcurlyeq: succcurlyeq,
  	Succeeds: Succeeds,
  	SucceedsEqual: SucceedsEqual,
  	SucceedsSlantEqual: SucceedsSlantEqual,
  	SucceedsTilde: SucceedsTilde,
  	succeq: succeq,
  	succnapprox: succnapprox,
  	succneqq: succneqq,
  	succnsim: succnsim,
  	succsim: succsim,
  	SuchThat: SuchThat,
  	sum: sum,
  	Sum: Sum,
  	sung: sung,
  	sup1: sup1$1,
  	sup2: sup2$1,
  	sup3: sup3$1,
  	sup: sup,
  	Sup: Sup,
  	supdot: supdot,
  	supdsub: supdsub,
  	supE: supE,
  	supe: supe,
  	supedot: supedot,
  	Superset: Superset,
  	SupersetEqual: SupersetEqual,
  	suphsol: suphsol,
  	suphsub: suphsub,
  	suplarr: suplarr,
  	supmult: supmult,
  	supnE: supnE,
  	supne: supne,
  	supplus: supplus,
  	supset: supset,
  	Supset: Supset,
  	supseteq: supseteq,
  	supseteqq: supseteqq,
  	supsetneq: supsetneq,
  	supsetneqq: supsetneqq,
  	supsim: supsim,
  	supsub: supsub,
  	supsup: supsup,
  	swarhk: swarhk,
  	swarr: swarr,
  	swArr: swArr,
  	swarrow: swarrow,
  	swnwar: swnwar,
  	szlig: szlig$1,
  	Tab: Tab$1,
  	target: target,
  	Tau: Tau,
  	tau: tau,
  	tbrk: tbrk,
  	Tcaron: Tcaron,
  	tcaron: tcaron,
  	Tcedil: Tcedil,
  	tcedil: tcedil,
  	Tcy: Tcy,
  	tcy: tcy,
  	tdot: tdot,
  	telrec: telrec,
  	Tfr: Tfr,
  	tfr: tfr,
  	there4: there4,
  	therefore: therefore,
  	Therefore: Therefore,
  	Theta: Theta,
  	theta: theta,
  	thetasym: thetasym,
  	thetav: thetav,
  	thickapprox: thickapprox,
  	thicksim: thicksim,
  	ThickSpace: ThickSpace,
  	ThinSpace: ThinSpace,
  	thinsp: thinsp,
  	thkap: thkap,
  	thksim: thksim,
  	THORN: THORN$1,
  	thorn: thorn$1,
  	tilde: tilde,
  	Tilde: Tilde,
  	TildeEqual: TildeEqual,
  	TildeFullEqual: TildeFullEqual,
  	TildeTilde: TildeTilde,
  	timesbar: timesbar,
  	timesb: timesb,
  	times: times$1,
  	timesd: timesd,
  	tint: tint,
  	toea: toea,
  	topbot: topbot,
  	topcir: topcir,
  	top: top,
  	Topf: Topf,
  	topf: topf,
  	topfork: topfork,
  	tosa: tosa,
  	tprime: tprime,
  	trade: trade,
  	TRADE: TRADE,
  	triangle: triangle,
  	triangledown: triangledown,
  	triangleleft: triangleleft,
  	trianglelefteq: trianglelefteq,
  	triangleq: triangleq,
  	triangleright: triangleright,
  	trianglerighteq: trianglerighteq,
  	tridot: tridot,
  	trie: trie,
  	triminus: triminus,
  	TripleDot: TripleDot,
  	triplus: triplus,
  	trisb: trisb,
  	tritime: tritime,
  	trpezium: trpezium,
  	Tscr: Tscr,
  	tscr: tscr,
  	TScy: TScy,
  	tscy: tscy,
  	TSHcy: TSHcy,
  	tshcy: tshcy,
  	Tstrok: Tstrok,
  	tstrok: tstrok,
  	twixt: twixt,
  	twoheadleftarrow: twoheadleftarrow,
  	twoheadrightarrow: twoheadrightarrow,
  	Uacute: Uacute$1,
  	uacute: uacute$1,
  	uarr: uarr,
  	Uarr: Uarr,
  	uArr: uArr,
  	Uarrocir: Uarrocir,
  	Ubrcy: Ubrcy,
  	ubrcy: ubrcy,
  	Ubreve: Ubreve,
  	ubreve: ubreve,
  	Ucirc: Ucirc$1,
  	ucirc: ucirc$1,
  	Ucy: Ucy,
  	ucy: ucy,
  	udarr: udarr,
  	Udblac: Udblac,
  	udblac: udblac,
  	udhar: udhar,
  	ufisht: ufisht,
  	Ufr: Ufr,
  	ufr: ufr,
  	Ugrave: Ugrave$1,
  	ugrave: ugrave$1,
  	uHar: uHar,
  	uharl: uharl,
  	uharr: uharr,
  	uhblk: uhblk,
  	ulcorn: ulcorn,
  	ulcorner: ulcorner,
  	ulcrop: ulcrop,
  	ultri: ultri,
  	Umacr: Umacr,
  	umacr: umacr,
  	uml: uml$1,
  	UnderBar: UnderBar,
  	UnderBrace: UnderBrace,
  	UnderBracket: UnderBracket,
  	UnderParenthesis: UnderParenthesis,
  	Union: Union,
  	UnionPlus: UnionPlus,
  	Uogon: Uogon,
  	uogon: uogon,
  	Uopf: Uopf,
  	uopf: uopf,
  	UpArrowBar: UpArrowBar,
  	uparrow: uparrow,
  	UpArrow: UpArrow,
  	Uparrow: Uparrow,
  	UpArrowDownArrow: UpArrowDownArrow,
  	updownarrow: updownarrow,
  	UpDownArrow: UpDownArrow,
  	Updownarrow: Updownarrow,
  	UpEquilibrium: UpEquilibrium,
  	upharpoonleft: upharpoonleft,
  	upharpoonright: upharpoonright,
  	uplus: uplus,
  	UpperLeftArrow: UpperLeftArrow,
  	UpperRightArrow: UpperRightArrow,
  	upsi: upsi,
  	Upsi: Upsi,
  	upsih: upsih,
  	Upsilon: Upsilon,
  	upsilon: upsilon,
  	UpTeeArrow: UpTeeArrow,
  	UpTee: UpTee,
  	upuparrows: upuparrows,
  	urcorn: urcorn,
  	urcorner: urcorner,
  	urcrop: urcrop,
  	Uring: Uring,
  	uring: uring,
  	urtri: urtri,
  	Uscr: Uscr,
  	uscr: uscr,
  	utdot: utdot,
  	Utilde: Utilde,
  	utilde: utilde,
  	utri: utri,
  	utrif: utrif,
  	uuarr: uuarr,
  	Uuml: Uuml$1,
  	uuml: uuml$1,
  	uwangle: uwangle,
  	vangrt: vangrt,
  	varepsilon: varepsilon,
  	varkappa: varkappa,
  	varnothing: varnothing,
  	varphi: varphi,
  	varpi: varpi,
  	varpropto: varpropto,
  	varr: varr,
  	vArr: vArr,
  	varrho: varrho,
  	varsigma: varsigma,
  	varsubsetneq: varsubsetneq,
  	varsubsetneqq: varsubsetneqq,
  	varsupsetneq: varsupsetneq,
  	varsupsetneqq: varsupsetneqq,
  	vartheta: vartheta,
  	vartriangleleft: vartriangleleft,
  	vartriangleright: vartriangleright,
  	vBar: vBar,
  	Vbar: Vbar,
  	vBarv: vBarv,
  	Vcy: Vcy,
  	vcy: vcy,
  	vdash: vdash,
  	vDash: vDash,
  	Vdash: Vdash,
  	VDash: VDash,
  	Vdashl: Vdashl,
  	veebar: veebar,
  	vee: vee,
  	Vee: Vee,
  	veeeq: veeeq,
  	vellip: vellip,
  	verbar: verbar,
  	Verbar: Verbar,
  	vert: vert,
  	Vert: Vert,
  	VerticalBar: VerticalBar,
  	VerticalLine: VerticalLine,
  	VerticalSeparator: VerticalSeparator,
  	VerticalTilde: VerticalTilde,
  	VeryThinSpace: VeryThinSpace,
  	Vfr: Vfr,
  	vfr: vfr,
  	vltri: vltri,
  	vnsub: vnsub,
  	vnsup: vnsup,
  	Vopf: Vopf,
  	vopf: vopf,
  	vprop: vprop,
  	vrtri: vrtri,
  	Vscr: Vscr,
  	vscr: vscr,
  	vsubnE: vsubnE,
  	vsubne: vsubne,
  	vsupnE: vsupnE,
  	vsupne: vsupne,
  	Vvdash: Vvdash,
  	vzigzag: vzigzag,
  	Wcirc: Wcirc,
  	wcirc: wcirc,
  	wedbar: wedbar,
  	wedge: wedge,
  	Wedge: Wedge,
  	wedgeq: wedgeq,
  	weierp: weierp,
  	Wfr: Wfr,
  	wfr: wfr,
  	Wopf: Wopf,
  	wopf: wopf,
  	wp: wp,
  	wr: wr,
  	wreath: wreath,
  	Wscr: Wscr,
  	wscr: wscr,
  	xcap: xcap,
  	xcirc: xcirc,
  	xcup: xcup,
  	xdtri: xdtri,
  	Xfr: Xfr,
  	xfr: xfr,
  	xharr: xharr,
  	xhArr: xhArr,
  	Xi: Xi,
  	xi: xi,
  	xlarr: xlarr,
  	xlArr: xlArr,
  	xmap: xmap,
  	xnis: xnis,
  	xodot: xodot,
  	Xopf: Xopf,
  	xopf: xopf,
  	xoplus: xoplus,
  	xotime: xotime,
  	xrarr: xrarr,
  	xrArr: xrArr,
  	Xscr: Xscr,
  	xscr: xscr,
  	xsqcup: xsqcup,
  	xuplus: xuplus,
  	xutri: xutri,
  	xvee: xvee,
  	xwedge: xwedge,
  	Yacute: Yacute$1,
  	yacute: yacute$1,
  	YAcy: YAcy,
  	yacy: yacy,
  	Ycirc: Ycirc,
  	ycirc: ycirc,
  	Ycy: Ycy,
  	ycy: ycy,
  	yen: yen$1,
  	Yfr: Yfr,
  	yfr: yfr,
  	YIcy: YIcy,
  	yicy: yicy,
  	Yopf: Yopf,
  	yopf: yopf,
  	Yscr: Yscr,
  	yscr: yscr,
  	YUcy: YUcy,
  	yucy: yucy,
  	yuml: yuml$1,
  	Yuml: Yuml,
  	Zacute: Zacute,
  	zacute: zacute,
  	Zcaron: Zcaron,
  	zcaron: zcaron,
  	Zcy: Zcy,
  	zcy: zcy,
  	Zdot: Zdot,
  	zdot: zdot,
  	zeetrf: zeetrf,
  	ZeroWidthSpace: ZeroWidthSpace,
  	Zeta: Zeta,
  	zeta: zeta,
  	zfr: zfr,
  	Zfr: Zfr,
  	ZHcy: ZHcy,
  	zhcy: zhcy,
  	zigrarr: zigrarr,
  	zopf: zopf,
  	Zopf: Zopf,
  	Zscr: Zscr,
  	zscr: zscr,
  	zwj: zwj,
  	zwnj: zwnj
  };

  var Aacute = "Á";
  var aacute = "á";
  var Acirc = "Â";
  var acirc = "â";
  var acute = "´";
  var AElig = "Æ";
  var aelig = "æ";
  var Agrave = "À";
  var agrave = "à";
  var amp$1 = "&";
  var AMP = "&";
  var Aring = "Å";
  var aring = "å";
  var Atilde = "Ã";
  var atilde = "ã";
  var Auml = "Ä";
  var auml = "ä";
  var brvbar = "¦";
  var Ccedil = "Ç";
  var ccedil = "ç";
  var cedil = "¸";
  var cent = "¢";
  var copy = "©";
  var COPY = "©";
  var curren = "¤";
  var deg = "°";
  var divide$1 = "÷";
  var Eacute = "É";
  var eacute = "é";
  var Ecirc = "Ê";
  var ecirc = "ê";
  var Egrave = "È";
  var egrave = "è";
  var ETH = "Ð";
  var eth = "ð";
  var Euml = "Ë";
  var euml = "ë";
  var frac12 = "½";
  var frac14 = "¼";
  var frac34 = "¾";
  var gt$1 = ">";
  var GT = ">";
  var Iacute = "Í";
  var iacute = "í";
  var Icirc = "Î";
  var icirc = "î";
  var iexcl = "¡";
  var Igrave = "Ì";
  var igrave = "ì";
  var iquest = "¿";
  var Iuml = "Ï";
  var iuml = "ï";
  var laquo = "«";
  var lt$1 = "<";
  var LT = "<";
  var macr = "¯";
  var micro = "µ";
  var middot = "·";
  var nbsp = " ";
  var not = "¬";
  var Ntilde = "Ñ";
  var ntilde = "ñ";
  var Oacute = "Ó";
  var oacute = "ó";
  var Ocirc = "Ô";
  var ocirc = "ô";
  var Ograve = "Ò";
  var ograve = "ò";
  var ordf = "ª";
  var ordm = "º";
  var Oslash = "Ø";
  var oslash = "ø";
  var Otilde = "Õ";
  var otilde = "õ";
  var Ouml = "Ö";
  var ouml = "ö";
  var para = "¶";
  var plusmn = "±";
  var pound = "£";
  var quot$1 = "\"";
  var QUOT = "\"";
  var raquo = "»";
  var reg = "®";
  var REG = "®";
  var sect = "§";
  var shy = "­";
  var sup1 = "¹";
  var sup2 = "²";
  var sup3 = "³";
  var szlig = "ß";
  var THORN = "Þ";
  var thorn = "þ";
  var times = "×";
  var Uacute = "Ú";
  var uacute = "ú";
  var Ucirc = "Û";
  var ucirc = "û";
  var Ugrave = "Ù";
  var ugrave = "ù";
  var uml = "¨";
  var Uuml = "Ü";
  var uuml = "ü";
  var Yacute = "Ý";
  var yacute = "ý";
  var yen = "¥";
  var yuml = "ÿ";
  var require$$1$1 = {
  	Aacute: Aacute,
  	aacute: aacute,
  	Acirc: Acirc,
  	acirc: acirc,
  	acute: acute,
  	AElig: AElig,
  	aelig: aelig,
  	Agrave: Agrave,
  	agrave: agrave,
  	amp: amp$1,
  	AMP: AMP,
  	Aring: Aring,
  	aring: aring,
  	Atilde: Atilde,
  	atilde: atilde,
  	Auml: Auml,
  	auml: auml,
  	brvbar: brvbar,
  	Ccedil: Ccedil,
  	ccedil: ccedil,
  	cedil: cedil,
  	cent: cent,
  	copy: copy,
  	COPY: COPY,
  	curren: curren,
  	deg: deg,
  	divide: divide$1,
  	Eacute: Eacute,
  	eacute: eacute,
  	Ecirc: Ecirc,
  	ecirc: ecirc,
  	Egrave: Egrave,
  	egrave: egrave,
  	ETH: ETH,
  	eth: eth,
  	Euml: Euml,
  	euml: euml,
  	frac12: frac12,
  	frac14: frac14,
  	frac34: frac34,
  	gt: gt$1,
  	GT: GT,
  	Iacute: Iacute,
  	iacute: iacute,
  	Icirc: Icirc,
  	icirc: icirc,
  	iexcl: iexcl,
  	Igrave: Igrave,
  	igrave: igrave,
  	iquest: iquest,
  	Iuml: Iuml,
  	iuml: iuml,
  	laquo: laquo,
  	lt: lt$1,
  	LT: LT,
  	macr: macr,
  	micro: micro,
  	middot: middot,
  	nbsp: nbsp,
  	not: not,
  	Ntilde: Ntilde,
  	ntilde: ntilde,
  	Oacute: Oacute,
  	oacute: oacute,
  	Ocirc: Ocirc,
  	ocirc: ocirc,
  	Ograve: Ograve,
  	ograve: ograve,
  	ordf: ordf,
  	ordm: ordm,
  	Oslash: Oslash,
  	oslash: oslash,
  	Otilde: Otilde,
  	otilde: otilde,
  	Ouml: Ouml,
  	ouml: ouml,
  	para: para,
  	plusmn: plusmn,
  	pound: pound,
  	quot: quot$1,
  	QUOT: QUOT,
  	raquo: raquo,
  	reg: reg,
  	REG: REG,
  	sect: sect,
  	shy: shy,
  	sup1: sup1,
  	sup2: sup2,
  	sup3: sup3,
  	szlig: szlig,
  	THORN: THORN,
  	thorn: thorn,
  	times: times,
  	Uacute: Uacute,
  	uacute: uacute,
  	Ucirc: Ucirc,
  	ucirc: ucirc,
  	Ugrave: Ugrave,
  	ugrave: ugrave,
  	uml: uml,
  	Uuml: Uuml,
  	uuml: uuml,
  	Yacute: Yacute,
  	yacute: yacute,
  	yen: yen,
  	yuml: yuml
  };

  var amp = "&";
  var apos = "'";
  var gt = ">";
  var lt = "<";
  var quot = "\"";
  var require$$0$1 = {
  	amp: amp,
  	apos: apos,
  	gt: gt,
  	lt: lt,
  	quot: quot
  };

  var require$$0 = {
  	"0": 65533,
  	"128": 8364,
  	"130": 8218,
  	"131": 402,
  	"132": 8222,
  	"133": 8230,
  	"134": 8224,
  	"135": 8225,
  	"136": 710,
  	"137": 8240,
  	"138": 352,
  	"139": 8249,
  	"140": 338,
  	"142": 381,
  	"145": 8216,
  	"146": 8217,
  	"147": 8220,
  	"148": 8221,
  	"149": 8226,
  	"150": 8211,
  	"151": 8212,
  	"152": 732,
  	"153": 8482,
  	"154": 353,
  	"155": 8250,
  	"156": 339,
  	"158": 382,
  	"159": 376
  };

  var __importDefault = (commonjsGlobal && commonjsGlobal.__importDefault) || function (mod) {
      return (mod && mod.__esModule) ? mod : { "default": mod };
  };

  var decode_json_1 = __importDefault(require$$0);
  // Adapted from https://github.com/mathiasbynens/he/blob/master/src/he.js#L94-L119
  var fromCodePoint = 
  // eslint-disable-next-line @typescript-eslint/no-unnecessary-condition
  String.fromCodePoint ||
      function (codePoint) {
          var output = "";
          if (codePoint > 0xffff) {
              codePoint -= 0x10000;
              output += String.fromCharCode(((codePoint >>> 10) & 0x3ff) | 0xd800);
              codePoint = 0xdc00 | (codePoint & 0x3ff);
          }
          output += String.fromCharCode(codePoint);
          return output;
      };
  function decodeCodePoint(codePoint) {
      if ((codePoint >= 0xd800 && codePoint <= 0xdfff) || codePoint > 0x10ffff) {
          return "\uFFFD";
      }
      if (codePoint in decode_json_1.default) {
          codePoint = decode_json_1.default[codePoint];
      }
      return fromCodePoint(codePoint);
  }
  var _default$2 = decodeCodePoint;

  var decode_codepoint = /*#__PURE__*/Object.defineProperty({
  	default: _default$2
  }, '__esModule', {value: true});

  var require$$3 = decode_codepoint;

  var decode = createCommonjsModule(function (module, exports) {
  var __importDefault = (commonjsGlobal && commonjsGlobal.__importDefault) || function (mod) {
      return (mod && mod.__esModule) ? mod : { "default": mod };
  };
  Object.defineProperty(exports, "__esModule", { value: true });
  exports.decodeHTML = exports.decodeHTMLStrict = exports.decodeXML = void 0;
  var entities_json_1 = __importDefault(require$$1$2);
  var legacy_json_1 = __importDefault(require$$1$1);
  var xml_json_1 = __importDefault(require$$0$1);
  var decode_codepoint_1 = __importDefault(require$$3);
  var strictEntityRe = /&(?:[a-zA-Z0-9]+|#[xX][\da-fA-F]+|#\d+);/g;
  exports.decodeXML = getStrictDecoder(xml_json_1.default);
  exports.decodeHTMLStrict = getStrictDecoder(entities_json_1.default);
  function getStrictDecoder(map) {
      var replace = getReplacer(map);
      return function (str) { return String(str).replace(strictEntityRe, replace); };
  }
  var sorter = function (a, b) { return (a < b ? 1 : -1); };
  exports.decodeHTML = (function () {
      var legacy = Object.keys(legacy_json_1.default).sort(sorter);
      var keys = Object.keys(entities_json_1.default).sort(sorter);
      for (var i = 0, j = 0; i < keys.length; i++) {
          if (legacy[j] === keys[i]) {
              keys[i] += ";?";
              j++;
          }
          else {
              keys[i] += ";";
          }
      }
      var re = new RegExp("&(?:" + keys.join("|") + "|#[xX][\\da-fA-F]+;?|#\\d+;?)", "g");
      var replace = getReplacer(entities_json_1.default);
      function replacer(str) {
          if (str.substr(-1) !== ";")
              str += ";";
          return replace(str);
      }
      // TODO consider creating a merged map
      return function (str) { return String(str).replace(re, replacer); };
  })();
  function getReplacer(map) {
      return function replace(str) {
          if (str.charAt(1) === "#") {
              var secondChar = str.charAt(2);
              if (secondChar === "X" || secondChar === "x") {
                  return decode_codepoint_1.default(parseInt(str.substr(3), 16));
              }
              return decode_codepoint_1.default(parseInt(str.substr(2), 10));
          }
          // eslint-disable-next-line @typescript-eslint/prefer-nullish-coalescing
          return map[str.slice(1, -1)] || str;
      };
  }
  });

  var encode = createCommonjsModule(function (module, exports) {
  var __importDefault = (commonjsGlobal && commonjsGlobal.__importDefault) || function (mod) {
      return (mod && mod.__esModule) ? mod : { "default": mod };
  };
  Object.defineProperty(exports, "__esModule", { value: true });
  exports.escapeUTF8 = exports.escape = exports.encodeNonAsciiHTML = exports.encodeHTML = exports.encodeXML = void 0;
  var xml_json_1 = __importDefault(require$$0$1);
  var inverseXML = getInverseObj(xml_json_1.default);
  var xmlReplacer = getInverseReplacer(inverseXML);
  /**
   * Encodes all non-ASCII characters, as well as characters not valid in XML
   * documents using XML entities.
   *
   * If a character has no equivalent entity, a
   * numeric hexadecimal reference (eg. `&#xfc;`) will be used.
   */
  exports.encodeXML = getASCIIEncoder(inverseXML);
  var entities_json_1 = __importDefault(require$$1$2);
  var inverseHTML = getInverseObj(entities_json_1.default);
  var htmlReplacer = getInverseReplacer(inverseHTML);
  /**
   * Encodes all entities and non-ASCII characters in the input.
   *
   * This includes characters that are valid ASCII characters in HTML documents.
   * For example `#` will be encoded as `&num;`. To get a more compact output,
   * consider using the `encodeNonAsciiHTML` function.
   *
   * If a character has no equivalent entity, a
   * numeric hexadecimal reference (eg. `&#xfc;`) will be used.
   */
  exports.encodeHTML = getInverse(inverseHTML, htmlReplacer);
  /**
   * Encodes all non-ASCII characters, as well as characters not valid in HTML
   * documents using HTML entities.
   *
   * If a character has no equivalent entity, a
   * numeric hexadecimal reference (eg. `&#xfc;`) will be used.
   */
  exports.encodeNonAsciiHTML = getASCIIEncoder(inverseHTML);
  function getInverseObj(obj) {
      return Object.keys(obj)
          .sort()
          .reduce(function (inverse, name) {
          inverse[obj[name]] = "&" + name + ";";
          return inverse;
      }, {});
  }
  function getInverseReplacer(inverse) {
      var single = [];
      var multiple = [];
      for (var _i = 0, _a = Object.keys(inverse); _i < _a.length; _i++) {
          var k = _a[_i];
          if (k.length === 1) {
              // Add value to single array
              single.push("\\" + k);
          }
          else {
              // Add value to multiple array
              multiple.push(k);
          }
      }
      // Add ranges to single characters.
      single.sort();
      for (var start = 0; start < single.length - 1; start++) {
          // Find the end of a run of characters
          var end = start;
          while (end < single.length - 1 &&
              single[end].charCodeAt(1) + 1 === single[end + 1].charCodeAt(1)) {
              end += 1;
          }
          var count = 1 + end - start;
          // We want to replace at least three characters
          if (count < 3)
              continue;
          single.splice(start, count, single[start] + "-" + single[end]);
      }
      multiple.unshift("[" + single.join("") + "]");
      return new RegExp(multiple.join("|"), "g");
  }
  // /[^\0-\x7F]/gu
  var reNonASCII = /(?:[\x80-\uD7FF\uE000-\uFFFF]|[\uD800-\uDBFF][\uDC00-\uDFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF])/g;
  var getCodePoint = 
  // eslint-disable-next-line @typescript-eslint/no-unnecessary-condition
  String.prototype.codePointAt != null
      ? // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
          function (str) { return str.codePointAt(0); }
      : // http://mathiasbynens.be/notes/javascript-encoding#surrogate-formulae
          function (c) {
              return (c.charCodeAt(0) - 0xd800) * 0x400 +
                  c.charCodeAt(1) -
                  0xdc00 +
                  0x10000;
          };
  function singleCharReplacer(c) {
      return "&#x" + (c.length > 1 ? getCodePoint(c) : c.charCodeAt(0))
          .toString(16)
          .toUpperCase() + ";";
  }
  function getInverse(inverse, re) {
      return function (data) {
          return data
              .replace(re, function (name) { return inverse[name]; })
              .replace(reNonASCII, singleCharReplacer);
      };
  }
  var reEscapeChars = new RegExp(xmlReplacer.source + "|" + reNonASCII.source, "g");
  /**
   * Encodes all non-ASCII characters, as well as characters not valid in XML
   * documents using numeric hexadecimal reference (eg. `&#xfc;`).
   *
   * Have a look at `escapeUTF8` if you want a more concise output at the expense
   * of reduced transportability.
   *
   * @param data String to escape.
   */
  function escape(data) {
      return data.replace(reEscapeChars, singleCharReplacer);
  }
  exports.escape = escape;
  /**
   * Encodes all characters not valid in XML documents using numeric hexadecimal
   * reference (eg. `&#xfc;`).
   *
   * Note that the output will be character-set dependent.
   *
   * @param data String to escape.
   */
  function escapeUTF8(data) {
      return data.replace(xmlReplacer, singleCharReplacer);
  }
  exports.escapeUTF8 = escapeUTF8;
  function getASCIIEncoder(obj) {
      return function (data) {
          return data.replace(reEscapeChars, function (c) { return obj[c] || singleCharReplacer(c); });
      };
  }
  });

  var decode_1 = decode;

  var encode_1 = encode;

  var lib$1 = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports, "__esModule", { value: true });
  exports.decodeXMLStrict = exports.decodeHTML5Strict = exports.decodeHTML4Strict = exports.decodeHTML5 = exports.decodeHTML4 = exports.decodeHTMLStrict = exports.decodeHTML = exports.decodeXML = exports.encodeHTML5 = exports.encodeHTML4 = exports.escapeUTF8 = exports.escape = exports.encodeNonAsciiHTML = exports.encodeHTML = exports.encodeXML = exports.encode = exports.decodeStrict = exports.decode = void 0;


  /**
   * Decodes a string with entities.
   *
   * @param data String to decode.
   * @param level Optional level to decode at. 0 = XML, 1 = HTML. Default is 0.
   * @deprecated Use `decodeXML` or `decodeHTML` directly.
   */
  function decode(data, level) {
      return (!level || level <= 0 ? decode_1.decodeXML : decode_1.decodeHTML)(data);
  }
  exports.decode = decode;
  /**
   * Decodes a string with entities. Does not allow missing trailing semicolons for entities.
   *
   * @param data String to decode.
   * @param level Optional level to decode at. 0 = XML, 1 = HTML. Default is 0.
   * @deprecated Use `decodeHTMLStrict` or `decodeXML` directly.
   */
  function decodeStrict(data, level) {
      return (!level || level <= 0 ? decode_1.decodeXML : decode_1.decodeHTMLStrict)(data);
  }
  exports.decodeStrict = decodeStrict;
  /**
   * Encodes a string with entities.
   *
   * @param data String to encode.
   * @param level Optional level to encode at. 0 = XML, 1 = HTML. Default is 0.
   * @deprecated Use `encodeHTML`, `encodeXML` or `encodeNonAsciiHTML` directly.
   */
  function encode(data, level) {
      return (!level || level <= 0 ? encode_1.encodeXML : encode_1.encodeHTML)(data);
  }
  exports.encode = encode;
  var encode_2 = encode_1;
  Object.defineProperty(exports, "encodeXML", { enumerable: true, get: function () { return encode_2.encodeXML; } });
  Object.defineProperty(exports, "encodeHTML", { enumerable: true, get: function () { return encode_2.encodeHTML; } });
  Object.defineProperty(exports, "encodeNonAsciiHTML", { enumerable: true, get: function () { return encode_2.encodeNonAsciiHTML; } });
  Object.defineProperty(exports, "escape", { enumerable: true, get: function () { return encode_2.escape; } });
  Object.defineProperty(exports, "escapeUTF8", { enumerable: true, get: function () { return encode_2.escapeUTF8; } });
  // Legacy aliases (deprecated)
  Object.defineProperty(exports, "encodeHTML4", { enumerable: true, get: function () { return encode_2.encodeHTML; } });
  Object.defineProperty(exports, "encodeHTML5", { enumerable: true, get: function () { return encode_2.encodeHTML; } });
  var decode_2 = decode_1;
  Object.defineProperty(exports, "decodeXML", { enumerable: true, get: function () { return decode_2.decodeXML; } });
  Object.defineProperty(exports, "decodeHTML", { enumerable: true, get: function () { return decode_2.decodeHTML; } });
  Object.defineProperty(exports, "decodeHTMLStrict", { enumerable: true, get: function () { return decode_2.decodeHTMLStrict; } });
  // Legacy aliases (deprecated)
  Object.defineProperty(exports, "decodeHTML4", { enumerable: true, get: function () { return decode_2.decodeHTML; } });
  Object.defineProperty(exports, "decodeHTML5", { enumerable: true, get: function () { return decode_2.decodeHTML; } });
  Object.defineProperty(exports, "decodeHTML4Strict", { enumerable: true, get: function () { return decode_2.decodeHTMLStrict; } });
  Object.defineProperty(exports, "decodeHTML5Strict", { enumerable: true, get: function () { return decode_2.decodeHTMLStrict; } });
  Object.defineProperty(exports, "decodeXMLStrict", { enumerable: true, get: function () { return decode_2.decodeXML; } });
  });

  var elementNames = {
  	altglyph: "altGlyph",
  	altglyphdef: "altGlyphDef",
  	altglyphitem: "altGlyphItem",
  	animatecolor: "animateColor",
  	animatemotion: "animateMotion",
  	animatetransform: "animateTransform",
  	clippath: "clipPath",
  	feblend: "feBlend",
  	fecolormatrix: "feColorMatrix",
  	fecomponenttransfer: "feComponentTransfer",
  	fecomposite: "feComposite",
  	feconvolvematrix: "feConvolveMatrix",
  	fediffuselighting: "feDiffuseLighting",
  	fedisplacementmap: "feDisplacementMap",
  	fedistantlight: "feDistantLight",
  	fedropshadow: "feDropShadow",
  	feflood: "feFlood",
  	fefunca: "feFuncA",
  	fefuncb: "feFuncB",
  	fefuncg: "feFuncG",
  	fefuncr: "feFuncR",
  	fegaussianblur: "feGaussianBlur",
  	feimage: "feImage",
  	femerge: "feMerge",
  	femergenode: "feMergeNode",
  	femorphology: "feMorphology",
  	feoffset: "feOffset",
  	fepointlight: "fePointLight",
  	fespecularlighting: "feSpecularLighting",
  	fespotlight: "feSpotLight",
  	fetile: "feTile",
  	feturbulence: "feTurbulence",
  	foreignobject: "foreignObject",
  	glyphref: "glyphRef",
  	lineargradient: "linearGradient",
  	radialgradient: "radialGradient",
  	textpath: "textPath"
  };
  var attributeNames = {
  	definitionurl: "definitionURL",
  	attributename: "attributeName",
  	attributetype: "attributeType",
  	basefrequency: "baseFrequency",
  	baseprofile: "baseProfile",
  	calcmode: "calcMode",
  	clippathunits: "clipPathUnits",
  	diffuseconstant: "diffuseConstant",
  	edgemode: "edgeMode",
  	filterunits: "filterUnits",
  	glyphref: "glyphRef",
  	gradienttransform: "gradientTransform",
  	gradientunits: "gradientUnits",
  	kernelmatrix: "kernelMatrix",
  	kernelunitlength: "kernelUnitLength",
  	keypoints: "keyPoints",
  	keysplines: "keySplines",
  	keytimes: "keyTimes",
  	lengthadjust: "lengthAdjust",
  	limitingconeangle: "limitingConeAngle",
  	markerheight: "markerHeight",
  	markerunits: "markerUnits",
  	markerwidth: "markerWidth",
  	maskcontentunits: "maskContentUnits",
  	maskunits: "maskUnits",
  	numoctaves: "numOctaves",
  	pathlength: "pathLength",
  	patterncontentunits: "patternContentUnits",
  	patterntransform: "patternTransform",
  	patternunits: "patternUnits",
  	pointsatx: "pointsAtX",
  	pointsaty: "pointsAtY",
  	pointsatz: "pointsAtZ",
  	preservealpha: "preserveAlpha",
  	preserveaspectratio: "preserveAspectRatio",
  	primitiveunits: "primitiveUnits",
  	refx: "refX",
  	refy: "refY",
  	repeatcount: "repeatCount",
  	repeatdur: "repeatDur",
  	requiredextensions: "requiredExtensions",
  	requiredfeatures: "requiredFeatures",
  	specularconstant: "specularConstant",
  	specularexponent: "specularExponent",
  	spreadmethod: "spreadMethod",
  	startoffset: "startOffset",
  	stddeviation: "stdDeviation",
  	stitchtiles: "stitchTiles",
  	surfacescale: "surfaceScale",
  	systemlanguage: "systemLanguage",
  	tablevalues: "tableValues",
  	targetx: "targetX",
  	targety: "targetY",
  	textlength: "textLength",
  	viewbox: "viewBox",
  	viewtarget: "viewTarget",
  	xchannelselector: "xChannelSelector",
  	ychannelselector: "yChannelSelector",
  	zoomandpan: "zoomAndPan"
  };
  var foreignNames = {
  	elementNames: elementNames,
  	attributeNames: attributeNames
  };

  var ElementType = lib$2;

  var entities = lib$1;

  /*
    Module dependencies
  */

  var domSerializer = createCommonjsModule(function (module) {
  /* mixed-case SVG and MathML tags & attributes
     recognized by the HTML parser, see
     https://html.spec.whatwg.org/multipage/parsing.html#parsing-main-inforeign
  */

  foreignNames.elementNames.__proto__ = null; /* use as a simple dictionary */
  foreignNames.attributeNames.__proto__ = null;

  var unencodedElements = {
    __proto__: null,
    style: true,
    script: true,
    xmp: true,
    iframe: true,
    noembed: true,
    noframes: true,
    plaintext: true,
    noscript: true
  };

  /*
    Format attributes
  */
  function formatAttrs(attributes, opts) {
    if (!attributes) return;

    var output = '';
    var value;

    // Loop through the attributes
    for (var key in attributes) {
      value = attributes[key];
      if (output) {
        output += ' ';
      }

      if (opts.xmlMode === 'foreign') {
        /* fix up mixed-case attribute names */
        key = foreignNames.attributeNames[key] || key;
      }
      output += key;
      if ((value !== null && value !== '') || opts.xmlMode) {
        output +=
          '="' +
          (opts.decodeEntities
            ? entities.encodeXML(value)
            : value.replace(/\"/g, '&quot;')) +
          '"';
      }
    }

    return output;
  }

  /*
    Self-enclosing tags (stolen from node-htmlparser)
  */
  var singleTag = {
    __proto__: null,
    area: true,
    base: true,
    basefont: true,
    br: true,
    col: true,
    command: true,
    embed: true,
    frame: true,
    hr: true,
    img: true,
    input: true,
    isindex: true,
    keygen: true,
    link: true,
    meta: true,
    param: true,
    source: true,
    track: true,
    wbr: true
  };

  var render = (module.exports = function(dom, opts) {
    if (!Array.isArray(dom) && !dom.cheerio) dom = [dom];
    opts = opts || {};

    var output = '';

    for (var i = 0; i < dom.length; i++) {
      var elem = dom[i];

      if (elem.type === 'root') output += render(elem.children, opts);
      else if (ElementType.isTag(elem)) output += renderTag(elem, opts);
      else if (elem.type === ElementType.Directive)
        output += renderDirective(elem);
      else if (elem.type === ElementType.Comment) output += renderComment(elem);
      else if (elem.type === ElementType.CDATA) output += renderCdata(elem);
      else output += renderText(elem, opts);
    }

    return output;
  });

  var foreignModeIntegrationPoints = [
    'mi',
    'mo',
    'mn',
    'ms',
    'mtext',
    'annotation-xml',
    'foreignObject',
    'desc',
    'title'
  ];

  function renderTag(elem, opts) {
    // Handle SVG / MathML in HTML
    if (opts.xmlMode === 'foreign') {
      /* fix up mixed-case element names */
      elem.name = foreignNames.elementNames[elem.name] || elem.name;
      /* exit foreign mode at integration points */
      if (
        elem.parent &&
        foreignModeIntegrationPoints.indexOf(elem.parent.name) >= 0
      )
        opts = Object.assign({}, opts, { xmlMode: false });
    }
    if (!opts.xmlMode && ['svg', 'math'].indexOf(elem.name) >= 0) {
      opts = Object.assign({}, opts, { xmlMode: 'foreign' });
    }

    var tag = '<' + elem.name;
    var attribs = formatAttrs(elem.attribs, opts);

    if (attribs) {
      tag += ' ' + attribs;
    }

    if (opts.xmlMode && (!elem.children || elem.children.length === 0)) {
      tag += '/>';
    } else {
      tag += '>';
      if (elem.children) {
        tag += render(elem.children, opts);
      }

      if (!singleTag[elem.name] || opts.xmlMode) {
        tag += '</' + elem.name + '>';
      }
    }

    return tag;
  }

  function renderDirective(elem) {
    return '<' + elem.data + '>';
  }

  function renderText(elem, opts) {
    var data = elem.data || '';

    // if entities weren't decoded, no need to encode them back
    if (
      opts.decodeEntities &&
      !(elem.parent && elem.parent.name in unencodedElements)
    ) {
      data = entities.encodeXML(data);
    }

    return data;
  }

  function renderCdata(elem) {
    return '<![CDATA[' + elem.children[0].data + ']]>';
  }

  function renderComment(elem) {
    return '<!--' + elem.data + '-->';
  }
  });

  var isTag$1 = domelementtype.isTag;

  var stringify$1 = {
  	getInnerHTML: getInnerHTML,
  	getOuterHTML: domSerializer,
  	getText: getText
  };

  function getInnerHTML(elem, opts){
  	return elem.children ? elem.children.map(function(elem){
  		return domSerializer(elem, opts);
  	}).join("") : "";
  }

  function getText(elem){
  	if(Array.isArray(elem)) return elem.map(getText).join("");
  	if(isTag$1(elem)) return elem.name === "br" ? "\n" : getText(elem.children);
  	if(elem.type === domelementtype.CDATA) return getText(elem.children);
  	if(elem.type === domelementtype.Text) return elem.data;
  	return "";
  }

  var traversal = createCommonjsModule(function (module, exports) {
  var getChildren = exports.getChildren = function(elem){
  	return elem.children;
  };

  var getParent = exports.getParent = function(elem){
  	return elem.parent;
  };

  exports.getSiblings = function(elem){
  	var parent = getParent(elem);
  	return parent ? getChildren(parent) : [elem];
  };

  exports.getAttributeValue = function(elem, name){
  	return elem.attribs && elem.attribs[name];
  };

  exports.hasAttrib = function(elem, name){
  	return !!elem.attribs && hasOwnProperty.call(elem.attribs, name);
  };

  exports.getName = function(elem){
  	return elem.name;
  };
  });

  var removeElement = function(elem){
  	if(elem.prev) elem.prev.next = elem.next;
  	if(elem.next) elem.next.prev = elem.prev;

  	if(elem.parent){
  		var childs = elem.parent.children;
  		childs.splice(childs.lastIndexOf(elem), 1);
  	}
  };

  var replaceElement = function(elem, replacement){
  	var prev = replacement.prev = elem.prev;
  	if(prev){
  		prev.next = replacement;
  	}

  	var next = replacement.next = elem.next;
  	if(next){
  		next.prev = replacement;
  	}

  	var parent = replacement.parent = elem.parent;
  	if(parent){
  		var childs = parent.children;
  		childs[childs.lastIndexOf(elem)] = replacement;
  	}
  };

  var appendChild = function(elem, child){
  	child.parent = elem;

  	if(elem.children.push(child) !== 1){
  		var sibling = elem.children[elem.children.length - 2];
  		sibling.next = child;
  		child.prev = sibling;
  		child.next = null;
  	}
  };

  var append = function(elem, next){
  	var parent = elem.parent,
  		currNext = elem.next;

  	next.next = currNext;
  	next.prev = elem;
  	elem.next = next;
  	next.parent = parent;

  	if(currNext){
  		currNext.prev = next;
  		if(parent){
  			var childs = parent.children;
  			childs.splice(childs.lastIndexOf(currNext), 0, next);
  		}
  	} else if(parent){
  		parent.children.push(next);
  	}
  };

  var prepend = function(elem, prev){
  	var parent = elem.parent;
  	if(parent){
  		var childs = parent.children;
  		childs.splice(childs.lastIndexOf(elem), 0, prev);
  	}

  	if(elem.prev){
  		elem.prev.next = prev;
  	}
  	
  	prev.parent = parent;
  	prev.prev = elem.prev;
  	prev.next = elem;
  	elem.prev = prev;
  };

  var manipulation = {
  	removeElement: removeElement,
  	replaceElement: replaceElement,
  	appendChild: appendChild,
  	append: append,
  	prepend: prepend
  };

  var isTag = domelementtype.isTag;

  var querying = {
  	filter: filter,
  	find: find,
  	findOneChild: findOneChild,
  	findOne: findOne,
  	existsOne: existsOne,
  	findAll: findAll
  };

  function filter(test, element, recurse, limit){
  	if(!Array.isArray(element)) element = [element];

  	if(typeof limit !== "number" || !isFinite(limit)){
  		limit = Infinity;
  	}
  	return find(test, element, recurse !== false, limit);
  }

  function find(test, elems, recurse, limit){
  	var result = [], childs;

  	for(var i = 0, j = elems.length; i < j; i++){
  		if(test(elems[i])){
  			result.push(elems[i]);
  			if(--limit <= 0) break;
  		}

  		childs = elems[i].children;
  		if(recurse && childs && childs.length > 0){
  			childs = find(test, childs, recurse, limit);
  			result = result.concat(childs);
  			limit -= childs.length;
  			if(limit <= 0) break;
  		}
  	}

  	return result;
  }

  function findOneChild(test, elems){
  	for(var i = 0, l = elems.length; i < l; i++){
  		if(test(elems[i])) return elems[i];
  	}

  	return null;
  }

  function findOne(test, elems){
  	var elem = null;

  	for(var i = 0, l = elems.length; i < l && !elem; i++){
  		if(!isTag(elems[i])){
  			continue;
  		} else if(test(elems[i])){
  			elem = elems[i];
  		} else if(elems[i].children.length > 0){
  			elem = findOne(test, elems[i].children);
  		}
  	}

  	return elem;
  }

  function existsOne(test, elems){
  	for(var i = 0, l = elems.length; i < l; i++){
  		if(
  			isTag(elems[i]) && (
  				test(elems[i]) || (
  					elems[i].children.length > 0 &&
  					existsOne(test, elems[i].children)
  				)
  			)
  		){
  			return true;
  		}
  	}

  	return false;
  }

  function findAll(test, rootElems){
  	var result = [];
  	var stack = rootElems.slice();
  	while(stack.length){
  		var elem = stack.shift();
  		if(!isTag(elem)) continue;
  		if (elem.children && elem.children.length > 0) {
  			stack.unshift.apply(stack, elem.children);
  		}
  		if(test(elem)) result.push(elem);
  	}
  	return result;
  }

  var legacy = createCommonjsModule(function (module, exports) {
  var isTag = exports.isTag = domelementtype.isTag;

  exports.testElement = function(options, element){
  	for(var key in options){
  		if(!options.hasOwnProperty(key));
  		else if(key === "tag_name"){
  			if(!isTag(element) || !options.tag_name(element.name)){
  				return false;
  			}
  		} else if(key === "tag_type"){
  			if(!options.tag_type(element.type)) return false;
  		} else if(key === "tag_contains"){
  			if(isTag(element) || !options.tag_contains(element.data)){
  				return false;
  			}
  		} else if(!element.attribs || !options[key](element.attribs[key])){
  			return false;
  		}
  	}
  	return true;
  };

  var Checks = {
  	tag_name: function(name){
  		if(typeof name === "function"){
  			return function(elem){ return isTag(elem) && name(elem.name); };
  		} else if(name === "*"){
  			return isTag;
  		} else {
  			return function(elem){ return isTag(elem) && elem.name === name; };
  		}
  	},
  	tag_type: function(type){
  		if(typeof type === "function"){
  			return function(elem){ return type(elem.type); };
  		} else {
  			return function(elem){ return elem.type === type; };
  		}
  	},
  	tag_contains: function(data){
  		if(typeof data === "function"){
  			return function(elem){ return !isTag(elem) && data(elem.data); };
  		} else {
  			return function(elem){ return !isTag(elem) && elem.data === data; };
  		}
  	}
  };

  function getAttribCheck(attrib, value){
  	if(typeof value === "function"){
  		return function(elem){ return elem.attribs && value(elem.attribs[attrib]); };
  	} else {
  		return function(elem){ return elem.attribs && elem.attribs[attrib] === value; };
  	}
  }

  function combineFuncs(a, b){
  	return function(elem){
  		return a(elem) || b(elem);
  	};
  }

  exports.getElements = function(options, element, recurse, limit){
  	var funcs = Object.keys(options).map(function(key){
  		var value = options[key];
  		return key in Checks ? Checks[key](value) : getAttribCheck(key, value);
  	});

  	return funcs.length === 0 ? [] : this.filter(
  		funcs.reduce(combineFuncs),
  		element, recurse, limit
  	);
  };

  exports.getElementById = function(id, element, recurse){
  	if(!Array.isArray(element)) element = [element];
  	return this.findOne(getAttribCheck("id", id), element, recurse !== false);
  };

  exports.getElementsByTagName = function(name, element, recurse, limit){
  	return this.filter(Checks.tag_name(name), element, recurse, limit);
  };

  exports.getElementsByTagType = function(type, element, recurse, limit){
  	return this.filter(Checks.tag_type(type), element, recurse, limit);
  };
  });

  var helpers = createCommonjsModule(function (module, exports) {
  // removeSubsets
  // Given an array of nodes, remove any member that is contained by another.
  exports.removeSubsets = function(nodes) {
  	var idx = nodes.length, node, ancestor, replace;

  	// Check if each node (or one of its ancestors) is already contained in the
  	// array.
  	while (--idx > -1) {
  		node = ancestor = nodes[idx];

  		// Temporarily remove the node under consideration
  		nodes[idx] = null;
  		replace = true;

  		while (ancestor) {
  			if (nodes.indexOf(ancestor) > -1) {
  				replace = false;
  				nodes.splice(idx, 1);
  				break;
  			}
  			ancestor = ancestor.parent;
  		}

  		// If the node has been found to be unique, re-insert it.
  		if (replace) {
  			nodes[idx] = node;
  		}
  	}

  	return nodes;
  };

  // Source: http://dom.spec.whatwg.org/#dom-node-comparedocumentposition
  var POSITION = {
  	DISCONNECTED: 1,
  	PRECEDING: 2,
  	FOLLOWING: 4,
  	CONTAINS: 8,
  	CONTAINED_BY: 16
  };

  // Compare the position of one node against another node in any other document.
  // The return value is a bitmask with the following values:
  //
  // document order:
  // > There is an ordering, document order, defined on all the nodes in the
  // > document corresponding to the order in which the first character of the
  // > XML representation of each node occurs in the XML representation of the
  // > document after expansion of general entities. Thus, the document element
  // > node will be the first node. Element nodes occur before their children.
  // > Thus, document order orders element nodes in order of the occurrence of
  // > their start-tag in the XML (after expansion of entities). The attribute
  // > nodes of an element occur after the element and before its children. The
  // > relative order of attribute nodes is implementation-dependent./
  // Source:
  // http://www.w3.org/TR/DOM-Level-3-Core/glossary.html#dt-document-order
  //
  // @argument {Node} nodaA The first node to use in the comparison
  // @argument {Node} nodeB The second node to use in the comparison
  //
  // @return {Number} A bitmask describing the input nodes' relative position.
  //         See http://dom.spec.whatwg.org/#dom-node-comparedocumentposition for
  //         a description of these values.
  var comparePos = exports.compareDocumentPosition = function(nodeA, nodeB) {
  	var aParents = [];
  	var bParents = [];
  	var current, sharedParent, siblings, aSibling, bSibling, idx;

  	if (nodeA === nodeB) {
  		return 0;
  	}

  	current = nodeA;
  	while (current) {
  		aParents.unshift(current);
  		current = current.parent;
  	}
  	current = nodeB;
  	while (current) {
  		bParents.unshift(current);
  		current = current.parent;
  	}

  	idx = 0;
  	while (aParents[idx] === bParents[idx]) {
  		idx++;
  	}

  	if (idx === 0) {
  		return POSITION.DISCONNECTED;
  	}

  	sharedParent = aParents[idx - 1];
  	siblings = sharedParent.children;
  	aSibling = aParents[idx];
  	bSibling = bParents[idx];

  	if (siblings.indexOf(aSibling) > siblings.indexOf(bSibling)) {
  		if (sharedParent === nodeB) {
  			return POSITION.FOLLOWING | POSITION.CONTAINED_BY;
  		}
  		return POSITION.FOLLOWING;
  	} else {
  		if (sharedParent === nodeA) {
  			return POSITION.PRECEDING | POSITION.CONTAINS;
  		}
  		return POSITION.PRECEDING;
  	}
  };

  // Sort an array of nodes based on their relative position in the document and
  // remove any duplicate nodes. If the array contains nodes that do not belong
  // to the same document, sort order is unspecified.
  //
  // @argument {Array} nodes Array of DOM nodes
  //
  // @returns {Array} collection of unique nodes, sorted in document order
  exports.uniqueSort = function(nodes) {
  	var idx = nodes.length, node, position;

  	nodes = nodes.slice();

  	while (--idx > -1) {
  		node = nodes[idx];
  		position = nodes.indexOf(node);
  		if (position > -1 && position < idx) {
  			nodes.splice(idx, 1);
  		}
  	}
  	nodes.sort(function(a, b) {
  		var relative = comparePos(a, b);
  		if (relative & POSITION.PRECEDING) {
  			return -1;
  		} else if (relative & POSITION.FOLLOWING) {
  			return 1;
  		}
  		return 0;
  	});

  	return nodes;
  };
  });

  var domutils = createCommonjsModule(function (module) {
  var DomUtils = module.exports;

  [
  	stringify$1,
  	traversal,
  	manipulation,
  	querying,
  	legacy,
  	helpers
  ].forEach(function(ext){
  	Object.keys(ext).forEach(function(key){
  		DomUtils[key] = ext[key].bind(DomUtils);
  	});
  });
  });

  var boolbase = {
  	trueFunc: function trueFunc(){
  		return true;
  	},
  	falseFunc: function falseFunc(){
  		return false;
  	}
  };

  var _default$1 = parse$2;
  var reName = /^[^\\]?(?:\\(?:[\da-f]{1,6}\s?|.)|[\w\-\u00b0-\uFFFF])+/;
  var reEscape = /\\([\da-f]{1,6}\s?|(\s)|.)/gi;
  // Modified version of https://github.com/jquery/sizzle/blob/master/src/sizzle.js#L87
  var reAttr = /^\s*((?:\\.|[\w\u00b0-\uFFFF-])+)\s*(?:(\S?)=\s*(?:(['"])((?:[^\\]|\\[^])*?)\3|(#?(?:\\.|[\w\u00b0-\uFFFF-])*)|)|)\s*(i)?\]/;
  var actionTypes$1 = {
      undefined: "exists",
      "": "equals",
      "~": "element",
      "^": "start",
      $: "end",
      "*": "any",
      "!": "not",
      "|": "hyphen",
  };
  var Traversals = {
      ">": "child",
      "<": "parent",
      "~": "sibling",
      "+": "adjacent",
  };
  var attribSelectors = {
      "#": ["id", "equals"],
      ".": ["class", "element"],
  };
  // Pseudos, whose data property is parsed as well.
  var unpackPseudos = new Set([
      "has",
      "not",
      "matches",
      "is",
      "host",
      "host-context",
  ]);
  var stripQuotesFromPseudos = new Set(["contains", "icontains"]);
  var quotes = new Set(['"', "'"]);
  // Unescape function taken from https://github.com/jquery/sizzle/blob/master/src/sizzle.js#L152
  function funescape(_, escaped, escapedWhitespace) {
      var high = parseInt(escaped, 16) - 0x10000;
      // NaN means non-codepoint
      return high !== high || escapedWhitespace
          ? escaped
          : high < 0
              ? // BMP codepoint
                  String.fromCharCode(high + 0x10000)
              : // Supplemental Plane codepoint (surrogate pair)
                  String.fromCharCode((high >> 10) | 0xd800, (high & 0x3ff) | 0xdc00);
  }
  function unescapeCSS(str) {
      return str.replace(reEscape, funescape);
  }
  function isWhitespace(c) {
      return c === " " || c === "\n" || c === "\t" || c === "\f" || c === "\r";
  }
  function parse$2(selector, options) {
      var subselects = [];
      selector = parseSelector(subselects, "" + selector, options);
      if (selector !== "") {
          throw new Error("Unmatched selector: " + selector);
      }
      return subselects;
  }
  function parseSelector(subselects, selector, options) {
      var _a, _b;
      if (options === void 0) { options = {}; }
      var tokens = [];
      var sawWS = false;
      function getName() {
          var match = selector.match(reName);
          if (!match) {
              throw new Error("Expected name, found " + selector);
          }
          var sub = match[0];
          selector = selector.substr(sub.length);
          return unescapeCSS(sub);
      }
      function stripWhitespace(start) {
          while (isWhitespace(selector.charAt(start)))
              start++;
          selector = selector.substr(start);
      }
      function isEscaped(pos) {
          var slashCount = 0;
          while (selector.charAt(--pos) === "\\")
              slashCount++;
          return (slashCount & 1) === 1;
      }
      stripWhitespace(0);
      while (selector !== "") {
          var firstChar = selector.charAt(0);
          if (isWhitespace(firstChar)) {
              sawWS = true;
              stripWhitespace(1);
          }
          else if (firstChar in Traversals) {
              tokens.push({ type: Traversals[firstChar] });
              sawWS = false;
              stripWhitespace(1);
          }
          else if (firstChar === ",") {
              if (tokens.length === 0) {
                  throw new Error("Empty sub-selector");
              }
              subselects.push(tokens);
              tokens = [];
              sawWS = false;
              stripWhitespace(1);
          }
          else {
              if (sawWS) {
                  if (tokens.length > 0) {
                      tokens.push({ type: "descendant" });
                  }
                  sawWS = false;
              }
              if (firstChar === "*") {
                  selector = selector.substr(1);
                  tokens.push({ type: "universal" });
              }
              else if (firstChar in attribSelectors) {
                  var _c = attribSelectors[firstChar], name_1 = _c[0], action = _c[1];
                  selector = selector.substr(1);
                  tokens.push({
                      type: "attribute",
                      name: name_1,
                      action: action,
                      value: getName(),
                      ignoreCase: false,
                  });
              }
              else if (firstChar === "[") {
                  selector = selector.substr(1);
                  var attributeMatch = selector.match(reAttr);
                  if (!attributeMatch) {
                      throw new Error("Malformed attribute selector: " + selector);
                  }
                  var completeSelector = attributeMatch[0], baseName = attributeMatch[1], actionType = attributeMatch[2], _d = attributeMatch[4], quotedValue = _d === void 0 ? "" : _d, _e = attributeMatch[5], value = _e === void 0 ? quotedValue : _e, ignoreCase = attributeMatch[6];
                  selector = selector.substr(completeSelector.length);
                  var name_2 = unescapeCSS(baseName);
                  if ((_a = options.lowerCaseAttributeNames) !== null && _a !== void 0 ? _a : !options.xmlMode) {
                      name_2 = name_2.toLowerCase();
                  }
                  tokens.push({
                      type: "attribute",
                      name: name_2,
                      action: actionTypes$1[actionType],
                      value: unescapeCSS(value),
                      ignoreCase: !!ignoreCase,
                  });
              }
              else if (firstChar === ":") {
                  if (selector.charAt(1) === ":") {
                      selector = selector.substr(2);
                      tokens.push({
                          type: "pseudo-element",
                          name: getName().toLowerCase(),
                      });
                      continue;
                  }
                  selector = selector.substr(1);
                  var name_3 = getName().toLowerCase();
                  var data = null;
                  if (selector.startsWith("(")) {
                      if (unpackPseudos.has(name_3)) {
                          var quot = selector.charAt(1);
                          var quoted = quotes.has(quot);
                          selector = selector.substr(quoted ? 2 : 1);
                          data = [];
                          selector = parseSelector(data, selector, options);
                          if (quoted) {
                              if (!selector.startsWith(quot)) {
                                  throw new Error("Unmatched quotes in :" + name_3);
                              }
                              else {
                                  selector = selector.substr(1);
                              }
                          }
                          if (!selector.startsWith(")")) {
                              throw new Error("Missing closing parenthesis in :" + name_3 + " (" + selector + ")");
                          }
                          selector = selector.substr(1);
                      }
                      else {
                          var pos = 1;
                          var counter = 1;
                          for (; counter > 0 && pos < selector.length; pos++) {
                              if (selector.charAt(pos) === "(" &&
                                  !isEscaped(pos)) {
                                  counter++;
                              }
                              else if (selector.charAt(pos) === ")" &&
                                  !isEscaped(pos)) {
                                  counter--;
                              }
                          }
                          if (counter) {
                              throw new Error("Parenthesis not matched");
                          }
                          data = selector.substr(1, pos - 2);
                          selector = selector.substr(pos);
                          if (stripQuotesFromPseudos.has(name_3)) {
                              var quot = data.charAt(0);
                              if (quot === data.slice(-1) && quotes.has(quot)) {
                                  data = data.slice(1, -1);
                              }
                              data = unescapeCSS(data);
                          }
                      }
                  }
                  tokens.push({ type: "pseudo", name: name_3, data: data });
              }
              else if (reName.test(selector)) {
                  var name_4 = getName();
                  if ((_b = options.lowerCaseTags) !== null && _b !== void 0 ? _b : !options.xmlMode) {
                      name_4 = name_4.toLowerCase();
                  }
                  tokens.push({ type: "tag", name: name_4 });
              }
              else {
                  if (tokens.length &&
                      tokens[tokens.length - 1].type === "descendant") {
                      tokens.pop();
                  }
                  addToken(subselects, tokens);
                  return selector;
              }
          }
      }
      addToken(subselects, tokens);
      return selector;
  }
  function addToken(subselects, tokens) {
      if (subselects.length > 0 && tokens.length === 0) {
          throw new Error("Empty sub-selector");
      }
      subselects.push(tokens);
  }

  var parse_1$2 = /*#__PURE__*/Object.defineProperty({
  	default: _default$1
  }, '__esModule', {value: true});

  var __spreadArrays = (commonjsGlobal && commonjsGlobal.__spreadArrays) || function () {
      for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
      for (var r = Array(s), k = 0, i = 0; i < il; i++)
          for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
              r[k] = a[j];
      return r;
  };

  var actionTypes = {
      equals: "",
      element: "~",
      start: "^",
      end: "$",
      any: "*",
      not: "!",
      hyphen: "|",
  };
  var charsToEscape = new Set(__spreadArrays(Object.keys(actionTypes)
      .map(function (typeKey) { return actionTypes[typeKey]; })
      .filter(Boolean), [
      ":",
      "[",
      "]",
      " ",
      "\\",
  ]));
  function stringify(token) {
      return token.map(stringifySubselector).join(", ");
  }
  var _default = stringify;
  function stringifySubselector(token) {
      return token.map(stringifyToken).join("");
  }
  function stringifyToken(token) {
      switch (token.type) {
          // Simple types
          case "child":
              return " > ";
          case "parent":
              return " < ";
          case "sibling":
              return " ~ ";
          case "adjacent":
              return " + ";
          case "descendant":
              return " ";
          case "universal":
              return "*";
          case "tag":
              return escapeName(token.name);
          case "pseudo-element":
              return "::" + escapeName(token.name);
          case "pseudo":
              if (token.data === null)
                  return ":" + escapeName(token.name);
              if (typeof token.data === "string") {
                  return ":" + escapeName(token.name) + "(" + token.data + ")";
              }
              return ":" + escapeName(token.name) + "(" + stringify(token.data) + ")";
          case "attribute":
              if (token.action === "exists") {
                  return "[" + escapeName(token.name) + "]";
              }
              if (token.name === "id" &&
                  token.action === "equals" &&
                  !token.ignoreCase) {
                  return "#" + escapeName(token.value);
              }
              if (token.name === "class" &&
                  token.action === "element" &&
                  !token.ignoreCase) {
                  return "." + escapeName(token.value);
              }
              return "[" + escapeName(token.name) + actionTypes[token.action] + "='" + escapeName(token.value) + "'" + (token.ignoreCase ? "i" : "") + "]";
      }
  }
  function escapeName(str) {
      return str
          .split("")
          .map(function (c) { return (charsToEscape.has(c) ? "\\" + c : c); })
          .join("");
  }

  var stringify_1 = /*#__PURE__*/Object.defineProperty({
  	default: _default
  }, '__esModule', {value: true});

  var lib = createCommonjsModule(function (module, exports) {
  var __createBinding = (commonjsGlobal && commonjsGlobal.__createBinding) || (Object.create ? (function(o, m, k, k2) {
      if (k2 === undefined) k2 = k;
      Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
  }) : (function(o, m, k, k2) {
      if (k2 === undefined) k2 = k;
      o[k2] = m[k];
  }));
  var __exportStar = (commonjsGlobal && commonjsGlobal.__exportStar) || function(m, exports) {
      for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
  };
  var __importDefault = (commonjsGlobal && commonjsGlobal.__importDefault) || function (mod) {
      return (mod && mod.__esModule) ? mod : { "default": mod };
  };
  Object.defineProperty(exports, "__esModule", { value: true });
  exports.stringify = exports.parse = void 0;
  __exportStar(parse_1$2, exports);

  Object.defineProperty(exports, "parse", { enumerable: true, get: function () { return __importDefault(parse_1$2).default; } });

  Object.defineProperty(exports, "stringify", { enumerable: true, get: function () { return __importDefault(stringify_1).default; } });
  });

  var universal = 50;
  var tag = 30;
  var attribute = 1;
  var pseudo = 0;
  var descendant = -1;
  var child = -1;
  var parent = -1;
  var sibling = -1;
  var adjacent = -1;
  var procedure = {
  	universal: universal,
  	tag: tag,
  	attribute: attribute,
  	pseudo: pseudo,
  	descendant: descendant,
  	child: child,
  	parent: parent,
  	sibling: sibling,
  	adjacent: adjacent
  };

  var sort = sortByProcedure;

  /*
  	sort the parts of the passed selector,
  	as there is potential for optimization
  	(some types of selectors are faster than others)
  */



  var attributes$1 = {
      __proto__: null,
      exists: 10,
      equals: 8,
      not: 7,
      start: 6,
      end: 6,
      any: 5,
      hyphen: 4,
      element: 4
  };

  function sortByProcedure(arr) {
      var procs = arr.map(getProcedure);
      for (var i = 1; i < arr.length; i++) {
          var procNew = procs[i];

          if (procNew < 0) continue;

          for (var j = i - 1; j >= 0 && procNew < procs[j]; j--) {
              var token = arr[j + 1];
              arr[j + 1] = arr[j];
              arr[j] = token;
              procs[j + 1] = procs[j];
              procs[j] = procNew;
          }
      }
  }

  function getProcedure(token) {
      var proc = procedure[token.type];

      if (proc === procedure.attribute) {
          proc = attributes$1[token.action];

          if (proc === attributes$1.equals && token.name === "id") {
              //prefer ID selectors (eg. #ID)
              proc = 9;
          }

          if (token.ignoreCase) {
              //ignoreCase adds some overhead, prefer "normal" token
              //this is a binary operation, to ensure it's still an int
              proc >>= 1;
          }
      } else if (proc === procedure.pseudo) {
          if (!token.data) {
              proc = 3;
          } else if (token.name === "has" || token.name === "contains") {
              proc = 0; //expensive in any case
          } else if (token.name === "matches" || token.name === "not") {
              proc = 0;
              for (var i = 0; i < token.data.length; i++) {
                  //TODO better handling of complex selectors
                  if (token.data[i].length !== 1) continue;
                  var cur = getProcedure(token.data[i][0]);
                  //avoid executing :has or :contains
                  if (cur === 0) {
                      proc = 0;
                      break;
                  }
                  if (cur > proc) proc = cur;
              }
              if (token.data.length > 1 && proc > 0) proc -= 1;
          } else {
              proc = 1;
          }
      }
      return proc;
  }

  var falseFunc$4 = boolbase.falseFunc;

  //https://github.com/slevithan/XRegExp/blob/master/src/xregexp.js#L469
  var reChars = /[-[\]{}()*+?.,\\^$|#\s]/g;

  /*
  	attribute selectors
  */
  var attributeRules = {
      __proto__: null,
      equals: function(next, data, options) {
          var name = data.name;
          var value = data.value;
          var adapter = options.adapter;

          if (data.ignoreCase) {
              value = value.toLowerCase();

              return function equalsIC(elem) {
                  var attr = adapter.getAttributeValue(elem, name);
                  return attr != null && attr.toLowerCase() === value && next(elem);
              };
          }

          return function equals(elem) {
              return adapter.getAttributeValue(elem, name) === value && next(elem);
          };
      },
      hyphen: function(next, data, options) {
          var name = data.name;
          var value = data.value;
          var len = value.length;
          var adapter = options.adapter;

          if (data.ignoreCase) {
              value = value.toLowerCase();

              return function hyphenIC(elem) {
                  var attr = adapter.getAttributeValue(elem, name);
                  return (
                      attr != null &&
                      (attr.length === len || attr.charAt(len) === "-") &&
                      attr.substr(0, len).toLowerCase() === value &&
                      next(elem)
                  );
              };
          }

          return function hyphen(elem) {
              var attr = adapter.getAttributeValue(elem, name);
              return (
                  attr != null &&
                  attr.substr(0, len) === value &&
                  (attr.length === len || attr.charAt(len) === "-") &&
                  next(elem)
              );
          };
      },
      element: function(next, data, options) {
          var name = data.name;
          var value = data.value;
          var adapter = options.adapter;

          if (/\s/.test(value)) {
              return falseFunc$4;
          }

          value = value.replace(reChars, "\\$&");

          var pattern = "(?:^|\\s)" + value + "(?:$|\\s)",
              flags = data.ignoreCase ? "i" : "",
              regex = new RegExp(pattern, flags);

          return function element(elem) {
              var attr = adapter.getAttributeValue(elem, name);
              return attr != null && regex.test(attr) && next(elem);
          };
      },
      exists: function(next, data, options) {
          var name = data.name;
          var adapter = options.adapter;

          return function exists(elem) {
              return adapter.hasAttrib(elem, name) && next(elem);
          };
      },
      start: function(next, data, options) {
          var name = data.name;
          var value = data.value;
          var len = value.length;
          var adapter = options.adapter;

          if (len === 0) {
              return falseFunc$4;
          }

          if (data.ignoreCase) {
              value = value.toLowerCase();

              return function startIC(elem) {
                  var attr = adapter.getAttributeValue(elem, name);
                  return attr != null && attr.substr(0, len).toLowerCase() === value && next(elem);
              };
          }

          return function start(elem) {
              var attr = adapter.getAttributeValue(elem, name);
              return attr != null && attr.substr(0, len) === value && next(elem);
          };
      },
      end: function(next, data, options) {
          var name = data.name;
          var value = data.value;
          var len = -value.length;
          var adapter = options.adapter;

          if (len === 0) {
              return falseFunc$4;
          }

          if (data.ignoreCase) {
              value = value.toLowerCase();

              return function endIC(elem) {
                  var attr = adapter.getAttributeValue(elem, name);
                  return attr != null && attr.substr(len).toLowerCase() === value && next(elem);
              };
          }

          return function end(elem) {
              var attr = adapter.getAttributeValue(elem, name);
              return attr != null && attr.substr(len) === value && next(elem);
          };
      },
      any: function(next, data, options) {
          var name = data.name;
          var value = data.value;
          var adapter = options.adapter;

          if (value === "") {
              return falseFunc$4;
          }

          if (data.ignoreCase) {
              var regex = new RegExp(value.replace(reChars, "\\$&"), "i");

              return function anyIC(elem) {
                  var attr = adapter.getAttributeValue(elem, name);
                  return attr != null && regex.test(attr) && next(elem);
              };
          }

          return function any(elem) {
              var attr = adapter.getAttributeValue(elem, name);
              return attr != null && attr.indexOf(value) >= 0 && next(elem);
          };
      },
      not: function(next, data, options) {
          var name = data.name;
          var value = data.value;
          var adapter = options.adapter;

          if (value === "") {
              return function notEmpty(elem) {
                  return !!adapter.getAttributeValue(elem, name) && next(elem);
              };
          } else if (data.ignoreCase) {
              value = value.toLowerCase();

              return function notIC(elem) {
                  var attr = adapter.getAttributeValue(elem, name);
                  return attr != null && attr.toLowerCase() !== value && next(elem);
              };
          }

          return function not(elem) {
              return adapter.getAttributeValue(elem, name) !== value && next(elem);
          };
      }
  };

  var attributes = {
      compile: function(next, data, options) {
          if (options && options.strict && (data.ignoreCase || data.action === "not")) {
              throw new Error("Unsupported attribute selector");
          }
          return attributeRules[data.action](next, data, options);
      },
      rules: attributeRules
  };

  var parse_1$1 = parse$1;

  //following http://www.w3.org/TR/css3-selectors/#nth-child-pseudo

  //[ ['-'|'+']? INTEGER? {N} [ S* ['-'|'+'] S* INTEGER ]?
  var re_nthElement = /^([+\-]?\d*n)?\s*(?:([+\-]?)\s*(\d+))?$/;

  /*
  	parses a nth-check formula, returns an array of two numbers
  */
  function parse$1(formula){
  	formula = formula.trim().toLowerCase();

  	if(formula === "even"){
  		return [2, 0];
  	} else if(formula === "odd"){
  		return [2, 1];
  	} else {
  		var parsed = formula.match(re_nthElement);

  		if(!parsed){
  			throw new SyntaxError("n-th rule couldn't be parsed ('" + formula + "')");
  		}

  		var a;

  		if(parsed[1]){
  			a = parseInt(parsed[1], 10);
  			if(isNaN(a)){
  				if(parsed[1].charAt(0) === "-") a = -1;
  				else a = 1;
  			}
  		} else a = 0;

  		return [
  			a,
  			parsed[3] ? parseInt((parsed[2] || "") + parsed[3], 10) : 0
  		];
  	}
  }

  var compile_1$2 = compile$2;

  var trueFunc$2  = boolbase.trueFunc,
      falseFunc$3 = boolbase.falseFunc;

  /*
  	returns a function that checks if an elements index matches the given rule
  	highly optimized to return the fastest solution
  */
  function compile$2(parsed){
  	var a = parsed[0],
  	    b = parsed[1] - 1;

  	//when b <= 0, a*n won't be possible for any matches when a < 0
  	//besides, the specification says that no element is matched when a and b are 0
  	if(b < 0 && a <= 0) return falseFunc$3;

  	//when a is in the range -1..1, it matches any element (so only b is checked)
  	if(a ===-1) return function(pos){ return pos <= b; };
  	if(a === 0) return function(pos){ return pos === b; };
  	//when b <= 0 and a === 1, they match any element
  	if(a === 1) return b < 0 ? trueFunc$2 : function(pos){ return pos >= b; };

  	//when a > 0, modulo can be used to check if there is a match
  	var bMod = b % a;
  	if(bMod < 0) bMod += a;

  	if(a > 1){
  		return function(pos){
  			return pos >= b && pos % a === bMod;
  		};
  	}

  	a *= -1; //make `a` positive

  	return function(pos){
  		return pos <= b && pos % a === bMod;
  	};
  }

  var nthCheck = function nthCheck(formula){
  	return compile_1$2(parse_1$1(formula));
  };

  var parse_1 = parse_1$1;
  var compile_1$1 = compile_1$2;
  nthCheck.parse = parse_1;
  nthCheck.compile = compile_1$1;

  /*
  	pseudo selectors

  	---

  	they are available in two forms:
  	* filters called when the selector
  	  is compiled and return a function
  	  that needs to return next()
  	* pseudos get called on execution
  	  they need to return a boolean
  */

  var trueFunc$1 = boolbase.trueFunc;
  var falseFunc$2 = boolbase.falseFunc;

  var checkAttrib = attributes.rules.equals;

  function getAttribFunc(name, value) {
      var data = { name: name, value: value };
      return function attribFunc(next, rule, options) {
          return checkAttrib(next, data, options);
      };
  }

  function getChildFunc(next, adapter) {
      return function(elem) {
          return !!adapter.getParent(elem) && next(elem);
      };
  }

  var filters$1 = {
      contains: function(next, text, options) {
          var adapter = options.adapter;

          return function contains(elem) {
              return next(elem) && adapter.getText(elem).indexOf(text) >= 0;
          };
      },
      icontains: function(next, text, options) {
          var itext = text.toLowerCase();
          var adapter = options.adapter;

          return function icontains(elem) {
              return (
                  next(elem) &&
                  adapter
                      .getText(elem)
                      .toLowerCase()
                      .indexOf(itext) >= 0
              );
          };
      },

      //location specific methods
      "nth-child": function(next, rule, options) {
          var func = nthCheck(rule);
          var adapter = options.adapter;

          if (func === falseFunc$2) return func;
          if (func === trueFunc$1) return getChildFunc(next, adapter);

          return function nthChild(elem) {
              var siblings = adapter.getSiblings(elem);

              for (var i = 0, pos = 0; i < siblings.length; i++) {
                  if (adapter.isTag(siblings[i])) {
                      if (siblings[i] === elem) break;
                      else pos++;
                  }
              }

              return func(pos) && next(elem);
          };
      },
      "nth-last-child": function(next, rule, options) {
          var func = nthCheck(rule);
          var adapter = options.adapter;

          if (func === falseFunc$2) return func;
          if (func === trueFunc$1) return getChildFunc(next, adapter);

          return function nthLastChild(elem) {
              var siblings = adapter.getSiblings(elem);

              for (var pos = 0, i = siblings.length - 1; i >= 0; i--) {
                  if (adapter.isTag(siblings[i])) {
                      if (siblings[i] === elem) break;
                      else pos++;
                  }
              }

              return func(pos) && next(elem);
          };
      },
      "nth-of-type": function(next, rule, options) {
          var func = nthCheck(rule);
          var adapter = options.adapter;

          if (func === falseFunc$2) return func;
          if (func === trueFunc$1) return getChildFunc(next, adapter);

          return function nthOfType(elem) {
              var siblings = adapter.getSiblings(elem);

              for (var pos = 0, i = 0; i < siblings.length; i++) {
                  if (adapter.isTag(siblings[i])) {
                      if (siblings[i] === elem) break;
                      if (adapter.getName(siblings[i]) === adapter.getName(elem)) pos++;
                  }
              }

              return func(pos) && next(elem);
          };
      },
      "nth-last-of-type": function(next, rule, options) {
          var func = nthCheck(rule);
          var adapter = options.adapter;

          if (func === falseFunc$2) return func;
          if (func === trueFunc$1) return getChildFunc(next, adapter);

          return function nthLastOfType(elem) {
              var siblings = adapter.getSiblings(elem);

              for (var pos = 0, i = siblings.length - 1; i >= 0; i--) {
                  if (adapter.isTag(siblings[i])) {
                      if (siblings[i] === elem) break;
                      if (adapter.getName(siblings[i]) === adapter.getName(elem)) pos++;
                  }
              }

              return func(pos) && next(elem);
          };
      },

      //TODO determine the actual root element
      root: function(next, rule, options) {
          var adapter = options.adapter;

          return function(elem) {
              return !adapter.getParent(elem) && next(elem);
          };
      },

      scope: function(next, rule, options, context) {
          var adapter = options.adapter;

          if (!context || context.length === 0) {
              //equivalent to :root
              return filters$1.root(next, rule, options);
          }

          function equals(a, b) {
              if (typeof adapter.equals === "function") return adapter.equals(a, b);

              return a === b;
          }

          if (context.length === 1) {
              //NOTE: can't be unpacked, as :has uses this for side-effects
              return function(elem) {
                  return equals(context[0], elem) && next(elem);
              };
          }

          return function(elem) {
              return context.indexOf(elem) >= 0 && next(elem);
          };
      },

      //jQuery extensions (others follow as pseudos)
      checkbox: getAttribFunc("type", "checkbox"),
      file: getAttribFunc("type", "file"),
      password: getAttribFunc("type", "password"),
      radio: getAttribFunc("type", "radio"),
      reset: getAttribFunc("type", "reset"),
      image: getAttribFunc("type", "image"),
      submit: getAttribFunc("type", "submit"),

      //dynamic state pseudos. These depend on optional Adapter methods.
      hover: function(next, rule, options) {
          var adapter = options.adapter;

          if (typeof adapter.isHovered === 'function') {
              return function hover(elem) {
                  return next(elem) && adapter.isHovered(elem);
              };
          }

          return falseFunc$2;
      },
      visited: function(next, rule, options) {
          var adapter = options.adapter;

          if (typeof adapter.isVisited === 'function') {
              return function visited(elem) {
                  return next(elem) && adapter.isVisited(elem);
              };
          }

          return falseFunc$2;
      },
      active: function(next, rule, options) {
          var adapter = options.adapter;

          if (typeof adapter.isActive === 'function') {
              return function active(elem) {
                  return next(elem) && adapter.isActive(elem);
              };
          }

          return falseFunc$2;
      }
  };

  //helper methods
  function getFirstElement(elems, adapter) {
      for (var i = 0; elems && i < elems.length; i++) {
          if (adapter.isTag(elems[i])) return elems[i];
      }
  }

  //while filters are precompiled, pseudos get called when they are needed
  var pseudos = {
      empty: function(elem, adapter) {
          return !adapter.getChildren(elem).some(function(elem) {
              return adapter.isTag(elem) || elem.type === "text";
          });
      },

      "first-child": function(elem, adapter) {
          return getFirstElement(adapter.getSiblings(elem), adapter) === elem;
      },
      "last-child": function(elem, adapter) {
          var siblings = adapter.getSiblings(elem);

          for (var i = siblings.length - 1; i >= 0; i--) {
              if (siblings[i] === elem) return true;
              if (adapter.isTag(siblings[i])) break;
          }

          return false;
      },
      "first-of-type": function(elem, adapter) {
          var siblings = adapter.getSiblings(elem);

          for (var i = 0; i < siblings.length; i++) {
              if (adapter.isTag(siblings[i])) {
                  if (siblings[i] === elem) return true;
                  if (adapter.getName(siblings[i]) === adapter.getName(elem)) break;
              }
          }

          return false;
      },
      "last-of-type": function(elem, adapter) {
          var siblings = adapter.getSiblings(elem);

          for (var i = siblings.length - 1; i >= 0; i--) {
              if (adapter.isTag(siblings[i])) {
                  if (siblings[i] === elem) return true;
                  if (adapter.getName(siblings[i]) === adapter.getName(elem)) break;
              }
          }

          return false;
      },
      "only-of-type": function(elem, adapter) {
          var siblings = adapter.getSiblings(elem);

          for (var i = 0, j = siblings.length; i < j; i++) {
              if (adapter.isTag(siblings[i])) {
                  if (siblings[i] === elem) continue;
                  if (adapter.getName(siblings[i]) === adapter.getName(elem)) {
                      return false;
                  }
              }
          }

          return true;
      },
      "only-child": function(elem, adapter) {
          var siblings = adapter.getSiblings(elem);

          for (var i = 0; i < siblings.length; i++) {
              if (adapter.isTag(siblings[i]) && siblings[i] !== elem) return false;
          }

          return true;
      },

      //:matches(a, area, link)[href]
      link: function(elem, adapter) {
          return adapter.hasAttrib(elem, "href");
      },
      //TODO: :any-link once the name is finalized (as an alias of :link)

      //forms
      //to consider: :target

      //:matches([selected], select:not([multiple]):not(> option[selected]) > option:first-of-type)
      selected: function(elem, adapter) {
          if (adapter.hasAttrib(elem, "selected")) return true;
          else if (adapter.getName(elem) !== "option") return false;

          //the first <option> in a <select> is also selected
          var parent = adapter.getParent(elem);

          if (!parent || adapter.getName(parent) !== "select" || adapter.hasAttrib(parent, "multiple")) {
              return false;
          }

          var siblings = adapter.getChildren(parent);
          var sawElem = false;

          for (var i = 0; i < siblings.length; i++) {
              if (adapter.isTag(siblings[i])) {
                  if (siblings[i] === elem) {
                      sawElem = true;
                  } else if (!sawElem) {
                      return false;
                  } else if (adapter.hasAttrib(siblings[i], "selected")) {
                      return false;
                  }
              }
          }

          return sawElem;
      },
      //https://html.spec.whatwg.org/multipage/scripting.html#disabled-elements
      //:matches(
      //  :matches(button, input, select, textarea, menuitem, optgroup, option)[disabled],
      //  optgroup[disabled] > option),
      // fieldset[disabled] * //TODO not child of first <legend>
      //)
      disabled: function(elem, adapter) {
          return adapter.hasAttrib(elem, "disabled");
      },
      enabled: function(elem, adapter) {
          return !adapter.hasAttrib(elem, "disabled");
      },
      //:matches(:matches(:radio, :checkbox)[checked], :selected) (TODO menuitem)
      checked: function(elem, adapter) {
          return adapter.hasAttrib(elem, "checked") || pseudos.selected(elem, adapter);
      },
      //:matches(input, select, textarea)[required]
      required: function(elem, adapter) {
          return adapter.hasAttrib(elem, "required");
      },
      //:matches(input, select, textarea):not([required])
      optional: function(elem, adapter) {
          return !adapter.hasAttrib(elem, "required");
      },

      //jQuery extensions

      //:not(:empty)
      parent: function(elem, adapter) {
          return !pseudos.empty(elem, adapter);
      },
      //:matches(h1, h2, h3, h4, h5, h6)
      header: namePseudo(["h1", "h2", "h3", "h4", "h5", "h6"]),

      //:matches(button, input[type=button])
      button: function(elem, adapter) {
          var name = adapter.getName(elem);
          return (
              name === "button" || (name === "input" && adapter.getAttributeValue(elem, "type") === "button")
          );
      },
      //:matches(input, textarea, select, button)
      input: namePseudo(["input", "textarea", "select", "button"]),
      //input:matches(:not([type!='']), [type='text' i])
      text: function(elem, adapter) {
          var attr;
          return (
              adapter.getName(elem) === "input" &&
              (!(attr = adapter.getAttributeValue(elem, "type")) || attr.toLowerCase() === "text")
          );
      }
  };

  function namePseudo(names) {
      if (typeof Set !== "undefined") {
          // eslint-disable-next-line no-undef
          var nameSet = new Set(names);

          return function(elem, adapter) {
              return nameSet.has(adapter.getName(elem));
          };
      }

      return function(elem, adapter) {
          return names.indexOf(adapter.getName(elem)) >= 0;
      };
  }

  function verifyArgs(func, name, subselect) {
      if (subselect === null) {
          if (func.length > 2 && name !== "scope") {
              throw new Error("pseudo-selector :" + name + " requires an argument");
          }
      } else {
          if (func.length === 2) {
              throw new Error("pseudo-selector :" + name + " doesn't have any arguments");
          }
      }
  }

  //FIXME this feels hacky
  var re_CSS3 = /^(?:(?:nth|last|first|only)-(?:child|of-type)|root|empty|(?:en|dis)abled|checked|not)$/;

  var pseudos_1 = {
      compile: function(next, data, options, context) {
          var name = data.name;
          var subselect = data.data;
          var adapter = options.adapter;

          if (options && options.strict && !re_CSS3.test(name)) {
              throw new Error(":" + name + " isn't part of CSS3");
          }

          if (typeof filters$1[name] === "function") {
              return filters$1[name](next, subselect, options, context);
          } else if (typeof pseudos[name] === "function") {
              var func = pseudos[name];

              verifyArgs(func, name, subselect);

              if (func === falseFunc$2) {
                  return func;
              }

              if (next === trueFunc$1) {
                  return function pseudoRoot(elem) {
                      return func(elem, adapter, subselect);
                  };
              }

              return function pseudoArgs(elem) {
                  return func(elem, adapter, subselect) && next(elem);
              };
          } else {
              throw new Error("unmatched pseudo-class :" + name);
          }
      },
      filters: filters$1,
      pseudos: pseudos
  };

  /*
  	all available rules
  */
  var general = {
      __proto__: null,

      attribute: attributes.compile,
      pseudo: pseudos_1.compile,

      //tags
      tag: function(next, data, options) {
          var name = data.name;
          var adapter = options.adapter;

          return function tag(elem) {
              return adapter.getName(elem) === name && next(elem);
          };
      },

      //traversal
      descendant: function(next, data, options) {
          // eslint-disable-next-line no-undef
          var isFalseCache = typeof WeakSet !== "undefined" ? new WeakSet() : null;
          var adapter = options.adapter;

          return function descendant(elem) {
              var found = false;

              while (!found && (elem = adapter.getParent(elem))) {
                  if (!isFalseCache || !isFalseCache.has(elem)) {
                      found = next(elem);
                      if (!found && isFalseCache) {
                          isFalseCache.add(elem);
                      }
                  }
              }

              return found;
          };
      },
      _flexibleDescendant: function(next, data, options) {
          var adapter = options.adapter;

          // Include element itself, only used while querying an array
          return function descendant(elem) {
              var found = next(elem);

              while (!found && (elem = adapter.getParent(elem))) {
                  found = next(elem);
              }

              return found;
          };
      },
      parent: function(next, data, options) {
          if (options && options.strict) {
              throw new Error("Parent selector isn't part of CSS3");
          }

          var adapter = options.adapter;

          return function parent(elem) {
              return adapter.getChildren(elem).some(test);
          };

          function test(elem) {
              return adapter.isTag(elem) && next(elem);
          }
      },
      child: function(next, data, options) {
          var adapter = options.adapter;

          return function child(elem) {
              var parent = adapter.getParent(elem);
              return !!parent && next(parent);
          };
      },
      sibling: function(next, data, options) {
          var adapter = options.adapter;

          return function sibling(elem) {
              var siblings = adapter.getSiblings(elem);

              for (var i = 0; i < siblings.length; i++) {
                  if (adapter.isTag(siblings[i])) {
                      if (siblings[i] === elem) break;
                      if (next(siblings[i])) return true;
                  }
              }

              return false;
          };
      },
      adjacent: function(next, data, options) {
          var adapter = options.adapter;

          return function adjacent(elem) {
              var siblings = adapter.getSiblings(elem),
                  lastElement;

              for (var i = 0; i < siblings.length; i++) {
                  if (adapter.isTag(siblings[i])) {
                      if (siblings[i] === elem) break;
                      lastElement = siblings[i];
                  }
              }

              return !!lastElement && next(lastElement);
          };
      },
      universal: function(next) {
          return next;
      }
  };

  /*
  	compiles a selector to an executable function
  */

  var compile_1 = compile$1;

  var parse = lib.parse;





  var trueFunc = boolbase.trueFunc;
  var falseFunc$1 = boolbase.falseFunc;

  var filters = pseudos_1.filters;

  function compile$1(selector, options, context) {
      var next = compileUnsafe$1(selector, options, context);
      return wrap(next, options);
  }

  function wrap(next, options) {
      var adapter = options.adapter;

      return function base(elem) {
          return adapter.isTag(elem) && next(elem);
      };
  }

  function compileUnsafe$1(selector, options, context) {
      var token = parse(selector, options);
      return compileToken(token, options, context);
  }

  function includesScopePseudo(t) {
      return (
          t.type === "pseudo" &&
          (t.name === "scope" ||
              (Array.isArray(t.data) &&
                  t.data.some(function(data) {
                      return data.some(includesScopePseudo);
                  })))
      );
  }

  var DESCENDANT_TOKEN = { type: "descendant" };
  var FLEXIBLE_DESCENDANT_TOKEN = { type: "_flexibleDescendant" };
  var SCOPE_TOKEN = { type: "pseudo", name: "scope" };
  var PLACEHOLDER_ELEMENT = {};

  //CSS 4 Spec (Draft): 3.3.1. Absolutizing a Scope-relative Selector
  //http://www.w3.org/TR/selectors4/#absolutizing
  function absolutize(token, options, context) {
      var adapter = options.adapter;

      //TODO better check if context is document
      var hasContext =
          !!context &&
          !!context.length &&
          context.every(function(e) {
              return e === PLACEHOLDER_ELEMENT || !!adapter.getParent(e);
          });

      token.forEach(function(t) {
          if (t.length > 0 && isTraversal(t[0]) && t[0].type !== "descendant") ; else if (hasContext && !(Array.isArray(t) ? t.some(includesScopePseudo) : includesScopePseudo(t))) {
              t.unshift(DESCENDANT_TOKEN);
          } else {
              return;
          }

          t.unshift(SCOPE_TOKEN);
      });
  }

  function compileToken(token, options, context) {
      token = token.filter(function(t) {
          return t.length > 0;
      });

      token.forEach(sort);

      var isArrayContext = Array.isArray(context);

      context = (options && options.context) || context;

      if (context && !isArrayContext) context = [context];

      absolutize(token, options, context);

      var shouldTestNextSiblings = false;

      var query = token
          .map(function(rules) {
              if (rules[0] && rules[1] && rules[0].name === "scope") {
                  var ruleType = rules[1].type;
                  if (isArrayContext && ruleType === "descendant") {
                      rules[1] = FLEXIBLE_DESCENDANT_TOKEN;
                  } else if (ruleType === "adjacent" || ruleType === "sibling") {
                      shouldTestNextSiblings = true;
                  }
              }
              return compileRules(rules, options, context);
          })
          .reduce(reduceRules, falseFunc$1);

      query.shouldTestNextSiblings = shouldTestNextSiblings;

      return query;
  }

  function isTraversal(t) {
      return procedure[t.type] < 0;
  }

  function compileRules(rules, options, context) {
      return rules.reduce(function(func, rule) {
          if (func === falseFunc$1) return func;

          if (!(rule.type in general)) {
              throw new Error("Rule type " + rule.type + " is not supported by css-select");
          }

          return general[rule.type](func, rule, options, context);
      }, (options && options.rootFunc) || trueFunc);
  }

  function reduceRules(a, b) {
      if (b === falseFunc$1 || a === trueFunc) {
          return a;
      }
      if (a === falseFunc$1 || b === trueFunc) {
          return b;
      }

      return function combine(elem) {
          return a(elem) || b(elem);
      };
  }

  function containsTraversal(t) {
      return t.some(isTraversal);
  }

  //:not, :has and :matches have to compile selectors
  //doing this in lib/pseudos.js would lead to circular dependencies,
  //so we add them here
  filters.not = function(next, token, options, context) {
      var opts = {
          xmlMode: !!(options && options.xmlMode),
          strict: !!(options && options.strict),
          adapter: options.adapter
      };

      if (opts.strict) {
          if (token.length > 1 || token.some(containsTraversal)) {
              throw new Error("complex selectors in :not aren't allowed in strict mode");
          }
      }

      var func = compileToken(token, opts, context);

      if (func === falseFunc$1) return next;
      if (func === trueFunc) return falseFunc$1;

      return function not(elem) {
          return !func(elem) && next(elem);
      };
  };

  filters.has = function(next, token, options) {
      var adapter = options.adapter;
      var opts = {
          xmlMode: !!(options && options.xmlMode),
          strict: !!(options && options.strict),
          adapter: adapter
      };

      //FIXME: Uses an array as a pointer to the current element (side effects)
      var context = token.some(containsTraversal) ? [PLACEHOLDER_ELEMENT] : null;

      var func = compileToken(token, opts, context);

      if (func === falseFunc$1) return falseFunc$1;
      if (func === trueFunc) {
          return function hasChild(elem) {
              return adapter.getChildren(elem).some(adapter.isTag) && next(elem);
          };
      }

      func = wrap(func, options);

      if (context) {
          return function has(elem) {
              return next(elem) && ((context[0] = elem), adapter.existsOne(func, adapter.getChildren(elem)));
          };
      }

      return function has(elem) {
          return next(elem) && adapter.existsOne(func, adapter.getChildren(elem));
      };
  };

  filters.matches = function(next, token, options, context) {
      var opts = {
          xmlMode: !!(options && options.xmlMode),
          strict: !!(options && options.strict),
          rootFunc: next,
          adapter: options.adapter
      };

      return compileToken(token, opts, context);
  };

  compile$1.compileToken = compileToken;
  compile$1.compileUnsafe = compileUnsafe$1;
  compile$1.Pseudos = pseudos_1;

  var cssSelect = CSSselect;


  var falseFunc = boolbase.falseFunc;


  function wrapCompile(func) {
      return function addAdapter(selector, options, context) {
          options = options || {};
          options.adapter = options.adapter || domutils;

          return func(selector, options, context);
      };
  }

  var compile = wrapCompile(compile_1);
  var compileUnsafe = wrapCompile(compile_1.compileUnsafe);

  function getSelectorFunc(searchFunc) {
      return function select(query, elems, options) {
          options = options || {};
          options.adapter = options.adapter || domutils;

          if (typeof query !== "function") {
              query = compileUnsafe(query, options, elems);
          }
          if (query.shouldTestNextSiblings) {
              elems = appendNextSiblings((options && options.context) || elems, options.adapter);
          }
          if (!Array.isArray(elems)) elems = options.adapter.getChildren(elems);
          else elems = options.adapter.removeSubsets(elems);
          return searchFunc(query, elems, options);
      };
  }

  function getNextSiblings(elem, adapter) {
      var siblings = adapter.getSiblings(elem);
      if (!Array.isArray(siblings)) return [];
      siblings = siblings.slice(0);
      while (siblings.shift() !== elem);
      return siblings;
  }

  function appendNextSiblings(elems, adapter) {
      // Order matters because jQuery seems to check the children before the siblings
      if (!Array.isArray(elems)) elems = [elems];
      var newElems = elems.slice(0);

      for (var i = 0, len = elems.length; i < len; i++) {
          var nextSiblings = getNextSiblings(newElems[i], adapter);
          newElems.push.apply(newElems, nextSiblings);
      }
      return newElems;
  }

  var selectAll = getSelectorFunc(function selectAll(query, elems, options) {
      return query === falseFunc || !elems || elems.length === 0 ? [] : options.adapter.findAll(query, elems);
  });

  var selectOne = getSelectorFunc(function selectOne(query, elems, options) {
      return query === falseFunc || !elems || elems.length === 0 ? null : options.adapter.findOne(query, elems);
  });

  function is(elem, query, options) {
      options = options || {};
      options.adapter = options.adapter || domutils;
      return (typeof query === "function" ? query : compile(query, options))(elem);
  }

  /*
  	the exported interface
  */
  function CSSselect(query, elems, options) {
      return selectAll(query, elems, options);
  }

  CSSselect.compile = compile;
  CSSselect.filters = compile_1.Pseudos.filters;
  CSSselect.pseudos = compile_1.Pseudos.pseudos;

  CSSselect.selectAll = selectAll;
  CSSselect.selectOne = selectOne;

  CSSselect.is = is;

  //legacy methods (might be removed)
  CSSselect.parse = compile;
  CSSselect.iterate = selectAll;

  //hooks
  CSSselect._compileUnsafe = compileUnsafe;
  CSSselect._compileToken = compile_1.compileToken;

  var css = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.SvgCss=SvgCss;exports.SvgCssUri=SvgCssUri;exports.SvgWithCssUri=exports.SvgWithCss=exports.inlineStyles=void 0;var _regenerator=interopRequireDefault(regenerator);var _classCallCheck2=interopRequireDefault(classCallCheck);var _createClass2=interopRequireDefault(createClass);var _possibleConstructorReturn2=interopRequireDefault(possibleConstructorReturn);var _getPrototypeOf4=interopRequireDefault(getPrototypeOf);var _assertThisInitialized2=interopRequireDefault(assertThisInitialized);var _inherits2=interopRequireDefault(inherits);var _defineProperty2=interopRequireDefault(defineProperty);var _slicedToArray2=interopRequireDefault(slicedToArray);var _react=interopRequireWildcard(React__default["default"]);var _cssTree=interopRequireWildcard(lib$3);var _cssSelect=interopRequireDefault(cssSelect);var _jsxFileName="/Users/horcrux/Work/react-native-svg/src/css.tsx";function isTag(node){return typeof node==='object';}function getParent(node){return typeof node==='object'&&node.parent||null;}function getChildren(node){return typeof node==='object'&&node.children||[];}function getName(elem){return elem.tag;}function getText(_node){return '';}function getAttributeValue(elem,name){return elem.props[name]||null;}function removeSubsets(nodes){var idx=nodes.length,node,ancestor,replace;while(--idx>-1){node=ancestor=nodes[idx];delete nodes[idx];replace=true;while(ancestor){if(nodes.includes(ancestor)){replace=false;nodes.splice(idx,1);break;}ancestor=typeof ancestor==='object'&&ancestor.parent||null;}if(replace){nodes[idx]=node;}}return nodes;}function existsOne(predicate,elems){return elems.some(function(elem){return typeof elem==='object'&&(predicate(elem)||existsOne(predicate,elem.children));});}function getSiblings(node){var parent=typeof node==='object'&&node.parent;return parent&&parent.children||[];}function hasAttrib(elem,name){return elem.props.hasOwnProperty(name);}function findOne(predicate,elems){var elem;for(var i=0,l=elems.length;i<l&&!elem;i++){var node=elems[i];if(typeof node==='string');else if(predicate(node)){elem=node;}else {var children=node.children;if(children.length!==0){elem=findOne(predicate,children);}}}return elem;}function findAll(predicate,nodes){var result=arguments.length>2&&arguments[2]!==undefined?arguments[2]:[];for(var i=0,j=nodes.length;i<j;i++){var node=nodes[i];if(typeof node!=='object'){continue;}if(predicate(node)){result.push(node);}var children=node.children;if(children.length!==0){findAll(predicate,children,result);}}return result;}var adapter={removeSubsets:removeSubsets,existsOne:existsOne,getSiblings:getSiblings,hasAttrib:hasAttrib,findOne:findOne,findAll:findAll,isTag:isTag,getParent:getParent,getChildren:getChildren,getName:getName,getText:getText,getAttributeValue:getAttributeValue};var cssSelectOpts={xmlMode:true,adapter:adapter};function querySelectorAll(query,elems){return (0, _cssSelect.default)(query,elems,cssSelectOpts);}function flattenToSelectors(cssAst,selectors){_cssTree.default.walk(cssAst,{visit:'Rule',enter:function enter(rule){var _ref=rule,type=_ref.type,prelude=_ref.prelude;if(type!=='Rule'){return;}var atrule=this.atrule;prelude.children.each(function(node,item){var _ref2=node,children=_ref2.children;var pseudos=[];selectors.push({item:item,atrule:atrule,rule:rule,pseudos:pseudos});children.each(function(_ref3,pseudoItem,list){var childType=_ref3.type;if(childType==='PseudoClassSelector'||childType==='PseudoElementSelector'){pseudos.push({item:pseudoItem,list:list});}});});}});}function filterByMqs(selectors){return selectors.filter(function(_ref4){var atrule=_ref4.atrule;if(atrule===null){return true;}var name=atrule.name,prelude=atrule.prelude;var atPrelude=prelude;var first=atPrelude&&atPrelude.children.first();var mq=first&&first.type==='MediaQueryList';var query=mq?_cssTree.default.generate(atPrelude):name;return useMqs.includes(query);});}var useMqs=['','screen'];function filterByPseudos(selectors){return selectors.filter(function(_ref5){var pseudos=_ref5.pseudos;return usePseudos.includes(_cssTree.default.generate({type:'Selector',children:new _cssTree.List().fromArray(pseudos.map(function(pseudo){return pseudo.item.data;}))}));});}var usePseudos=[''];function cleanPseudos(selectors){selectors.forEach(function(_ref6){var pseudos=_ref6.pseudos;return pseudos.forEach(function(pseudo){return pseudo.list.remove(pseudo.item);});});}function specificity(selector){var A=0;var B=0;var C=0;selector.children.each(function walk(node){switch(node.type){case'SelectorList':case'Selector':node.children.each(walk);break;case'IdSelector':A++;break;case'ClassSelector':case'AttributeSelector':B++;break;case'PseudoClassSelector':switch(node.name.toLowerCase()){case'not':var children=node.children;children&&children.each(walk);break;case'before':case'after':case'first-line':case'first-letter':C++;break;default:B++;}break;case'PseudoElementSelector':C++;break;case'TypeSelector':var name=node.name;if(name.charAt(name.length-1)!=='*'){C++;}break;}});return [A,B,C];}function compareSpecificity(aSpecificity,bSpecificity){for(var i=0;i<4;i+=1){if(aSpecificity[i]<bSpecificity[i]){return -1;}else if(aSpecificity[i]>bSpecificity[i]){return 1;}}return 0;}function selectorWithSpecificity(selector){return {selector:selector,specificity:specificity(selector.item.data)};}function bySelectorSpecificity(a,b){return compareSpecificity(a.specificity,b.specificity);}function pass(arr,len,chk,result){var dbl=chk*2;var l,r,e;var li,ri;var i=0;for(l=0;l<len;l+=dbl){r=l+chk;e=r+chk;if(r>len){r=len;}if(e>len){e=len;}li=l;ri=r;while(true){if(li<r&&ri<e){if(bySelectorSpecificity(arr[li],arr[ri])<=0){result[i++]=arr[li++];}else {result[i++]=arr[ri++];}}else if(li<r){result[i++]=arr[li++];}else if(ri<e){result[i++]=arr[ri++];}else {break;}}}}function exec(arr,len){var buffer=new Array(len);for(var chk=1;chk<len;chk*=2){pass(arr,len,chk,buffer);var tmp=arr;arr=buffer;buffer=tmp;}return arr;}function sortSelectors(selectors){var len=selectors.length;if(len<=1){return selectors;}var specs=selectors.map(selectorWithSpecificity);return exec(specs,len).map(function(s){return s.selector;});}var declarationParseProps={context:'declarationList',parseValue:false};function CSSStyleDeclaration(ast){var props=ast.props,styles=ast.styles;if(!props.style){props.style={};}var style=props.style;var priority=new Map();ast.style=style;ast.priority=priority;if(!styles||styles.length===0){return;}try{var declarations=_cssTree.default.parse(styles,declarationParseProps);declarations.children.each(function(node){try{var _ref7=node,property=_ref7.property,value=_ref7.value,important=_ref7.important;var name=property.trim();priority.set(name,important);style[(0,xml.camelCase)(name)]=_cssTree.default.generate(value).trim();}catch(styleError){if(styleError.message!=='Unknown node type: undefined'){console.warn("Warning: Parse error when parsing inline styles, style properties of this element cannot be used. The raw styles can still be get/set using .attr('style').value. Error details: "+styleError);}}});}catch(parseError){console.warn("Warning: Parse error when parsing inline styles, style properties of this element cannot be used. The raw styles can still be get/set using .attr('style').value. Error details: "+parseError);}}function initStyle(selectedEl){if(!selectedEl.style){CSSStyleDeclaration(selectedEl);}return selectedEl;}function closestElem(node,elemName){var elem=node;while((elem=elem.parent)&&elem.tag!==elemName){}return elem;}var parseProps={parseValue:false,parseCustomProperty:false};var inlineStyles=function inlineStyles(document){var styleElements=querySelectorAll('style',document);if(styleElements.length===0){return document;}var selectors=[];for(var _iterator=styleElements,_isArray=Array.isArray(_iterator),_i=0,_iterator=_isArray?_iterator:_iterator[typeof Symbol==="function"?Symbol.iterator:"@@iterator"]();;){var _ref8;if(_isArray){if(_i>=_iterator.length)break;_ref8=_iterator[_i++];}else {_i=_iterator.next();if(_i.done)break;_ref8=_i.value;}var _element=_ref8;var _children=_element.children;if(!_children.length||closestElem(_element,'foreignObject')){continue;}try{var styleString=_children.join('');flattenToSelectors(_cssTree.default.parse(styleString,parseProps),selectors);}catch(parseError){console.warn('Warning: Parse error of styles of <style/> element, skipped. Error details: '+parseError);}}var selectorsMq=filterByMqs(selectors);var selectorsPseudo=filterByPseudos(selectorsMq);cleanPseudos(selectorsPseudo);var sortedSelectors=sortSelectors(selectorsPseudo).reverse();for(var _iterator2=sortedSelectors,_isArray2=Array.isArray(_iterator2),_i2=0,_iterator2=_isArray2?_iterator2:_iterator2[typeof Symbol==="function"?Symbol.iterator:"@@iterator"]();;){var _ref10;if(_isArray2){if(_i2>=_iterator2.length)break;_ref10=_iterator2[_i2++];}else {_i2=_iterator2.next();if(_i2.done)break;_ref10=_i2.value;}var _ref11=_ref10;var _rule=_ref11.rule;var _item=_ref11.item;if(_rule===null){continue;}var _selectorStr=_cssTree.default.generate(_item.data);try{var _ret=function(){var matched=querySelectorAll(_selectorStr,document).map(initStyle);if(matched.length===0){return "continue";}_cssTree.default.walk(_rule,{visit:'Declaration',enter:function enter(node){var _ref12=node,property=_ref12.property,value=_ref12.value,important=_ref12.important;var name=property.trim();var camel=(0,xml.camelCase)(name);var val=_cssTree.default.generate(value).trim();for(var _iterator3=matched,_isArray3=Array.isArray(_iterator3),_i3=0,_iterator3=_isArray3?_iterator3:_iterator3[typeof Symbol==="function"?Symbol.iterator:"@@iterator"]();;){var _ref13;if(_isArray3){if(_i3>=_iterator3.length)break;_ref13=_iterator3[_i3++];}else {_i3=_iterator3.next();if(_i3.done)break;_ref13=_i3.value;}var _element3=_ref13;var _style=_element3.style,_priority=_element3.priority;var _current=_priority.get(name);if(_current===undefined||_current<important){_priority.set(name,important);_style[camel]=val;}}}});}();if(_ret==="continue")continue;}catch(selectError){if(selectError.constructor===SyntaxError){console.warn('Warning: Syntax error when trying to select \n\n'+_selectorStr+'\n\n, skipped. Error details: '+selectError);continue;}throw selectError;}}return document;};exports.inlineStyles=inlineStyles;function SvgCss(props){var xml$1=props.xml,override=props.override;var ast=(0, _react.useMemo)(function(){return xml$1!==null?(0, xml.parse)(xml$1,inlineStyles):null;},[xml$1]);return _react.default.createElement(xml.SvgAst,{ast:ast,override:override||props,__source:{fileName:_jsxFileName,lineNumber:701}});}function SvgCssUri(props){var uri=props.uri;var _useState=(0, _react.useState)(null),_useState2=(0, _slicedToArray2.default)(_useState,2),xml$1=_useState2[0],setXml=_useState2[1];(0, _react.useEffect)(function(){uri?(0, xml.fetchText)(uri).then(setXml).catch(xml.err):setXml(null);},[uri]);return _react.default.createElement(SvgCss,{xml:xml$1,override:props,__source:{fileName:_jsxFileName,lineNumber:714}});}var SvgWithCss=function(_Component){(0, _inherits2.default)(SvgWithCss,_Component);function SvgWithCss(){var _getPrototypeOf2;var _this;(0, _classCallCheck2.default)(this,SvgWithCss);for(var _len=arguments.length,args=new Array(_len),_key=0;_key<_len;_key++){args[_key]=arguments[_key];}_this=(0, _possibleConstructorReturn2.default)(this,(_getPrototypeOf2=(0, _getPrototypeOf4.default)(SvgWithCss)).call.apply(_getPrototypeOf2,[this].concat(args)));(0, _defineProperty2.default)((0, _assertThisInitialized2.default)(_this),"state",{ast:null});return _this;}(0, _createClass2.default)(SvgWithCss,[{key:"componentDidMount",value:function componentDidMount(){this.parse(this.props.xml);}},{key:"componentDidUpdate",value:function componentDidUpdate(prevProps){var xml=this.props.xml;if(xml!==prevProps.xml){this.parse(xml);}}},{key:"parse",value:function parse(xml$1){try{this.setState({ast:xml$1?(0,xml.parse)(xml$1,inlineStyles):null});}catch(e){console.error(e);}}},{key:"render",value:function render(){var props=this.props,ast=this.state.ast;return _react.default.createElement(xml.SvgAst,{ast:ast,override:props.override||props,__source:{fileName:_jsxFileName,lineNumber:742}});}}]);return SvgWithCss;}(_react.Component);exports.SvgWithCss=SvgWithCss;var SvgWithCssUri=function(_Component2){(0, _inherits2.default)(SvgWithCssUri,_Component2);function SvgWithCssUri(){var _getPrototypeOf3;var _this2;(0, _classCallCheck2.default)(this,SvgWithCssUri);for(var _len3=arguments.length,args=new Array(_len3),_key3=0;_key3<_len3;_key3++){args[_key3]=arguments[_key3];}_this2=(0, _possibleConstructorReturn2.default)(this,(_getPrototypeOf3=(0, _getPrototypeOf4.default)(SvgWithCssUri)).call.apply(_getPrototypeOf3,[this].concat(args)));(0, _defineProperty2.default)((0, _assertThisInitialized2.default)(_this2),"state",{xml:null});return _this2;}(0, _createClass2.default)(SvgWithCssUri,[{key:"componentDidMount",value:function componentDidMount(){this.fetch(this.props.uri);}},{key:"componentDidUpdate",value:function componentDidUpdate(prevProps){var uri=this.props.uri;if(uri!==prevProps.uri){this.fetch(uri);}}},{key:"fetch",value:function fetch(uri){return _regenerator.default.async(function fetch$(_context){while(1){switch(_context.prev=_context.next){case 0:_context.prev=0;_context.t0=this;if(!uri){_context.next=8;break;}_context.next=5;return _regenerator.default.awrap((0, xml.fetchText)(uri));case 5:_context.t1=_context.sent;_context.next=9;break;case 8:_context.t1=null;case 9:_context.t2=_context.t1;_context.t3={xml:_context.t2};_context.t0.setState.call(_context.t0,_context.t3);_context.next=17;break;case 14:_context.prev=14;_context.t4=_context["catch"](0);console.error(_context.t4);case 17:case"end":return _context.stop();}}},null,this,[[0,14]],Promise);}},{key:"render",value:function render(){var props=this.props,xml=this.state.xml;return _react.default.createElement(SvgWithCss,{xml:xml,override:props,__source:{fileName:_jsxFileName,lineNumber:769}});}}]);return SvgWithCssUri;}(_react.Component);exports.SvgWithCssUri=SvgWithCssUri;

  });

  var LocalSvg_1 = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});exports.getUriFromSource=getUriFromSource;exports.loadLocalRawResourceDefault=loadLocalRawResourceDefault;exports.isUriAnAndroidResourceIdentifier=isUriAnAndroidResourceIdentifier;exports.loadAndroidRawResource=loadAndroidRawResource;exports.loadLocalRawResourceAndroid=loadLocalRawResourceAndroid;exports.LocalSvg=LocalSvg;exports.default=exports.WithLocalSvg=exports.loadLocalRawResource=void 0;var _classCallCheck2=interopRequireDefault(classCallCheck);var _createClass2=interopRequireDefault(createClass);var _possibleConstructorReturn2=interopRequireDefault(possibleConstructorReturn);var _getPrototypeOf3=interopRequireDefault(getPrototypeOf);var _assertThisInitialized2=interopRequireDefault(assertThisInitialized);var _inherits2=interopRequireDefault(inherits);var _defineProperty2=interopRequireDefault(defineProperty);var _extends2=interopRequireDefault(_extends_1);var _slicedToArray2=interopRequireDefault(slicedToArray);var _objectWithoutProperties2=interopRequireDefault(objectWithoutProperties);var _regenerator=interopRequireDefault(regenerator);var _react=interopRequireWildcard(React__default["default"]);var _resolveAssetSource=interopRequireDefault(require$$12__default["default"]);var _jsxFileName="/Users/horcrux/Work/react-native-svg/src/LocalSvg.tsx";var _ref=_reactNative__default["default"].NativeModules.RNSVGRenderableManager||{},getRawResource=_ref.getRawResource;function getUriFromSource(source){var resolvedAssetSource=(0, _resolveAssetSource.default)(source);return resolvedAssetSource.uri;}function loadLocalRawResourceDefault(source){var uri=getUriFromSource(source);return (0, xml.fetchText)(uri);}function isUriAnAndroidResourceIdentifier(uri){return typeof uri==='string'&&uri.indexOf('/')<=-1;}function loadAndroidRawResource(uri){return _regenerator.default.async(function loadAndroidRawResource$(_context){while(1){switch(_context.prev=_context.next){case 0:_context.prev=0;_context.next=3;return _regenerator.default.awrap(getRawResource(uri));case 3:return _context.abrupt("return",_context.sent);case 6:_context.prev=6;_context.t0=_context["catch"](0);console.error('Error in RawResourceUtils while trying to natively load an Android raw resource: ',_context.t0);return _context.abrupt("return",null);case 10:case"end":return _context.stop();}}},null,null,[[0,6]],Promise);}function loadLocalRawResourceAndroid(source){var uri=getUriFromSource(source);if(isUriAnAndroidResourceIdentifier(uri)){return loadAndroidRawResource(uri);}else {return (0, xml.fetchText)(uri);}}var loadLocalRawResource=_reactNative__default["default"].Platform.OS!=='android'?loadLocalRawResourceDefault:loadLocalRawResourceAndroid;exports.loadLocalRawResource=loadLocalRawResource;function LocalSvg(props){var asset=props.asset,rest=(0, _objectWithoutProperties2.default)(props,["asset"]);var _useState=(0, _react.useState)(null),_useState2=(0, _slicedToArray2.default)(_useState,2),xml=_useState2[0],setXml=_useState2[1];(0, _react.useEffect)(function(){loadLocalRawResource(asset).then(setXml);},[asset]);return _react.default.createElement(css.SvgCss,(0, _extends2.default)({xml:xml},rest,{__source:{fileName:_jsxFileName,lineNumber:60}}));}var WithLocalSvg=function(_Component){(0, _inherits2.default)(WithLocalSvg,_Component);function WithLocalSvg(){var _getPrototypeOf2;var _this;(0, _classCallCheck2.default)(this,WithLocalSvg);for(var _len=arguments.length,args=new Array(_len),_key=0;_key<_len;_key++){args[_key]=arguments[_key];}_this=(0, _possibleConstructorReturn2.default)(this,(_getPrototypeOf2=(0, _getPrototypeOf3.default)(WithLocalSvg)).call.apply(_getPrototypeOf2,[this].concat(args)));(0, _defineProperty2.default)((0, _assertThisInitialized2.default)(_this),"state",{xml:null});return _this;}(0, _createClass2.default)(WithLocalSvg,[{key:"componentDidMount",value:function componentDidMount(){this.load(this.props.asset);}},{key:"componentDidUpdate",value:function componentDidUpdate(prevProps){var asset=this.props.asset;if(asset!==prevProps.asset){this.load(asset);}}},{key:"load",value:function load(asset){return _regenerator.default.async(function load$(_context2){while(1){switch(_context2.prev=_context2.next){case 0:_context2.prev=0;_context2.t0=this;if(!asset){_context2.next=8;break;}_context2.next=5;return _regenerator.default.awrap(loadLocalRawResource(asset));case 5:_context2.t1=_context2.sent;_context2.next=9;break;case 8:_context2.t1=null;case 9:_context2.t2=_context2.t1;_context2.t3={xml:_context2.t2};_context2.t0.setState.call(_context2.t0,_context2.t3);_context2.next=17;break;case 14:_context2.prev=14;_context2.t4=_context2["catch"](0);console.error(_context2.t4);case 17:case"end":return _context2.stop();}}},null,this,[[0,14]],Promise);}},{key:"render",value:function render(){var props=this.props,xml=this.state.xml;return _react.default.createElement(css.SvgWithCss,{xml:xml,override:props,__source:{fileName:_jsxFileName,lineNumber:86}});}}]);return WithLocalSvg;}(_react.Component);exports.WithLocalSvg=WithLocalSvg;var _default=LocalSvg;exports.default=_default;

  });

  var ReactNativeSVG = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});Object.defineProperty(exports,"Shape",{enumerable:true,get:function get(){return _Shape.default;}});Object.defineProperty(exports,"Rect",{enumerable:true,get:function get(){return _Rect.default;}});Object.defineProperty(exports,"Circle",{enumerable:true,get:function get(){return _Circle.default;}});Object.defineProperty(exports,"Ellipse",{enumerable:true,get:function get(){return _Ellipse.default;}});Object.defineProperty(exports,"Polygon",{enumerable:true,get:function get(){return _Polygon.default;}});Object.defineProperty(exports,"Polyline",{enumerable:true,get:function get(){return _Polyline.default;}});Object.defineProperty(exports,"Line",{enumerable:true,get:function get(){return _Line.default;}});Object.defineProperty(exports,"Svg",{enumerable:true,get:function get(){return _Svg.default;}});Object.defineProperty(exports,"Path",{enumerable:true,get:function get(){return _Path.default;}});Object.defineProperty(exports,"G",{enumerable:true,get:function get(){return _G.default;}});Object.defineProperty(exports,"Text",{enumerable:true,get:function get(){return _Text.default;}});Object.defineProperty(exports,"TSpan",{enumerable:true,get:function get(){return _TSpan.default;}});Object.defineProperty(exports,"TextPath",{enumerable:true,get:function get(){return _TextPath.default;}});Object.defineProperty(exports,"Use",{enumerable:true,get:function get(){return _Use.default;}});Object.defineProperty(exports,"Image",{enumerable:true,get:function get(){return _Image.default;}});Object.defineProperty(exports,"Symbol",{enumerable:true,get:function get(){return _Symbol$1.default;}});Object.defineProperty(exports,"Defs",{enumerable:true,get:function get(){return _Defs.default;}});Object.defineProperty(exports,"LinearGradient",{enumerable:true,get:function get(){return _LinearGradient.default;}});Object.defineProperty(exports,"RadialGradient",{enumerable:true,get:function get(){return _RadialGradient.default;}});Object.defineProperty(exports,"Stop",{enumerable:true,get:function get(){return _Stop.default;}});Object.defineProperty(exports,"ClipPath",{enumerable:true,get:function get(){return _ClipPath.default;}});Object.defineProperty(exports,"Pattern",{enumerable:true,get:function get(){return _Pattern.default;}});Object.defineProperty(exports,"Mask",{enumerable:true,get:function get(){return _Mask.default;}});Object.defineProperty(exports,"Marker",{enumerable:true,get:function get(){return _Marker.default;}});Object.defineProperty(exports,"ForeignObject",{enumerable:true,get:function get(){return _ForeignObject.default;}});Object.defineProperty(exports,"parse",{enumerable:true,get:function get(){return xml.parse;}});Object.defineProperty(exports,"SvgAst",{enumerable:true,get:function get(){return xml.SvgAst;}});Object.defineProperty(exports,"SvgFromUri",{enumerable:true,get:function get(){return xml.SvgFromUri;}});Object.defineProperty(exports,"SvgFromXml",{enumerable:true,get:function get(){return xml.SvgFromXml;}});Object.defineProperty(exports,"SvgUri",{enumerable:true,get:function get(){return xml.SvgUri;}});Object.defineProperty(exports,"SvgXml",{enumerable:true,get:function get(){return xml.SvgXml;}});Object.defineProperty(exports,"SvgCss",{enumerable:true,get:function get(){return css.SvgCss;}});Object.defineProperty(exports,"SvgCssUri",{enumerable:true,get:function get(){return css.SvgCssUri;}});Object.defineProperty(exports,"SvgWithCss",{enumerable:true,get:function get(){return css.SvgWithCss;}});Object.defineProperty(exports,"SvgWithCssUri",{enumerable:true,get:function get(){return css.SvgWithCssUri;}});Object.defineProperty(exports,"inlineStyles",{enumerable:true,get:function get(){return css.inlineStyles;}});Object.defineProperty(exports,"LocalSvg",{enumerable:true,get:function get(){return LocalSvg_1.LocalSvg;}});Object.defineProperty(exports,"WithLocalSvg",{enumerable:true,get:function get(){return LocalSvg_1.WithLocalSvg;}});Object.defineProperty(exports,"loadLocalRawResource",{enumerable:true,get:function get(){return LocalSvg_1.loadLocalRawResource;}});Object.defineProperty(exports,"RNSVGCircle",{enumerable:true,get:function get(){return NativeComponents.RNSVGCircle;}});Object.defineProperty(exports,"RNSVGClipPath",{enumerable:true,get:function get(){return NativeComponents.RNSVGClipPath;}});Object.defineProperty(exports,"RNSVGDefs",{enumerable:true,get:function get(){return NativeComponents.RNSVGDefs;}});Object.defineProperty(exports,"RNSVGEllipse",{enumerable:true,get:function get(){return NativeComponents.RNSVGEllipse;}});Object.defineProperty(exports,"RNSVGForeignObject",{enumerable:true,get:function get(){return NativeComponents.RNSVGForeignObject;}});Object.defineProperty(exports,"RNSVGGroup",{enumerable:true,get:function get(){return NativeComponents.RNSVGGroup;}});Object.defineProperty(exports,"RNSVGImage",{enumerable:true,get:function get(){return NativeComponents.RNSVGImage;}});Object.defineProperty(exports,"RNSVGLine",{enumerable:true,get:function get(){return NativeComponents.RNSVGLine;}});Object.defineProperty(exports,"RNSVGLinearGradient",{enumerable:true,get:function get(){return NativeComponents.RNSVGLinearGradient;}});Object.defineProperty(exports,"RNSVGMarker",{enumerable:true,get:function get(){return NativeComponents.RNSVGMarker;}});Object.defineProperty(exports,"RNSVGMask",{enumerable:true,get:function get(){return NativeComponents.RNSVGMask;}});Object.defineProperty(exports,"RNSVGPath",{enumerable:true,get:function get(){return NativeComponents.RNSVGPath;}});Object.defineProperty(exports,"RNSVGPattern",{enumerable:true,get:function get(){return NativeComponents.RNSVGPattern;}});Object.defineProperty(exports,"RNSVGRadialGradient",{enumerable:true,get:function get(){return NativeComponents.RNSVGRadialGradient;}});Object.defineProperty(exports,"RNSVGRect",{enumerable:true,get:function get(){return NativeComponents.RNSVGRect;}});Object.defineProperty(exports,"RNSVGSvg",{enumerable:true,get:function get(){return NativeComponents.RNSVGSvg;}});Object.defineProperty(exports,"RNSVGSymbol",{enumerable:true,get:function get(){return NativeComponents.RNSVGSymbol;}});Object.defineProperty(exports,"RNSVGText",{enumerable:true,get:function get(){return NativeComponents.RNSVGText;}});Object.defineProperty(exports,"RNSVGTextPath",{enumerable:true,get:function get(){return NativeComponents.RNSVGTextPath;}});Object.defineProperty(exports,"RNSVGTSpan",{enumerable:true,get:function get(){return NativeComponents.RNSVGTSpan;}});Object.defineProperty(exports,"RNSVGUse",{enumerable:true,get:function get(){return NativeComponents.RNSVGUse;}});exports.default=void 0;var _Shape=interopRequireDefault(Shape_1);var _Rect=interopRequireDefault(Rect_1);var _Circle=interopRequireDefault(Circle_1);var _Ellipse=interopRequireDefault(Ellipse_1);var _Polygon=interopRequireDefault(Polygon_1);var _Polyline=interopRequireDefault(Polyline_1);var _Line=interopRequireDefault(Line_1);var _Svg=interopRequireDefault(Svg_1);var _Path=interopRequireDefault(Path_1);var _G=interopRequireDefault(G_1);var _Text=interopRequireDefault(Text_1);var _TSpan=interopRequireDefault(TSpan_1);var _TextPath=interopRequireDefault(TextPath_1);var _Use=interopRequireDefault(Use_1);var _Image=interopRequireDefault(Image$1);var _Symbol$1=interopRequireDefault(_Symbol);var _Defs=interopRequireDefault(Defs_1);var _LinearGradient=interopRequireDefault(LinearGradient_1);var _RadialGradient=interopRequireDefault(RadialGradient_1);var _Stop=interopRequireDefault(Stop_1);var _ClipPath=interopRequireDefault(ClipPath_1);var _Pattern=interopRequireDefault(Pattern_1);var _Mask=interopRequireDefault(Mask_1);var _Marker=interopRequireDefault(Marker_1);var _ForeignObject=interopRequireDefault(ForeignObject_1);var _default=_Svg.default;exports.default=_default;

  });

  var module = createCommonjsModule(function (module, exports) {
  Object.defineProperty(exports,"__esModule",{value:true});var _exportNames={};Object.defineProperty(exports,"default",{enumerable:true,get:function get(){return _ReactNativeSVG.default;}});var _ReactNativeSVG=interopRequireWildcard(ReactNativeSVG);Object.keys(_ReactNativeSVG).forEach(function(key){if(key==="default"||key==="__esModule")return;if(Object.prototype.hasOwnProperty.call(_exportNames,key))return;Object.defineProperty(exports,key,{enumerable:true,get:function get(){return _ReactNativeSVG[key];}});});

  });

  var fn = function fn(handle) {
    return function () {
      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      return function (t) {
        var input = args.map(function (arg) {
          var value = typeof arg === 'function' ? arg(t) : arg;
          return value;
        });
        return handle(input, t);
      };
    };
  };
  /* eslint-disable arrow-body-style */
  // Color contrast
  // A list of pre-calculated numbers of pow(divide((divide($value, 255) + .055), 1.055), 2.4). (from 0 to 255)

  var luminanceList = [0.0008, 0.001, 0.0011, 0.0013, 0.0015, 0.0017, 0.002, 0.0022, 0.0025, 0.0027, 0.003, 0.0033, 0.0037, 0.004, 0.0044, 0.0048, 0.0052, 0.0056, 0.006, 0.0065, 0.007, 0.0075, 0.008, 0.0086, 0.0091, 0.0097, 0.0103, 0.011, 0.0116, 0.0123, 0.013, 0.0137, 0.0144, 0.0152, 0.016, 0.0168, 0.0176, 0.0185, 0.0194, 0.0203, 0.0212, 0.0222, 0.0232, 0.0242, 0.0252, 0.0262, 0.0273, 0.0284, 0.0296, 0.0307, 0.0319, 0.0331, 0.0343, 0.0356, 0.0369, 0.0382, 0.0395, 0.0409, 0.0423, 0.0437, 0.0452, 0.0467, 0.0482, 0.0497, 0.0513, 0.0529, 0.0545, 0.0561, 0.0578, 0.0595, 0.0612, 0.063, 0.0648, 0.0666, 0.0685, 0.0704, 0.0723, 0.0742, 0.0762, 0.0782, 0.0802, 0.0823, 0.0844, 0.0865, 0.0887, 0.0908, 0.0931, 0.0953, 0.0976, 0.0999, 0.1022, 0.1046, 0.107, 0.1095, 0.1119, 0.1144, 0.117, 0.1195, 0.1221, 0.1248, 0.1274, 0.1301, 0.1329, 0.1356, 0.1384, 0.1413, 0.1441, 0.147, 0.15, 0.1529, 0.1559, 0.159, 0.162, 0.1651, 0.1683, 0.1714, 0.1746, 0.1779, 0.1812, 0.1845, 0.1878, 0.1912, 0.1946, 0.1981, 0.2016, 0.2051, 0.2086, 0.2122, 0.2159, 0.2195, 0.2232, 0.227, 0.2307, 0.2346, 0.2384, 0.2423, 0.2462, 0.2502, 0.2542, 0.2582, 0.2623, 0.2664, 0.2705, 0.2747, 0.2789, 0.2831, 0.2874, 0.2918, 0.2961, 0.3005, 0.305, 0.3095, 0.314, 0.3185, 0.3231, 0.3278, 0.3325, 0.3372, 0.3419, 0.3467, 0.3515, 0.3564, 0.3613, 0.3663, 0.3712, 0.3763, 0.3813, 0.3864, 0.3916, 0.3968, 0.402, 0.4072, 0.4125, 0.4179, 0.4233, 0.4287, 0.4342, 0.4397, 0.4452, 0.4508, 0.4564, 0.4621, 0.4678, 0.4735, 0.4793, 0.4851, 0.491, 0.4969, 0.5029, 0.5089, 0.5149, 0.521, 0.5271, 0.5333, 0.5395, 0.5457, 0.552, 0.5583, 0.5647, 0.5711, 0.5776, 0.5841, 0.5906, 0.5972, 0.6038, 0.6105, 0.6172, 0.624, 0.6308, 0.6376, 0.6445, 0.6514, 0.6584, 0.6654, 0.6724, 0.6795, 0.6867, 0.6939, 0.7011, 0.7084, 0.7157, 0.7231, 0.7305, 0.7379, 0.7454, 0.7529, 0.7605, 0.7682, 0.7758, 0.7835, 0.7913, 0.7991, 0.807, 0.8148, 0.8228, 0.8308, 0.8388, 0.8469, 0.855, 0.8632, 0.8714, 0.8796, 0.8879, 0.8963, 0.9047, 0.9131, 0.9216, 0.9301, 0.9387, 0.9473, 0.956, 0.9647, 0.9734, 0.9823, 0.9911, 1]; // Return WCAG2.0 relative luminance
  // See https://www.w3.org/WAI/GL/wiki/Relative_luminance
  // See https://www.w3.org/TR/WCAG20-TECHS/G17.html#G17-tests

  var luminance = function luminance(color) {
    var rgb = parseToRgb(color);
    Object.entries(rgb).forEach(function (_ref) {
      var _ref2 = _slicedToArray(_ref, 2),
          name = _ref2[0],
          value = _ref2[1];

      rgb[name] = value / 255 < 0.03928 ? value / 255 / 12.92 : luminanceList[value];
    });
    return rgb.red * 0.2126 + rgb.green * 0.7152 + rgb.blue * 0.0722;
  }; // Return opaque color
  // opaque(#fff, rgba(0, 0, 0, .5)) => #808080


  var opaque = function opaque(background, foreground) {
    var opacity = parseToRgb(foreground).alpha || 1;
    return mix$1$1(opacity, rgba$1(foreground, 1), background);
  };

  var contrastRatio = function contrastRatio(background, foreground) {
    var l1 = luminance(background);
    var l2 = luminance(opaque(background, foreground));
    return l1 > l2 ? (l1 + 0.05) / (l2 + 0.05) : (l2 + 0.05) / (l1 + 0.05);
  };

  var colorContrast = fn(function (_ref3, t) {
    var _ref4 = _slicedToArray(_ref3, 1),
        background = _ref4[0];

    var foregrounds = [t['color-contrast-light'], t['color-contrast-dark'], t.white, t.black];
    var maxRatio = 0;
    var maxRatioColor = null;
    var result = foregrounds.find(function (color) {
      var ratio = contrastRatio(background, color);

      if (ratio > t['min-contrast-ratio']) {
        return true;
      }

      if (ratio > maxRatio) {
        maxRatio = ratio;
        maxRatioColor = color;
      }

      return false;
    });

    if (result) {
      return result;
    } // eslint-disable-next-line no-console


    console.warn("Found no color leading to ".concat(t['min-contrast-ratio'], ":1 contrast ratio against ").concat(background, "..."));
    return maxRatioColor;
  }); // Tint a color: mix a color with white

  var tintColor = fn(function (_ref5, t) {
    var _ref6 = _slicedToArray(_ref5, 2),
        weight = _ref6[0],
        color = _ref6[1];

    return mix$1$1(weight, t.white, color);
  }); // Shade a color: mix a color with black

  var shadeColor = fn(function (_ref7, t) {
    var _ref8 = _slicedToArray(_ref7, 2),
        weight = _ref8[0],
        color = _ref8[1];

    return mix$1$1(weight, t.black, color);
  }); // Shade the color if the weight is positive, else tint it

  var shiftColor = fn(function (_ref9, t) {
    var _ref10 = _slicedToArray(_ref9, 2),
        weight = _ref10[0],
        color = _ref10[1];

    var handle = weight > 0 ? shadeColor(weight, color) : tintColor(-weight, color);
    return handle(t);
  });
  var add = fn(function (_ref11) {
    var _ref12 = _slicedToArray(_ref11, 2),
        value1 = _ref12[0],
        value2 = _ref12[1];

    if (value1 === null) {
      return value2;
    }

    if (value2 === null) {
      return value1;
    }

    return calculateAdvanced(value1, '+', value2);
  });
  var subtract = fn(function (_ref13) {
    var _ref14 = _slicedToArray(_ref13, 2),
        value1 = _ref14[0],
        value2 = _ref14[1];

    if (value1 === null && value2 === null) {
      return null;
    }

    if (value1 === null) {
      return "-".concat(value2);
    }

    if (value2 === null) {
      return value1;
    }

    return calculateAdvanced(value1, '-', value2);
  });
  var divide = fn(function (_ref15) {
    var _ref16 = _slicedToArray(_ref15, 2),
        dividend = _ref16[0],
        divisor = _ref16[1];

    if (Math.abs(parseFloat(dividend)) === 0) {
      return 0;
    }

    if (Math.abs(parseFloat(divisor)) === 0) {
      throw new Error('Cannot divide by 0');
    }

    return calculateAdvanced(dividend, '/', divisor);
  });
  /* eslint-enable */

  var _templateObject$1a;
  // Also all elements have tabIndex={-1} until the following is merged:
  // https://github.com/react-native-svg/react-native-svg/pull/1585

  var svgs = {
    'form-check-input-checked-bg-image': function formCheckInputCheckedBgImage(t) {
      return /*#__PURE__*/React__default["default"].createElement(module.Svg, {
        viewBox: "0 0 20 20",
        tabIndex: -1
      }, /*#__PURE__*/React__default["default"].createElement(module.Path, {
        fill: "none",
        stroke: t['form-check-input-checked-color'],
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: 3,
        d: "m6 10 3 3 6-6",
        tabIndex: -1
      }));
    },
    'form-check-radio-checked-bg-image': function formCheckRadioCheckedBgImage(t) {
      return /*#__PURE__*/React__default["default"].createElement(module.Svg, {
        viewBox: "-4 -4 8 8",
        tabIndex: -1
      }, /*#__PURE__*/React__default["default"].createElement(module.Circle, {
        r: 2,
        fill: t['form-check-input-checked-color'],
        tabIndex: -1
      }));
    },
    'form-check-input-indeterminate-bg-image': function formCheckInputIndeterminateBgImage(t) {
      return /*#__PURE__*/React__default["default"].createElement(module.Svg, {
        viewBox: "0 0 20 20",
        tabIndex: -1
      }, /*#__PURE__*/React__default["default"].createElement(module.Path, {
        fill: "none",
        stroke: t['form-check-input-indeterminate-color'],
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: 3,
        d: "M6 10h8",
        tabIndex: -1
      }));
    },
    'form-switch-bg-image': function formSwitchBgImage(t) {
      return /*#__PURE__*/React__default["default"].createElement(module.Svg, {
        height: 14,
        width: 14,
        viewBox: "-4 -4 8 8",
        tabIndex: -1
      }, /*#__PURE__*/React__default["default"].createElement(module.Circle, {
        r: 3,
        fill: t['form-switch-color'],
        tabIndex: -1
      }));
    },
    'form-switch-focus-bg-image': function formSwitchFocusBgImage(t) {
      return /*#__PURE__*/React__default["default"].createElement(module.Svg, {
        viewBox: "-4 -4 8 8",
        tabIndex: -1
      }, /*#__PURE__*/React__default["default"].createElement(module.Circle, {
        r: 3,
        fill: t['form-switch-focus-color'],
        tabIndex: -1
      }));
    },
    'form-switch-checked-bg-image': function formSwitchCheckedBgImage(t) {
      return /*#__PURE__*/React__default["default"].createElement(module.Svg, {
        viewBox: "-4 -4 8 8",
        tabIndex: -1
      }, /*#__PURE__*/React__default["default"].createElement(module.Circle, {
        r: 3,
        fill: t['form-switch-checked-color'],
        tabIndex: -1
      }));
    },
    'form-select-indicator': function formSelectIndicator(t) {
      return /*#__PURE__*/React__default["default"].createElement(module.Svg, {
        viewBox: "0 0 16 16",
        tabIndex: -1
      }, /*#__PURE__*/React__default["default"].createElement(module.Path, {
        fill: "none",
        stroke: t['form-select-indicator-color'],
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: 2,
        d: "m2 5 6 6 6-6",
        tabIndex: -1
      }));
    },
    'form-feedback-icon-valid': function formFeedbackIconValid(t) {
      return /*#__PURE__*/React__default["default"].createElement(module.Svg, {
        viewBox: "0 0 8 8",
        tabIndex: -1
      }, /*#__PURE__*/React__default["default"].createElement(module.Path, {
        fill: t['form-feedback-icon-valid-color'],
        d: "M2.3 6.73.6 4.53c-.4-1.04.46-1.4 1.1-.8l1.1 1.4 3.4-3.8c.6-.63 1.6-.27 1.2.7l-4 4.6c-.43.5-.8.4-1.1.1z",
        tabIndex: -1
      }));
    },
    'form-feedback-icon-invalid': function formFeedbackIconInvalid(t) {
      return /*#__PURE__*/React__default["default"].createElement(module.Svg, {
        viewBox: "0 0 12 12",
        width: 12,
        height: 12,
        fill: "none",
        stroke: t['form-feedback-icon-invalid-color'],
        tabIndex: -1
      }, /*#__PURE__*/React__default["default"].createElement(module.Circle, {
        cx: 6,
        cy: 6,
        r: 4.5,
        tabIndex: -1
      }), /*#__PURE__*/React__default["default"].createElement(module.Path, {
        strokeLinejoin: "round",
        d: "M5.8 3.6h.4L6 6.5z",
        tabIndex: -1
      }), /*#__PURE__*/React__default["default"].createElement(module.Circle, {
        cx: 6,
        cy: 8.2,
        r: 0.6,
        fill: t['form-feedback-icon-invalid-color'],
        stroke: "none",
        tabIndex: -1
      }));
    },
    'navbar-dark-toggler-icon-bg': function navbarDarkTogglerIconBg(t) {
      return /*#__PURE__*/React__default["default"].createElement(module.Svg, {
        viewBox: "0 0 30 30"
      }, /*#__PURE__*/React__default["default"].createElement(module.Path, {
        stroke: t['navbar-dark-color'],
        strokeLinecap: "round",
        strokeMiterlimit: "10",
        strokeWidth: "2",
        d: "M4 7h22M4 15h22M4 23h22"
      }));
    },
    'navbar-light-toggler-icon-bg': function navbarLightTogglerIconBg(t) {
      return /*#__PURE__*/React__default["default"].createElement(module.Svg, {
        viewBox: "0 0 30 30"
      }, /*#__PURE__*/React__default["default"].createElement(module.Path, {
        stroke: t['navbar-light-color'],
        strokeLinecap: "round",
        strokeMiterlimit: "10",
        strokeWidth: "2",
        d: "M4 7h22M4 15h22M4 23h22"
      }));
    },
    'btn-close-bg': function btnCloseBg(t) {
      return /*#__PURE__*/React__default["default"].createElement(module.Svg, {
        viewBox: "0 0 16 16",
        fill: t['btn-close-color'],
        tabIndex: -1
      }, /*#__PURE__*/React__default["default"].createElement(module.Path, {
        d: "M.293.293a1 1 0 0 1 1.414 0L8 6.586 14.293.293a1 1 0 1 1 1.414 1.414L9.414 8l6.293 6.293a1 1 0 0 1-1.414 1.414L8 9.414l-6.293 6.293a1 1 0 0 1-1.414-1.414L6.586 8 .293 1.707a1 1 0 0 1 0-1.414z",
        tabIndex: -1
      }));
    }
  };
  var variables = css$1(_templateObject$1a || (_templateObject$1a = _taggedTemplateLiteral(["\n  // Color system\n\n  $white: #fff;\n  $gray-100: #f8f9fa;\n  $gray-200: #e9ecef;\n  $gray-300: #dee2e6;\n  $gray-400: #ced4da;\n  $gray-500: #adb5bd;\n  $gray-600: #6c757d;\n  $gray-700: #495057;\n  $gray-800: #343a40;\n  $gray-900: #212529;\n  $black: #000;\n\n  $grays: ", ";\n\n  $blue: #0d6efd;\n  $indigo: #6610f2;\n  $purple: #6f42c1;\n  $pink: #d63384;\n  $red: #dc3545;\n  $orange: #fd7e14;\n  $yellow: #ffc107;\n  $green: #198754;\n  $teal: #20c997;\n  $cyan: #0dcaf0;\n\n  $colors: ", ";\n\n  $primary: $blue;\n  $secondary: $gray-600;\n  $success: $green;\n  $info: $cyan;\n  $warning: $yellow;\n  $danger: $red;\n  $light: $gray-100;\n  $dark: $gray-900;\n\n  $theme-colors: ", ";\n\n  // The contrast ratio to reach against white, to determine if color changes from \"light\" to \"dark\". Acceptable values for WCAG 2.0 are 3, 4.5 and 7.\n  // See https://www.w3.org/TR/WCAG20/#visual-audio-contrast-contrast\n  $min-contrast-ratio: 4.5;\n\n  // Customize the light and dark text colors for use in our color contrast function.\n  $color-contrast-dark: $black;\n  $color-contrast-light: $white;\n\n  $blue-100: tint-color($blue, 80%);\n  $blue-200: tint-color($blue, 60%);\n  $blue-300: tint-color($blue, 40%);\n  $blue-400: tint-color($blue, 20%);\n  $blue-500: $blue;\n  $blue-600: shade-color($blue, 20%);\n  $blue-700: shade-color($blue, 40%);\n  $blue-800: shade-color($blue, 60%);\n  $blue-900: shade-color($blue, 80%);\n\n  $indigo-100: tint-color($indigo, 80%);\n  $indigo-200: tint-color($indigo, 60%);\n  $indigo-300: tint-color($indigo, 40%);\n  $indigo-400: tint-color($indigo, 20%);\n  $indigo-500: $indigo;\n  $indigo-600: shade-color($indigo, 20%);\n  $indigo-700: shade-color($indigo, 40%);\n  $indigo-800: shade-color($indigo, 60%);\n  $indigo-900: shade-color($indigo, 80%);\n\n  $purple-100: tint-color($purple, 80%);\n  $purple-200: tint-color($purple, 60%);\n  $purple-300: tint-color($purple, 40%);\n  $purple-400: tint-color($purple, 20%);\n  $purple-500: $purple;\n  $purple-600: shade-color($purple, 20%);\n  $purple-700: shade-color($purple, 40%);\n  $purple-800: shade-color($purple, 60%);\n  $purple-900: shade-color($purple, 80%);\n\n  $pink-100: tint-color($pink, 80%);\n  $pink-200: tint-color($pink, 60%);\n  $pink-300: tint-color($pink, 40%);\n  $pink-400: tint-color($pink, 20%);\n  $pink-500: $pink;\n  $pink-600: shade-color($pink, 20%);\n  $pink-700: shade-color($pink, 40%);\n  $pink-800: shade-color($pink, 60%);\n  $pink-900: shade-color($pink, 80%);\n\n  $red-100: tint-color($red, 80%);\n  $red-200: tint-color($red, 60%);\n  $red-300: tint-color($red, 40%);\n  $red-400: tint-color($red, 20%);\n  $red-500: $red;\n  $red-600: shade-color($red, 20%);\n  $red-700: shade-color($red, 40%);\n  $red-800: shade-color($red, 60%);\n  $red-900: shade-color($red, 80%);\n\n  $orange-100: tint-color($orange, 80%);\n  $orange-200: tint-color($orange, 60%);\n  $orange-300: tint-color($orange, 40%);\n  $orange-400: tint-color($orange, 20%);\n  $orange-500: $orange;\n  $orange-600: shade-color($orange, 20%);\n  $orange-700: shade-color($orange, 40%);\n  $orange-800: shade-color($orange, 60%);\n  $orange-900: shade-color($orange, 80%);\n\n  $yellow-100: tint-color($yellow, 80%);\n  $yellow-200: tint-color($yellow, 60%);\n  $yellow-300: tint-color($yellow, 40%);\n  $yellow-400: tint-color($yellow, 20%);\n  $yellow-500: $yellow;\n  $yellow-600: shade-color($yellow, 20%);\n  $yellow-700: shade-color($yellow, 40%);\n  $yellow-800: shade-color($yellow, 60%);\n  $yellow-900: shade-color($yellow, 80%);\n\n  $green-100: tint-color($green, 80%);\n  $green-200: tint-color($green, 60%);\n  $green-300: tint-color($green, 40%);\n  $green-400: tint-color($green, 20%);\n  $green-500: $green;\n  $green-600: shade-color($green, 20%);\n  $green-700: shade-color($green, 40%);\n  $green-800: shade-color($green, 60%);\n  $green-900: shade-color($green, 80%);\n\n  $teal-100: tint-color($teal, 80%);\n  $teal-200: tint-color($teal, 60%);\n  $teal-300: tint-color($teal, 40%);\n  $teal-400: tint-color($teal, 20%);\n  $teal-500: $teal;\n  $teal-600: shade-color($teal, 20%);\n  $teal-700: shade-color($teal, 40%);\n  $teal-800: shade-color($teal, 60%);\n  $teal-900: shade-color($teal, 80%);\n\n  $cyan-100: tint-color($cyan, 80%);\n  $cyan-200: tint-color($cyan, 60%);\n  $cyan-300: tint-color($cyan, 40%);\n  $cyan-400: tint-color($cyan, 20%);\n  $cyan-500: $cyan;\n  $cyan-600: shade-color($cyan, 20%);\n  $cyan-700: shade-color($cyan, 40%);\n  $cyan-800: shade-color($cyan, 60%);\n  $cyan-900: shade-color($cyan, 80%);\n\n  $blues: ", ";\n\n  $indigos: ", ";\n\n  $purples: ", ";\n\n  $pinks: ", ";\n\n  $reds: ", ";\n\n  $oranges: ", ";\n\n  $yellows: ", ";\n\n  $greens: ", ";\n\n  $teals: ", ";\n\n  $cyans: ", ";\n\n  // Characters which are escaped by the escape-svg function\n  // $escaped characters\n\n  // Options\n  //\n  // Quickly modify global styling by enabling or disabling optional features.\n\n  // NOTE: Handled by JavaScript.\n\n  // Gradient\n  //\n  // The gradient which is added to components if \"$enable-gradients\" is \"true\"\n  // This gradient is also added to elements with \".bg-gradient\"\n  $gradient: linear-gradient(180deg, rgba($white, 0.15), rgba($white, 0));\n\n  // Spacing\n  //\n  // Control the default styling of most Bootstrap elements by modifying these\n  // variables. Mostly focused on spacing.\n  // You can add more entries to the $spacers map, should you need more variation.\n\n  $spacer: 1rem;\n  $spacers: ", ";\n\n  // Position\n  //\n  // Define the edge positioning anchors of the position utilities.\n\n  $position-values: ", ";\n\n  // Placeholder\n\n  $placeholder-opacity-max: 0.5;\n  $placeholder-opacity-min: 0.2;\n\n  // Body\n  //\n  // Settings for the \"<body>\" element.\n\n  $body-bg: $white;\n  $body-color: $gray-900;\n  $body-text-align: null;\n\n  // Links\n  //\n  // Style anchor elements.\n\n  $link-color: $primary;\n  $link-decoration: underline;\n  $link-shade-percentage: 0.2; // 20%;\n  $link-hover-color: ", ";\n  $link-hover-decoration: null;\n\n  $stretched-link-pseudo-element: after;\n  $stretched-link-z-index: 1;\n\n  // Paragraphs\n  //\n  // Style p element.\n\n  $paragraph-margin-bottom: 1rem;\n\n  // Grid breakpoints\n  //\n  // Define the minimum dimensions at which your layout will change,\n  // adapting to different screen sizes, for use in media queries.\n\n  $grid-breakpoints: ", ";\n\n  // Grid containers\n  //\n  // Define the maximum width of \".container\" for different screen sizes.\n\n  $container-max-widths: ", ";\n\n  // Grid columns\n  //\n  // Set the number of columns and specify the width of the gutters.\n\n  // $grid-columns: 12;\n  $grid-gutter-width: 1.5rem;\n  // $grid-row-columns: 6;\n\n  // Container padding\n\n  $container-padding-x: $grid-gutter-width * 0.5;\n\n  // Components\n  //\n  // Define common padding and border radius sizes and more.\n\n  $border-width: 1px;\n  $border-widths: ", ";\n\n  $border-color: $gray-300;\n\n  $border-radius: 0.25rem;\n  $border-radius-sm: 0.2rem;\n  $border-radius-lg: 0.3rem;\n  $border-radius-pill: 50rem;\n\n  $box-shadow: 0 0.5rem 1rem rgba($black, 0.15);\n  $box-shadow-sm: 0 0.125rem 0.25rem rgba($black, 0.075);\n  $box-shadow-lg: 0 1rem 3rem rgba($black, 0.175);\n  $box-shadow-inset: inset 0 1px 2px rgba($black, 0.075);\n\n  $component-active-color: $white;\n  $component-active-bg: $primary;\n\n  $caret-width: 0.3em;\n  $caret-vertical-align: $caret-width * 0.85;\n  $caret-spacing: $caret-width * 0.85;\n\n  $transition-base: all 0.2s ease-in-out;\n  $transition-fade: opacity 0.15s linear;\n  $transition-collapse: height 0.35s ease;\n  $transition-collapse-width: width 0.35s ease;\n\n  $aspect-ratios: ", ";\n\n  // Typography\n  //\n  // Font, line-height, and color for body text, headings, and more.\n\n  $font-family-sans-serif: ", ";\n  $font-family-monospace: ", ";\n  $font-family-base: $font-family-sans-serif;\n  $font-family-code: $font-family-monospace;\n\n  // $font-size-root affects the value of \"rem\", which is used for as well font sizes, paddings, and margins\n  // $font-size-base affects the font size of the body text\n  $font-size-root: null;\n  $font-size-base: 1rem; // Assumes the browser default, typically \"16px\"\n  $font-size-sm: $font-size-base * 0.875;\n  $font-size-lg: $font-size-base * 1.25;\n\n  $font-weight-lighter: 300; // lighter;\n  $font-weight-light: 300;\n  $font-weight-normal: 400;\n  $font-weight-bold: 700;\n  $font-weight-bolder: 500; // bolder;\n\n  $font-weight-base: $font-weight-normal;\n\n  $line-height-base: 1.5;\n  $line-height-sm: 1.25;\n  $line-height-lg: 2;\n\n  $h1-font-size: $font-size-base * 2.5;\n  $h2-font-size: $font-size-base * 2;\n  $h3-font-size: $font-size-base * 1.75;\n  $h4-font-size: $font-size-base * 1.5;\n  $h5-font-size: $font-size-base * 1.25;\n  $h6-font-size: $font-size-base;\n\n  $font-sizes: ", ";\n\n  $headings-margin-bottom: $spacer * 0.5;\n  $headings-font-family: null;\n  $headings-font-style: null;\n  $headings-font-weight: 500;\n  $headings-line-height: 1.2;\n  $headings-color: null;\n\n  $display-font-sizes: ", ";\n\n  $display-font-weight: 300;\n  $display-line-height: $headings-line-height;\n\n  $lead-font-size: $font-size-base * 1.25;\n  $lead-font-weight: 300;\n\n  $small-font-size: $font-size-base * 0.875; // 0.875em;\n\n  $sub-sup-font-size: $font-size-base * 0.75; // 0.75em;\n\n  $text-muted: $gray-600;\n\n  $initialism-font-size: $small-font-size;\n\n  $blockquote-margin-y: $spacer;\n  $blockquote-font-size: $font-size-base * 1.25;\n  $blockquote-footer-color: $gray-600;\n  $blockquote-footer-font-size: $small-font-size;\n\n  $hr-margin-y: $spacer;\n  $hr-color: inherit;\n  $hr-bg-color: currentColor;\n  $hr-border-width: 0;\n  $hr-height: $border-width;\n  $hr-opacity: 0.25;\n\n  $legend-margin-bottom: 0.5rem;\n  $legend-font-size: 1.5rem;\n  $legend-font-weight: null;\n\n  $mark-padding: $font-size-base * 0.2; // 0.2em;\n\n  $dt-font-weight: $font-weight-bold;\n\n  $nested-kbd-font-weight: $font-weight-bold;\n\n  $list-inline-padding: 0.5rem;\n\n  $mark-bg: #fcf8e3;\n\n  // ...\n\n  // Buttons + Forms\n  //\n  // Shared variables that are reassigned to \"$input-\" and \"$btn-\" specific variables.\n\n  $input-btn-padding-y: 0.375rem;\n  $input-btn-padding-x: 0.75rem;\n  $input-btn-font-family: null;\n  $input-btn-font-size: $font-size-base;\n  $input-btn-line-height: $line-height-base;\n\n  $input-btn-focus-width: 0.25rem;\n  $input-btn-focus-color-opacity: 0.25;\n  $input-btn-focus-color: rgba(\n    $component-active-bg,\n    $input-btn-focus-color-opacity\n  );\n  $input-btn-focus-blur: 0;\n  $input-btn-focus-box-shadow: 0 0 $input-btn-focus-blur $input-btn-focus-width\n    $input-btn-focus-color;\n\n  $input-btn-padding-y-sm: 0.25rem;\n  $input-btn-padding-x-sm: 0.5rem;\n  $input-btn-font-size-sm: $font-size-sm;\n\n  $input-btn-padding-y-lg: 0.5rem;\n  $input-btn-padding-x-lg: 1rem;\n  $input-btn-font-size-lg: $font-size-lg;\n\n  $input-btn-border-width: $border-width;\n\n  // Buttons\n  //\n  // For each of Bootstrap's buttons, define text, background, and border color.\n\n  $btn-padding-y: $input-btn-padding-y;\n  $btn-padding-x: $input-btn-padding-x;\n  $btn-font-family: $input-btn-font-family;\n  $btn-font-size: $input-btn-font-size;\n  $btn-line-height: $input-btn-line-height;\n  $btn-white-space: null; // Set to \"nowrap\" to prevent text wrapping\n\n  $btn-padding-y-sm: $input-btn-padding-y-sm;\n  $btn-padding-x-sm: $input-btn-padding-x-sm;\n  $btn-font-size-sm: $input-btn-font-size-sm;\n\n  $btn-padding-y-lg: $input-btn-padding-y-lg;\n  $btn-padding-x-lg: $input-btn-padding-x-lg;\n  $btn-font-size-lg: $input-btn-font-size-lg;\n\n  $btn-border-width: $input-btn-border-width;\n\n  $btn-font-weight: $font-weight-normal;\n  $btn-box-shadow: inset 0 1px 0 rgba($white, 0.15),\n    0 1px 1px rgba($black, 0.075);\n  $btn-focus-width: $input-btn-focus-width;\n  $btn-focus-box-shadow: $input-btn-focus-box-shadow;\n  $btn-disabled-opacity: 0.65;\n  $btn-active-box-shadow: inset 0 3px 5px rgba($black, 0.125);\n\n  $btn-link-color: $link-color;\n  $btn-link-hover-color: $link-hover-color;\n  $btn-link-disabled-color: $gray-600;\n\n  // Allows for customizing button radius independently from global border radius\n  $btn-border-radius: $border-radius;\n  $btn-border-radius-sm: $border-radius-sm;\n  $btn-border-radius-lg: $border-radius-lg;\n\n  $btn-transition: color 0.15s ease-in-out, background-color 0.15s ease-in-out,\n    border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;\n\n  $btn-hover-bg-shade-amount: 0.15; // 15%;\n  $btn-hover-bg-tint-amount: 0.15; // 15%;\n  $btn-hover-border-shade-amount: 0.2; // 20%;\n  $btn-hover-border-tint-amount: 0.1; // 10%;\n  $btn-active-bg-shade-amount: 0.2; // 20%;\n  $btn-active-bg-tint-amount: 0.2; // 20%;\n  $btn-active-border-shade-amount: 0.25; // 25%;\n  $btn-active-border-tint-amount: 0.1; // 10%;\n\n  // Breadcrumb\n\n  $breadcrumb-font-size: null;\n  $breadcrumb-padding-y: 0;\n  $breadcrumb-padding-x: 0;\n  $breadcrumb-item-padding-x: 0.5rem;\n  $breadcrumb-margin-bottom: 1rem;\n  $breadcrumb-bg: null;\n  $breadcrumb-divider-color: $gray-600;\n  $breadcrumb-active-color: $gray-600;\n  //$breadcrumb-divider: quote('/');\n  //$breadcrumb-divider-flipped: $breadcrumb-divider;\n  $breadcrumb-border-radius: null;\n\n  // Forms\n\n  $form-text-margin-top: 0.25rem;\n  $form-text-font-size: $small-font-size;\n  $form-text-font-style: null;\n  $form-text-font-weight: null;\n  $form-text-color: $text-muted;\n\n  $form-label-margin-bottom: 0.5rem;\n  $form-label-font-size: null;\n  $form-label-font-style: null;\n  $form-label-font-weight: null;\n  $form-label-color: null;\n\n  $input-padding-y: $input-btn-padding-y;\n  $input-padding-x: $input-btn-padding-x;\n  $input-font-family: $input-btn-font-family;\n  $input-font-size: $input-btn-font-size;\n  $input-font-weight: $font-weight-base;\n  $input-line-height: $input-btn-line-height;\n\n  $input-padding-y-sm: $input-btn-padding-y-sm;\n  $input-padding-x-sm: $input-btn-padding-x-sm;\n  $input-font-size-sm: $input-btn-font-size-sm;\n\n  $input-padding-y-lg: $input-btn-padding-y-lg;\n  $input-padding-x-lg: $input-btn-padding-x-lg;\n  $input-font-size-lg: $input-btn-font-size-lg;\n\n  $input-bg: $body-bg;\n  $input-disabled-bg: $gray-200;\n  $input-disabled-border-color: null;\n\n  $input-color: $body-color;\n  $input-border-color: $gray-400;\n  $input-border-width: $input-btn-border-width;\n  $input-box-shadow: $box-shadow-inset;\n\n  $input-border-radius: $border-radius;\n  $input-border-radius-sm: $border-radius-sm;\n  $input-border-radius-lg: $border-radius-lg;\n\n  $input-focus-bg: $input-bg;\n  $input-focus-border-color: ", ";\n  $input-focus-color: $input-color;\n  $input-focus-width: $input-btn-focus-width;\n  $input-focus-box-shadow: $input-btn-focus-box-shadow;\n\n  $input-placeholder-color: $gray-600;\n  $input-plaintext-color: $body-color;\n\n  $input-height-border: $input-border-width * 2;\n\n  $input-height-inner: ", ";\n  $input-height-inner-half: ", ";\n  $input-height-inner-quarter: ", ";\n\n  $input-height: ", ";\n  $input-height-sm: ", ";\n  $input-height-lg: ", ";\n\n  $input-transition: border-color 0.15s ease-in-out,\n    box-shadow 0.15s ease-in-out;\n\n  $form-color-width: 3rem;\n\n  $form-check-input-width: $font-size-base * 1; // 1em;\n  $form-check-min-height: $font-size-base * $line-height-base;\n  $form-check-padding-start: $form-check-input-width + 0.5rem; // 0.5em;\n  $form-check-margin-bottom: 0.125rem;\n  $form-check-label-color: null;\n  $form-check-label-cursor: null;\n  $form-check-transition: null;\n\n  $form-check-input-active-filter: brightness(90%);\n\n  $form-check-input-bg: $input-bg;\n  $form-check-input-border: 1px solid rgba($black, 0.25);\n  $form-check-input-border-radius: $font-size-base * 0.25; // 0.25em;\n  $form-check-radio-border-radius: 50px; // 50%;\n  $form-check-input-focus-border: $input-focus-border-color;\n  $form-check-input-focus-box-shadow: $input-btn-focus-box-shadow;\n\n  $form-check-input-checked-color: $component-active-color;\n  $form-check-input-checked-bg-color: $component-active-bg;\n  $form-check-input-checked-border-color: $form-check-input-checked-bg-color;\n  $form-check-input-checked-bg-image: ", ";\n  $form-check-radio-checked-bg-image: ", ";\n\n  $form-check-input-indeterminate-color: $component-active-color;\n  $form-check-input-indeterminate-bg-color: $component-active-bg;\n  $form-check-input-indeterminate-border-color: $form-check-input-indeterminate-bg-color;\n  $form-check-input-indeterminate-bg-image: ", ";\n\n  $form-check-input-disabled-opacity: 0.5;\n  $form-check-label-disabled-opacity: $form-check-input-disabled-opacity;\n  $form-check-btn-check-disabled-opacity: $btn-disabled-opacity;\n\n  $form-check-inline-margin-end: 1rem;\n\n  $form-switch-color: rgba($black, 0.25);\n  $form-switch-width: 2rem;\n  $form-switch-padding-start: $form-switch-width + 0.5rem;\n  $form-switch-bg-image: ", ";\n  $form-switch-border-radius: $form-switch-width;\n  $form-switch-transition: background-position 0.15s ease-in-out;\n\n  $form-switch-focus-color: $input-focus-border-color;\n  $form-switch-focus-bg-image: ", ";\n\n  $form-switch-checked-color: $component-active-color;\n  $form-switch-checked-bg-image: ", ";\n  $form-switch-checked-bg-position: right center;\n\n  $input-group-addon-padding-y: $input-padding-y;\n  $input-group-addon-padding-x: $input-padding-x;\n  $input-group-addon-font-weight: $input-font-weight;\n  $input-group-addon-color: $input-color;\n  $input-group-addon-bg: $gray-200;\n  $input-group-addon-border-color: $input-border-color;\n\n  $form-select-padding-y: $input-padding-y;\n  $form-select-padding-x: $input-padding-x;\n  $form-select-font-family: $input-font-family;\n  $form-select-font-size: $input-font-size;\n  $form-select-indicator-padding: $form-select-padding-x * 3; // Extra padding for background-image\n  $form-select-font-weight: $input-font-weight;\n  $form-select-line-height: $input-line-height;\n  $form-select-color: $input-color;\n  $form-select-bg: $input-bg;\n  $form-select-disabled-color: null;\n  $form-select-disabled-bg: $gray-200;\n  $form-select-disabled-border-color: $input-disabled-border-color;\n  $form-select-bg-position: right $form-select-padding-x center;\n  $form-select-bg-size: 16px 12px; // In pixels because image dimensions\n  $form-select-indicator-color: $gray-800;\n  $form-select-indicator: ", ";\n\n  $form-select-feedback-icon-padding-end: $form-select-padding-x * 2.5 +\n    $form-select-indicator-padding;\n  $form-select-feedback-icon-position: center right\n    $form-select-indicator-padding;\n  $form-select-feedback-icon-size: $input-height-inner-half\n    $input-height-inner-half;\n\n  $form-select-border-width: $input-border-width;\n  $form-select-border-color: $input-border-color;\n  $form-select-border-radius: $input-border-radius;\n  $form-select-box-shadow: $box-shadow-inset;\n\n  $form-select-focus-border-color: $input-focus-border-color;\n  $form-select-focus-width: $input-focus-width;\n  $form-select-focus-box-shadow: 0 0 0 $form-select-focus-width\n    $input-btn-focus-color;\n\n  $form-select-padding-y-sm: $input-padding-y-sm;\n  $form-select-padding-x-sm: $input-padding-x-sm;\n  $form-select-font-size-sm: $input-font-size-sm;\n  $form-select-border-radius-sm: $input-border-radius-sm;\n\n  $form-select-padding-y-lg: $input-padding-y-lg;\n  $form-select-padding-x-lg: $input-padding-x-lg;\n  $form-select-font-size-lg: $input-font-size-lg;\n  $form-select-border-radius-lg: $input-border-radius-lg;\n\n  $form-select-transition: $input-transition;\n\n  $form-range-track-width: 100%;\n  $form-range-track-height: 0.5rem;\n  $form-range-track-cursor: pointer;\n  $form-range-track-bg: $gray-300;\n  $form-range-track-border-radius: 1rem;\n  $form-range-track-box-shadow: $box-shadow-inset;\n\n  $form-range-thumb-width: 1rem;\n  $form-range-thumb-height: $form-range-thumb-width;\n  $form-range-thumb-bg: $component-active-bg;\n  $form-range-thumb-border: 0;\n  $form-range-thumb-border-radius: 1rem;\n  $form-range-thumb-box-shadow: 0 0.1rem 0.25rem rgba($black, 0.1);\n  $form-range-thumb-focus-box-shadow: 0 0 0 1px $body-bg,\n    $input-focus-box-shadow;\n  $form-range-thumb-focus-box-shadow-width: $input-focus-width; // For focus box shadow issue in Edge\n  $form-range-thumb-active-bg: tint-color($component-active-bg, 70%);\n  $form-range-thumb-disabled-bg: $gray-500;\n  $form-range-thumb-transition: background-color 0.15s ease-in-out,\n    border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;\n\n  $form-file-button-color: $input-color;\n  $form-file-button-bg: $input-group-addon-bg;\n  $form-file-button-hover-bg: shade-color($form-file-button-bg, 5%);\n\n  $form-floating-height: ", ";\n  $form-floating-line-height: 1.25;\n  $form-floating-padding-x: $input-padding-x;\n  $form-floating-padding-y: 1rem;\n  $form-floating-input-padding-t: 1.625rem;\n  $form-floating-input-padding-b: 0.625rem;\n  $form-floating-label-opacity: 0.65;\n  $form-floating-label-transform: scale(0.85) translateY(-0.5rem)\n    translateX(0.15rem);\n  $form-floating-transition: opacity 0.1s ease-in-out,\n    transform 0.1s ease-in-out;\n\n  // Form validation\n\n  $form-feedback-margin-top: $form-text-margin-top;\n  $form-feedback-font-size: $form-text-font-size;\n  $form-feedback-font-style: $form-text-font-style;\n  $form-feedback-valid-color: $success;\n  $form-feedback-invalid-color: $danger;\n\n  $form-feedback-icon-valid-color: $form-feedback-valid-color;\n  $form-feedback-icon-valid: ", ";\n  $form-feedback-icon-invalid-color: $form-feedback-invalid-color;\n  $form-feedback-icon-invalid: ", ";\n\n  $form-validation-states: ", ";\n\n  // Z-index master list\n  //\n  // Warning: Avoid customizing these values. They're used for a bird's eye view\n  // of components dependent on the z-axis and are designed to all work together.\n\n  $zindex-dropdown: 1000;\n  $zindex-sticky: 1020;\n  $zindex-fixed: 1030;\n  $zindex-offcanvas-backdrop: 1040;\n  $zindex-offcanvas: 1045;\n  $zindex-modal-backdrop: 1050;\n  $zindex-modal: 1055;\n  $zindex-popover: 1070;\n  $zindex-tooltip: 1080;\n\n  // Navs\n\n  $nav-link-padding-y: 0.5rem;\n  $nav-link-padding-x: 1rem;\n  $nav-link-font-size: null;\n  $nav-link-font-weight: null;\n  $nav-link-color: $link-color;\n  $nav-link-hover-color: $link-hover-color;\n  $nav-link-transition: color 0.15s ease-in-out,\n    background-color 0.15s ease-in-out, border-color 0.15s ease-in-out;\n  $nav-link-disabled-color: $gray-600;\n\n  $nav-tabs-border-color: $gray-300;\n  $nav-tabs-border-width: $border-width;\n  $nav-tabs-border-radius: $border-radius;\n  $nav-tabs-link-hover-border-color: $gray-200 $gray-200 $nav-tabs-border-color;\n  $nav-tabs-link-active-color: $gray-700;\n  $nav-tabs-link-active-bg: $body-bg;\n  $nav-tabs-link-active-border-color: $gray-300 $gray-300\n    $nav-tabs-link-active-bg;\n\n  $nav-pills-border-radius: $border-radius;\n  $nav-pills-link-active-color: $component-active-color;\n  $nav-pills-link-active-bg: $component-active-bg;\n\n  // Navbar\n\n  $navbar-padding-y: $spacer * 0.5;\n  $navbar-padding-x: null;\n\n  $navbar-nav-link-padding-x: 0.5rem;\n\n  $navbar-brand-font-size: $font-size-lg;\n\n  $nav-link-height: $font-size-base * $line-height-base + $nav-link-padding-y *\n    2;\n  $navbar-brand-height: $navbar-brand-font-size * $line-height-base;\n  $navbar-brand-padding-y-intermediate-result: $nav-link-height -\n    $navbar-brand-height;\n  $navbar-brand-padding-y: $navbar-brand-padding-y-intermediate-result * 0.5;\n  $navbar-brand-margin-end: 1rem;\n\n  $navbar-toggler-padding-y: 0.25rem;\n  $navbar-toggler-padding-x: 0.75rem;\n  $navbar-toggler-font-size: $font-size-lg;\n  $navbar-toggler-border-radius: $btn-border-radius;\n  $navbar-toggler-focus-width: $btn-focus-width;\n  $navbar-toggler-transition: box-shadow 0.15s ease-in-out;\n\n  $navbar-dark-color: rgba($white, 0.55);\n  $navbar-dark-hover-color: rgba($white, 0.75);\n  $navbar-dark-active-color: $white;\n  $navbar-dark-disabled-color: rgba($white, 0.25);\n  $navbar-dark-toggler-icon-bg: ", ";\n  $navbar-dark-toggler-border-color: rgba($white, 0.1);\n\n  $navbar-light-color: rgba($black, 0.55);\n  $navbar-light-hover-color: rgba($black, 0.7);\n  $navbar-light-active-color: rgba($black, 0.9);\n  $navbar-light-disabled-color: rgba($black, 0.3);\n  $navbar-light-toggler-icon-bg: ", ";\n  $navbar-light-toggler-border-color: rgba($black, 0.1);\n\n  $navbar-light-brand-color: $navbar-light-active-color;\n  $navbar-light-brand-hover-color: $navbar-light-active-color;\n  $navbar-dark-brand-color: $navbar-dark-active-color;\n  $navbar-dark-brand-hover-color: $navbar-dark-active-color;\n\n  // Dropdowns\n  //\n  // Dropdown menu container and contents.\n\n  $dropdown-min-width: 10rem;\n  $dropdown-padding-x: 0;\n  $dropdown-padding-y: 0.5rem;\n  $dropdown-spacer: 0.125rem;\n  $dropdown-font-size: $font-size-base;\n  $dropdown-color: $body-color;\n  $dropdown-bg: $white;\n  $dropdown-border-color: rgba($black, 0.15);\n  $dropdown-border-radius: $border-radius;\n  $dropdown-border-width: $border-width;\n  $dropdown-inner-border-radius: ", ";\n  $dropdown-divider-bg: $dropdown-border-color;\n  $dropdown-divider-margin-y: $spacer * 0.5;\n  $dropdown-box-shadow: $box-shadow;\n\n  $dropdown-link-color: $gray-900;\n\n  $dropdown-link-hover-color: ", ";\n  $dropdown-link-hover-bg: $gray-200;\n\n  $dropdown-link-active-color: $component-active-color;\n  $dropdown-link-active-bg: $component-active-bg;\n\n  $dropdown-link-disabled-color: $gray-500;\n\n  $dropdown-item-padding-y: $spacer * 0.25;\n  $dropdown-item-padding-x: $spacer;\n\n  $dropdown-header-color: $gray-600;\n  $dropdown-header-padding: $dropdown-padding-y $dropdown-item-padding-x;\n\n  $dropdown-dark-color: $gray-300;\n  $dropdown-dark-bg: $gray-800;\n  $dropdown-dark-border-color: $dropdown-border-color;\n  $dropdown-dark-divider-bg: $dropdown-divider-bg;\n  $dropdown-dark-box-shadow: null;\n  $dropdown-dark-link-color: $dropdown-dark-color;\n  $dropdown-dark-link-hover-color: $white;\n  $dropdown-dark-link-hover-bg: rgba($white, 0.15);\n  $dropdown-dark-link-active-color: $dropdown-link-active-color;\n  $dropdown-dark-link-active-bg: $dropdown-link-active-bg;\n  $dropdown-dark-link-disabled-color: $gray-500;\n  $dropdown-dark-header-color: $gray-500;\n\n  // ...\n\n  // Cards\n\n  $card-spacer-y: $spacer;\n  $card-spacer-x: $spacer;\n  $card-title-spacer-y: $spacer * 0.5;\n  $card-border-width: $border-width;\n  $card-border-color: rgba($black, 0.125);\n  $card-border-radius: $border-radius;\n  $card-box-shadow: null;\n  $card-inner-border-radius: ", ";\n  $card-cap-padding-y: $card-spacer-y * 0.5;\n  $card-cap-padding-x: $card-spacer-x;\n  $card-cap-bg: rgba($black, 0.03);\n  $card-cap-color: null;\n  $card-height: null;\n  $card-color: null;\n  $card-bg: $white;\n  $card-img-overlay-padding: $spacer;\n  $card-group-margin: $grid-gutter-width * 0.5;\n\n  // ...\n\n  // Tooltips\n\n  $tooltip-font-size: $font-size-sm;\n  $tooltip-max-width: 200px;\n  $tooltip-color: $white;\n  $tooltip-bg: $black;\n  $tooltip-border-radius: $border-radius;\n  $tooltip-opacity: 0.9;\n  $tooltip-padding-y: $spacer * 0.25;\n  $tooltip-padding-x: $spacer * 0.5;\n  $tooltip-margin: 0;\n\n  $tooltip-arrow-width: 0.8rem;\n  $tooltip-arrow-height: 0.4rem;\n  $tooltip-arrow-color: $tooltip-bg;\n\n  // Popovers\n\n  $popover-font-size: $font-size-sm;\n  $popover-bg: $white;\n  $popover-max-width: 276px;\n  $popover-border-width: $border-width;\n  $popover-border-color: rgba($black, 0.2);\n  $popover-border-radius: $border-radius-lg;\n  $popover-inner-border-radius: ", ";\n  $popover-box-shadow: $box-shadow;\n\n  $popover-header-bg: ", ";\n  $popover-header-color: $headings-color;\n  $popover-header-padding-y: 0.5rem;\n  $popover-header-padding-x: $spacer;\n\n  $popover-body-color: $body-color;\n  $popover-body-padding-y: $spacer;\n  $popover-body-padding-x: $spacer;\n\n  $popover-arrow-width: 1rem;\n  $popover-arrow-height: 0.5rem;\n  $popover-arrow-color: $popover-bg;\n\n  $popover-arrow-outer-color: $popover-border-color;\n\n  // Toasts\n\n  $toast-max-width: 350px;\n  $toast-padding-x: 0.75rem;\n  $toast-padding-y: 0.5rem;\n  $toast-font-size: 0.875rem;\n  $toast-color: null;\n  $toast-background-color: rgba($white, 0.85);\n  $toast-border-width: 1px;\n  $toast-border-color: rgba($black, 0.1);\n  $toast-border-radius: $border-radius;\n  $toast-box-shadow: $box-shadow;\n  $toast-spacing: $container-padding-x;\n\n  $toast-header-color: $gray-600;\n  $toast-header-background-color: rgba($white, 0.85);\n  $toast-header-border-color: rgba($black, 0.05);\n\n  // Badges\n\n  $badge-font-size: $font-size-base * 0.75; // 0.75em;\n  $badge-font-weight: $font-weight-bold;\n  $badge-color: $white;\n  $badge-padding-y: $badge-font-size * 0.35; // 0.35em;\n  $badge-padding-x: $badge-font-size * 0.65; // 0.65em;\n  $badge-border-radius: $border-radius;\n\n  // Modals\n\n  $modal-inner-padding: $spacer;\n\n  $modal-footer-margin-between: 0.5rem;\n\n  $modal-dialog-margin: 0.5rem;\n  $modal-dialog-margin-y-sm-up: 1.75rem;\n\n  $modal-title-line-height: $line-height-base;\n\n  $modal-content-color: null;\n  $modal-content-bg: $white;\n  $modal-content-border-color: rgba($black, 0.65); // rgba($black, 0.2);\n  $modal-content-border-width: $border-width;\n  $modal-content-border-radius: $border-radius-lg;\n  $modal-content-inner-border-radius: ", ";\n  $modal-content-box-shadow-xs: $box-shadow-sm;\n  $modal-content-box-shadow-sm-up: $box-shadow;\n\n  $modal-backdrop-bg: $black;\n  $modal-backdrop-opacity: 0.5;\n  $modal-header-border-color: $border-color;\n  $modal-footer-border-color: $modal-header-border-color;\n  $modal-header-border-width: $modal-content-border-width;\n  $modal-footer-border-width: $modal-header-border-width;\n  $modal-header-padding-y: $modal-inner-padding;\n  $modal-header-padding-x: $modal-inner-padding;\n  $modal-header-padding: $modal-header-padding-y $modal-header-padding-x; // Keep this for backwards compatibility\n\n  $modal-sm: 300px;\n  $modal-md: 500px;\n  $modal-lg: 800px;\n  $modal-xl: 1140px;\n\n  $modal-fade-transform: translate(0, -50px);\n  $modal-show-transform: none;\n  $modal-transition: transform 0.3s ease-out;\n  $modal-scale-transform: scale(1.02);\n\n  // ...\n\n  // Alerts\n  //\n  // Define alert colors, border radius, and padding.\n\n  $alert-padding-y: $spacer;\n  $alert-padding-x: $spacer;\n  $alert-margin-bottom: 1rem;\n  $alert-border-radius: $border-radius;\n  $alert-link-font-weight: $font-weight-bold;\n  $alert-border-width: $border-width;\n  $alert-bg-scale: -0.8; // 80%;\n  $alert-border-scale: -0.7; // 70%;\n  $alert-color-scale: 0.4; // 40%;\n  $alert-dismissible-padding-r: $alert-padding-x * 3; // 3x covers width of x plus default padding on either side\n\n  // Pagination\n\n  $pagination-padding-y: 0.375rem;\n  $pagination-padding-x: 0.75rem;\n  $pagination-padding-y-sm: 0.25rem;\n  $pagination-padding-x-sm: 0.5rem;\n  $pagination-padding-y-lg: 0.75rem;\n  $pagination-padding-x-lg: 1.5rem;\n\n  $pagination-color: $link-color;\n  $pagination-bg: $white;\n  $pagination-border-width: $border-width;\n  $pagination-border-radius: $border-radius;\n  $pagination-margin-start: -$pagination-border-width;\n  $pagination-border-color: $gray-300;\n\n  $pagination-focus-color: $link-hover-color;\n  $pagination-focus-bg: $gray-200;\n  $pagination-focus-box-shadow: $input-btn-focus-box-shadow;\n  $pagination-focus-outline: 0;\n\n  $pagination-hover-color: $link-hover-color;\n  $pagination-hover-bg: $gray-200;\n  $pagination-hover-border-color: $gray-300;\n\n  $pagination-active-color: $component-active-color;\n  $pagination-active-bg: $component-active-bg;\n  $pagination-active-border-color: $pagination-active-bg;\n\n  $pagination-disabled-color: $gray-600;\n  $pagination-disabled-bg: $white;\n  $pagination-disabled-border-color: $gray-300;\n\n  $pagination-transition: color 0.15s ease-in-out,\n    background-color 0.15s ease-in-out, border-color 0.15s ease-in-out,\n    box-shadow 0.15s ease-in-out;\n\n  $pagination-border-radius-sm: $border-radius-sm;\n  $pagination-border-radius-lg: $border-radius-lg;\n\n  // Progress bars\n\n  $progress-height: 1rem;\n  $progress-font-size: $font-size-base * 0.75;\n  $progress-bg: $gray-200;\n  $progress-border-radius: $border-radius;\n  $progress-box-shadow: $box-shadow-inset;\n  $progress-bar-color: $white;\n  $progress-bar-bg: $primary;\n  $progress-bar-animation-timing: 1s linear infinite;\n  $progress-bar-transition: width 0.6s ease;\n\n  // List group\n\n  $list-group-color: $gray-900;\n  $list-group-bg: $white;\n  $list-group-border-color: rgba($black, 0.125);\n  $list-group-border-width: $border-width;\n  $list-group-border-radius: $border-radius;\n\n  $list-group-item-padding-y: $spacer * 0.5;\n  $list-group-item-padding-x: $spacer;\n  $list-group-item-bg-scale: -0.8; // 80%;\n  $list-group-item-color-scale: 0.4; // 40%;\n\n  $list-group-hover-bg: $gray-100;\n  $list-group-active-color: $component-active-color;\n  $list-group-active-bg: $component-active-bg;\n  $list-group-active-border-color: $list-group-active-bg;\n\n  $list-group-disabled-color: $gray-600;\n  $list-group-disabled-bg: $list-group-bg;\n\n  $list-group-action-color: $gray-700;\n  $list-group-action-hover-color: $list-group-action-color;\n\n  $list-group-action-active-color: $body-color;\n  $list-group-action-active-bg: $gray-200;\n\n  // ...\n\n  // Spinners\n\n  $spinner-width: 2rem;\n  $spinner-height: $spinner-width;\n  $spinner-vertical-align: $font-size-base * -0.125; // -.125em;\n  $spinner-border-width: $font-size-base * 0.25; // .25em;\n  $spinner-animation-speed: 0.75s;\n\n  $spinner-width-sm: 1rem;\n  $spinner-height-sm: $spinner-width-sm;\n  $spinner-border-width-sm: $font-size-base * 0.2; // .2em;\n\n  // Close\n\n  $btn-close-width: $font-size-base * 1; // 1em;\n  $btn-close-height: $btn-close-width;\n  $btn-close-padding-x: $font-size-base * 0.25; // .25em;\n  $btn-close-padding-y: $btn-close-padding-x;\n  $btn-close-color: $black;\n  $btn-close-bg: ", ";\n  $btn-close-focus-shadow: $input-btn-focus-box-shadow;\n  $btn-close-opacity: 0.5;\n  $btn-close-hover-opacity: 0.75;\n  $btn-close-focus-opacity: 1;\n  $btn-close-disabled-opacity: 0.25;\n  // $btn-close-white-filter: invert(1) grayscale(100%) brightness(200%);\n\n  // Offcanvas\n\n  $offcanvas-padding-y: $modal-inner-padding;\n  $offcanvas-padding-x: $modal-inner-padding;\n  $offcanvas-horizontal-width: 400px;\n  $offcanvas-vertical-height: 200px; // 30vh;\n  $offcanvas-transition-duration: 0.3s;\n  $offcanvas-border-color: $modal-content-border-color;\n  $offcanvas-border-width: $modal-content-border-width;\n  $offcanvas-title-line-height: $modal-title-line-height;\n  $offcanvas-bg-color: $modal-content-bg;\n  $offcanvas-color: $modal-content-color;\n  $offcanvas-box-shadow: $modal-content-box-shadow-xs;\n  $offcanvas-backdrop-bg: $modal-backdrop-bg;\n  $offcanvas-backdrop-opacity: $modal-backdrop-opacity;\n\n  // Code\n\n  $code-font-size: $small-font-size;\n  $code-color: $pink;\n\n  $kbd-padding-y: 0.2rem;\n  $kbd-padding-x: 0.4rem;\n  $kbd-font-size: $code-font-size;\n  $kbd-color: $white;\n  $kbd-bg: $gray-900;\n\n  $pre-color: null;\n"])), function (t) {
    return {
      100: t['gray-100'],
      200: t['gray-200'],
      300: t['gray-300'],
      400: t['gray-400'],
      500: t['gray-500'],
      600: t['gray-600'],
      700: t['gray-700'],
      800: t['gray-800'],
      900: t['gray-900']
    };
  }, function (t) {
    return {
      blue: t.blue,
      indigo: t.indigo,
      purple: t.purple,
      pink: t.pink,
      red: t.red,
      orange: t.orange,
      yellow: t.yellow,
      green: t.green,
      teal: t.teal,
      cyan: t.cyan
    };
  }, function (t) {
    return {
      primary: t.primary,
      secondary: t.secondary,
      success: t.success,
      info: t.info,
      warning: t.warning,
      danger: t.danger,
      light: t.light,
      dark: t.dark
    };
  }, function (t) {
    return {
      'blue-100': t['blue-100'],
      'blue-200': t['blue-200'],
      'blue-300': t['blue-300'],
      'blue-400': t['blue-400'],
      'blue-500': t['blue-500'],
      'blue-600': t['blue-600'],
      'blue-700': t['blue-700'],
      'blue-800': t['blue-800'],
      'blue-900': t['blue-900']
    };
  }, function (t) {
    return {
      'indigo-100': t['indigo-100'],
      'indigo-200': t['indigo-200'],
      'indigo-300': t['indigo-300'],
      'indigo-400': t['indigo-400'],
      'indigo-500': t['indigo-500'],
      'indigo-600': t['indigo-600'],
      'indigo-700': t['indigo-700'],
      'indigo-800': t['indigo-800'],
      'indigo-900': t['indigo-900']
    };
  }, function (t) {
    return {
      'purple-100': t['purple-100'],
      'purple-200': t['purple-200'],
      'purple-300': t['purple-300'],
      'purple-400': t['purple-400'],
      'purple-500': t['purple-500'],
      'purple-600': t['purple-600'],
      'purple-700': t['purple-700'],
      'purple-800': t['purple-800'],
      'purple-900': t['purple-900']
    };
  }, function (t) {
    return {
      'pink-100': t['pink-100'],
      'pink-200': t['pink-200'],
      'pink-300': t['pink-300'],
      'pink-400': t['pink-400'],
      'pink-500': t['pink-500'],
      'pink-600': t['pink-600'],
      'pink-700': t['pink-700'],
      'pink-800': t['pink-800'],
      'pink-900': t['pink-900']
    };
  }, function (t) {
    return {
      'red-100': t['red-100'],
      'red-200': t['red-200'],
      'red-300': t['red-300'],
      'red-400': t['red-400'],
      'red-500': t['red-500'],
      'red-600': t['red-600'],
      'red-700': t['red-700'],
      'red-800': t['red-800'],
      'red-900': t['red-900']
    };
  }, function (t) {
    return {
      'orange-100': t['orange-100'],
      'orange-200': t['orange-200'],
      'orange-300': t['orange-300'],
      'orange-400': t['orange-400'],
      'orange-500': t['orange-500'],
      'orange-600': t['orange-600'],
      'orange-700': t['orange-700'],
      'orange-800': t['orange-800'],
      'orange-900': t['orange-900']
    };
  }, function (t) {
    return {
      'yellow-100': t['yellow-100'],
      'yellow-200': t['yellow-200'],
      'yellow-300': t['yellow-300'],
      'yellow-400': t['yellow-400'],
      'yellow-500': t['yellow-500'],
      'yellow-600': t['yellow-600'],
      'yellow-700': t['yellow-700'],
      'yellow-800': t['yellow-800'],
      'yellow-900': t['yellow-900']
    };
  }, function (t) {
    return {
      'green-100': t['green-100'],
      'green-200': t['green-200'],
      'green-300': t['green-300'],
      'green-400': t['green-400'],
      'green-500': t['green-500'],
      'green-600': t['green-600'],
      'green-700': t['green-700'],
      'green-800': t['green-800'],
      'green-900': t['green-900']
    };
  }, function (t) {
    return {
      'teal-100': t['teal-100'],
      'teal-200': t['teal-200'],
      'teal-300': t['teal-300'],
      'teal-400': t['teal-400'],
      'teal-500': t['teal-500'],
      'teal-600': t['teal-600'],
      'teal-700': t['teal-700'],
      'teal-800': t['teal-800'],
      'teal-900': t['teal-900']
    };
  }, function (t) {
    return {
      'cyan-100': t['cyan-100'],
      'cyan-200': t['cyan-200'],
      'cyan-300': t['cyan-300'],
      'cyan-400': t['cyan-400'],
      'cyan-500': t['cyan-500'],
      'cyan-600': t['cyan-600'],
      'cyan-700': t['cyan-700'],
      'cyan-800': t['cyan-800'],
      'cyan-900': t['cyan-900']
    };
  }, function (t) {
    return {
      0: '0px',
      1: "".concat(t.spacer, " * 0.25"),
      2: "".concat(t.spacer, " * 0.5"),
      3: t.spacer,
      4: "".concat(t.spacer, " * 1.5"),
      5: "".concat(t.spacer, " * 3")
    };
  }, function () {
    return {
      0: '0px',
      50: '50%',
      100: '100%'
    };
  }, shiftColor(function (t) {
    return t['link-shade-percentage'];
  }, function (t) {
    return t['link-color'];
  }), function () {
    return {
      xs: 0,
      sm: 576,
      md: 768,
      lg: 992,
      xl: 1200,
      xxl: 1400
    };
  }, function () {
    return {
      sm: '540px',
      md: '720px',
      lg: '960px',
      xl: '1140px',
      xxl: '1320px'
    };
  }, function () {
    return {
      1: '1px',
      2: '2px',
      3: '3px',
      4: '4px',
      5: '5px'
    };
  }, function () {
    return {
      '1x1': '100%',
      '4x3': 'calc(3 / 4 * 100%)',
      '16x9': 'calc(9 / 16 * 100%)',
      '21x9': 'calc(9 / 21 * 100%)'
    };
  }, function () {
    return _reactNative.Platform.select({
      native: 'System',
      default: "\"system-ui, -apple-system, 'Segoe UI', Roboto, 'Helvetica Neue', Arial, 'Noto Sans', 'Liberation Sans', sans-serif, 'Apple Color Emoji', 'Segoe UI Emoji', 'Segoe UI Symbol', 'Noto Color Emoji'\""
    });
  }, function () {
    return _reactNative.Platform.select({
      android: 'monospace',
      ios: 'Courier',
      default: "\"SFMono-Regular, Menlo, Monaco, Consolas, 'Liberation Mono', 'Courier New', monospace\""
    });
  }, function (t) {
    return {
      1: t['h1-font-size'],
      2: t['h2-font-size'],
      3: t['h3-font-size'],
      4: t['h4-font-size'],
      5: t['h5-font-size'],
      6: t['h6-font-size']
    };
  }, function () {
    return {
      1: '5rem',
      2: '4.5rem',
      3: '4rem',
      4: '3.5rem',
      5: '3rem',
      6: '2.5rem'
    };
  }, tintColor(0.5, function (t) {
    return t['component-active-bg'];
  }), add(function (t) {
    return calculate(t['input-line-height'], '*', 1);
  }, function (t) {
    return calculate(t['input-padding-y'], '*', 2);
  }), add(function (t) {
    return calculate(t['input-line-height'], '*', 0.5);
  }, function (t) {
    return t['input-padding-y'];
  }), add(function (t) {
    return calculate(t['input-line-height'], '*', 0.25);
  }, function (t) {
    return calculate(t['input-padding-y'], '*', 0.5);
  }), add(function (t) {
    return calculate(t['input-line-height'], '*', 1);
  }, // 1em
  add(function (t) {
    return calculate(t['input-padding-y'], '*', 2);
  }, function (t) {
    return t['input-height-border'];
  })), add(function (t) {
    return calculate(t['input-line-height'], '*', 1);
  }, // 1em
  add(function (t) {
    return calculate(t['input-padding-y-sm'], '*', 2);
  }, function (t) {
    return t['input-height-border'];
  })), add(function (t) {
    return calculate(t['input-line-height'], '*', 1);
  }, // 1em
  add(function (t) {
    return calculate(t['input-padding-y-lg'], '*', 2);
  }, function (t) {
    return t['input-height-border'];
  })), svgs['form-check-input-checked-bg-image'], svgs['form-check-radio-checked-bg-image'], svgs['form-check-input-indeterminate-bg-image'], svgs['form-switch-bg-image'], svgs['form-switch-focus-bg-image'], svgs['form-switch-checked-bg-image'], svgs['form-select-indicator'], add('3.5rem', function (t) {
    return t['input-height-border'];
  }), svgs['form-feedback-icon-valid'], svgs['form-feedback-icon-invalid'], function (t) {
    return {
      valid: {
        color: t['form-feedback-valid-color'],
        icon: t['form-feedback-icon-valid']
      },
      invalid: {
        color: t['form-feedback-invalid-color'],
        icon: t['form-feedback-icon-invalid']
      }
    };
  }, svgs['navbar-dark-toggler-icon-bg'], svgs['navbar-light-toggler-icon-bg'], subtract(function (t) {
    return t['dropdown-border-radius'];
  }, function (t) {
    return t['dropdown-border-width'];
  }), shadeColor(0.1, function (t) {
    return t['dropdown-link-color'];
  }), subtract(function (t) {
    return t['card-border-radius'];
  }, function (t) {
    return t['card-border-width'];
  }), subtract(function (t) {
    return t['popover-border-radius'];
  }, function (t) {
    return t['popover-border-width'];
  }), shadeColor(0.06, function (t) {
    return t['popover-bg'];
  }), subtract(function (t) {
    return t['modal-content-border-radius'];
  }, function (t) {
    return t['modal-content-border-width'];
  }), svgs['btn-close-bg']);

  var extractVariables = function extractVariables(source) {
    var baseVariables = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    var options = arguments.length > 2 ? arguments[2] : undefined;

    if (typeof source !== 'function') {
      // TODO: Resolve t => ... functions on source object.
      return _objectSpread2(_objectSpread2({}, source), baseVariables);
    }

    var result = transform$2(source.ast.children, baseVariables, options);
    return _objectSpread2(_objectSpread2({}, result[0].variables), baseVariables);
  };

  function makeTheme(customVariables) {
    var customTheme = extractVariables(customVariables);
    return extractVariables(variables, customTheme, {
      preferTheme: true
    });
  }

  var activeKey = null;
  var themes = {};
  var sheets = [];

  var createSheet = function createSheet(sheet) {
    var theme = themes[activeKey];
    var statelessSource = {};
    var statefulSource = {}; // Apply theme to themeable styles.

    Object.entries(sheet.source).forEach(function (_ref) {
      var _ref2 = _slicedToArray(_ref, 2),
          key = _ref2[0],
          style = _ref2[1];

      // Resolve theme.
      var value = typeof style === 'function' ? style(theme, activeKey) : style;

      if (typeof value === 'function') {
        statefulSource[key] = value;
      } else {
        statelessSource[key] = value;
      }
    }); // Wrap stateful and stateless in a proxy, so that we can update the styles on theme change.
    // For using Object.assign below we need some additional methods on the proxy that are mentioned here:
    // https://stackoverflow.com/questions/43185453/object-assign-and-proxies

    return new Proxy({
      keys: Object.keys(sheet.source),
      stateless: _reactNative.StyleSheet.create(statelessSource),
      stateful: statefulSource
    }, {
      get: function get(target, prop) {
        return target.stateless[prop] || target.stateful[prop] || undefined;
      },
      ownKeys: function ownKeys(target) {
        return target.keys;
      },
      getOwnPropertyDescriptor: function getOwnPropertyDescriptor(target, name) {
        var proxy = this;
        return {
          get value() {
            return proxy.get(target, name);
          },

          configurable: true,
          enumerable: true
        };
      },
      has: function has(target, name) {
        return target.keys.indexOf(name) >= 0;
      }
    });
  };

  var StyleSheet = {
    create: function create(source) {
      // Create sheet object.
      var sheet = {
        source: source,
        cache: {},
        active: null
      }; // If initialized, set active sheet based by active theme.

      if (activeKey !== null) {
        sheet.cache[activeKey] = createSheet(sheet);
        sheet.active = sheet.cache[activeKey];
      } else {
        // Placeholder until build method is called.
        sheet.active = {};
      }

      sheets.push(sheet);
      return sheet.active;
    },
    build: function build(theme) {
      var key = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'default';

      if (!themes[key]) {
        themes[key] = theme;
      } // If theme is already set, we don't need to do anything.


      if (key === activeKey) {
        return;
      } // Set new theme active.


      activeKey = key; // Update style sheets.

      sheets.forEach(function (_, i) {
        // If there is no result for the active theme, we'll create a themed
        // style sheet.
        if (!sheets[i].cache[key]) {
          sheets[i].cache[key] = createSheet(sheets[i]);
        } // Assign active object, which is also returned from the create
        // function, so style changes will be applied on next rerender in
        // the components as well.


        Object.assign(sheets[i].active, sheets[i].cache[key]);
      });
    },
    value: function value(key) {
      if (activeKey === null) {
        throw new Error('Use of StyleSheet.value() before initializing.');
      }

      var theme = themes[activeKey];
      return theme[key];
    }
  };

  var Context = /*#__PURE__*/React__default["default"].createContext();
  Context.displayName = 'BootstrapRNContext';

  /** @license React v16.13.1
   * react-is.development.js
   *
   * Copyright (c) Facebook, Inc. and its affiliates.
   *
   * This source code is licensed under the MIT license found in the
   * LICENSE file in the root directory of this source tree.
   */

  var reactIs_development = createCommonjsModule(function (module, exports) {



  {
    (function() {

  // The Symbol used to tag the ReactElement-like types. If there is no native Symbol
  // nor polyfill, then a plain number is used for performance.
  var hasSymbol = typeof Symbol === 'function' && Symbol.for;
  var REACT_ELEMENT_TYPE = hasSymbol ? Symbol.for('react.element') : 0xeac7;
  var REACT_PORTAL_TYPE = hasSymbol ? Symbol.for('react.portal') : 0xeaca;
  var REACT_FRAGMENT_TYPE = hasSymbol ? Symbol.for('react.fragment') : 0xeacb;
  var REACT_STRICT_MODE_TYPE = hasSymbol ? Symbol.for('react.strict_mode') : 0xeacc;
  var REACT_PROFILER_TYPE = hasSymbol ? Symbol.for('react.profiler') : 0xead2;
  var REACT_PROVIDER_TYPE = hasSymbol ? Symbol.for('react.provider') : 0xeacd;
  var REACT_CONTEXT_TYPE = hasSymbol ? Symbol.for('react.context') : 0xeace; // TODO: We don't use AsyncMode or ConcurrentMode anymore. They were temporary
  // (unstable) APIs that have been removed. Can we remove the symbols?

  var REACT_ASYNC_MODE_TYPE = hasSymbol ? Symbol.for('react.async_mode') : 0xeacf;
  var REACT_CONCURRENT_MODE_TYPE = hasSymbol ? Symbol.for('react.concurrent_mode') : 0xeacf;
  var REACT_FORWARD_REF_TYPE = hasSymbol ? Symbol.for('react.forward_ref') : 0xead0;
  var REACT_SUSPENSE_TYPE = hasSymbol ? Symbol.for('react.suspense') : 0xead1;
  var REACT_SUSPENSE_LIST_TYPE = hasSymbol ? Symbol.for('react.suspense_list') : 0xead8;
  var REACT_MEMO_TYPE = hasSymbol ? Symbol.for('react.memo') : 0xead3;
  var REACT_LAZY_TYPE = hasSymbol ? Symbol.for('react.lazy') : 0xead4;
  var REACT_BLOCK_TYPE = hasSymbol ? Symbol.for('react.block') : 0xead9;
  var REACT_FUNDAMENTAL_TYPE = hasSymbol ? Symbol.for('react.fundamental') : 0xead5;
  var REACT_RESPONDER_TYPE = hasSymbol ? Symbol.for('react.responder') : 0xead6;
  var REACT_SCOPE_TYPE = hasSymbol ? Symbol.for('react.scope') : 0xead7;

  function isValidElementType(type) {
    return typeof type === 'string' || typeof type === 'function' || // Note: its typeof might be other than 'symbol' or 'number' if it's a polyfill.
    type === REACT_FRAGMENT_TYPE || type === REACT_CONCURRENT_MODE_TYPE || type === REACT_PROFILER_TYPE || type === REACT_STRICT_MODE_TYPE || type === REACT_SUSPENSE_TYPE || type === REACT_SUSPENSE_LIST_TYPE || typeof type === 'object' && type !== null && (type.$$typeof === REACT_LAZY_TYPE || type.$$typeof === REACT_MEMO_TYPE || type.$$typeof === REACT_PROVIDER_TYPE || type.$$typeof === REACT_CONTEXT_TYPE || type.$$typeof === REACT_FORWARD_REF_TYPE || type.$$typeof === REACT_FUNDAMENTAL_TYPE || type.$$typeof === REACT_RESPONDER_TYPE || type.$$typeof === REACT_SCOPE_TYPE || type.$$typeof === REACT_BLOCK_TYPE);
  }

  function typeOf(object) {
    if (typeof object === 'object' && object !== null) {
      var $$typeof = object.$$typeof;

      switch ($$typeof) {
        case REACT_ELEMENT_TYPE:
          var type = object.type;

          switch (type) {
            case REACT_ASYNC_MODE_TYPE:
            case REACT_CONCURRENT_MODE_TYPE:
            case REACT_FRAGMENT_TYPE:
            case REACT_PROFILER_TYPE:
            case REACT_STRICT_MODE_TYPE:
            case REACT_SUSPENSE_TYPE:
              return type;

            default:
              var $$typeofType = type && type.$$typeof;

              switch ($$typeofType) {
                case REACT_CONTEXT_TYPE:
                case REACT_FORWARD_REF_TYPE:
                case REACT_LAZY_TYPE:
                case REACT_MEMO_TYPE:
                case REACT_PROVIDER_TYPE:
                  return $$typeofType;

                default:
                  return $$typeof;
              }

          }

        case REACT_PORTAL_TYPE:
          return $$typeof;
      }
    }

    return undefined;
  } // AsyncMode is deprecated along with isAsyncMode

  var AsyncMode = REACT_ASYNC_MODE_TYPE;
  var ConcurrentMode = REACT_CONCURRENT_MODE_TYPE;
  var ContextConsumer = REACT_CONTEXT_TYPE;
  var ContextProvider = REACT_PROVIDER_TYPE;
  var Element = REACT_ELEMENT_TYPE;
  var ForwardRef = REACT_FORWARD_REF_TYPE;
  var Fragment = REACT_FRAGMENT_TYPE;
  var Lazy = REACT_LAZY_TYPE;
  var Memo = REACT_MEMO_TYPE;
  var Portal = REACT_PORTAL_TYPE;
  var Profiler = REACT_PROFILER_TYPE;
  var StrictMode = REACT_STRICT_MODE_TYPE;
  var Suspense = REACT_SUSPENSE_TYPE;
  var hasWarnedAboutDeprecatedIsAsyncMode = false; // AsyncMode should be deprecated

  function isAsyncMode(object) {
    {
      if (!hasWarnedAboutDeprecatedIsAsyncMode) {
        hasWarnedAboutDeprecatedIsAsyncMode = true; // Using console['warn'] to evade Babel and ESLint

        console['warn']('The ReactIs.isAsyncMode() alias has been deprecated, ' + 'and will be removed in React 17+. Update your code to use ' + 'ReactIs.isConcurrentMode() instead. It has the exact same API.');
      }
    }

    return isConcurrentMode(object) || typeOf(object) === REACT_ASYNC_MODE_TYPE;
  }
  function isConcurrentMode(object) {
    return typeOf(object) === REACT_CONCURRENT_MODE_TYPE;
  }
  function isContextConsumer(object) {
    return typeOf(object) === REACT_CONTEXT_TYPE;
  }
  function isContextProvider(object) {
    return typeOf(object) === REACT_PROVIDER_TYPE;
  }
  function isElement(object) {
    return typeof object === 'object' && object !== null && object.$$typeof === REACT_ELEMENT_TYPE;
  }
  function isForwardRef(object) {
    return typeOf(object) === REACT_FORWARD_REF_TYPE;
  }
  function isFragment(object) {
    return typeOf(object) === REACT_FRAGMENT_TYPE;
  }
  function isLazy(object) {
    return typeOf(object) === REACT_LAZY_TYPE;
  }
  function isMemo(object) {
    return typeOf(object) === REACT_MEMO_TYPE;
  }
  function isPortal(object) {
    return typeOf(object) === REACT_PORTAL_TYPE;
  }
  function isProfiler(object) {
    return typeOf(object) === REACT_PROFILER_TYPE;
  }
  function isStrictMode(object) {
    return typeOf(object) === REACT_STRICT_MODE_TYPE;
  }
  function isSuspense(object) {
    return typeOf(object) === REACT_SUSPENSE_TYPE;
  }

  exports.AsyncMode = AsyncMode;
  exports.ConcurrentMode = ConcurrentMode;
  exports.ContextConsumer = ContextConsumer;
  exports.ContextProvider = ContextProvider;
  exports.Element = Element;
  exports.ForwardRef = ForwardRef;
  exports.Fragment = Fragment;
  exports.Lazy = Lazy;
  exports.Memo = Memo;
  exports.Portal = Portal;
  exports.Profiler = Profiler;
  exports.StrictMode = StrictMode;
  exports.Suspense = Suspense;
  exports.isAsyncMode = isAsyncMode;
  exports.isConcurrentMode = isConcurrentMode;
  exports.isContextConsumer = isContextConsumer;
  exports.isContextProvider = isContextProvider;
  exports.isElement = isElement;
  exports.isForwardRef = isForwardRef;
  exports.isFragment = isFragment;
  exports.isLazy = isLazy;
  exports.isMemo = isMemo;
  exports.isPortal = isPortal;
  exports.isProfiler = isProfiler;
  exports.isStrictMode = isStrictMode;
  exports.isSuspense = isSuspense;
  exports.isValidElementType = isValidElementType;
  exports.typeOf = typeOf;
    })();
  }
  });

  var reactIs = createCommonjsModule(function (module) {

  {
    module.exports = reactIs_development;
  }
  });

  /*
  object-assign
  (c) Sindre Sorhus
  @license MIT
  */
  /* eslint-disable no-unused-vars */
  var getOwnPropertySymbols = Object.getOwnPropertySymbols;
  var hasOwnProperty$1 = Object.prototype.hasOwnProperty;
  var propIsEnumerable = Object.prototype.propertyIsEnumerable;

  function toObject(val) {
  	if (val === null || val === undefined) {
  		throw new TypeError('Object.assign cannot be called with null or undefined');
  	}

  	return Object(val);
  }

  function shouldUseNative() {
  	try {
  		if (!Object.assign) {
  			return false;
  		}

  		// Detect buggy property enumeration order in older V8 versions.

  		// https://bugs.chromium.org/p/v8/issues/detail?id=4118
  		var test1 = new String('abc');  // eslint-disable-line no-new-wrappers
  		test1[5] = 'de';
  		if (Object.getOwnPropertyNames(test1)[0] === '5') {
  			return false;
  		}

  		// https://bugs.chromium.org/p/v8/issues/detail?id=3056
  		var test2 = {};
  		for (var i = 0; i < 10; i++) {
  			test2['_' + String.fromCharCode(i)] = i;
  		}
  		var order2 = Object.getOwnPropertyNames(test2).map(function (n) {
  			return test2[n];
  		});
  		if (order2.join('') !== '0123456789') {
  			return false;
  		}

  		// https://bugs.chromium.org/p/v8/issues/detail?id=3056
  		var test3 = {};
  		'abcdefghijklmnopqrst'.split('').forEach(function (letter) {
  			test3[letter] = letter;
  		});
  		if (Object.keys(Object.assign({}, test3)).join('') !==
  				'abcdefghijklmnopqrst') {
  			return false;
  		}

  		return true;
  	} catch (err) {
  		// We don't expect any of the above to throw, but better to be safe.
  		return false;
  	}
  }

  var objectAssign = shouldUseNative() ? Object.assign : function (target, source) {
  	var from;
  	var to = toObject(target);
  	var symbols;

  	for (var s = 1; s < arguments.length; s++) {
  		from = Object(arguments[s]);

  		for (var key in from) {
  			if (hasOwnProperty$1.call(from, key)) {
  				to[key] = from[key];
  			}
  		}

  		if (getOwnPropertySymbols) {
  			symbols = getOwnPropertySymbols(from);
  			for (var i = 0; i < symbols.length; i++) {
  				if (propIsEnumerable.call(from, symbols[i])) {
  					to[symbols[i]] = from[symbols[i]];
  				}
  			}
  		}
  	}

  	return to;
  };

  /**
   * Copyright (c) 2013-present, Facebook, Inc.
   *
   * This source code is licensed under the MIT license found in the
   * LICENSE file in the root directory of this source tree.
   */

  var ReactPropTypesSecret$2 = 'SECRET_DO_NOT_PASS_THIS_OR_YOU_WILL_BE_FIRED';

  var ReactPropTypesSecret_1 = ReactPropTypesSecret$2;

  var has$2 = Function.call.bind(Object.prototype.hasOwnProperty);

  var ReactPropTypesSecret$1 = ReactPropTypesSecret_1;

  var has$1 = has$2;

  /**
   * Copyright (c) 2013-present, Facebook, Inc.
   *
   * This source code is licensed under the MIT license found in the
   * LICENSE file in the root directory of this source tree.
   */

  var printWarning$1 = function() {};

  {
    var ReactPropTypesSecret = ReactPropTypesSecret$1;
    var loggedTypeFailures = {};
    var has = has$1;

    printWarning$1 = function(text) {
      var message = 'Warning: ' + text;
      if (typeof console !== 'undefined') {
        console.error(message);
      }
      try {
        // --- Welcome to debugging React ---
        // This error was thrown as a convenience so that you can use this stack
        // to find the callsite that caused this warning to fire.
        throw new Error(message);
      } catch (x) { /**/ }
    };
  }

  /**
   * Assert that the values match with the type specs.
   * Error messages are memorized and will only be shown once.
   *
   * @param {object} typeSpecs Map of name to a ReactPropType
   * @param {object} values Runtime values that need to be type-checked
   * @param {string} location e.g. "prop", "context", "child context"
   * @param {string} componentName Name of the component for error messages.
   * @param {?Function} getStack Returns the component stack.
   * @private
   */
  function checkPropTypes$1(typeSpecs, values, location, componentName, getStack) {
    {
      for (var typeSpecName in typeSpecs) {
        if (has(typeSpecs, typeSpecName)) {
          var error;
          // Prop type validation may throw. In case they do, we don't want to
          // fail the render phase where it didn't fail before. So we log it.
          // After these have been cleaned up, we'll let them throw.
          try {
            // This is intentionally an invariant that gets caught. It's the same
            // behavior as without this statement except with a better message.
            if (typeof typeSpecs[typeSpecName] !== 'function') {
              var err = Error(
                (componentName || 'React class') + ': ' + location + ' type `' + typeSpecName + '` is invalid; ' +
                'it must be a function, usually from the `prop-types` package, but received `' + typeof typeSpecs[typeSpecName] + '`.' +
                'This often happens because of typos such as `PropTypes.function` instead of `PropTypes.func`.'
              );
              err.name = 'Invariant Violation';
              throw err;
            }
            error = typeSpecs[typeSpecName](values, typeSpecName, componentName, location, null, ReactPropTypesSecret);
          } catch (ex) {
            error = ex;
          }
          if (error && !(error instanceof Error)) {
            printWarning$1(
              (componentName || 'React class') + ': type specification of ' +
              location + ' `' + typeSpecName + '` is invalid; the type checker ' +
              'function must return `null` or an `Error` but returned a ' + typeof error + '. ' +
              'You may have forgotten to pass an argument to the type checker ' +
              'creator (arrayOf, instanceOf, objectOf, oneOf, oneOfType, and ' +
              'shape all require an argument).'
            );
          }
          if (error instanceof Error && !(error.message in loggedTypeFailures)) {
            // Only monitor this failure once because there tends to be a lot of the
            // same error.
            loggedTypeFailures[error.message] = true;

            var stack = getStack ? getStack() : '';

            printWarning$1(
              'Failed ' + location + ' type: ' + error.message + (stack != null ? stack : '')
            );
          }
        }
      }
    }
  }

  /**
   * Resets warning cache when testing.
   *
   * @private
   */
  checkPropTypes$1.resetWarningCache = function() {
    {
      loggedTypeFailures = {};
    }
  };

  var checkPropTypes_1 = checkPropTypes$1;

  var checkPropTypes = checkPropTypes_1;

  /**
   * Copyright (c) 2013-present, Facebook, Inc.
   *
   * This source code is licensed under the MIT license found in the
   * LICENSE file in the root directory of this source tree.
   */








  var printWarning = function() {};

  {
    printWarning = function(text) {
      var message = 'Warning: ' + text;
      if (typeof console !== 'undefined') {
        console.error(message);
      }
      try {
        // --- Welcome to debugging React ---
        // This error was thrown as a convenience so that you can use this stack
        // to find the callsite that caused this warning to fire.
        throw new Error(message);
      } catch (x) {}
    };
  }

  function emptyFunctionThatReturnsNull() {
    return null;
  }

  var factoryWithTypeCheckers = function(isValidElement, throwOnDirectAccess) {
    /* global Symbol */
    var ITERATOR_SYMBOL = typeof Symbol === 'function' && Symbol.iterator;
    var FAUX_ITERATOR_SYMBOL = '@@iterator'; // Before Symbol spec.

    /**
     * Returns the iterator method function contained on the iterable object.
     *
     * Be sure to invoke the function with the iterable as context:
     *
     *     var iteratorFn = getIteratorFn(myIterable);
     *     if (iteratorFn) {
     *       var iterator = iteratorFn.call(myIterable);
     *       ...
     *     }
     *
     * @param {?object} maybeIterable
     * @return {?function}
     */
    function getIteratorFn(maybeIterable) {
      var iteratorFn = maybeIterable && (ITERATOR_SYMBOL && maybeIterable[ITERATOR_SYMBOL] || maybeIterable[FAUX_ITERATOR_SYMBOL]);
      if (typeof iteratorFn === 'function') {
        return iteratorFn;
      }
    }

    /**
     * Collection of methods that allow declaration and validation of props that are
     * supplied to React components. Example usage:
     *
     *   var Props = require('ReactPropTypes');
     *   var MyArticle = React.createClass({
     *     propTypes: {
     *       // An optional string prop named "description".
     *       description: Props.string,
     *
     *       // A required enum prop named "category".
     *       category: Props.oneOf(['News','Photos']).isRequired,
     *
     *       // A prop named "dialog" that requires an instance of Dialog.
     *       dialog: Props.instanceOf(Dialog).isRequired
     *     },
     *     render: function() { ... }
     *   });
     *
     * A more formal specification of how these methods are used:
     *
     *   type := array|bool|func|object|number|string|oneOf([...])|instanceOf(...)
     *   decl := ReactPropTypes.{type}(.isRequired)?
     *
     * Each and every declaration produces a function with the same signature. This
     * allows the creation of custom validation functions. For example:
     *
     *  var MyLink = React.createClass({
     *    propTypes: {
     *      // An optional string or URI prop named "href".
     *      href: function(props, propName, componentName) {
     *        var propValue = props[propName];
     *        if (propValue != null && typeof propValue !== 'string' &&
     *            !(propValue instanceof URI)) {
     *          return new Error(
     *            'Expected a string or an URI for ' + propName + ' in ' +
     *            componentName
     *          );
     *        }
     *      }
     *    },
     *    render: function() {...}
     *  });
     *
     * @internal
     */

    var ANONYMOUS = '<<anonymous>>';

    // Important!
    // Keep this list in sync with production version in `./factoryWithThrowingShims.js`.
    var ReactPropTypes = {
      array: createPrimitiveTypeChecker('array'),
      bigint: createPrimitiveTypeChecker('bigint'),
      bool: createPrimitiveTypeChecker('boolean'),
      func: createPrimitiveTypeChecker('function'),
      number: createPrimitiveTypeChecker('number'),
      object: createPrimitiveTypeChecker('object'),
      string: createPrimitiveTypeChecker('string'),
      symbol: createPrimitiveTypeChecker('symbol'),

      any: createAnyTypeChecker(),
      arrayOf: createArrayOfTypeChecker,
      element: createElementTypeChecker(),
      elementType: createElementTypeTypeChecker(),
      instanceOf: createInstanceTypeChecker,
      node: createNodeChecker(),
      objectOf: createObjectOfTypeChecker,
      oneOf: createEnumTypeChecker,
      oneOfType: createUnionTypeChecker,
      shape: createShapeTypeChecker,
      exact: createStrictShapeTypeChecker,
    };

    /**
     * inlined Object.is polyfill to avoid requiring consumers ship their own
     * https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object/is
     */
    /*eslint-disable no-self-compare*/
    function is(x, y) {
      // SameValue algorithm
      if (x === y) {
        // Steps 1-5, 7-10
        // Steps 6.b-6.e: +0 != -0
        return x !== 0 || 1 / x === 1 / y;
      } else {
        // Step 6.a: NaN == NaN
        return x !== x && y !== y;
      }
    }
    /*eslint-enable no-self-compare*/

    /**
     * We use an Error-like object for backward compatibility as people may call
     * PropTypes directly and inspect their output. However, we don't use real
     * Errors anymore. We don't inspect their stack anyway, and creating them
     * is prohibitively expensive if they are created too often, such as what
     * happens in oneOfType() for any type before the one that matched.
     */
    function PropTypeError(message, data) {
      this.message = message;
      this.data = data && typeof data === 'object' ? data: {};
      this.stack = '';
    }
    // Make `instanceof Error` still work for returned errors.
    PropTypeError.prototype = Error.prototype;

    function createChainableTypeChecker(validate) {
      {
        var manualPropTypeCallCache = {};
        var manualPropTypeWarningCount = 0;
      }
      function checkType(isRequired, props, propName, componentName, location, propFullName, secret) {
        componentName = componentName || ANONYMOUS;
        propFullName = propFullName || propName;

        if (secret !== ReactPropTypesSecret$1) {
          if (throwOnDirectAccess) {
            // New behavior only for users of `prop-types` package
            var err = new Error(
              'Calling PropTypes validators directly is not supported by the `prop-types` package. ' +
              'Use `PropTypes.checkPropTypes()` to call them. ' +
              'Read more at http://fb.me/use-check-prop-types'
            );
            err.name = 'Invariant Violation';
            throw err;
          } else if (typeof console !== 'undefined') {
            // Old behavior for people using React.PropTypes
            var cacheKey = componentName + ':' + propName;
            if (
              !manualPropTypeCallCache[cacheKey] &&
              // Avoid spamming the console because they are often not actionable except for lib authors
              manualPropTypeWarningCount < 3
            ) {
              printWarning(
                'You are manually calling a React.PropTypes validation ' +
                'function for the `' + propFullName + '` prop on `' + componentName + '`. This is deprecated ' +
                'and will throw in the standalone `prop-types` package. ' +
                'You may be seeing this warning due to a third-party PropTypes ' +
                'library. See https://fb.me/react-warning-dont-call-proptypes ' + 'for details.'
              );
              manualPropTypeCallCache[cacheKey] = true;
              manualPropTypeWarningCount++;
            }
          }
        }
        if (props[propName] == null) {
          if (isRequired) {
            if (props[propName] === null) {
              return new PropTypeError('The ' + location + ' `' + propFullName + '` is marked as required ' + ('in `' + componentName + '`, but its value is `null`.'));
            }
            return new PropTypeError('The ' + location + ' `' + propFullName + '` is marked as required in ' + ('`' + componentName + '`, but its value is `undefined`.'));
          }
          return null;
        } else {
          return validate(props, propName, componentName, location, propFullName);
        }
      }

      var chainedCheckType = checkType.bind(null, false);
      chainedCheckType.isRequired = checkType.bind(null, true);

      return chainedCheckType;
    }

    function createPrimitiveTypeChecker(expectedType) {
      function validate(props, propName, componentName, location, propFullName, secret) {
        var propValue = props[propName];
        var propType = getPropType(propValue);
        if (propType !== expectedType) {
          // `propValue` being instance of, say, date/regexp, pass the 'object'
          // check, but we can offer a more precise error message here rather than
          // 'of type `object`'.
          var preciseType = getPreciseType(propValue);

          return new PropTypeError(
            'Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + preciseType + '` supplied to `' + componentName + '`, expected ') + ('`' + expectedType + '`.'),
            {expectedType: expectedType}
          );
        }
        return null;
      }
      return createChainableTypeChecker(validate);
    }

    function createAnyTypeChecker() {
      return createChainableTypeChecker(emptyFunctionThatReturnsNull);
    }

    function createArrayOfTypeChecker(typeChecker) {
      function validate(props, propName, componentName, location, propFullName) {
        if (typeof typeChecker !== 'function') {
          return new PropTypeError('Property `' + propFullName + '` of component `' + componentName + '` has invalid PropType notation inside arrayOf.');
        }
        var propValue = props[propName];
        if (!Array.isArray(propValue)) {
          var propType = getPropType(propValue);
          return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + propType + '` supplied to `' + componentName + '`, expected an array.'));
        }
        for (var i = 0; i < propValue.length; i++) {
          var error = typeChecker(propValue, i, componentName, location, propFullName + '[' + i + ']', ReactPropTypesSecret$1);
          if (error instanceof Error) {
            return error;
          }
        }
        return null;
      }
      return createChainableTypeChecker(validate);
    }

    function createElementTypeChecker() {
      function validate(props, propName, componentName, location, propFullName) {
        var propValue = props[propName];
        if (!isValidElement(propValue)) {
          var propType = getPropType(propValue);
          return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + propType + '` supplied to `' + componentName + '`, expected a single ReactElement.'));
        }
        return null;
      }
      return createChainableTypeChecker(validate);
    }

    function createElementTypeTypeChecker() {
      function validate(props, propName, componentName, location, propFullName) {
        var propValue = props[propName];
        if (!reactIs.isValidElementType(propValue)) {
          var propType = getPropType(propValue);
          return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + propType + '` supplied to `' + componentName + '`, expected a single ReactElement type.'));
        }
        return null;
      }
      return createChainableTypeChecker(validate);
    }

    function createInstanceTypeChecker(expectedClass) {
      function validate(props, propName, componentName, location, propFullName) {
        if (!(props[propName] instanceof expectedClass)) {
          var expectedClassName = expectedClass.name || ANONYMOUS;
          var actualClassName = getClassName(props[propName]);
          return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + actualClassName + '` supplied to `' + componentName + '`, expected ') + ('instance of `' + expectedClassName + '`.'));
        }
        return null;
      }
      return createChainableTypeChecker(validate);
    }

    function createEnumTypeChecker(expectedValues) {
      if (!Array.isArray(expectedValues)) {
        {
          if (arguments.length > 1) {
            printWarning(
              'Invalid arguments supplied to oneOf, expected an array, got ' + arguments.length + ' arguments. ' +
              'A common mistake is to write oneOf(x, y, z) instead of oneOf([x, y, z]).'
            );
          } else {
            printWarning('Invalid argument supplied to oneOf, expected an array.');
          }
        }
        return emptyFunctionThatReturnsNull;
      }

      function validate(props, propName, componentName, location, propFullName) {
        var propValue = props[propName];
        for (var i = 0; i < expectedValues.length; i++) {
          if (is(propValue, expectedValues[i])) {
            return null;
          }
        }

        var valuesString = JSON.stringify(expectedValues, function replacer(key, value) {
          var type = getPreciseType(value);
          if (type === 'symbol') {
            return String(value);
          }
          return value;
        });
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of value `' + String(propValue) + '` ' + ('supplied to `' + componentName + '`, expected one of ' + valuesString + '.'));
      }
      return createChainableTypeChecker(validate);
    }

    function createObjectOfTypeChecker(typeChecker) {
      function validate(props, propName, componentName, location, propFullName) {
        if (typeof typeChecker !== 'function') {
          return new PropTypeError('Property `' + propFullName + '` of component `' + componentName + '` has invalid PropType notation inside objectOf.');
        }
        var propValue = props[propName];
        var propType = getPropType(propValue);
        if (propType !== 'object') {
          return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + propType + '` supplied to `' + componentName + '`, expected an object.'));
        }
        for (var key in propValue) {
          if (has$1(propValue, key)) {
            var error = typeChecker(propValue, key, componentName, location, propFullName + '.' + key, ReactPropTypesSecret$1);
            if (error instanceof Error) {
              return error;
            }
          }
        }
        return null;
      }
      return createChainableTypeChecker(validate);
    }

    function createUnionTypeChecker(arrayOfTypeCheckers) {
      if (!Array.isArray(arrayOfTypeCheckers)) {
        printWarning('Invalid argument supplied to oneOfType, expected an instance of array.') ;
        return emptyFunctionThatReturnsNull;
      }

      for (var i = 0; i < arrayOfTypeCheckers.length; i++) {
        var checker = arrayOfTypeCheckers[i];
        if (typeof checker !== 'function') {
          printWarning(
            'Invalid argument supplied to oneOfType. Expected an array of check functions, but ' +
            'received ' + getPostfixForTypeWarning(checker) + ' at index ' + i + '.'
          );
          return emptyFunctionThatReturnsNull;
        }
      }

      function validate(props, propName, componentName, location, propFullName) {
        var expectedTypes = [];
        for (var i = 0; i < arrayOfTypeCheckers.length; i++) {
          var checker = arrayOfTypeCheckers[i];
          var checkerResult = checker(props, propName, componentName, location, propFullName, ReactPropTypesSecret$1);
          if (checkerResult == null) {
            return null;
          }
          if (checkerResult.data && has$1(checkerResult.data, 'expectedType')) {
            expectedTypes.push(checkerResult.data.expectedType);
          }
        }
        var expectedTypesMessage = (expectedTypes.length > 0) ? ', expected one of type [' + expectedTypes.join(', ') + ']': '';
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` supplied to ' + ('`' + componentName + '`' + expectedTypesMessage + '.'));
      }
      return createChainableTypeChecker(validate);
    }

    function createNodeChecker() {
      function validate(props, propName, componentName, location, propFullName) {
        if (!isNode(props[propName])) {
          return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` supplied to ' + ('`' + componentName + '`, expected a ReactNode.'));
        }
        return null;
      }
      return createChainableTypeChecker(validate);
    }

    function invalidValidatorError(componentName, location, propFullName, key, type) {
      return new PropTypeError(
        (componentName || 'React class') + ': ' + location + ' type `' + propFullName + '.' + key + '` is invalid; ' +
        'it must be a function, usually from the `prop-types` package, but received `' + type + '`.'
      );
    }

    function createShapeTypeChecker(shapeTypes) {
      function validate(props, propName, componentName, location, propFullName) {
        var propValue = props[propName];
        var propType = getPropType(propValue);
        if (propType !== 'object') {
          return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type `' + propType + '` ' + ('supplied to `' + componentName + '`, expected `object`.'));
        }
        for (var key in shapeTypes) {
          var checker = shapeTypes[key];
          if (typeof checker !== 'function') {
            return invalidValidatorError(componentName, location, propFullName, key, getPreciseType(checker));
          }
          var error = checker(propValue, key, componentName, location, propFullName + '.' + key, ReactPropTypesSecret$1);
          if (error) {
            return error;
          }
        }
        return null;
      }
      return createChainableTypeChecker(validate);
    }

    function createStrictShapeTypeChecker(shapeTypes) {
      function validate(props, propName, componentName, location, propFullName) {
        var propValue = props[propName];
        var propType = getPropType(propValue);
        if (propType !== 'object') {
          return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type `' + propType + '` ' + ('supplied to `' + componentName + '`, expected `object`.'));
        }
        // We need to check all keys in case some are required but missing from props.
        var allKeys = objectAssign({}, props[propName], shapeTypes);
        for (var key in allKeys) {
          var checker = shapeTypes[key];
          if (has$1(shapeTypes, key) && typeof checker !== 'function') {
            return invalidValidatorError(componentName, location, propFullName, key, getPreciseType(checker));
          }
          if (!checker) {
            return new PropTypeError(
              'Invalid ' + location + ' `' + propFullName + '` key `' + key + '` supplied to `' + componentName + '`.' +
              '\nBad object: ' + JSON.stringify(props[propName], null, '  ') +
              '\nValid keys: ' + JSON.stringify(Object.keys(shapeTypes), null, '  ')
            );
          }
          var error = checker(propValue, key, componentName, location, propFullName + '.' + key, ReactPropTypesSecret$1);
          if (error) {
            return error;
          }
        }
        return null;
      }

      return createChainableTypeChecker(validate);
    }

    function isNode(propValue) {
      switch (typeof propValue) {
        case 'number':
        case 'string':
        case 'undefined':
          return true;
        case 'boolean':
          return !propValue;
        case 'object':
          if (Array.isArray(propValue)) {
            return propValue.every(isNode);
          }
          if (propValue === null || isValidElement(propValue)) {
            return true;
          }

          var iteratorFn = getIteratorFn(propValue);
          if (iteratorFn) {
            var iterator = iteratorFn.call(propValue);
            var step;
            if (iteratorFn !== propValue.entries) {
              while (!(step = iterator.next()).done) {
                if (!isNode(step.value)) {
                  return false;
                }
              }
            } else {
              // Iterator will provide entry [k,v] tuples rather than values.
              while (!(step = iterator.next()).done) {
                var entry = step.value;
                if (entry) {
                  if (!isNode(entry[1])) {
                    return false;
                  }
                }
              }
            }
          } else {
            return false;
          }

          return true;
        default:
          return false;
      }
    }

    function isSymbol(propType, propValue) {
      // Native Symbol.
      if (propType === 'symbol') {
        return true;
      }

      // falsy value can't be a Symbol
      if (!propValue) {
        return false;
      }

      // 19.4.3.5 Symbol.prototype[@@toStringTag] === 'Symbol'
      if (propValue['@@toStringTag'] === 'Symbol') {
        return true;
      }

      // Fallback for non-spec compliant Symbols which are polyfilled.
      if (typeof Symbol === 'function' && propValue instanceof Symbol) {
        return true;
      }

      return false;
    }

    // Equivalent of `typeof` but with special handling for array and regexp.
    function getPropType(propValue) {
      var propType = typeof propValue;
      if (Array.isArray(propValue)) {
        return 'array';
      }
      if (propValue instanceof RegExp) {
        // Old webkits (at least until Android 4.0) return 'function' rather than
        // 'object' for typeof a RegExp. We'll normalize this here so that /bla/
        // passes PropTypes.object.
        return 'object';
      }
      if (isSymbol(propType, propValue)) {
        return 'symbol';
      }
      return propType;
    }

    // This handles more types than `getPropType`. Only used for error messages.
    // See `createPrimitiveTypeChecker`.
    function getPreciseType(propValue) {
      if (typeof propValue === 'undefined' || propValue === null) {
        return '' + propValue;
      }
      var propType = getPropType(propValue);
      if (propType === 'object') {
        if (propValue instanceof Date) {
          return 'date';
        } else if (propValue instanceof RegExp) {
          return 'regexp';
        }
      }
      return propType;
    }

    // Returns a string that is postfixed to a warning about an invalid type.
    // For example, "undefined" or "of type array"
    function getPostfixForTypeWarning(value) {
      var type = getPreciseType(value);
      switch (type) {
        case 'array':
        case 'object':
          return 'an ' + type;
        case 'boolean':
        case 'date':
        case 'regexp':
          return 'a ' + type;
        default:
          return type;
      }
    }

    // Returns class name of the object, if any.
    function getClassName(propValue) {
      if (!propValue.constructor || !propValue.constructor.name) {
        return ANONYMOUS;
      }
      return propValue.constructor.name;
    }

    ReactPropTypes.checkPropTypes = checkPropTypes;
    ReactPropTypes.resetWarningCache = checkPropTypes.resetWarningCache;
    ReactPropTypes.PropTypes = ReactPropTypes;

    return ReactPropTypes;
  };

  var require$$1 = factoryWithTypeCheckers;

  /**
   * Copyright (c) 2013-present, Facebook, Inc.
   *
   * This source code is licensed under the MIT license found in the
   * LICENSE file in the root directory of this source tree.
   */

  var propTypes$1r = createCommonjsModule(function (module) {
  {
    var ReactIs = reactIs;

    // By explicitly using `prop-types` you are opting into new development behavior.
    // http://fb.me/prop-types-in-prod
    var throwOnDirectAccess = true;
    module.exports = require$$1(ReactIs.isElement, throwOnDirectAccess);
  }
  });

  var PropTypes = propTypes$1r;

  function useViewport(initialViewport) {
    var _useState = React.useState(initialViewport),
        _useState2 = _slicedToArray(_useState, 2),
        viewport = _useState2[0],
        setViewport = _useState2[1];

    var breakpoints = StyleSheet.value('grid-breakpoints');

    var calculateViewport = function calculateViewport(width) {
      if (width < breakpoints.sm) {
        return 'xs';
      }

      if (width < breakpoints.md) {
        return 'sm';
      }

      if (width < breakpoints.lg) {
        return 'md';
      }

      if (width < breakpoints.xl) {
        return 'lg';
      }

      return 'xl';
    };

    var handleChange = function handleChange(dimensions) {
      var nextViewport = calculateViewport(dimensions.window.width);

      if (viewport !== nextViewport) {
        setViewport(nextViewport);
      }
    }; // Initially determine viewport after mounting.


    React.useEffect(function () {
      handleChange({
        window: _reactNative.Dimensions.get('window')
      });
    }, []);
    React.useEffect(function () {
      var subscription = _reactNative.Dimensions.addEventListener('change', handleChange);
      return function () {
        subscription.remove();
      };
    }, [viewport]);
    return viewport;
  }

  var propTypes$1q = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types,
    utilities: PropTypes.object,
    // eslint-disable-next-line react/forbid-prop-types,
    modifiers: PropTypes.object,
    ssrViewport: PropTypes.string
  };

  function Provider(props) {
    var children = props.children,
        _props$utilities = props.utilities,
        utilities = _props$utilities === void 0 ? {} : _props$utilities,
        _props$modifiers = props.modifiers,
        modifiers = _props$modifiers === void 0 ? {} : _props$modifiers,
        ssrViewport = props.ssrViewport;
    var viewport = useViewport(ssrViewport);
    var counter = React.useRef(0);
    var context = {
      utilities: utilities,
      modifiers: modifiers,
      getViewport: function getViewport() {
        return viewport;
      },
      generateKey: function generateKey(prefix) {
        counter.current += 1;
        return "ui-".concat(prefix, "-").concat(counter.current);
      }
    };
    return /*#__PURE__*/React__default["default"].createElement(Context.Provider, {
      value: context
    }, /*#__PURE__*/React__default["default"].createElement(OverlayProvider, null, children));
  }

  Provider.propTypes = propTypes$1q;

  var TextStyleContext = /*#__PURE__*/React__default["default"].createContext();
  TextStyleContext.displayName = 'TextStyleContext';

  function useMedia() {
    var context = React.useContext(Context);
    var viewport = context.getViewport();
    var breakpoints = StyleSheet.value('grid-breakpoints');
    var breakpointKeys = Object.keys(breakpoints);
    return {
      up: function up(point) {
        return breakpointKeys.indexOf(viewport) >= breakpointKeys.indexOf(point);
      },
      down: function down(point) {
        return breakpointKeys.indexOf(viewport) <= breakpointKeys.indexOf(point);
      },
      only: function only(point) {
        return viewport === point;
      },
      between: function between(lower, upper) {
        return this.up(lower) && this.down(upper);
      }
    };
  }

  var normalize = function normalize(style) {
    if (!Array.isArray(style)) {
      return [style];
    }

    return style.filter(function (val) {
      return !!val;
    }).reduce(function (res, val) {
      return [].concat(_toConsumableArray(res), _toConsumableArray(normalize(val)));
    }, []);
  };

  function useStyle(style, styleName) {
    var _useContext = React.useContext(Context),
        utilitiesStyles = _useContext.utilities;

    var utilities = React.useMemo(function () {
      if (!styleName) {
        return null;
      }

      var names = styleName.split(' ');
      return names.map(function (name) {
        if (!utilitiesStyles[name]) {
          throw new Error("Unknown utility style \"".concat(name, "\"."));
        }

        return utilitiesStyles[name];
      });
    }, [styleName]);
    var styles = normalize(utilities ? [style].concat(_toConsumableArray(utilities)) : style);
    return function (state) {
      var basicStyles = [];
      var interactionStyles = [];
      styles.forEach(function (value) {
        if (value && value.$$typeof === BOOTSTRAP_RN_STYLE) {
          // Style is a bootstrap style that contains basic and interaction styles.
          var _value = value(state),
              _value2 = _slicedToArray(_value, 2),
              resolvedBasicStyles = _value2[0],
              resolvedInteractionStyles = _value2[1];

          basicStyles.push.apply(basicStyles, _toConsumableArray(resolvedBasicStyles));
          interactionStyles.push.apply(interactionStyles, _toConsumableArray(resolvedInteractionStyles));
        } else if (typeof value === 'function') {
          // Style is some other custom function type style.
          basicStyles.push(value(state));
        } else {
          // Style is basic object style.
          basicStyles.push(value);
        }
      }); // Put basic styles first, then interaction styles for hover, focus, pressed.

      return [].concat(basicStyles, interactionStyles);
    };
  }

  var _excluded$1r = ["children", "style", "textStyle", "styleName"];
  var propTypes$1p = {
    children: PropTypes.node,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    styleName: PropTypes.any
  };
  var View = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        styleName = props.styleName,
        elementProps = _objectWithoutProperties(props, _excluded$1r);

    var media = useMedia();
    var context = React.useContext(TextStyleContext);
    var resolveStyle = useStyle(style, styleName);
    var resolveTextStyle = useStyle([context && context.style, textStyle]);
    var hasTextStyle = context && context.style || textStyle;
    return /*#__PURE__*/React__default["default"].createElement(_reactNative.View, _extends$1({}, elementProps, {
      ref: ref,
      style: resolveStyle({
        media: media
      })
    }), hasTextStyle ? /*#__PURE__*/React__default["default"].createElement(TextStyleContext.Provider, {
      value: {
        style: resolveTextStyle({
          media: media
        }),
        hasAncestor: context && context.hasTextAncestor
      }
    }, children) : children);
  });
  View.displayName = 'View';
  View.propTypes = propTypes$1p;

  var _excluded$1q = ["children", "color", "dismissible", "style", "textStyle"];

  var _templateObject$19, _templateObject2$R, _templateObject3$q;
  var propTypes$1o = {
    children: PropTypes.node.isRequired,
    color: PropTypes.oneOf(Object.keys(THEME_COLORS)),
    dismissible: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$18 = StyleSheet.create(_objectSpread2(_objectSpread2({
    '.alert': css$1(_templateObject$19 || (_templateObject$19 = _taggedTemplateLiteral(["\n    position: relative;\n    padding: $alert-padding-y $alert-padding-x;\n    margin-bottom: $alert-margin-bottom;\n    background-color: transparent;\n    border: $alert-border-width solid transparent;\n    border-radius: $alert-border-radius;\n  "])))
  }, each(THEME_COLORS, function (state, value) {
    var _ref;

    return _ref = {}, _defineProperty(_ref, ".alert-".concat(state), css$1(_templateObject2$R || (_templateObject2$R = _taggedTemplateLiteral(["\n      background-color: ", ";\n      border-color: ", ";\n    "])), shiftColor(function (t) {
      return t['alert-bg-scale'];
    }, value), shiftColor(function (t) {
      return t['alert-border-scale'];
    }, value))), _defineProperty(_ref, ".alert-".concat(state, "-text"), css$1(_templateObject3$q || (_templateObject3$q = _taggedTemplateLiteral(["\n      color: ", ";\n    "])), shiftColor(function (t) {
      return t['alert-color-scale'];
    }, value))), _ref;
  })), {}, {
    '.alert-dismissible': {// TODO
    }
  }));
  var Alert = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        _props$color = props.color,
        color = _props$color === void 0 ? 'primary' : _props$color,
        _props$dismissible = props.dismissible,
        dismissible = _props$dismissible === void 0 ? false : _props$dismissible,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$1q);

    var classes = getStyles(styles$18, ['.alert', ".alert-".concat(color), dismissible && '.alert-dismissible']);
    var textClasses = getStyles(styles$18, [".alert-".concat(color, "-text")]);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: "alert",
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children);
  });
  Alert.displayName = 'Alert';
  Alert.propTypes = propTypes$1o;

  var _excluded$1p = ["children", "style", "textStyle"];

  var _templateObject$18, _templateObject2$Q;
  var propTypes$1n = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$17 = StyleSheet.create({
    '.badge': css$1(_templateObject$18 || (_templateObject$18 = _taggedTemplateLiteral(["\n    // display: inline-block;\n    padding: $badge-padding-y $badge-padding-x;\n    border-radius: $badge-border-radius;\n    // @include gradient-bg();\n  "]))),
    '.badge-text': css$1(_templateObject2$Q || (_templateObject2$Q = _taggedTemplateLiteral(["\n    font-size: $badge-font-size;\n    font-weight: $badge-font-weight;\n    line-height: $badge-font-size * 1;\n    color: $badge-color;\n    text-align: center;\n    // white-space: nowrap;\n    // vertical-align: baseline;\n  "])))
  });
  var Badge = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$1p);

    var classes = getStyles(styles$17, ['.badge']);
    var textClasses = getStyles(styles$17, ['.badge-text']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children);
  });
  Badge.displayName = 'Badge';
  Badge.propTypes = propTypes$1n;

  var _excluded$1o = ["children", "active", "style", "textStyle"];

  var _templateObject$17, _templateObject2$P, _templateObject3$p;
  var propTypes$1m = {
    children: PropTypes.node.isRequired,
    active: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$16 = StyleSheet.create({
    '.breadcrumb-item': css$1(_templateObject$17 || (_templateObject$17 = _taggedTemplateLiteral(["\n    padding-left: $breadcrumb-item-padding-x;\n    padding-right: $breadcrumb-item-padding-x;\n  "]))),
    '.breadcrumb-text': css$1(_templateObject2$P || (_templateObject2$P = _taggedTemplateLiteral(["\n    color: $primary;\n  "]))),
    '.breadcrumb-item-active': css$1(_templateObject3$p || (_templateObject3$p = _taggedTemplateLiteral(["\n    color: $breadcrumb-active-color;\n  "])))
  });
  var BreadcrumbItem = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        _props$active = props.active,
        active = _props$active === void 0 ? false : _props$active,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$1o);

    var classes = getStyles(styles$16, ['.breadcrumb-item', active && '.breadcrumb-item-active']);
    var textClasses = getStyles(styles$16, ['.breadcrumb-text', active && '.breadcrumb-item-active']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children);
  });
  BreadcrumbItem.displayName = 'BreadcrumbItem';
  BreadcrumbItem.propTypes = propTypes$1m;
  /*
  $breadcrumb-font-size:              null;
  $breadcrumb-padding-y:              0;
  $breadcrumb-padding-x:              0;
  $breadcrumb-item-padding-x:         .5rem;
  $breadcrumb-margin-bottom:          1rem;
  $breadcrumb-bg:                     null;
  $breadcrumb-divider-color:          $gray-600;
  $breadcrumb-active-color:           $gray-600;
  $breadcrumb-divider:                quote("/");
  $breadcrumb-divider-flipped:        $breadcrumb-divider;
  $breadcrumb-border-radius:          null;
  */

  var _excluded$1n = ["children", "style"];

  var _templateObject$16;
  var propTypes$1l = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$15 = StyleSheet.create({
    '.breadcrumb': css$1(_templateObject$16 || (_templateObject$16 = _taggedTemplateLiteral(["\n    flex-direction: row;\n  "])))
  });
  var Breadcrumb = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$1n);

    var classes = getStyles(styles$15, ['.breadcrumb']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), makeListChildren(children));
  });
  Breadcrumb.displayName = 'Breadcrumb';
  Breadcrumb.propTypes = propTypes$1l;
  Breadcrumb.Item = BreadcrumbItem;
  /*
  $breadcrumb-font-size:              null;
  $breadcrumb-padding-y:              0;
  $breadcrumb-padding-x:              0;
  $breadcrumb-item-padding-x:         .5rem;
  $breadcrumb-margin-bottom:          1rem;
  $breadcrumb-bg:                     null;
  $breadcrumb-divider-color:          $gray-600;
  $breadcrumb-active-color:           $gray-600;
  $breadcrumb-divider:                quote("/");
  $breadcrumb-divider-flipped:        $breadcrumb-divider;
  $breadcrumb-border-radius:          null;
  */

  var ButtonGroupContext = /*#__PURE__*/React__default["default"].createContext();
  ButtonGroupContext.displayName = 'ButtonGroupContext';

  var _excluded$1m = ["children", "size", "style"];

  var _templateObject$15;
  var propTypes$1k = {
    children: PropTypes.node.isRequired,
    size: PropTypes.oneOf(['lg', 'sm']),
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$14 = StyleSheet.create({
    '.btn-group': css$1(_templateObject$15 || (_templateObject$15 = _taggedTemplateLiteral(["\n    flex-direction: row; // added for bootstrap-rn\n    border-radius: $btn-border-radius;\n  "])))
  });
  var ButtonGroup = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        size = props.size,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$1m);

    var classes = getStyles(styles$14, ['.btn-group']); // Accessiblity role tabpanel is only supported on web.

    var role = _reactNative.Platform.OS === 'web' ? 'group' : null;
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: role,
      style: [classes, style]
    }), /*#__PURE__*/React__default["default"].createElement(ButtonGroupContext.Provider, {
      value: {
        size: size
      }
    }, makeListChildren(children)));
  });
  ButtonGroup.displayName = 'ButtonGroup';
  ButtonGroup.propTypes = propTypes$1k;

  var _excluded$1l = ["children", "style"];

  var _templateObject$14;
  var propTypes$1j = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$13 = StyleSheet.create({
    '.btn-toolbar': css$1(_templateObject$14 || (_templateObject$14 = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: row; // added for bootstrap-rn\n    flex-wrap: wrap;\n    justify-content: flex-start;\n  "])))
  });
  var ButtonToolbar = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$1l);

    var classes = getStyles(styles$13, ['.btn-toolbar']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: "toolbar",
      style: [classes, style]
    }), children);
  });
  ButtonToolbar.displayName = 'ButtonToolbar';
  ButtonToolbar.propTypes = propTypes$1j;

  var prefix = 'Invariant failed';
  function invariant(condition, message) {
      if (condition) {
          return;
      }
      var provided = typeof message === 'function' ? message() : message;
      var value = provided ? prefix + ": " + provided : prefix;
      throw new Error(value);
  }

  function useForcedContext(Context) {
    var context = React.useContext(Context);
    invariant(context, "Failed to get context \"".concat(Context.displayName, "\"."));
    return context;
  }

  var _excluded$1k = ["ref"];
  function useModifier(name, props, ref) {
    var context = useForcedContext(Context);
    var useModifierHook = context.modifiers[name];

    if (!useModifier) {
      return [props, ref];
    }

    var _useModifierHook = useModifierHook(props),
        modifierRef = _useModifierHook.ref,
        modifierProps = _objectWithoutProperties(_useModifierHook, _excluded$1k);

    return [modifierProps, concatRefs(modifierRef, ref)];
  }

  var _excluded$1j = ["toggle", "dismiss"],
      _excluded2$2 = ["ref"];

  var getActionHook = function getActionHook(toggle, dismiss) {
    if (toggle) {
      return toggle.useToggle || toggle;
    }

    if (dismiss) {
      return dismiss.useDismiss || dismiss;
    }

    return null;
  };

  function useAction(props, ref) {
    var toggle = props.toggle,
        dismiss = props.dismiss,
        restProps = _objectWithoutProperties(props, _excluded$1j);

    var useActionHook = getActionHook(toggle, dismiss);

    if (!useActionHook) {
      return [props, ref];
    }

    if (typeof useActionHook !== 'function') {
      throw new Error('Action hook must be of type function.');
    }

    var _useActionHook = useActionHook(restProps),
        actionRef = _useActionHook.ref,
        actionProps = _objectWithoutProperties(_useActionHook, _excluded2$2);

    return [actionProps, concatRefs(actionRef, ref)];
  }

  var _excluded$1i = ["children", "active", "style", "activeStyle", "textStyle", "activeTextStyle", "styleName"];
  var propTypes$1i = {
    children: PropTypes.node,
    active: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    activeStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    activeTextStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    styleName: PropTypes.any
  }; // One of the following should be set for aria support:
  // 1) accessibilityRole
  // 2) accessibilityLabel + accessibilityHint
  // 3) accessibilityActions + onAccessibilityAction

  var getRole$1 = function getRole(props) {
    var accessibilityRole = props.accessibilityRole,
        accessibilityLabel = props.accessibilityLabel,
        accessibilityActions = props.accessibilityActions;

    if (accessibilityRole) {
      return accessibilityRole;
    }

    if (accessibilityLabel || accessibilityActions) {
      return null;
    }

    return 'button';
  };
  var Pressable = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var _useModifier = useModifier('useActionable', props, ref),
        _useModifier2 = _slicedToArray(_useModifier, 2),
        modifierProps = _useModifier2[0],
        modifierRef = _useModifier2[1];

    var _useAction = useAction(modifierProps, modifierRef),
        _useAction2 = _slicedToArray(_useAction, 2),
        actionProps = _useAction2[0],
        actionRef = _useAction2[1];

    var children = actionProps.children,
        _actionProps$active = actionProps.active,
        active = _actionProps$active === void 0 ? false : _actionProps$active,
        style = actionProps.style,
        activeStyle = actionProps.activeStyle,
        textStyle = actionProps.textStyle,
        activeTextStyle = actionProps.activeTextStyle,
        styleName = actionProps.styleName,
        elementProps = _objectWithoutProperties(actionProps, _excluded$1i);

    var media = useMedia();
    var context = React.useContext(TextStyleContext);
    var resolveStyle = useStyle(style, styleName);
    var resolveActiveStyle = useStyle(active && activeStyle);
    var resolveTextStyle = useStyle([context && context.style, textStyle]);
    var resolveActiveTextStyle = useStyle(active && activeTextStyle);
    var hasTextStyle = context && context.style || textStyle;
    return /*#__PURE__*/React__default["default"].createElement(_reactNative.Pressable, _extends$1({}, elementProps, {
      ref: actionRef,
      accessibilityRole: getRole$1(actionProps),
      style: function style(interaction) {
        return [resolveStyle({
          media: media,
          interaction: interaction
        }), resolveActiveStyle({
          media: media,
          interaction: interaction
        })];
      }
    }), hasTextStyle ? function (interaction) {
      return /*#__PURE__*/React__default["default"].createElement(TextStyleContext.Provider, {
        value: {
          style: [resolveTextStyle({
            media: media,
            interaction: interaction
          }), resolveActiveTextStyle({
            media: media,
            interaction: interaction
          })],
          hasAncestor: context && context.hasTextAncestor
        }
      }, children);
    } : children);
  });
  Pressable.displayName = 'Pressable';
  Pressable.propTypes = propTypes$1i;

  var _excluded$1h = ["active", "handlePress"];
  function useToggleButton(props) {
    var active = props.active,
        handlePress = props.handlePress,
        restProps = _objectWithoutProperties(props, _excluded$1h);

    var _useState = React.useState(active),
        _useState2 = _slicedToArray(_useState, 2),
        pressed = _useState2[0],
        setPressed = _useState2[1];

    return _objectSpread2(_objectSpread2({}, restProps), {}, {
      active: pressed,
      onPress: function onPress(event) {
        if (handlePress) handlePress(event);
        setPressed(function (value) {
          return !value;
        });
      },
      accessibilityPressed: pressed
    });
  }

  var _excluded$1g = ["children", "color", "size", "outline", "first", "last", "active", "disabled", "style", "activeStyle", "textStyle", "activeTextStyle"];

  var _templateObject$13, _templateObject2$O, _templateObject3$o, _templateObject4$m, _templateObject5$k, _templateObject6$g, _templateObject7$c, _templateObject8$b, _templateObject9$8, _templateObject10$8, _templateObject11$6, _templateObject12$5, _templateObject13$5, _templateObject14$3, _templateObject15$2, _templateObject16$1, _templateObject17$1, _templateObject18$1, _templateObject19$1, _templateObject20$1, _templateObject21, _templateObject22, _templateObject23;
  var propTypes$1h = {
    children: PropTypes.node.isRequired,
    color: PropTypes.oneOf([].concat(_toConsumableArray(Object.keys(THEME_COLORS)), ['link'])),
    size: PropTypes.oneOf(['lg', 'sm']),
    outline: PropTypes.bool,
    first: PropTypes.bool,
    last: PropTypes.bool,
    active: PropTypes.bool,
    disabled: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    activeStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    activeTextStyle: PropTypes.any
  };
  var styles$12 = StyleSheet.create(_objectSpread2(_objectSpread2({
    '.btn': css$1(_templateObject$13 || (_templateObject$13 = _taggedTemplateLiteral(["\n    flex-direction: row; // added for bootstrap-rn\n    justify-content: center; // added for bootstrap-rn\n    // display: inline-block;\n    @include platform(web) {\n      // cursor: if($enable-button-pointers, pointer, null);\n      user-select: none;\n    }\n    background-color: transparent;\n    border: $btn-border-width solid transparent;\n    padding: $btn-padding-y $btn-padding-x;\n    // Manually declare to provide an override to the browser default\n    border-radius: $btn-border-radius;\n    // @include transition($btn-transition);\n\n    &:focus {\n      // outline: 0;\n      // box-shadow: $btn-focus-box-shadow;\n    }\n\n    &:active {\n      // @include box-shadow($btn-active-box-shadow);\n\n      &:focus {\n        // @include box-shadow($btn-focus-box-shadow, $btn-active-box-shadow);\n      }\n    }\n  "]))),
    '.btn-text': css$1(_templateObject2$O || (_templateObject2$O = _taggedTemplateLiteral(["\n    font-family: $btn-font-family;\n    font-weight: $btn-font-weight;\n    line-height: $btn-font-size * $btn-line-height;\n    color: $body-color;\n    text-align: center;\n    text-decoration: none; // if($link-decoration == none, null, none);\n    white-space: $btn-white-space;\n    // vertical-align: middle;\n    font-size: $btn-font-size;\n\n    &:hover {\n      color: $body-color;\n      text-decoration: none; // if($link-decoration == none, null, none);\n    }\n  "]))),
    '.btn-disabled': css$1(_templateObject3$o || (_templateObject3$o = _taggedTemplateLiteral(["\n    // pointer-events: none;\n    opacity: $btn-disabled-opacity;\n    // @include box-shadow(none);\n  "])))
  }, each(THEME_COLORS, function (color, value) {
    var _ref;

    return _ref = {}, _defineProperty(_ref, ".btn-".concat(color), css$1(_templateObject4$m || (_templateObject4$m = _taggedTemplateLiteral(["\n      background-color: ", ";\n      border-color: ", ";\n      // @include box-shadow($btn-box-shadow);\n\n      &:hover {\n        background-color: ", ";\n        border-color: ", ";\n      }\n\n      &:focus {\n        background-color: ", ";\n        border-color: ", ";\n        /* @if $enable-shadows {\n          @include box-shadow($btn-box-shadow, 0 0 0 $btn-focus-width rgba(mix($color, $border, 15%), .5));\n        } @else {\n          // Avoid using mixin so we can pass custom focus shadow properly\n          box-shadow: 0 0 0 $btn-focus-width rgba(mix($color, $border, 15%), .5);\n        } */\n      }\n\n      &:active {\n        background-color: ", ";\n        // Remove CSS gradients if they're enabled\n        // background-image: if($enable-gradients, none, null);\n        border-color: ", ";\n      }\n    "])), value, value, shadeColor(function (t) {
      return t['btn-hover-bg-shade-amount'];
    }, value), shadeColor(function (t) {
      return t['btn-hover-border-shade-amount'];
    }, value), shadeColor(function (t) {
      return t['btn-hover-bg-shade-amount'];
    }, value), shadeColor(function (t) {
      return t['btn-hover-border-shade-amount'];
    }, value), shadeColor(function (t) {
      return t['btn-active-bg-shade-amount'];
    }, value), shadeColor(function (t) {
      return t['btn-active-border-shade-amount'];
    }, value))), _defineProperty(_ref, ".btn-".concat(color, "-text"), css$1(_templateObject5$k || (_templateObject5$k = _taggedTemplateLiteral(["\n      color: ", ";\n\n      &:hover {\n        color: ", ";\n      }\n\n      &:focus {\n        color: ", ";\n      }\n\n      &:active {\n        color: ", ";\n      }\n    "])), colorContrast(value), colorContrast(value), colorContrast(value), colorContrast(value))), _defineProperty(_ref, ".btn-".concat(color, "-active"), css$1(_templateObject6$g || (_templateObject6$g = _taggedTemplateLiteral(["\n      background-color: ", ";\n      // Remove CSS gradients if they're enabled\n      // background-image: if($enable-gradients, none, null);\n      border-color: ", ";\n    "])), shadeColor(function (t) {
      return t['btn-active-bg-shade-amount'];
    }, value), shadeColor(function (t) {
      return t['btn-active-border-shade-amount'];
    }, value))), _defineProperty(_ref, ".btn-".concat(color, "-active-text"), css$1(_templateObject7$c || (_templateObject7$c = _taggedTemplateLiteral(["\n      color: ", ";\n    "])), colorContrast(value))), _defineProperty(_ref, ".btn-".concat(color, "-disabled"), css$1(_templateObject8$b || (_templateObject8$b = _taggedTemplateLiteral(["\n      $disabled-background: ", ";\n      $disabled-border: ", ";\n\n      background-color: $disabled-background;\n      // Remove CSS gradients if they're enabled\n      // background-image: if($enable-gradients, none, null);\n      border-color: $disabled-border;\n    "])), value, value)), _defineProperty(_ref, ".btn-".concat(color, "-disabled-text"), css$1(_templateObject9$8 || (_templateObject9$8 = _taggedTemplateLiteral(["\n      $disabled-color: ", ";\n\n      color: $disabled-color;\n    "])), colorContrast(value))), _defineProperty(_ref, ".btn-outline-".concat(color), css$1(_templateObject10$8 || (_templateObject10$8 = _taggedTemplateLiteral(["\n      border-color: ", ";\n\n      &:hover {\n        background-color: ", ";\n        border-color: ", ";\n      }\n\n      &:focus {\n        // box-shadow: 0 0 0 $btn-focus-width rgba($color, .5);\n      }\n\n      &:active {\n        background-color: ", ";\n        border-color: ", ";\n\n        /* &:focus {\n          @if $enable-shadows {\n            @include box-shadow(\n              $btn-active-box-shadow,\n              0 0 0 $btn-focus-width rgba($color, 0.5)\n            );\n          } @else {\n            // Avoid using mixin so we can pass custom focus shadow properly\n            box-shadow: 0 0 0 $btn-focus-width rgba($color, 0.5);\n          }\n        } */\n      }\n    "])), value, value, value, value, value)), _defineProperty(_ref, ".btn-outline-".concat(color, "-text"), css$1(_templateObject11$6 || (_templateObject11$6 = _taggedTemplateLiteral(["\n      color: ", ";\n\n      &:hover {\n        color: ", ";\n      }\n\n      &:active {\n        color: ", ";\n      }\n    "])), value, colorContrast(value), colorContrast(value))), _defineProperty(_ref, ".btn-outline-".concat(color, "-disabled"), css$1(_templateObject12$5 || (_templateObject12$5 = _taggedTemplateLiteral(["\n      background-color: transparent;\n    "])))), _defineProperty(_ref, ".btn-outline-".concat(color, "-disabled-text"), css$1(_templateObject13$5 || (_templateObject13$5 = _taggedTemplateLiteral(["\n      color: ", ";\n    "])), value)), _ref;
  })), {}, {
    '.btn-link-text': css$1(_templateObject14$3 || (_templateObject14$3 = _taggedTemplateLiteral(["\n    font-weight: $font-weight-normal;\n    color: $btn-link-color;\n    text-decoration-color: $btn-link-color; // added for bootstrap-rn\n    text-decoration-line: $link-decoration;\n\n    &:hover {\n      color: $btn-link-hover-color;\n      text-decoration-color: $btn-link-hover-color; // added for bootstrap-rn\n      text-decoration-line: $link-hover-decoration;\n    }\n\n    &:focus {\n      text-decoration-line: $link-hover-decoration;\n    }\n\n    // No need for an active state here\n  "]))),
    '.btn-link-text-disabled': css$1(_templateObject15$2 || (_templateObject15$2 = _taggedTemplateLiteral(["\n    color: $btn-link-disabled-color;\n  "]))),
    '.btn-lg': css$1(_templateObject16$1 || (_templateObject16$1 = _taggedTemplateLiteral(["\n    padding: $btn-padding-y-lg $btn-padding-x-lg;\n    // Manually declare to provide an override to the browser default\n    border-radius: $btn-border-radius-lg;\n  "]))),
    '.btn-lg-text': css$1(_templateObject17$1 || (_templateObject17$1 = _taggedTemplateLiteral(["\n    line-height: $btn-font-size-lg * $btn-line-height;\n    font-size: $btn-font-size-lg;\n  "]))),
    '.btn-sm': css$1(_templateObject18$1 || (_templateObject18$1 = _taggedTemplateLiteral(["\n    padding: $btn-padding-y-sm $btn-padding-x-sm;\n    // Manually declare to provide an override to the browser default\n    border-radius: $btn-border-radius-sm;\n  "]))),
    '.btn-sm-text': css$1(_templateObject19$1 || (_templateObject19$1 = _taggedTemplateLiteral(["\n    line-height: $btn-font-size-sm * $btn-line-height;\n    font-size: $btn-font-size-sm;\n  "]))),
    '.btn-group > .btn': css$1(_templateObject20$1 || (_templateObject20$1 = _taggedTemplateLiteral(["\n    position: relative;\n    // flex: 1 1 auto;\n\n    &:hover {\n      z-index: 1;\n    }\n    &:focus {\n      z-index: 1;\n    }\n    &:active {\n      z-index: 1;\n    }\n  "]))),
    '.btn-group > .btn-active': css$1(_templateObject21 || (_templateObject21 = _taggedTemplateLiteral(["\n    z-index: 2; // 1;\n  "]))),
    '.btn-group > .btn-not-first': css$1(_templateObject22 || (_templateObject22 = _taggedTemplateLiteral(["\n    margin-left: -$btn-border-width;\n    border-top-left-radius: 0;\n    border-bottom-left-radius: 0;\n  "]))),
    '.btn-group > .btn-not-last': css$1(_templateObject23 || (_templateObject23 = _taggedTemplateLiteral(["\n    border-top-right-radius: 0;\n    border-bottom-right-radius: 0;\n  "])))
  }));

  var getVariant = function getVariant(color, outline) {
    if (color === 'link') {
      return null;
    }

    if (outline) {
      return ".btn-outline-".concat(color);
    }

    return ".btn-".concat(color);
  };

  var hasSize = function hasSize(size, group, value) {
    if (size !== undefined || !group) {
      return size === value;
    }

    return group.size === value;
  };

  var Button = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        _props$color = props.color,
        color = _props$color === void 0 ? 'primary' : _props$color,
        size = props.size,
        _props$outline = props.outline,
        outline = _props$outline === void 0 ? false : _props$outline,
        _props$first = props.first,
        first = _props$first === void 0 ? false : _props$first,
        _props$last = props.last,
        last = _props$last === void 0 ? false : _props$last,
        _props$active = props.active,
        active = _props$active === void 0 ? false : _props$active,
        _props$disabled = props.disabled,
        disabled = _props$disabled === void 0 ? false : _props$disabled,
        style = props.style,
        activeStyle = props.activeStyle,
        textStyle = props.textStyle,
        activeTextStyle = props.activeTextStyle,
        elementProps = _objectWithoutProperties(props, _excluded$1g);

    invariant(color !== 'link' || !outline, 'Button link variant is only available as non outline style.');
    var group = React.useContext(ButtonGroupContext);
    var classes = getStyles(styles$12, ['.btn', getVariant(color, outline), disabled && '.btn-disabled', disabled && "".concat(getVariant(color, outline), "-disabled"), hasSize(size, group, 'lg') && '.btn-lg', hasSize(size, group, 'sm') && '.btn-sm', group && '.btn-group > .btn', group && active && '.btn-group > .btn-active', group && !first && '.btn-group > .btn-not-first', group && !last && '.btn-group > .btn-not-last']);
    var activeClasses = getStyles(styles$12, ["".concat(getVariant(color, outline), "-active")]);
    var textClasses = getStyles(styles$12, ['.btn-text', "".concat(getVariant(color, outline), "-text"), color === 'link' && '.btn-link-text', disabled && "".concat(getVariant(color, outline), "-text-disabled"), disabled && color === 'link' && '.btn-link-text-disabled', hasSize(size, group, 'lg') && '.btn-lg-text', hasSize(size, group, 'sm') && '.btn-sm-text']);
    var activeTextClasses = getStyles(styles$12, ["".concat(getVariant(color, outline), "-active-text")]);
    return /*#__PURE__*/React__default["default"].createElement(Pressable, _extends$1({}, elementProps, {
      ref: ref,
      active: active,
      disabled: disabled,
      style: [].concat(_toConsumableArray(classes), [style]),
      activeStyle: [].concat(_toConsumableArray(activeClasses), [activeStyle]),
      textStyle: [].concat(_toConsumableArray(textClasses), [textStyle]),
      activeTextStyle: [].concat(_toConsumableArray(activeTextClasses), [activeTextStyle])
    }), children);
  });
  Button.displayName = 'Button';
  Button.propTypes = propTypes$1h;
  Button.useToggle = useToggleButton;

  var _excluded$1f = ["children", "style", "textStyle"];

  var _templateObject$12, _templateObject2$N;
  var propTypes$1g = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$11 = StyleSheet.create({
    blockquote: css$1(_templateObject$12 || (_templateObject$12 = _taggedTemplateLiteral(["\n    margin-bottom: $blockquote-margin-y;\n  "]))),
    'blockquote-text': css$1(_templateObject2$N || (_templateObject2$N = _taggedTemplateLiteral(["\n    font-size: $blockquote-font-size;\n  "])))
  });
  var Blockquote = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$1f);

    var classes = getStyles(styles$11, ['blockquote']);
    var textClasses = getStyles(styles$11, ['blockquote-text']); // Accessiblity role blockquote is only supported on web.

    var role = _reactNative.Platform.OS === 'web' ? 'blockquote' : null;
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: role,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children);
  });
  Blockquote.displayName = 'Blockquote';
  Blockquote.propTypes = propTypes$1g;

  var _excluded$1e = ["children", "style", "textStyle"];

  var _templateObject$11, _templateObject2$M;
  var propTypes$1f = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$10 = StyleSheet.create({
    body: css$1(_templateObject$11 || (_templateObject$11 = _taggedTemplateLiteral(["\n    background-color: $body-bg;\n    height: 100%; // added for bootstrap-rn\n  "]))),
    'body-text': css$1(_templateObject2$M || (_templateObject2$M = _taggedTemplateLiteral(["\n    color: $body-color;\n    text-align: $body-text-align;\n  "])))
  });
  var Body = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$1e);

    var classes = getStyles(styles$10, ['body']);
    var textClasses = getStyles(styles$10, ['body-text']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children);
  });
  Body.displayName = 'Body';
  Body.propTypes = propTypes$1f;

  var _excluded$1d = ["children", "style", "textStyle"];

  var _templateObject$10, _templateObject2$L;
  var propTypes$1e = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$$ = StyleSheet.create({
    '.card-body': css$1(_templateObject$10 || (_templateObject$10 = _taggedTemplateLiteral(["\n    // flex: 1 1 auto;\n    padding: $card-spacer-y $card-spacer-x;\n  "]))),
    '.card-body-text': css$1(_templateObject2$L || (_templateObject2$L = _taggedTemplateLiteral(["\n    color: $card-color;\n  "])))
  });
  var CardBody = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$1d);

    var classes = getStyles(styles$$, ['.card-body']);
    var textClasses = getStyles(styles$$, [".card-body-text"]);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children);
  });
  CardBody.displayName = 'CardBody';
  CardBody.propTypes = propTypes$1e;

  var _excluded$1c = ["children", "style", "textStyle"];

  var _templateObject$$, _templateObject2$K;
  var propTypes$1d = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$_ = StyleSheet.create({
    '.card-header': css$1(_templateObject$$ || (_templateObject$$ = _taggedTemplateLiteral(["\n    padding: $card-cap-padding-y $card-cap-padding-x;\n    margin-bottom: 0; // Removes the default margin-bottom of <hN>\n    background-color: $card-cap-bg;\n    border-bottom-width: $card-border-width;\n    border-style: solid;\n    border-color: $card-border-color;\n    border-radius: $card-inner-border-radius $card-inner-border-radius 0 0;\n  "]))),
    '.card-header-text': css$1(_templateObject2$K || (_templateObject2$K = _taggedTemplateLiteral(["\n    color: $card-cap-color;\n  "])))
  });
  var CardHeader = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$1c);

    var classes = getStyles(styles$_, ['.card-header']);
    var textClasses = getStyles(styles$_, ['.card-header-text']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children);
  });
  CardHeader.displayName = 'CardHeader';
  CardHeader.propTypes = propTypes$1d;

  var _excluded$1b = ["children", "style", "textStyle"];

  var _templateObject$_, _templateObject2$J;
  var propTypes$1c = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$Z = StyleSheet.create({
    '.card-footer': css$1(_templateObject$_ || (_templateObject$_ = _taggedTemplateLiteral(["\n    padding: $card-cap-padding-y $card-cap-padding-x;\n    background-color: $card-cap-bg;\n    border-top-width: $card-border-width;\n    border-style: solid;\n    border-color: $card-border-color;\n    border-radius: 0 0 $card-inner-border-radius $card-inner-border-radius;\n  "]))),
    '.card-footer-text': css$1(_templateObject2$J || (_templateObject2$J = _taggedTemplateLiteral(["\n    color: $card-cap-color;\n  "])))
  });
  var CardFooter = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$1b);

    var classes = getStyles(styles$Z, ['.card-footer']);
    var textClasses = getStyles(styles$Z, ['.card-footer-text']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children);
  });
  CardFooter.displayName = 'CardFooter';
  CardFooter.propTypes = propTypes$1c;

  var _excluded$1a = ["children", "style"];

  var _templateObject$Z;
  var propTypes$1b = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$Y = StyleSheet.create({
    '.card': css$1(_templateObject$Z || (_templateObject$Z = _taggedTemplateLiteral(["\n    position: relative;\n    display: flex;\n    flex-direction: column;\n    min-width: 0;\n    height: $card-height;\n    // word-wrap: break-word;\n    background-color: $card-bg;\n    // background-clip: border-box;\n    border: $card-border-width solid $card-border-color;\n    border-radius: $card-border-radius;\n    // @include box-shadow($card-box-shadow);\n  "])))
  });
  var Card = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$1a);

    var classes = getStyles(styles$Y, ['.card']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), children);
  });
  Card.displayName = 'Card';
  Card.propTypes = propTypes$1b;
  Card.Header = CardHeader;
  Card.Body = CardBody;
  Card.Footer = CardFooter;

  var ModalContext = /*#__PURE__*/React__default["default"].createContext();
  ModalContext.displayName = 'ModalContext';

  var OffcanvasContext = /*#__PURE__*/React__default["default"].createContext();
  OffcanvasContext.displayName = 'OffcanvasContext';

  var _excluded$19 = ["children", "disabled", "style", "textStyle"];

  var _templateObject$Y, _templateObject2$I, _templateObject3$n, _templateObject4$l, _templateObject5$j;
  var propTypes$1a = {
    children: PropTypes.node,
    disabled: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$X = StyleSheet.create({
    '.btn-close': css$1(_templateObject$Y || (_templateObject$Y = _taggedTemplateLiteral(["\n    // Workaround for missing box-sizing in react native.\n    $additional-width: $btn-close-padding-x * 2;\n    $additional-height: $btn-close-padding-y * 2;\n\n    // box-sizing: content-box;\n    width: $btn-close-width + $additional-width;\n    height: $btn-close-height + $additional-height;\n    padding: $btn-close-padding-y $btn-close-padding-x;\n    background: transparent;\n    border-width: 0; // for button elements\n    // @include border-radius();\n    opacity: $btn-close-opacity;\n\n    &:hover {\n      opacity: $btn-close-hover-opacity;\n    }\n\n    &:focus {\n      // outline: 0;\n      // box-shadow: $btn-close-focus-shadow;\n      opacity: $btn-close-focus-opacity;\n    }\n  "]))),
    '.btn-close-text': css$1(_templateObject2$I || (_templateObject2$I = _taggedTemplateLiteral(["\n    color: $btn-close-color;\n\n    // Override <a>'s hover style\n    &:hover {\n      color: $btn-close-color;\n      text-decoration: none;\n    }\n  "]))),
    '.btn-close-disabled': css$1(_templateObject3$n || (_templateObject3$n = _taggedTemplateLiteral(["\n    // pointer-events: none;\n    // user-select: none;\n    opacity: $btn-close-disabled-opacity;\n  "]))),
    // Modal styles
    '.modal-header .btn-close': css$1(_templateObject4$l || (_templateObject4$l = _taggedTemplateLiteral(["\n    padding: $modal-header-padding-y * 0.5 $modal-header-padding-x * 0.5;\n    margin: -0.5 * $modal-header-padding-y -0.5 * $modal-header-padding-x -0.5 *\n      $modal-header-padding-y auto;\n\n    // Workaround for missing box-sizing in react native.\n    width: $btn-close-width + $modal-header-padding-x;\n    height: $btn-close-height + $modal-header-padding-y;\n  "]))),
    // Offcanvas styles
    '.offcanvas-header .btn-close': css$1(_templateObject5$j || (_templateObject5$j = _taggedTemplateLiteral(["\n    padding: $offcanvas-padding-y * 0.5 $offcanvas-padding-x * 0.5;\n    margin-top: -0.5 * $offcanvas-padding-y;\n    margin-right: -0.5 * $offcanvas-padding-x;\n    margin-bottom: -0.5 * $offcanvas-padding-y;\n\n    // Workaround for missing box-sizing in react native.\n    width: $btn-close-width + $offcanvas-padding-x;\n    height: $btn-close-height + $offcanvas-padding-y;\n  "])))
  });
  var CloseButton = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    props.children;
        var _props$disabled = props.disabled,
        disabled = _props$disabled === void 0 ? false : _props$disabled,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$19);

    var modal = React.useContext(ModalContext);
    var offcanvas = React.useContext(OffcanvasContext);
    var classes = getStyles(styles$X, ['.btn-close', disabled && '.btn-close-disabled', // Modal styles
    modal && '.modal-header .btn-close', // Offcanvas styles
    offcanvas && '.offcanvas-header .btn-close']);
    var textClasses = getStyles(styles$X, ['.btn-close-text']);
    return /*#__PURE__*/React__default["default"].createElement(Pressable, _extends$1({}, elementProps, {
      ref: ref,
      disabled: disabled,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), StyleSheet.value('btn-close-bg'));
  });
  CloseButton.displayName = 'CloseButton';
  CloseButton.propTypes = propTypes$1a;

  var CollapseContext = /*#__PURE__*/React__default["default"].createContext();
  CollapseContext.displayName = 'CollapseContext';

  function useIdentifier(prefix) {
    var context = React.useContext(Context);
    var ref = React.useRef();

    if (!ref.current) {
      ref.current = context.generateKey(prefix);
    }

    return ref.current;
  }

  function useControlledState(defaultValue, controlledValue) {
    var onChange = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : function () {};

    var _useState = React.useState(defaultValue),
        _useState2 = _slicedToArray(_useState, 2),
        stateValue = _useState2[0],
        setStateValue = _useState2[1];

    var isControlled = typeof controlledValue === 'boolean';
    var value = isControlled ? controlledValue : stateValue;

    var setValue = function setValue(nextValue) {
      if (value === nextValue) {
        return;
      }

      if (!isControlled) {
        setStateValue(nextValue);
      }

      onChange(nextValue);
    };

    return [value, setValue];
  }

  function useCollapse(defaultVisible, controlledVisible, onToggle) {
    var identifier = useIdentifier('collapse');

    var _useControlledState = useControlledState(defaultVisible, controlledVisible, onToggle),
        _useControlledState2 = _slicedToArray(_useControlledState, 2),
        visible = _useControlledState2[0],
        setVisible = _useControlledState2[1];

    return React.useMemo(function () {
      return {
        identifier: identifier,
        visible: visible,
        setVisible: setVisible
      };
    }, [visible]);
  }

  var propTypes$19 = {
    children: PropTypes.node.isRequired,
    defaultVisible: PropTypes.bool,
    visible: PropTypes.bool,
    onToggle: PropTypes.func
  };

  var CollapseProvider = function CollapseProvider(props) {
    var children = props.children,
        _props$defaultVisible = props.defaultVisible,
        defaultVisible = _props$defaultVisible === void 0 ? false : _props$defaultVisible,
        visible = props.visible,
        onToggle = props.onToggle;
    var collapse = useCollapse(defaultVisible, visible, onToggle);
    return /*#__PURE__*/React__default["default"].createElement(CollapseContext.Provider, {
      value: collapse
    }, children);
  };

  CollapseProvider.displayName = 'CollapseProvider';
  CollapseProvider.propTypes = propTypes$19;

  var _excluded$18 = ["onPress"];
  function useToggleCollapse(props) {
    var context = useForcedContext(CollapseContext);

    var handlePress = props.onPress,
        restProps = _objectWithoutProperties(props, _excluded$18);

    return _objectSpread2(_objectSpread2({}, restProps), {}, {
      onPress: function onPress(event) {
        if (handlePress) handlePress(event);
        context.setVisible(function (value) {
          return !value;
        });
      },
      accessibilityExpanded: context.visible,
      accessibilityControls: context.identifier
    });
  }

  var _excluded$17 = ["children"];
  var propTypes$18 = {
    children: PropTypes.node
  };
  var Collapse = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        elementProps = _objectWithoutProperties(props, _excluded$17);

    var _useForcedContext = useForcedContext(CollapseContext),
        identifier = _useForcedContext.identifier,
        visible = _useForcedContext.visible;

    if (!visible) {
      return null;
    }

    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      nativeID: identifier
    }), children);
  });
  Collapse.displayName = 'Collapse';
  Collapse.propTypes = propTypes$18;
  Collapse.Provider = CollapseProvider;
  Collapse.useToggle = useToggleCollapse;

  function next(name) {
    var names = Object.keys(GRID_BREAKPOINTS);
    var n = names.indexOf(name);

    if (n === -1) {
      throw new Error("Breakpoint ".concat(name, " not found."));
    }

    return n < names.length ? names[n + 1] : '';
  }
  function infix(breakpoint) {
    if (!breakpoint || breakpoint === 'xs') {
      return '';
    }

    return "-".concat(breakpoint);
  }

  var NavbarContext = /*#__PURE__*/React__default["default"].createContext();
  NavbarContext.displayName = 'NavbarContext';

  var _excluded$16 = ["fluid", "style"];

  var _templateObject$X, _templateObject2$H, _templateObject3$m, _templateObject4$k, _templateObject5$i, _templateObject6$f, _templateObject7$b, _templateObject8$a;
  var propTypes$17 = {
    children: PropTypes.node.isRequired,
    fluid: PropTypes.oneOf([true].concat(_toConsumableArray(Object.keys(CONTAINER_MAX_WIDTHS)))),
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$W = StyleSheet.create(_objectSpread2({
    '.container': css$1(_templateObject$X || (_templateObject$X = _taggedTemplateLiteral(["\n    width: 100%;\n    padding-right: $container-padding-x;\n    padding-left: $container-padding-x;\n    margin-right: auto;\n    margin-left: auto;\n  "]))),
    '.container-sm': css$1(_templateObject2$H || (_templateObject2$H = _taggedTemplateLiteral(["\n    @include media-breakpoint-up(sm) {\n      max-width: ", ";\n    }\n    @include media-breakpoint-up(md) {\n      max-width: ", ";\n    }\n    @include media-breakpoint-up(lg) {\n      max-width: ", ";\n    }\n    @include media-breakpoint-up(xl) {\n      max-width: ", ";\n    }\n    @include media-breakpoint-up(xxl) {\n      max-width: ", ";\n    }\n  "])), function (t) {
      return t['container-max-widths'].sm;
    }, function (t) {
      return t['container-max-widths'].md;
    }, function (t) {
      return t['container-max-widths'].lg;
    }, function (t) {
      return t['container-max-widths'].xl;
    }, function (t) {
      return t['container-max-widths'].xxl;
    }),
    '.container-md': css$1(_templateObject3$m || (_templateObject3$m = _taggedTemplateLiteral(["\n    @include media-breakpoint-up(md) {\n      max-width: ", ";\n    }\n    @include media-breakpoint-up(lg) {\n      max-width: ", ";\n    }\n    @include media-breakpoint-up(xl) {\n      max-width: ", ";\n    }\n    @include media-breakpoint-up(xxl) {\n      max-width: ", ";\n    }\n  "])), function (t) {
      return t['container-max-widths'].md;
    }, function (t) {
      return t['container-max-widths'].lg;
    }, function (t) {
      return t['container-max-widths'].xl;
    }, function (t) {
      return t['container-max-widths'].xxl;
    }),
    '.container-lg': css$1(_templateObject4$k || (_templateObject4$k = _taggedTemplateLiteral(["\n    @include media-breakpoint-up(lg) {\n      max-width: ", ";\n    }\n    @include media-breakpoint-up(xl) {\n      max-width: ", ";\n    }\n    @include media-breakpoint-up(xxl) {\n      max-width: ", ";\n    }\n  "])), function (t) {
      return t['container-max-widths'].lg;
    }, function (t) {
      return t['container-max-widths'].xl;
    }, function (t) {
      return t['container-max-widths'].xxl;
    }),
    '.container-xl': css$1(_templateObject5$i || (_templateObject5$i = _taggedTemplateLiteral(["\n    @include media-breakpoint-up(xl) {\n      max-width: ", ";\n    }\n    @include media-breakpoint-up(xxl) {\n      max-width: ", ";\n    }\n  "])), function (t) {
      return t['container-max-widths'].xl;
    }, function (t) {
      return t['container-max-widths'].xxl;
    }),
    '.container-xxl': css$1(_templateObject6$f || (_templateObject6$f = _taggedTemplateLiteral(["\n    @include media-breakpoint-up(xxl) {\n      max-width: ", ";\n    }\n  "])), function (t) {
      return t['container-max-widths'].xxl;
    }),
    // Navbar styles
    '.navbar .container': css$1(_templateObject7$b || (_templateObject7$b = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: row; // added for bootstrap-rn\n    flex-wrap: wrap;\n    align-items: center;\n    justify-content: space-between;\n  "])))
  }, each(GRID_BREAKPOINTS, function (breakpoint) {
    return _defineProperty({}, ".navbar-expand".concat(infix(next(breakpoint)), " .container"), css$1(_templateObject8$a || (_templateObject8$a = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        flex-wrap: nowrap;\n      }\n    "])), next(breakpoint)));
  })));
  var Container = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var _props$fluid = props.fluid,
        fluid = _props$fluid === void 0 ? 'sm' : _props$fluid,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$16);

    var navbar = React.useContext(NavbarContext);
    var classes = getStyles(styles$W, ['.container', // Hint: Bootstrap's .container class is identical with .container-sm.
    fluid !== true && ".container-".concat(fluid), // Navbar styles
    navbar && '.navbar .container', navbar && navbar.expand && ".navbar-expand".concat(navbar.expand === true ? '' : "-".concat(navbar.expand), " .container")]);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }));
  });
  Container.displayName = 'Container';
  Container.propTypes = propTypes$17;

  var _excluded$15 = ["children", "type", "value", "onChange", "onPress", "label", "disabled", "valid", "invalid", "style", "inputStyle", "labelStyle", "labelTextStyle"];

  var _templateObject$W, _templateObject2$G, _templateObject3$l, _templateObject4$j, _templateObject5$h, _templateObject6$e, _templateObject7$a, _templateObject8$9, _templateObject9$7, _templateObject10$7, _templateObject11$5, _templateObject12$4, _templateObject13$4;
  var propTypes$16 = {
    children: PropTypes.node,
    type: PropTypes.oneOf(['checkbox', 'radio', 'switch']).isRequired,
    value: PropTypes.bool.isRequired,
    onChange: PropTypes.func,
    onPress: PropTypes.func,
    label: PropTypes.string,
    disabled: PropTypes.bool,
    valid: PropTypes.bool,
    invalid: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    inputStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    labelStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    labelTextStyle: PropTypes.any
  };
  var styles$V = StyleSheet.create(_objectSpread2({
    '.form-check': css$1(_templateObject$W || (_templateObject$W = _taggedTemplateLiteral(["\n    // display: block;\n    flex-direction: row; // added for bootstrap-rn\n    min-height: $form-check-min-height;\n    padding-left: $form-check-padding-start;\n    margin-bottom: $form-check-margin-bottom;\n  "]))),
    '.form-check-disabled': css$1(_templateObject2$G || (_templateObject2$G = _taggedTemplateLiteral(["\n    opacity: $form-check-label-disabled-opacity;\n  "]))),
    '.form-check-input': css$1(_templateObject3$l || (_templateObject3$l = _taggedTemplateLiteral(["\n    // Use additional variables instead of brackets, because brackets not supported yet.\n    $lineHeight: $line-height-base * 1rem;\n    $rawMarginTop: $lineHeight - $form-check-input-width;\n\n    // float: left;\n    margin-left: $form-check-padding-start * -1;\n    margin-right: $form-check-padding-start - $form-check-input-width; // added for bootstrap-rn\n\n    width: $form-check-input-width;\n    height: $form-check-input-width;\n    margin-top: $rawMarginTop * 0.5; // line-height minus check height\n    // vertical-align: top;\n    background-color: $form-check-input-bg;\n    // background-repeat: no-repeat;\n    // background-position: center;\n    // background-size: contain;\n    border: $form-check-input-border;\n    @include platform(web) {\n      appearance: none;\n      user-select: none; // added for bootstrap-rn\n    }\n    // color-adjust: exact; // Keep themed appearance for print\n    // @include transition($form-check-transition);\n\n    &:active {\n      // filter: $form-check-input-active-filter;\n    }\n\n    &:focus {\n      border-color: $form-check-input-focus-border;\n      // outline: 0;\n      // box-shadow: $form-check-input-focus-box-shadow;\n    }\n  "]))),
    '.form-check-input-checkbox': css$1(_templateObject4$j || (_templateObject4$j = _taggedTemplateLiteral(["\n    border-radius: $form-check-input-border-radius;\n  "]))),
    '.form-check-input-radio': css$1(_templateObject5$h || (_templateObject5$h = _taggedTemplateLiteral(["\n    border-radius: $form-check-radio-border-radius;\n  "]))),
    '.form-check-input-checked': css$1(_templateObject6$e || (_templateObject6$e = _taggedTemplateLiteral(["\n    background-color: $form-check-input-checked-bg-color;\n    border-color: $form-check-input-checked-border-color;\n  "]))),
    '.form-check-label': css$1(_templateObject7$a || (_templateObject7$a = _taggedTemplateLiteral(["\n    color: $form-check-label-color;\n    @include platform(web) {\n      cursor: $form-check-label-cursor;\n    }\n  "]))),
    '.form-switch': css$1(_templateObject8$9 || (_templateObject8$9 = _taggedTemplateLiteral(["\n    padding-left: $form-switch-padding-start;\n  "]))),
    '.form-check-input-switch': css$1(_templateObject9$7 || (_templateObject9$7 = _taggedTemplateLiteral(["\n    width: $form-switch-width;\n    margin-left: $form-switch-padding-start * -1;\n    margin-right: $form-switch-padding-start - $form-switch-width; // added for bootstrap-rn\n    border-radius: $form-switch-border-radius;\n    // @include transition($form-switch-transition);\n    align-items: flex-start; // added for bootstrap-rn\n    justify-content: center; // added for bootstrap-rn\n  "]))),
    '.form-check-input-switch-checked': css$1(_templateObject10$7 || (_templateObject10$7 = _taggedTemplateLiteral(["\n    align-items: flex-end; // added for bootstrap-rn\n    justify-content: center; // added for bootstrap-rn\n  "])))
  }, each(FORM_VALIDATION_STATES, function (state, data) {
    var _ref;

    return _ref = {}, _defineProperty(_ref, ".form-check-input.is-".concat(state), css$1(_templateObject11$5 || (_templateObject11$5 = _taggedTemplateLiteral(["\n      border: ", ";\n\n      &:focus {\n        // box-shadow: $focus-box-shadow;\n      }\n    "])), function (t) {
      return data(t).color;
    })), _defineProperty(_ref, ".form-check-input-checked.is-".concat(state), css$1(_templateObject12$4 || (_templateObject12$4 = _taggedTemplateLiteral(["\n      background-color: ", ";\n    "])), function (t) {
      return data(t).color;
    })), _defineProperty(_ref, ".form-check-label.is-".concat(state), css$1(_templateObject13$4 || (_templateObject13$4 = _taggedTemplateLiteral(["\n      color: ", ";\n    "])), function (t) {
      return data(t).color;
    })), _ref;
  })));

  var getSvg = function getSvg(type, value) {
    if (type === 'checkbox' && value) {
      return StyleSheet.value('form-check-input-checked-bg-image');
    }

    if (type === 'radio' && value) {
      return StyleSheet.value('form-check-radio-checked-bg-image');
    }

    if (type === 'switch') {
      return StyleSheet.value(value ? 'form-switch-checked-bg-image' : 'form-switch-bg-image');
    }

    return null;
  };

  var CheckInput = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var _useModifier = useModifier('useFormField', props, ref),
        _useModifier2 = _slicedToArray(_useModifier, 2),
        modifierProps = _useModifier2[0],
        modifierRef = _useModifier2[1];

    var children = modifierProps.children,
        type = modifierProps.type,
        value = modifierProps.value,
        handleChange = modifierProps.onChange,
        handlePress = modifierProps.onPress,
        label = modifierProps.label,
        _modifierProps$disabl = modifierProps.disabled,
        disabled = _modifierProps$disabl === void 0 ? false : _modifierProps$disabl,
        _modifierProps$valid = modifierProps.valid,
        valid = _modifierProps$valid === void 0 ? false : _modifierProps$valid,
        _modifierProps$invali = modifierProps.invalid,
        invalid = _modifierProps$invali === void 0 ? false : _modifierProps$invali,
        style = modifierProps.style,
        inputStyle = modifierProps.inputStyle,
        labelStyle = modifierProps.labelStyle,
        labelTextStyle = modifierProps.labelTextStyle,
        elementProps = _objectWithoutProperties(modifierProps, _excluded$15);

    if (!children && !label) {
      // eslint-disable-next-line no-console
      console.warn('You need to provide either children or a label for accessibility.');
    }

    var classes = getStyles(styles$V, ['.form-check', type === 'switch' && '.form-switch', disabled && '.form-check-disabled']);
    var inputClasses = getStyles(styles$V, ['.form-check-input', type === 'checkbox' && '.form-check-input-checkbox', type === 'radio' && '.form-check-input-radio', type === 'switch' && '.form-check-input-switch', value && '.form-check-input-checked', type === 'switch' && value && '.form-check-input-switch-checked', valid && '.form-check-input.is-valid', valid && value && '.form-check-input-checked.is-valid', invalid && '.form-check-input.is-invalid', invalid && value && '.form-check-input-checked.is-invalid']);
    var labelTextClasses = getStyles(styles$V, ['.form-check-label', valid && '.form-check-label.is-valid', invalid && '.form-check-label.is-invalid']); // TODO &:focus, &:active

    return /*#__PURE__*/React__default["default"].createElement(Pressable, _extends$1({}, elementProps, {
      ref: modifierRef,
      accessibilityRole: type,
      accessibilityChecked: value,
      accessibilityLabel: label,
      onPress: concatFns(function () {
        handleChange(!value);
      }, handlePress),
      disabled: disabled,
      style: [classes, style]
    }), /*#__PURE__*/React__default["default"].createElement(View, {
      style: [inputClasses, inputStyle]
    }, getSvg(type, value)), children && /*#__PURE__*/React__default["default"].createElement(View, {
      style: labelStyle,
      textStyle: [labelTextClasses, labelTextStyle]
    }, children));
  });
  CheckInput.displayName = 'CheckInput';
  CheckInput.propTypes = propTypes$16;

  var Checkbox = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var elementProps = _extends$1({}, props);

    return /*#__PURE__*/React__default["default"].createElement(CheckInput, _extends$1({}, elementProps, {
      ref: ref,
      type: "checkbox"
    }));
  });
  Checkbox.displayName = 'Checkbox';

  var _excluded$14 = ["children", "size", "sizeSm", "sizeMd", "sizeLg", "sizeXl", "style"];

  var _templateObject$V, _templateObject2$F, _templateObject3$k, _templateObject4$i, _templateObject5$g;
  var sizes = makeArray(GRID_COLUMNS).map(function (v) {
    return v + 1;
  });
  var propTypes$15 = {
    children: PropTypes.node.isRequired,
    size: PropTypes.oneOf(['auto'].concat(_toConsumableArray(sizes))),
    sizeSm: PropTypes.oneOf(['auto'].concat(_toConsumableArray(sizes))),
    sizeMd: PropTypes.oneOf(['auto'].concat(_toConsumableArray(sizes))),
    sizeLg: PropTypes.oneOf(['auto'].concat(_toConsumableArray(sizes))),
    sizeXl: PropTypes.oneOf(['auto'].concat(_toConsumableArray(sizes))),
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$U = StyleSheet.create(_objectSpread2({
    '*': css$1(_templateObject$V || (_templateObject$V = _taggedTemplateLiteral(["\n    // Add box sizing if only the grid is loaded\n    /* box-sizing: if(\n      variable-exists(include-column-box-sizing) and $include-column-box-sizing,\n      border-box,\n      null\n    ); */\n    // Prevent columns from becoming too narrow when at smaller grid tiers by\n    // always setting \"width: 100%;\". This works because we set the width\n    // later on to override this initial width.\n    flex-shrink: 0;\n    width: 100%;\n    @include platform(web) {\n      max-width: 100%; // Prevent \".col-auto\", \".col\" (& responsive variants) from breaking out the grid\n    }\n    padding-right: $grid-gutter-width * 0.5;\n    padding-left: $grid-gutter-width * 0.5;\n    margin-top: 0;\n  "])))
  }, each(GRID_BREAKPOINTS, function (breakpoint) {
    var _objectSpread2$1;

    return _objectSpread2((_objectSpread2$1 = {}, _defineProperty(_objectSpread2$1, ".col".concat(infix(breakpoint)), css$1(_templateObject2$F || (_templateObject2$F = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        flex: 1 0 0%; // Flexbugs #4: https://github.com/philipwalton/flexbugs#flexbug-4\n      }\n    "])), breakpoint)), _defineProperty(_objectSpread2$1, ".col".concat(infix(breakpoint), "-auto"), css$1(_templateObject3$k || (_templateObject3$k = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        flex: 0 0 auto;\n        width: auto;\n      }\n    "])), breakpoint)), _objectSpread2$1), normalize$1(makeArray(GRID_COLUMNS - 1, function (i) {
      var _ref;

      return _ref = {}, _defineProperty(_ref, ".col".concat(infix(breakpoint), "-").concat(i + 1), css$1(_templateObject4$i || (_templateObject4$i = _taggedTemplateLiteral(["\n          @include media-breakpoint-up(", ") {\n            flex: 0 0 auto;\n            width: ", "%;\n          }\n        "])), breakpoint, (i + 1) / GRID_COLUMNS * 100)), _defineProperty(_ref, ".offset".concat(infix(breakpoint), "-").concat(i), css$1(_templateObject5$g || (_templateObject5$g = _taggedTemplateLiteral(["\n          @include media-breakpoint-up(", ") {\n            margin-left: ", "%;\n          }\n        "])), breakpoint, i / GRID_COLUMNS * 100)), _ref;
    })));
  })));
  var Col = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        size = props.size,
        sizeSm = props.sizeSm,
        sizeMd = props.sizeMd,
        sizeLg = props.sizeLg,
        sizeXl = props.sizeXl,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$14);

    var classes = getStyles(styles$U, ['*', ".col-".concat(size.toString()), sizeSm && ".col-sm-".concat(sizeSm.toString()), sizeMd && ".col-md-".concat(sizeMd.toString()), sizeLg && ".col-lg-".concat(sizeLg.toString()), sizeXl && ".col-xl-".concat(sizeXl.toString())]);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), children);
  });
  Col.displayName = 'Col';
  Col.propTypes = propTypes$15;

  var _excluded$13 = ["color", "bold", "italic", "mark", "small", "style", "styleName"];

  var _templateObject$U, _templateObject2$E, _templateObject3$j, _templateObject4$h, _templateObject5$f;
  var propTypes$14 = {
    color: PropTypes.oneOf([].concat(_toConsumableArray(Object.keys(THEME_COLORS)), ['muted', 'black-50', 'white-50'])),
    small: PropTypes.bool,
    mark: PropTypes.bool,
    bold: PropTypes.bool,
    italic: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    styleName: PropTypes.any
  };
  var styles$T = StyleSheet.create({
    text: css$1(_templateObject$U || (_templateObject$U = _taggedTemplateLiteral(["\n    font-family: $font-family-base;\n    font-size: $font-size-base;\n    font-weight: $font-weight-base;\n    line-height: $font-size-base * $line-height-base;\n  "]))),
    strong: css$1(_templateObject2$E || (_templateObject2$E = _taggedTemplateLiteral(["\n    font-weight: $font-weight-bolder;\n  "]))),
    italic: css$1(_templateObject3$j || (_templateObject3$j = _taggedTemplateLiteral(["\n    font-style: italic;\n  "]))),
    small: css$1(_templateObject4$h || (_templateObject4$h = _taggedTemplateLiteral(["\n    font-size: $small-font-size;\n    line-height: $small-font-size * $line-height-base;\n  "]))),
    mark: css$1(_templateObject5$f || (_templateObject5$f = _taggedTemplateLiteral(["\n    padding: $mark-padding;\n    background-color: $mark-bg;\n  "])))
  });

  var getStyleName = function getStyleName(styleName, color) {
    if (!color) {
      return styleName;
    }

    return styleName ? "text-".concat(color, " ").concat(styleName) : "text-".concat(color);
  };

  var Text = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var color = props.color,
        _props$bold = props.bold,
        bold = _props$bold === void 0 ? false : _props$bold,
        _props$italic = props.italic,
        italic = _props$italic === void 0 ? false : _props$italic,
        _props$mark = props.mark,
        mark = _props$mark === void 0 ? false : _props$mark,
        _props$small = props.small,
        small = _props$small === void 0 ? false : _props$small,
        style = props.style,
        styleName = props.styleName,
        elementProps = _objectWithoutProperties(props, _excluded$13);

    var media = useMedia();
    var context = React.useContext(TextStyleContext);
    var classes = getStyles(styles$T, [bold && 'strong', italic && 'italic', small && 'small', mark && 'mark']);
    var resolveStyle = useStyle([// eslint-disable-next-line react/destructuring-assignment
    (!context || !context.hasTextAncestor) && styles$T.text, // eslint-disable-next-line react/destructuring-assignment
    context && context.style, classes, style], getStyleName(styleName, color));
    var element = /*#__PURE__*/React__default["default"].createElement(_reactNative.Text, _extends$1({}, elementProps, {
      ref: ref,
      style: resolveStyle({
        media: media
      })
    })); // eslint-disable-next-line react/destructuring-assignment

    if (context && context.hasTextAncestor && !context.style) {
      return element;
    } // If we are not in an ancestor context yet, we need to set hasTextAncestor
    // to true for nested text components. Furthermore we need to reset the
    // context style, because we only need to apply the style once.


    return /*#__PURE__*/React__default["default"].createElement(TextStyleContext.Provider, {
      value: {
        style: null,
        hasTextAncestor: true
      }
    }, element);
  });
  Text.displayName = 'Text';
  Text.propTypes = propTypes$14;

  var _excluded$12 = ["children", "style"];

  var _templateObject$T;
  var propTypes$13 = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$S = StyleSheet.create({
    code: css$1(_templateObject$T || (_templateObject$T = _taggedTemplateLiteral(["\n    font-family: $font-family-code;\n    font-size: $code-font-size;\n    color: $code-color;\n    @include platform(web) {\n      word-wrap: break-word;\n    }\n  "])))
  });
  var Code = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$12);

    var classes = getStyles(styles$S, ['code']); // Accessiblity role code is only supported on web.

    var role = _reactNative.Platform.OS === 'web' ? 'code' : null;
    return /*#__PURE__*/React__default["default"].createElement(Text, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: role,
      style: [classes, style]
    }), children);
  });
  Code.displayName = 'Code';
  Code.propTypes = propTypes$13;

  var DropdownContext = /*#__PURE__*/React__default["default"].createContext();
  DropdownContext.displayName = 'DropdownContext';

  var _excluded$11 = ["onPress"];
  function useToggleDropdown(props) {
    var context = useForcedContext(DropdownContext);

    var handlePress = props.onPress,
        restProps = _objectWithoutProperties(props, _excluded$11);

    return _objectSpread2(_objectSpread2({}, restProps), {}, {
      nativeID: context.identifier,
      ref: context.toggleRef,
      onPress: function onPress(event) {
        if (handlePress) handlePress(event);
        context.setVisible(function (value) {
          return !value;
        });
      },
      accessibilityHasPopup: true,
      accessibilityExpanded: context.visible
    });
  }

  var propTypes$12 = {
    children: PropTypes.func.isRequired
  };

  var DropdownToggle = function DropdownToggle(props) {
    var children = props.children;
    return children(useToggleDropdown({}));
  };

  DropdownToggle.displayName = 'DropdownToggle';
  DropdownToggle.propTypes = propTypes$12;

  var propTypes$11 = {
    children: PropTypes.func.isRequired,
    placement: PropTypes.string.isRequired,
    targetRef: PropTypes.oneOfType([PropTypes.func, PropTypes.object]),
    offset: PropTypes.number,
    arrowOffset: PropTypes.number,
    visible: PropTypes.bool.isRequired
  };

  var Overlay = function Overlay(props) {
    var children = props.children,
        targetRef = props.targetRef,
        placement = props.placement,
        offset = props.offset,
        _props$arrowOffset = props.arrowOffset,
        arrowOffset = _props$arrowOffset === void 0 ? 0 : _props$arrowOffset,
        visible = props.visible;
    var overlayRef = React.useRef();
    var overlay = useOverlayPosition({
      placement: placement,
      targetRef: targetRef,
      overlayRef: overlayRef,
      offset: offset,
      isOpen: visible
    }); // Remove undefined arrow styles and adjust arrow offset.

    if (overlay.arrowProps.style.left === undefined) {
      delete overlay.arrowProps.style.left;

      if (overlay.arrowProps.style.top) {
        overlay.arrowProps.style.top -= arrowOffset;
      }
    }

    if (overlay.arrowProps.style.top === undefined) {
      delete overlay.arrowProps.style.top;

      if (overlay.arrowProps.style.left) {
        overlay.arrowProps.style.left -= arrowOffset;
      }
    } // Adjust bottom value by status bar height on Android


    if (_reactNative.Platform.OS === 'android' && overlay.overlayProps.style.bottom !== undefined && _reactNative.StatusBar.currentHeight) {
      overlay.overlayProps.style.bottom -= _reactNative.StatusBar.currentHeight;
    }

    return children(overlay, overlayRef);
  };

  Overlay.displayName = 'Overlay';
  Overlay.propTypes = propTypes$11;

  var _templateObject$S;
  var propTypes$10 = {
    toggleRef: PropTypes.oneOfType([PropTypes.func, PropTypes.object]),
    dialogRef: PropTypes.oneOfType([PropTypes.func, PropTypes.object]),
    onClose: PropTypes.func,
    autoClose: PropTypes.oneOfType([PropTypes.bool, PropTypes.oneOf(['inside', 'outside'])]),
    backdrop: PropTypes.oneOfType([PropTypes.bool, PropTypes.oneOf(['static'])])
  };
  var styles$R = StyleSheet.create({
    handler: css$1(_templateObject$S || (_templateObject$S = _taggedTemplateLiteral(["\n    top: 0;\n    bottom: 0;\n    left: 0;\n    right: 0;\n    position: absolute;\n    flex-grow: 1;\n  "])))
  });
  var initialState = {
    waitingForMouseUp: false,
    isDialogClick: false
  };

  var BackdropHandler = function BackdropHandler(props) {
    var toggleRef = props.toggleRef,
        dialogRef = props.dialogRef,
        handleClose = props.onClose,
        _props$backdrop = props.backdrop,
        backdrop = _props$backdrop === void 0 ? true : _props$backdrop,
        _props$autoClose = props.autoClose,
        autoClose = _props$autoClose === void 0 ? 'outside' : _props$autoClose;

    if (_reactNative.Platform.OS === 'web') {
      var state = React.useMemo(function () {
        return initialState;
      }, []);
      React.useEffect(function () {
        var toggle = toggleRef ? _reactNative.findNodeHandle(toggleRef.current) : undefined;
        var dialog = _reactNative.findNodeHandle(dialogRef.current);

        var handleDialogMouseDown = function handleDialogMouseDown() {
          state.waitingForMouseUp = true;
        };

        var handleDocumentClick = function handleDocumentClick(_ref) {
          var target = _ref.target;

          if (backdrop === 'static' || autoClose === false) {
            return;
          } // Click outside -> return if autoClose is inside.


          if (!state.isDialogClick && autoClose === 'inside') {
            return;
          } // Click inside / on dialog -> return if autoClose is outside.


          if (state.isDialogClick) {
            state.isDialogClick = false;

            if (autoClose === 'outside') {
              return;
            }
          } // Click on toggle -> return always.


          if (toggle && (target === toggle || toggle.contains(target))) {
            return;
          }

          handleClose();
        };

        var handleDocumentMouseUp = function handleDocumentMouseUp() {
          if (state.waitingForMouseUp) {
            state.isDialogClick = true;
          }

          state.waitingForMouseUp = false;
        };

        dialog.addEventListener('mousedown', handleDialogMouseDown); // See https://github.com/necolas/react-native-web/issues/2115

        document.addEventListener('click', handleDocumentClick, true);
        document.addEventListener('mouseup', handleDocumentMouseUp, true);
        return function () {
          dialog.addEventListener('mousedown', handleDialogMouseDown);
          document.removeEventListener('click', handleDocumentClick, true);
          document.removeEventListener('mouseup', handleDocumentMouseUp, true);
        };
      }, [backdrop, autoClose]);
      return null;
    }

    if (backdrop !== true) {
      return null;
    }

    return /*#__PURE__*/React__default["default"].createElement(Pressable, {
      style: styles$R.handler,
      onPress: function onPress() {
        handleClose();
      },
      accessible: false,
      importantForAccessibility: "no"
    });
  };

  BackdropHandler.displayName = 'BackdropHandler';
  BackdropHandler.propTypes = propTypes$10;

  var _excluded$10 = ["children", "start", "end", "style", "textStyle"];

  var _templateObject$R, _templateObject2$D, _templateObject3$i, _templateObject4$g, _templateObject5$e, _templateObject6$d, _templateObject7$9, _templateObject8$8, _templateObject9$6, _templateObject10$6;
  var ALIGNMENT_BREAKPOINTS = [true, 'sm', 'md', 'lg', 'xl', 'xxl'];
  var propTypes$$ = {
    children: PropTypes.node.isRequired,
    start: PropTypes.oneOf(ALIGNMENT_BREAKPOINTS),
    end: PropTypes.oneOf(ALIGNMENT_BREAKPOINTS),
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$Q = StyleSheet.create(_objectSpread2(_objectSpread2(_objectSpread2({
    '.dropdown-menu': css$1(_templateObject$R || (_templateObject$R = _taggedTemplateLiteral(["\n    position: absolute;\n    z-index: $zindex-dropdown;\n    // display: none; // none by default, but block on \"open\" of the menu\n    min-width: $dropdown-min-width;\n    padding: $dropdown-padding-y $dropdown-padding-x;\n    margin: 0; // Override default margin of ul\n    // list-style: none;\n    background-color: $dropdown-bg;\n    // background-clip: padding-box;\n    border: $dropdown-border-width solid $dropdown-border-color;\n    border-radius: $dropdown-border-radius;\n    // @include box-shadow($dropdown-box-shadow);\n  "]))),
    '.dropdown-menu[data-bs-popper]': css$1(_templateObject2$D || (_templateObject2$D = _taggedTemplateLiteral(["\n    top: 100%;\n    left: 0;\n    margin-top: $dropdown-spacer;\n  "])))
  }, each(GRID_BREAKPOINTS, function (breakpoint) {
    var _ref;

    return _ref = {}, _defineProperty(_ref, ".dropdown-menu".concat(infix(breakpoint), "-start[data-bs-popper]"), css$1(_templateObject3$i || (_templateObject3$i = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        right: auto;\n        left: 0;\n      }\n    "])), breakpoint)), _defineProperty(_ref, ".dropdown-menu".concat(infix(breakpoint), "-end[data-bs-popper]"), css$1(_templateObject4$g || (_templateObject4$g = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        right: 0;\n        left: auto;\n      }\n    "])), breakpoint)), _ref;
  })), {}, {
    '.dropup .dropdown-menu[data-bs-popper]': css$1(_templateObject5$e || (_templateObject5$e = _taggedTemplateLiteral(["\n    top: auto;\n    bottom: 100%;\n    margin-top: 0;\n    margin-bottom: $dropdown-spacer;\n  "]))),
    '.dropend .dropdown-menu[data-bs-popper]': css$1(_templateObject6$d || (_templateObject6$d = _taggedTemplateLiteral(["\n    top: 0;\n    right: auto;\n    left: 100%;\n    margin-top: 0;\n    margin-left: $dropdown-spacer;\n  "]))),
    '.dropstart .dropdown-menu[data-bs-popper]': css$1(_templateObject7$9 || (_templateObject7$9 = _taggedTemplateLiteral(["\n    top: 0;\n    right: 100%;\n    left: auto;\n    margin-top: 0;\n    margin-right: $dropdown-spacer;\n  "]))),
    '.navbar-nav .dropdown-menu': css$1(_templateObject8$8 || (_templateObject8$8 = _taggedTemplateLiteral(["\n    position: relative; // static;\n  "])))
  }, each(GRID_BREAKPOINTS, function (breakpoint) {
    return _defineProperty({}, ".navbar-expand".concat(infix(next(breakpoint)), " .navbar-nav .dropdown-menu"), css$1(_templateObject9$6 || (_templateObject9$6 = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        position: absolute;\n      }\n    "])), next(breakpoint)));
  })), {}, {
    '.dropdown-menu-text': css$1(_templateObject10$6 || (_templateObject10$6 = _taggedTemplateLiteral(["\n    font-size: $dropdown-font-size;\n    color: $dropdown-color;\n    text-align: left; // Ensures proper alignment if parent has it changed (e.g., modal footer)\n  "])))
  }));

  var getAlignment = function getAlignment(media, start, end) {
    var alignStart = typeof start === 'boolean' ? start : media.up(start);
    var alignEnd = typeof end === 'boolean' ? end : media.up(end);

    if (!alignEnd) {
      return 'start';
    }

    if (!alignStart) {
      return 'end';
    }

    var startIndex = ALIGNMENT_BREAKPOINTS.indexOf(start);
    var endIndex = ALIGNMENT_BREAKPOINTS.indexOf(end);
    return startIndex > endIndex ? 'start' : 'end';
  };

  var transformPlacement = function transformPlacement(media, direction, start, end) {
    if (direction === 'start' || direction === 'end') {
      return "".concat(direction, " top");
    }

    return "".concat(direction, " ").concat(getAlignment(media, start, end));
  };

  var DropdownMenu = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        _props$start = props.start,
        start = _props$start === void 0 ? true : _props$start,
        _props$end = props.end,
        end = _props$end === void 0 ? false : _props$end,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$10);

    var navbar = React.useContext(NavbarContext);
    var media = useMedia();
    var dialogRef = React.useRef();
    var dropdown = useForcedContext(DropdownContext);
    var identifier = dropdown.identifier,
        toggleRef = dropdown.toggleRef,
        visible = dropdown.visible,
        setVisible = dropdown.setVisible,
        direction = dropdown.direction,
        display = dropdown.display,
        autoClose = dropdown.autoClose;

    if (!visible) {
      return null;
    }

    var isStatic = _reactNative.Platform.OS === 'web' && display === 'static';
    var isCollapsedNavbar = navbar && !(navbar.expand && (navbar.expand === true || media.up(navbar.expand)));
    var hasStaticStyle = isStatic && !isCollapsedNavbar;
    var classes = getStyles(styles$Q, ['.dropdown-menu', // Non-Popper styles
    hasStaticStyle && '.dropdown-menu[data-bs-popper]', hasStaticStyle && start && ".dropdown-menu".concat(start === true ? '' : "-".concat(start), "-start[data-bs-popper]"), hasStaticStyle && end && ".dropdown-menu".concat(end === true ? '' : "-".concat(end), "-end[data-bs-popper]"), hasStaticStyle && direction === 'up' && '.dropup .dropdown-menu[data-bs-popper]', hasStaticStyle && direction === 'end' && '.dropend .dropdown-menu[data-bs-popper]', hasStaticStyle && direction === 'start' && '.dropstart .dropdown-menu[data-bs-popper]', // Navbar styles
    navbar && '.navbar-nav .dropdown-menu', navbar && navbar.expand && ".navbar-expand".concat(navbar.expand === true ? '' : "-".concat(navbar.expand), " .navbar-nav .dropdown-menu")]);
    var textClasses = getStyles(styles$Q, ['.dropdown-menu-text']);

    if (isStatic || isCollapsedNavbar) {
      return /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, !isCollapsedNavbar && /*#__PURE__*/React__default["default"].createElement(BackdropHandler, {
        toggleRef: toggleRef,
        dialogRef: dialogRef,
        onClose: function onClose() {
          setVisible(false);
        },
        autoClose: autoClose
      }), /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
        ref: concatRefs(dialogRef, ref),
        accessibilityLabelledBy: identifier,
        style: [classes, style],
        textStyle: [textClasses, textStyle]
      }), children));
    }

    return /*#__PURE__*/React__default["default"].createElement(OverlayContainer, null, /*#__PURE__*/React__default["default"].createElement(Overlay, {
      placement: transformPlacement(media, direction, start, end),
      targetRef: toggleRef,
      offset: convertToNumber(StyleSheet.value('dropdown-spacer')),
      visible: visible
    }, function (overlay, overlayRef) {
      return /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement(BackdropHandler, {
        toggleRef: toggleRef,
        dialogRef: overlayRef,
        onClose: function onClose() {
          setVisible(false);
        },
        autoClose: autoClose
      }), /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
        ref: concatRefs(overlayRef, ref),
        accessibilityLabelledBy: identifier,
        style: [classes, overlay.overlayProps.style, {
          maxHeight: 'auto',
          opacity: overlay.rendered ? 1 : 0
        }, style],
        textStyle: [textClasses, textStyle]
      }), /*#__PURE__*/React__default["default"].createElement(DropdownContext.Provider, {
        value: dropdown
      }, children)));
    }));
  });
  DropdownMenu.displayName = 'DropdownMenu';
  DropdownMenu.propTypes = propTypes$$;

  var _excluded$$ = ["children", "size", "style"];

  var _templateObject$Q, _templateObject2$C;
  var propTypes$_ = {
    children: PropTypes.node.isRequired,
    size: PropTypes.oneOf(Object.keys(FONT_SIZES).map(function (k) {
      return Number(k);
    })).isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$P = StyleSheet.create(_objectSpread2({
    heading: css$1(_templateObject$Q || (_templateObject$Q = _taggedTemplateLiteral(["\n    margin-top: 0; // 1\n    margin-bottom: $headings-margin-bottom;\n    font-family: $headings-font-family;\n    font-style: $headings-font-style;\n    font-weight: $headings-font-weight;\n    color: $headings-color;\n  "])))
  }, each(FONT_SIZES, function (size, value) {
    return _defineProperty({}, ".h".concat(size), css$1(_templateObject2$C || (_templateObject2$C = _taggedTemplateLiteral(["\n      font-size: ", ";\n      line-height: ", " * $headings-line-height;\n    "])), value, value));
  })));
  var Heading$1 = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        size = props.size,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$$);

    var classes = getStyles(styles$P, ['heading', ".h".concat(size)]);
    return /*#__PURE__*/React__default["default"].createElement(Text, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: "header",
      accessibilityLevel: size,
      style: [classes, style]
    }), children);
  });
  Heading$1.displayName = 'Heading';
  Heading$1.propTypes = propTypes$_;

  var _excluded$_ = ["children", "style", "textStyle"];

  var _templateObject$P, _templateObject2$B;
  var propTypes$Z = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$O = StyleSheet.create({
    '.dropdown-header': css$1(_templateObject$P || (_templateObject$P = _taggedTemplateLiteral(["\n    // display: block;\n    padding: $dropdown-header-padding;\n  "]))),
    '.dropdown-header-text': css$1(_templateObject2$B || (_templateObject2$B = _taggedTemplateLiteral(["\n    margin-bottom: 0; // for use with heading elements\n    font-size: $font-size-sm;\n    color: $dropdown-header-color;\n    // white-space: nowrap; // as with > li > a\n  "])))
  });
  var DropdownHeader = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$_);

    var classes = getStyles(styles$O, ['.dropdown-header']);
    var textClasses = getStyles(styles$O, ['.dropdown-header-text']); // composite component

    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      size: 6,
      style: [classes, style]
    }), /*#__PURE__*/React__default["default"].createElement(Heading$1, {
      style: [textClasses, textStyle]
    }, children));
  });
  DropdownHeader.displayName = 'DropdownHeader';
  DropdownHeader.propTypes = propTypes$Z;

  var _excluded$Z = ["children", "onPress", "active", "disabled", "style", "textStyle"];

  var _templateObject$O, _templateObject2$A, _templateObject3$h, _templateObject4$f, _templateObject5$d, _templateObject6$c;
  var propTypes$Y = {
    children: PropTypes.node.isRequired,
    onPress: PropTypes.func,
    active: PropTypes.bool,
    disabled: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$N = StyleSheet.create({
    '.dropdown-item': css$1(_templateObject$O || (_templateObject$O = _taggedTemplateLiteral(["\n    width: 100%;\n    padding: $dropdown-item-padding-y $dropdown-item-padding-x;\n    // clear: both;\n    background-color: transparent;\n    border: 0;\n\n    &:hover {\n      // @include gradient-bg($dropdown-link-hover-bg);\n      background-color: $dropdown-link-hover-bg;\n    }\n    &:focus {\n      // @include gradient-bg($dropdown-link-hover-bg);\n      background-color: $dropdown-link-hover-bg;\n    }\n  "]))),
    '.dropdown-item-text': css$1(_templateObject2$A || (_templateObject2$A = _taggedTemplateLiteral(["\n    font-weight: $font-weight-normal;\n    color: $dropdown-link-color;\n    // text-align: inherit;\n    text-decoration: none; // if($link-decoration == none, null, none);\n    // white-space: nowrap;\n\n    &:hover {\n      color: $dropdown-link-hover-color;\n      text-decoration: none; // if($link-hover-decoration == underline, none, null);\n    }\n    &:focus {\n      color: $dropdown-link-hover-color;\n      text-decoration: none; // if($link-hover-decoration == underline, none, null);\n    }\n  "]))),
    '.dropdown-item-active': css$1(_templateObject3$h || (_templateObject3$h = _taggedTemplateLiteral(["\n    // @include gradient-bg($dropdown-link-active-bg);\n    background-color: $dropdown-link-active-bg;\n\n    &:hover {\n      background-color: $dropdown-link-active-bg;\n    }\n    &:focus {\n      background-color: $dropdown-link-active-bg;\n    }\n  "]))),
    '.dropdown-item-active-text': css$1(_templateObject4$f || (_templateObject4$f = _taggedTemplateLiteral(["\n    color: $dropdown-link-active-color;\n    text-decoration: none;\n\n    &:hover {\n      color: $dropdown-link-active-color;\n    }\n    &:focus {\n      color: $dropdown-link-active-color;\n    }\n  "]))),
    '.dropdown-item-disabled': css$1(_templateObject5$d || (_templateObject5$d = _taggedTemplateLiteral(["\n    // pointer-events: none;\n    background-color: transparent;\n    // Remove CSS gradients if they're enabled\n    // background-image: if($enable-gradients, none, null);\n\n    &:hover {\n      background-color: transparent;\n    }\n    &:focus {\n      background-color: transparent;\n    }\n  "]))),
    '.dropdown-item-disabled-text': css$1(_templateObject6$c || (_templateObject6$c = _taggedTemplateLiteral(["\n    color: $dropdown-link-disabled-color;\n\n    &:hover {\n      color: $dropdown-link-disabled-color;\n    }\n    &:focus {\n      color: $dropdown-link-disabled-color;\n    }\n  "])))
  });

  var DropdownItem = function DropdownItem(props) {
    var children = props.children,
        handlePress = props.onPress,
        _props$active = props.active,
        active = _props$active === void 0 ? false : _props$active,
        _props$disabled = props.disabled,
        disabled = _props$disabled === void 0 ? false : _props$disabled,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$Z);

    var dropdown = useForcedContext(DropdownContext);
    var classes = getStyles(styles$N, ['.dropdown-item', active && '.dropdown-item-active', disabled && '.dropdown-item-disabled']);
    var textClasses = getStyles(styles$N, ['.dropdown-item-text', active && '.dropdown-item-active-text', disabled && '.dropdown-item-disabled-text']);
    return /*#__PURE__*/React__default["default"].createElement(Pressable, _extends$1({}, elementProps, {
      onPress: concatFns(function () {
        dropdown.setVisible(false);
      }, handlePress),
      disabled: disabled,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children);
  };

  DropdownItem.displayName = 'DropdownItem';
  DropdownItem.propTypes = propTypes$Y;

  var _excluded$Y = ["children", "style", "textStyle"];

  var _templateObject$N, _templateObject2$z;
  var propTypes$X = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$M = StyleSheet.create({
    '.dropdown-item-text': css$1(_templateObject$N || (_templateObject$N = _taggedTemplateLiteral(["\n    // display: block;\n    padding: $dropdown-item-padding-y $dropdown-item-padding-x;\n  "]))),
    '.dropdown-item-text-text': css$1(_templateObject2$z || (_templateObject2$z = _taggedTemplateLiteral(["\n    color: $dropdown-link-color;\n  "])))
  });
  var DropdownItemText = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$Y);

    var classes = getStyles(styles$M, ['.dropdown-item-text']);
    var textClasses = getStyles(styles$M, ['.dropdown-item-text-text']); // composite component

    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), /*#__PURE__*/React__default["default"].createElement(Text, {
      style: [textClasses, textStyle]
    }, children));
  });
  DropdownItemText.displayName = 'DropdownItemText';
  DropdownItemText.propTypes = propTypes$X;

  var _excluded$X = ["style"];

  var _templateObject$M;
  var propTypes$W = {
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$L = StyleSheet.create({
    '.dropdown-divider': css$1(_templateObject$M || (_templateObject$M = _taggedTemplateLiteral(["\n    height: 0;\n    margin: $dropdown-divider-margin-y 0;\n    overflow: hidden;\n    border-top-width: 1px;\n    border-style: solid;\n    border-color: $dropdown-divider-bg;\n  "])))
  });
  var DropdownDivider = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$X);

    var classes = getStyles(styles$L, ['.dropdown-divider']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }));
  });
  DropdownDivider.displayName = 'DropdownDivider';
  DropdownDivider.propTypes = propTypes$W;

  function useDropdown(defaultVisible, controlledVisible, onToggle, direction, display, autoClose) {
    var identifier = useIdentifier('dropdown');
    var toggleRef = React.useRef();

    var _useControlledState = useControlledState(defaultVisible, controlledVisible, onToggle),
        _useControlledState2 = _slicedToArray(_useControlledState, 2),
        visible = _useControlledState2[0],
        setVisible = _useControlledState2[1];

    return React.useMemo(function () {
      return {
        identifier: identifier,
        visible: visible,
        setVisible: setVisible,
        toggleRef: toggleRef,
        direction: direction,
        display: display,
        autoClose: autoClose
      };
    }, [visible]);
  }

  var _excluded$W = ["onPress"];
  function useDismissDropdown(props) {
    var context = useForcedContext(DropdownContext);

    var handlePress = props.onPress,
        restProps = _objectWithoutProperties(props, _excluded$W);

    return _objectSpread2(_objectSpread2({}, restProps), {}, {
      onPress: function onPress(event) {
        if (handlePress) handlePress(event);
        context.setVisible(false);
      }
    });
  }

  var _excluded$V = ["children", "defaultVisible", "visible", "onToggle", "direction", "display", "autoClose", "style"];

  var _templateObject$L;
  var DIRECTIONS = ['top', 'bottom', 'start', 'end'];
  var propTypes$V = {
    children: PropTypes.node,
    defaultVisible: PropTypes.bool,
    visible: PropTypes.bool,
    onToggle: PropTypes.func,
    direction: PropTypes.oneOf(DIRECTIONS),
    display: PropTypes.oneOf(['dynamic', 'static']),
    autoClose: PropTypes.oneOfType([PropTypes.bool, PropTypes.oneOf(['inside', 'outside'])]),
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$K = StyleSheet.create({
    '.dropdown': css$1(_templateObject$L || (_templateObject$L = _taggedTemplateLiteral(["\n    position: relative;\n  "])))
  });
  var Dropdown = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        _props$defaultVisible = props.defaultVisible,
        defaultVisible = _props$defaultVisible === void 0 ? false : _props$defaultVisible,
        visible = props.visible,
        onToggle = props.onToggle,
        _props$direction = props.direction,
        direction = _props$direction === void 0 ? 'bottom' : _props$direction,
        _props$display = props.display,
        display = _props$display === void 0 ? 'dynamic' : _props$display,
        _props$autoClose = props.autoClose,
        autoClose = _props$autoClose === void 0 ? 'outside' : _props$autoClose,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$V);

    var dropdown = useDropdown(defaultVisible, visible, onToggle, direction, display, autoClose);
    var classes = getStyles(styles$K, ['.dropdown']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), /*#__PURE__*/React__default["default"].createElement(DropdownContext.Provider, {
      value: dropdown
    }, children));
  });
  Dropdown.displayName = 'Dropdown';
  Dropdown.propTypes = propTypes$V;
  Dropdown.Context = DropdownContext;
  Dropdown.Toggle = DropdownToggle;
  Dropdown.Menu = DropdownMenu;
  Dropdown.Header = DropdownHeader;
  Dropdown.Item = DropdownItem;
  Dropdown.ItemText = DropdownItemText;
  Dropdown.Divider = DropdownDivider;
  Dropdown.useDismiss = useDismissDropdown;
  Dropdown.useToggle = useToggleDropdown;

  var _excluded$U = ["children", "size", "style"];

  var _templateObject$K;
  var propTypes$U = {
    children: PropTypes.node.isRequired,
    size: PropTypes.oneOf(Object.keys(DISPLAY_FONT_SIZES).map(function (k) {
      return Number(k);
    })).isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$J = StyleSheet.create(_objectSpread2({}, each(DISPLAY_FONT_SIZES, function (size, value) {
    return _defineProperty({}, ".display-".concat(size), css$1(_templateObject$K || (_templateObject$K = _taggedTemplateLiteral(["\n      font-size: ", ";\n      line-height: ", " * $headings-line-height;\n    "])), value, value));
  })));
  var DisplayHeading = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        size = props.size,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$U);

    var classes = getStyles(styles$J, [".display-".concat(size)]);
    return /*#__PURE__*/React__default["default"].createElement(Heading$1, _extends$1({}, elementProps, {
      ref: ref,
      size: 1,
      style: [classes, style]
    }), children);
  });
  DisplayHeading.displayName = 'Heading';
  DisplayHeading.propTypes = propTypes$U;

  var _excluded$T = ["children", "type", "style"];

  var _templateObject$J;
  var propTypes$T = {
    children: PropTypes.node.isRequired,
    type: PropTypes.oneOf(Object.keys(FORM_VALIDATION_STATES)),
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$I = StyleSheet.create(_objectSpread2({}, each(FORM_VALIDATION_STATES, function (state, data) {
    return _defineProperty({}, ".".concat(state, "-feedback"), css$1(_templateObject$J || (_templateObject$J = _taggedTemplateLiteral(["\n      // display: none;\n      width: 100%;\n      margin-top: $form-feedback-margin-top;\n      font-size: $form-feedback-font-size;\n      font-style: $form-feedback-font-style;\n      color: ", ";\n    "])), function (t) {
      return data(t).color;
    }));
  })));
  var Feedback = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        type = props.type,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$T);

    var classes = getStyles(styles$I, [".".concat(type, "-feedback")]);
    return /*#__PURE__*/React__default["default"].createElement(Text, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), children);
  });
  Feedback.displayName = 'Feedback';
  Feedback.propTypes = propTypes$T;

  var _excluded$S = ["children", "style", "textStyle"];

  var _templateObject$I, _templateObject2$y;
  var propTypes$S = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$H = StyleSheet.create({
    '.form-text': css$1(_templateObject$I || (_templateObject$I = _taggedTemplateLiteral(["\n    margin-top: $form-text-margin-top;\n  "]))),
    '.form-text-text': css$1(_templateObject2$y || (_templateObject2$y = _taggedTemplateLiteral(["\n    font-size: $form-text-font-size;\n    font-style: $form-text-font-style;\n    font-weight: $form-text-font-weight;\n    color: $form-text-color;\n  "])))
  });
  var FormText = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$S);

    var classes = getStyles(styles$H, ['.form-text']);
    var textClasses = getStyles(styles$H, ['.form-text-text']); // composite component

    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), /*#__PURE__*/React__default["default"].createElement(Text, {
      style: [textClasses, textStyle]
    }, children));
  });
  FormText.displayName = 'FormText';
  FormText.propTypes = propTypes$S;

  var _excluded$R = ["onFocus", "onBlur", "style", "styleName"];
  var propTypes$R = {
    onFocus: PropTypes.func,
    onBlur: PropTypes.func,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    styleName: PropTypes.any
  };
  var TextInput = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var _props$onFocus = props.onFocus,
        _onFocus = _props$onFocus === void 0 ? function () {} : _props$onFocus,
        _props$onBlur = props.onBlur,
        _onBlur = _props$onBlur === void 0 ? function () {} : _props$onBlur,
        style = props.style,
        styleName = props.styleName,
        elementProps = _objectWithoutProperties(props, _excluded$R);

    var _useState = React.useState(false),
        _useState2 = _slicedToArray(_useState, 2),
        focused = _useState2[0],
        setFocused = _useState2[1];

    var media = useMedia();
    var resolveStyle = useStyle(style, styleName);
    return /*#__PURE__*/React__default["default"].createElement(_reactNative.TextInput, _extends$1({}, elementProps, {
      ref: ref,
      onFocus: function onFocus() {
        setFocused(true);

        _onFocus();
      },
      onBlur: function onBlur() {
        setFocused(false);

        _onBlur();
      },
      style: resolveStyle({
        media: media,
        interaction: {
          focused: focused
        }
      })
    }));
  });
  TextInput.displayName = 'TextInput';
  TextInput.propTypes = propTypes$R;

  var _excluded$Q = ["size", "placeholderTextColor", "multiline", "disabled", "valid", "invalid", "style"];

  var _templateObject$H, _templateObject2$x, _templateObject3$g, _templateObject4$e, _templateObject5$c, _templateObject6$b, _templateObject7$8, _templateObject8$7;
  var propTypes$Q = {
    size: PropTypes.oneOf(['sm', 'lg']),
    placeholderTextColor: PropTypes.string,
    multiline: PropTypes.bool,
    disabled: PropTypes.bool,
    valid: PropTypes.bool,
    invalid: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$G = StyleSheet.create(_objectSpread2({
    '.form-control': css$1(_templateObject$H || (_templateObject$H = _taggedTemplateLiteral(["\n    // display: block;\n    width: 100%;\n    padding: $input-padding-y $input-padding-x;\n    font-family: $input-font-family;\n    font-size: $input-font-size;\n    font-weight: $input-font-weight;\n    line-height: $input-font-size * $input-line-height;\n    color: $input-color;\n    background-color: $input-bg;\n    // background-clip: padding-box;\n    border: $input-border-width solid $input-border-color;\n    @include platform(web) {\n      appearance: none; // Fix appearance for date inputs in Safari\n    }\n\n    // Note: This has no effect on <select>s in some browsers, due to the limited stylability of \"<select>\"s in CSS.\n    border-radius: $input-border-radius;\n\n    // @include box-shadow($input-box-shadow);\n    // @include transition($input-transition);\n\n    // Customize the \":focus\" state to imitate native WebKit styles.\n    &:focus {\n      color: $input-focus-color;\n      background-color: $input-focus-bg;\n      border-color: $input-focus-border-color;\n      @include platform(web) {\n        outline-width: 0; // outline: 0;\n      }\n      /* @if $enable-shadows {\n        @include box-shadow($input-box-shadow, $input-focus-box-shadow);\n      } @else {\n        // Avoid using mixin so we can pass custom focus shadow properly\n        box-shadow: $input-focus-box-shadow;\n      } */\n    }\n  "]))),
    '.form-control-disabled': css$1(_templateObject2$x || (_templateObject2$x = _taggedTemplateLiteral(["\n    background-color: $input-disabled-bg;\n    border-color: $input-disabled-border-color;\n    // iOS fix for unreadable disabled content; see https://github.com/twbs/bootstrap/issues/11655.\n    opacity: 1;\n  "]))),
    '.form-control-sm': css$1(_templateObject3$g || (_templateObject3$g = _taggedTemplateLiteral(["\n    min-height: $input-height-sm;\n    padding: $input-padding-y-sm $input-padding-x-sm;\n    font-size: $input-font-size-sm;\n    line-height: $input-font-size-sm * $line-height-base; // added for bootstrap-rn\n    border-radius: $input-border-radius-sm;\n  "]))),
    '.form-control-lg': css$1(_templateObject4$e || (_templateObject4$e = _taggedTemplateLiteral(["\n    min-height: $input-height-lg;\n    padding: $input-padding-y-lg $input-padding-x-lg;\n    font-size: $input-font-size-lg;\n    line-height: $input-font-size-lg * $line-height-base; // added for bootstrap-rn\n    border-radius: $input-border-radius-lg;\n  "]))),
    '.form-control-multiline': css$1(_templateObject5$c || (_templateObject5$c = _taggedTemplateLiteral(["\n    text-align-vertical: top; // added for bootstrap-rn\n    min-height: $input-height;\n\n    @include platform(ios) {\n      min-height: $input-height-sm + 8rem; // added for bootstrap-rn\n    }\n  "]))),
    '.form-control-multiline-sm': css$1(_templateObject6$b || (_templateObject6$b = _taggedTemplateLiteral(["\n    min-height: $input-height-sm;\n\n    @include platform(ios) {\n      // TODO: Adjust ios height to sm size\n      min-height: $input-height-sm + 8rem; // added for bootstrap-rn\n    }\n  "]))),
    '.form-control-multiline-lg': css$1(_templateObject7$8 || (_templateObject7$8 = _taggedTemplateLiteral(["\n    min-height: $input-height-lg;\n\n    @include platform(ios) {\n      // TODO: Adjust ios height to lg size\n      min-height: $input-height-sm + 8rem; // added for bootstrap-rn\n    }\n  "])))
  }, each(FORM_VALIDATION_STATES, function (state, data) {
    return _defineProperty({}, ".form-control.is-".concat(state), css$1(_templateObject8$7 || (_templateObject8$7 = _taggedTemplateLiteral(["\n      border-color: ", ";\n\n      &:focus {\n        border-color: ", ";\n        // box-shadow: $focus-box-shadow;\n      }\n    "])), function (t) {
      return data(t).color;
    }, function (t) {
      return data(t).color;
    }));
  })));
  var Input = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var _useModifier = useModifier('useFormField', props, ref),
        _useModifier2 = _slicedToArray(_useModifier, 2),
        modifierProps = _useModifier2[0],
        modifierRef = _useModifier2[1];

    var size = modifierProps.size,
        placeholderTextColor = modifierProps.placeholderTextColor,
        _modifierProps$multil = modifierProps.multiline,
        multiline = _modifierProps$multil === void 0 ? false : _modifierProps$multil,
        _modifierProps$disabl = modifierProps.disabled,
        disabled = _modifierProps$disabl === void 0 ? false : _modifierProps$disabl,
        _modifierProps$valid = modifierProps.valid,
        valid = _modifierProps$valid === void 0 ? false : _modifierProps$valid,
        _modifierProps$invali = modifierProps.invalid,
        invalid = _modifierProps$invali === void 0 ? false : _modifierProps$invali,
        style = modifierProps.style,
        elementProps = _objectWithoutProperties(modifierProps, _excluded$Q);

    var classes = getStyles(styles$G, ['.form-control', disabled && '.form-control-disabled', size === 'sm' && '.form-control-sm', size === 'lg' && '.form-control-lg', multiline && '.form-control-multiline', multiline && size === 'sm' && '.form-control-multiline-sm', multiline && size === 'lg' && '.form-control-multiline-lg', valid && '.form-control.is-valid', invalid && '.form-control.is-invalid']);
    return /*#__PURE__*/React__default["default"].createElement(TextInput, _extends$1({}, elementProps, {
      ref: modifierRef,
      placeholderTextColor: placeholderTextColor || StyleSheet.value('input-placeholder-color'),
      multiline: multiline,
      disabled: disabled,
      editable: !disabled,
      selectTextOnFocus: !disabled,
      style: [classes, style]
    }));
  });
  Input.displayName = 'Input';
  Input.propTypes = propTypes$Q;

  var PLACEMENTS$1 = ['top', 'bottom', 'left', 'right'];
  var TRIGGERS = ['press', 'hover', 'focus', 'manual', 'press hover', 'hover press', 'hover focus', 'focus hover', 'press focus', 'focus press'];
  var TriggerPropTypes = {
    trigger: PropTypes.oneOf(TRIGGERS),
    placement: PropTypes.oneOf(PLACEMENTS$1),
    offset: PropTypes.number,
    defaultVisible: PropTypes.bool,
    visible: PropTypes.bool,
    onToggle: PropTypes.func
  };
  function useTrigger(rawTrigger, props, elementProps, ref) {
    var _props$defaultVisible = props.defaultVisible,
        defaultVisible = _props$defaultVisible === void 0 ? false : _props$defaultVisible,
        controlledVisible = props.visible,
        onToggle = props.onToggle;
    var _onPress = elementProps.onPress,
        _onFocus = elementProps.onFocus,
        _onBlur = elementProps.onBlur,
        _onMouseOver = elementProps.onMouseOver,
        _onMouseLeave = elementProps.onMouseLeave;
    var trigger = rawTrigger.split(' ');
    var identifier = useIdentifier('overlay');

    var _useControlledState = useControlledState(defaultVisible, controlledVisible, onToggle),
        _useControlledState2 = _slicedToArray(_useControlledState, 2),
        visible = _useControlledState2[0],
        setVisible = _useControlledState2[1];

    var _useState = React.useState(false),
        _useState2 = _slicedToArray(_useState, 2),
        focused = _useState2[0],
        setFocused = _useState2[1];

    var _useState3 = React.useState(false),
        _useState4 = _slicedToArray(_useState3, 2),
        hovered = _useState4[0],
        setHovered = _useState4[1];

    var targetRef = React.useRef();
    return {
      visible: visible,
      setVisible: setVisible,
      targetProps: _objectSpread2(_objectSpread2({
        ref: concatRefs(targetRef, ref)
      }, optional(visible, {
        accessibilityDescribedBy: identifier
      })), {}, {
        onPress: function onPress(event) {
          var handleHoverAsPress = (_reactNative.Platform.OS === 'android' || _reactNative.Platform.OS === 'ios') && trigger.includes('hover');

          if (trigger.includes('press') || handleHoverAsPress) {
            setVisible(function (value) {
              return !value;
            });
          }

          if (_onPress) {
            _onPress(event);
          }
        },
        onFocus: function onFocus(event) {
          if (trigger.includes('focus')) {
            setFocused(true);

            if (!visible) {
              setVisible(true);
            }
          }

          if (_onFocus) {
            _onFocus(event);
          }
        },
        onBlur: function onBlur(event) {
          if (trigger.includes('focus')) {
            setFocused(false);
            var activeHoverTrigger = trigger.includes('hover') && hovered;

            if (visible && !activeHoverTrigger) {
              setVisible(false);
            }
          }

          if (_onBlur) {
            _onBlur(event);
          }
        },
        onMouseOver: function onMouseOver(event) {
          if (trigger.includes('hover')) {
            setHovered(true);

            if (!visible && !focused) {
              setVisible(true);
            }
          }

          if (_onMouseOver) {
            _onMouseOver(event);
          }
        },
        onMouseLeave: function onMouseLeave(event) {
          if (trigger.includes('hover')) {
            setHovered(false);
            var activeFocusTrigger = trigger.includes('focus') && focused;

            if (visible && !activeFocusTrigger) {
              setVisible(false);
            }
          }

          if (_onMouseLeave) {
            _onMouseLeave(event);
          }
        }
      }),
      targetRef: targetRef,
      templateProps: {
        nativeID: identifier
      }
    };
  }

  var PopoverContext = /*#__PURE__*/React__default["default"].createContext();
  PopoverContext.displayName = 'PopoverContext';

  var _excluded$P = ["style"];

  var _templateObject$G, _templateObject2$w, _templateObject3$f, _templateObject4$d, _templateObject5$b, _templateObject6$a, _templateObject7$7, _templateObject8$6, _templateObject9$5, _templateObject10$5, _templateObject11$4, _templateObject12$3, _templateObject13$3, _templateObject14$2, _templateObject15$1;
  var propTypes$P = {
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$F = StyleSheet.create({
    '.popover-arrow': css$1(_templateObject$G || (_templateObject$G = _taggedTemplateLiteral(["\n    position: absolute;\n    // display: block;\n    width: $popover-arrow-width;\n    height: $popover-arrow-height;\n  "]))),
    '.popover-arrow::before': css$1(_templateObject2$w || (_templateObject2$w = _taggedTemplateLiteral(["\n    position: absolute;\n    // display: block;\n    // content: \"\";\n    border-top-color: transparent;\n    border-right-color: transparent;\n    border-left-color: transparent;\n    border-bottom-color: transparent;\n    border-style: solid;\n  "]))),
    '.popover-arrow::after': css$1(_templateObject3$f || (_templateObject3$f = _taggedTemplateLiteral(["\n    position: absolute;\n    // display: block;\n    // content: \"\";\n    border-top-color: transparent;\n    border-right-color: transparent;\n    border-left-color: transparent;\n    border-bottom-color: transparent;\n    border-style: solid;\n  "]))),
    '.bs-popover-top .popover-arrow': css$1(_templateObject4$d || (_templateObject4$d = _taggedTemplateLiteral(["\n    bottom: ", ";\n  "])), subtract(function (t) {
      return "-".concat(t['popover-arrow-height']);
    }, function (t) {
      return t['popover-border-width'];
    })),
    '.bs-popover-top .popover-arrow::before': css$1(_templateObject5$b || (_templateObject5$b = _taggedTemplateLiteral(["\n    bottom: 0;\n    border-top-width: $popover-arrow-height;\n    border-right-width: $popover-arrow-width * 0.5;\n    border-left-width: $popover-arrow-width * 0.5;\n    border-bottom-width: 0;\n    border-top-color: $popover-arrow-outer-color;\n  "]))),
    '.bs-popover-top .popover-arrow::after': css$1(_templateObject6$a || (_templateObject6$a = _taggedTemplateLiteral(["\n    bottom: $popover-border-width;\n    border-top-width: $popover-arrow-height;\n    border-right-width: $popover-arrow-width * 0.5;\n    border-left-width: $popover-arrow-width * 0.5;\n    border-bottom-width: 0;\n    border-top-color: $popover-arrow-color;\n  "]))),
    '.bs-popover-end .popover-arrow': css$1(_templateObject7$7 || (_templateObject7$7 = _taggedTemplateLiteral(["\n    left: ", ";\n    width: $popover-arrow-height;\n    height: $popover-arrow-width;\n  "])), subtract(function (t) {
      return "-".concat(t['popover-arrow-height']);
    }, function (t) {
      return t['popover-border-width'];
    })),
    '.bs-popover-end .popover-arrow::before': css$1(_templateObject8$6 || (_templateObject8$6 = _taggedTemplateLiteral(["\n    left: 0;\n    border-top-width: $popover-arrow-width * 0.5;\n    border-right-width: $popover-arrow-height;\n    border-left-width: 0;\n    border-bottom-width: $popover-arrow-width * 0.5;\n    border-right-color: $popover-arrow-outer-color;\n  "]))),
    '.bs-popover-end .popover-arrow::after': css$1(_templateObject9$5 || (_templateObject9$5 = _taggedTemplateLiteral(["\n    left: $popover-border-width;\n    border-top-width: $popover-arrow-width * 0.5;\n    border-right-width: $popover-arrow-height;\n    border-left-width: 0;\n    border-bottom-width: $popover-arrow-width * 0.5;\n    border-right-color: $popover-arrow-color;\n  "]))),
    '.bs-popover-bottom .popover-arrow': css$1(_templateObject10$5 || (_templateObject10$5 = _taggedTemplateLiteral(["\n    top: ", ";\n  "])), subtract(function (t) {
      return "-".concat(t['popover-arrow-height']);
    }, function (t) {
      return t['popover-border-width'];
    })),
    '.bs-popover-bottom .popover-arrow::before': css$1(_templateObject11$4 || (_templateObject11$4 = _taggedTemplateLiteral(["\n    top: 0;\n    border-top-width: 0;\n    border-right-width: $popover-arrow-width * 0.5;\n    border-left-width: $popover-arrow-width * 0.5;\n    border-bottom-width: $popover-arrow-height;\n    border-bottom-color: $popover-arrow-outer-color;\n  "]))),
    '.bs-popover-bottom .popover-arrow::after': css$1(_templateObject12$3 || (_templateObject12$3 = _taggedTemplateLiteral(["\n    top: $popover-border-width;\n    border-top-width: 0;\n    border-right-width: $popover-arrow-width * 0.5;\n    border-left-width: $popover-arrow-width * 0.5;\n    border-bottom-width: $popover-arrow-height;\n    border-bottom-color: $popover-arrow-color;\n  "]))),
    '.bs-popover-start .popover-arrow': css$1(_templateObject13$3 || (_templateObject13$3 = _taggedTemplateLiteral(["\n    right: ", ";\n    width: $popover-arrow-height;\n    height: $popover-arrow-width;\n  "])), subtract(function (t) {
      return "-".concat(t['popover-arrow-height']);
    }, function (t) {
      return t['popover-border-width'];
    })),
    '.bs-popover-start .popover-arrow::before': css$1(_templateObject14$2 || (_templateObject14$2 = _taggedTemplateLiteral(["\n    right: 0;\n    border-top-width: $popover-arrow-width * 0.5;\n    border-right-width: 0;\n    border-left-width: $popover-arrow-height;\n    border-bottom-width: $popover-arrow-width * 0.5;\n    border-left-color: $popover-arrow-outer-color;\n  "]))),
    '.bs-popover-start .popover-arrow::after': css$1(_templateObject15$1 || (_templateObject15$1 = _taggedTemplateLiteral(["\n    right: $popover-border-width;\n    border-top-width: $popover-arrow-width * 0.5;\n    border-right-width: 0;\n    border-left-width: $popover-arrow-height;\n    border-bottom-width: $popover-arrow-width * 0.5;\n    border-left-color: $popover-arrow-color;\n  "])))
  });
  var PopoverArrow = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$P);

    var _useForcedContext = useForcedContext(PopoverContext),
        placement = _useForcedContext.placement,
        arrowStyle = _useForcedContext.arrowStyle,
        popper = _useForcedContext.popper;

    var classes = getStyles(styles$F, ['.popover-arrow', popper && ".bs-popover-".concat(placement, " .popover-arrow")]);
    var beforeClasses = getStyles(styles$F, ['.popover-arrow::before', popper && ".bs-popover-".concat(placement, " .popover-arrow::before")]);
    var afterClasses = getStyles(styles$F, ['.popover-arrow::after', popper && ".bs-popover-".concat(placement, " .popover-arrow::after")]);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, arrowStyle, style]
    }), /*#__PURE__*/React__default["default"].createElement(View, {
      style: beforeClasses
    }), /*#__PURE__*/React__default["default"].createElement(View, {
      style: afterClasses
    }));
  });
  PopoverArrow.displayName = 'PopoverArrow';
  PopoverArrow.propTypes = propTypes$P;

  var _excluded$O = ["children", "style", "textStyle"];

  var _templateObject$F, _templateObject2$v;
  var propTypes$O = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$E = StyleSheet.create({
    '.popover-header': css$1(_templateObject$F || (_templateObject$F = _taggedTemplateLiteral(["\n    padding: $popover-header-padding-y $popover-header-padding-x;\n    background-color: $popover-header-bg;\n    border-bottom-width: $popover-border-width;\n    border-style: solid;\n    border-color: $popover-border-color;\n    border-top-left-radius: $popover-border-radius;\n    border-top-right-radius: $popover-border-radius;\n  "]))),
    '.popover-header-text': css$1(_templateObject2$v || (_templateObject2$v = _taggedTemplateLiteral(["\n    margin-bottom: 0; // Reset the default from Reboot\n    font-size: $font-size-base;\n    line-height: $font-size-base * $headings-line-height; // added for bootstrap-rn\n    color: $popover-header-color;\n  "])))
  });
  var PopoverHeader = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$O);

    var classes = getStyles(styles$E, ['.popover-header']);
    var textClasses = getStyles(styles$E, ['.popover-header-text']); // composite component

    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), /*#__PURE__*/React__default["default"].createElement(Heading$1, {
      size: 3,
      style: [textClasses, textStyle]
    }, children));
  });
  PopoverHeader.displayName = 'PopoverHeader';
  PopoverHeader.propTypes = propTypes$O;

  var _excluded$N = ["children", "style", "textStyle"];

  var _templateObject$E, _templateObject2$u;
  var propTypes$N = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$D = StyleSheet.create({
    '.popover-body': css$1(_templateObject$E || (_templateObject$E = _taggedTemplateLiteral(["\n    padding: $popover-body-padding-y $popover-body-padding-x;\n  "]))),
    '.popover-body-text': css$1(_templateObject2$u || (_templateObject2$u = _taggedTemplateLiteral(["\n    color: $popover-body-color;\n  "])))
  });
  var PopoverBody = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$N);

    var classes = getStyles(styles$D, ['.popover-body']);
    var textClasses = getStyles(styles$D, ['.popover-body-text']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children);
  });
  PopoverBody.displayName = 'PopoverBody';
  PopoverBody.propTypes = propTypes$N;

  var _excluded$M = ["children", "placement", "popper", "style", "textStyle", "arrowStyle"];

  var _templateObject$D, _templateObject2$t;
  var propTypes$M = {
    children: PropTypes.node.isRequired,
    placement: PropTypes.string,
    popper: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    arrowStyle: PropTypes.any
  };
  var styles$C = StyleSheet.create({
    '.popover': css$1(_templateObject$D || (_templateObject$D = _taggedTemplateLiteral(["\n    position: absolute;\n    // top: 0;\n    // left: 0 #{\"/* rtl:ignore */\"};\n    z-index: $zindex-popover;\n    // display: block;\n    max-width: $popover-max-width;\n    background-color: $popover-bg;\n    // background-clip: padding-box;\n    border: $popover-border-width solid $popover-border-color;\n    border-radius: $popover-border-radius;\n    // @include box-shadow($popover-box-shadow);\n  "]))),
    '.popover-text': css$1(_templateObject2$t || (_templateObject2$t = _taggedTemplateLiteral(["\n    // Our parent element can be arbitrary since tooltips are by default inserted as a sibling of their target element.\n    // So reset our font and text properties to avoid inheriting weird values.\n    // @include reset-text();\n    font-size: $popover-font-size;\n    // Allow breaking very long words so they don't overflow the popover's bounds\n    // word-wrap: break-word;\n  "])))
  });
  var Popover = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        _props$placement = props.placement,
        placement = _props$placement === void 0 ? 'right' : _props$placement,
        popper = props.popper,
        style = props.style,
        textStyle = props.textStyle,
        arrowStyle = props.arrowStyle,
        elementProps = _objectWithoutProperties(props, _excluded$M);

    var popover = {
      placement: transformPlacement$1(placement),
      arrowStyle: arrowStyle,
      popper: popper
    };
    var classes = getStyles(styles$C, ['.popover']);
    var textClasses = getStyles(styles$C, ['.popover-text']); // Accessiblity role tooltip is only supported on web.

    var role = _reactNative.Platform.OS === 'web' ? 'tooltip' : null;
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: role,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), /*#__PURE__*/React__default["default"].createElement(PopoverContext.Provider, {
      value: popover
    }, children));
  });
  Popover.displayName = 'Popover';
  Popover.propTypes = propTypes$M;
  Popover.Arrow = PopoverArrow;
  Popover.Header = PopoverHeader;
  Popover.Body = PopoverBody;

  var _excluded$L = ["title", "content", "autoClose", "trigger", "placement"],
      _excluded2$1 = ["popover"];
  var propTypes$L = {
    popover: PropTypes.shape(_objectSpread2({
      title: PropTypes.node,
      content: PropTypes.node.isRequired,
      autoClose: PropTypes.oneOfType([PropTypes.bool, PropTypes.oneOf(['inside', 'outside'])])
    }, TriggerPropTypes))
  };
  function injectPopover(Target) {
    var OverlayPopover = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
      /* eslint-disable react/prop-types */
      var _props$popover = props.popover,
          title = _props$popover.title,
          content = _props$popover.content,
          _props$popover$autoCl = _props$popover.autoClose,
          autoClose = _props$popover$autoCl === void 0 ? 'outside' : _props$popover$autoCl,
          _props$popover$trigge = _props$popover.trigger,
          trigger = _props$popover$trigge === void 0 ? 'press' : _props$popover$trigge,
          _props$popover$placem = _props$popover.placement,
          placement = _props$popover$placem === void 0 ? 'right' : _props$popover$placem,
          tooltipProps = _objectWithoutProperties(_props$popover, _excluded$L),
          elementProps = _objectWithoutProperties(props, _excluded2$1);
      /* eslint-enable */


      var _useTrigger = useTrigger(trigger, tooltipProps, elementProps, ref),
          visible = _useTrigger.visible,
          setVisible = _useTrigger.setVisible,
          targetProps = _useTrigger.targetProps,
          targetRef = _useTrigger.targetRef,
          templateProps = _useTrigger.templateProps;

      var offset = convertToNumber(StyleSheet.value('popover-arrow-height'));
      return /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement(Target, _extends$1({}, elementProps, targetProps)), visible && /*#__PURE__*/React__default["default"].createElement(OverlayContainer, null, /*#__PURE__*/React__default["default"].createElement(Overlay, {
        placement: placement,
        offset: offset,
        arrowOffset: offset,
        targetRef: targetRef,
        visible: visible
      }, function (overlay, overlayRef) {
        return /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement(BackdropHandler, {
          toggleRef: targetRef,
          dialogRef: overlayRef,
          onClose: function onClose() {
            setVisible(false);
          },
          autoClose: autoClose
        }), /*#__PURE__*/React__default["default"].createElement(Popover, _extends$1({}, templateProps, {
          ref: overlayRef,
          placement: overlay.placement,
          popper: overlay.rendered,
          style: [overlay.overlayProps.style, {
            maxHeight: 'auto',
            opacity: overlay.rendered ? 1 : 0
          }],
          arrowStyle: overlay.arrowProps.style
        }), /*#__PURE__*/React__default["default"].createElement(Popover.Arrow, null), title && /*#__PURE__*/React__default["default"].createElement(Popover.Header, null, title), /*#__PURE__*/React__default["default"].createElement(Popover.Body, null, content)));
      })));
    });
    OverlayPopover.displayName = 'Overlay(Popover)';
    OverlayPopover.propTypes = propTypes$L;
    return OverlayPopover;
  }

  var TooltipContext = /*#__PURE__*/React__default["default"].createContext();
  TooltipContext.displayName = 'TooltipContext';

  var _excluded$K = ["style"];

  var _templateObject$C, _templateObject2$s, _templateObject3$e, _templateObject4$c, _templateObject5$a, _templateObject6$9, _templateObject7$6, _templateObject8$5, _templateObject9$4, _templateObject10$4;
  var propTypes$K = {
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$B = StyleSheet.create({
    '.tooltip-arrow': css$1(_templateObject$C || (_templateObject$C = _taggedTemplateLiteral(["\n    position: absolute;\n    // display: block;\n    width: $tooltip-arrow-width;\n    height: $tooltip-arrow-height;\n  "]))),
    '.tooltip-arrow::before': css$1(_templateObject2$s || (_templateObject2$s = _taggedTemplateLiteral(["\n    position: absolute;\n    // content: \"\";\n    border-top-color: transparent;\n    border-right-color: transparent;\n    border-left-color: transparent;\n    border-bottom-color: transparent;\n    border-style: solid;\n  "]))),
    '.bs-tooltip-top .tooltip-arrow': css$1(_templateObject3$e || (_templateObject3$e = _taggedTemplateLiteral(["\n    bottom: 0;\n  "]))),
    '.bs-tooltip-top .tooltip-arrow::before': css$1(_templateObject4$c || (_templateObject4$c = _taggedTemplateLiteral(["\n    top: -1px;\n    border-top-width: $tooltip-arrow-height;\n    border-right-width: $tooltip-arrow-width * 0.5;\n    border-left-width: $tooltip-arrow-width * 0.5;\n    border-bottom-width: 0;\n    border-top-color: $tooltip-arrow-color;\n  "]))),
    '.bs-tooltip-end .tooltip-arrow': css$1(_templateObject5$a || (_templateObject5$a = _taggedTemplateLiteral(["\n    left: 0;\n    width: $tooltip-arrow-height;\n    height: $tooltip-arrow-width;\n  "]))),
    '.bs-tooltip-end .tooltip-arrow::before': css$1(_templateObject6$9 || (_templateObject6$9 = _taggedTemplateLiteral(["\n    right: -1px;\n    border-top-width: $tooltip-arrow-width * 0.5;\n    border-right-width: $tooltip-arrow-height;\n    border-left-width: 0;\n    border-bottom-width: $tooltip-arrow-width * 0.5;\n    border-right-color: $tooltip-arrow-color;\n  "]))),
    '.bs-tooltip-bottom .tooltip-arrow': css$1(_templateObject7$6 || (_templateObject7$6 = _taggedTemplateLiteral(["\n    top: 0;\n  "]))),
    '.bs-tooltip-bottom .tooltip-arrow::before': css$1(_templateObject8$5 || (_templateObject8$5 = _taggedTemplateLiteral(["\n    bottom: -1px;\n    border-top-width: 0;\n    border-right-width: $tooltip-arrow-width * 0.5;\n    border-left-width: $tooltip-arrow-width * 0.5;\n    border-bottom-width: $tooltip-arrow-height;\n    border-bottom-color: $tooltip-arrow-color;\n  "]))),
    '.bs-tooltip-start .tooltip-arrow': css$1(_templateObject9$4 || (_templateObject9$4 = _taggedTemplateLiteral(["\n    right: 0;\n    width: $tooltip-arrow-height;\n    height: $tooltip-arrow-width;\n  "]))),
    '.bs-tooltip-start .tooltip-arrow::before': css$1(_templateObject10$4 || (_templateObject10$4 = _taggedTemplateLiteral(["\n    left: -1px;\n    border-top-width: $tooltip-arrow-width * 0.5;\n    border-right-width: 0;\n    border-left-width: $tooltip-arrow-height;\n    border-bottom-width: $tooltip-arrow-width * 0.5;\n    border-left-color: $tooltip-arrow-color;\n  "])))
  });
  var TooltipArrow = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$K);

    var _useForcedContext = useForcedContext(TooltipContext),
        placement = _useForcedContext.placement,
        arrowStyle = _useForcedContext.arrowStyle,
        popper = _useForcedContext.popper;

    var classes = getStyles(styles$B, ['.tooltip-arrow', popper && ".bs-tooltip-".concat(placement, " .tooltip-arrow")]);
    var beforeClasses = getStyles(styles$B, ['.tooltip-arrow::before', popper && ".bs-tooltip-".concat(placement, " .tooltip-arrow::before")]);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, arrowStyle, style]
    }), /*#__PURE__*/React__default["default"].createElement(View, {
      style: beforeClasses
    }));
  });
  TooltipArrow.displayName = 'TooltipArrow';
  TooltipArrow.propTypes = propTypes$K;

  var _excluded$J = ["children", "style", "textStyle"];

  var _templateObject$B, _templateObject2$r;
  var propTypes$J = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$A = StyleSheet.create({
    '.tooltip-inner': css$1(_templateObject$B || (_templateObject$B = _taggedTemplateLiteral(["\n    max-width: $tooltip-max-width;\n    padding: $tooltip-padding-y $tooltip-padding-x;\n    background-color: $tooltip-bg;\n    border-radius: $tooltip-border-radius;\n  "]))),
    '.tooltip-inner-text': css$1(_templateObject2$r || (_templateObject2$r = _taggedTemplateLiteral(["\n    color: $tooltip-color;\n    text-align: center;\n  "])))
  });
  var TooltipInner = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$J);

    var classes = getStyles(styles$A, ['.tooltip-inner']);
    var textClasses = getStyles(styles$A, ['.tooltip-inner-text']); // composite component

    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), /*#__PURE__*/React__default["default"].createElement(Text, {
      style: [textClasses, textStyle]
    }, children));
  });
  TooltipInner.displayName = 'TooltipInner';
  TooltipInner.propTypes = propTypes$J;

  var _excluded$I = ["children", "placement", "popper", "style", "textStyle", "arrowStyle"];

  var _templateObject$A, _templateObject2$q, _templateObject3$d, _templateObject4$b, _templateObject5$9, _templateObject6$8;
  var propTypes$I = {
    children: PropTypes.node.isRequired,
    placement: PropTypes.string,
    popper: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    arrowStyle: PropTypes.any
  };
  var styles$z = StyleSheet.create({
    '.tooltip': css$1(_templateObject$A || (_templateObject$A = _taggedTemplateLiteral(["\n    position: absolute;\n    z-index: $zindex-tooltip;\n    // display: block;\n    margin: $tooltip-margin;\n    // opacity: 0;\n  "]))),
    '.tooltip-text': css$1(_templateObject2$q || (_templateObject2$q = _taggedTemplateLiteral(["\n    // Our parent element can be arbitrary since tooltips are by default inserted as a sibling of their target element.\n    // So reset our font and text properties to avoid inheriting weird values.\n    // @include reset-text();\n    font-size: $tooltip-font-size;\n    // Allow breaking very long words so they don't overflow the tooltip's bounds\n    // word-wrap: break-word;\n  "]))),
    '.bs-tooltip-top': css$1(_templateObject3$d || (_templateObject3$d = _taggedTemplateLiteral(["\n    padding: $tooltip-arrow-height 0;\n  "]))),
    '.bs-tooltip-end': css$1(_templateObject4$b || (_templateObject4$b = _taggedTemplateLiteral(["\n    padding: 0 $tooltip-arrow-height;\n  "]))),
    '.bs-tooltip-bottom': css$1(_templateObject5$9 || (_templateObject5$9 = _taggedTemplateLiteral(["\n    padding: $tooltip-arrow-height 0;\n  "]))),
    '.bs-tooltip-start': css$1(_templateObject6$8 || (_templateObject6$8 = _taggedTemplateLiteral(["\n    padding: 0 $tooltip-arrow-height;\n  "])))
  });
  var Tooltip = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        _props$placement = props.placement,
        placement = _props$placement === void 0 ? 'top' : _props$placement,
        popper = props.popper,
        style = props.style,
        textStyle = props.textStyle,
        arrowStyle = props.arrowStyle,
        elementProps = _objectWithoutProperties(props, _excluded$I);

    var tooltip = {
      placement: transformPlacement$1(placement),
      arrowStyle: arrowStyle,
      popper: popper
    };
    var classes = getStyles(styles$z, ['.tooltip', // Wait for rendering (of Overlay) before setting the offset.
    popper && ".bs-tooltip-".concat(tooltip.placement)]);
    var textClasses = getStyles(styles$z, ['.tooltip-text']); // Accessiblity role tooltip is only supported on web.

    var role = _reactNative.Platform.OS === 'web' ? 'tooltip' : null;
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: role,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), /*#__PURE__*/React__default["default"].createElement(TooltipContext.Provider, {
      value: tooltip
    }, children));
  });
  Tooltip.displayName = 'Tooltip';
  Tooltip.propTypes = propTypes$I;
  Tooltip.Arrow = TooltipArrow;
  Tooltip.Inner = TooltipInner;

  var _excluded$H = ["title", "autoClose", "trigger", "placement"],
      _excluded2 = ["tooltip"];
  var propTypes$H = {
    tooltip: PropTypes.shape(_objectSpread2({
      title: PropTypes.node.isRequired,
      autoClose: PropTypes.oneOfType([PropTypes.bool, PropTypes.oneOf(['inside', 'outside'])])
    }, TriggerPropTypes))
  };
  function injectTooltip(Target) {
    var OverlayTooltip = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
      /* eslint-disable react/prop-types */
      var _props$tooltip = props.tooltip,
          title = _props$tooltip.title,
          _props$tooltip$autoCl = _props$tooltip.autoClose,
          autoClose = _props$tooltip$autoCl === void 0 ? 'outside' : _props$tooltip$autoCl,
          _props$tooltip$trigge = _props$tooltip.trigger,
          trigger = _props$tooltip$trigge === void 0 ? 'hover focus' : _props$tooltip$trigge,
          _props$tooltip$placem = _props$tooltip.placement,
          placement = _props$tooltip$placem === void 0 ? 'top' : _props$tooltip$placem,
          tooltipProps = _objectWithoutProperties(_props$tooltip, _excluded$H),
          elementProps = _objectWithoutProperties(props, _excluded2);
      /* eslint-enable */


      var _useTrigger = useTrigger(trigger, tooltipProps, elementProps, ref),
          visible = _useTrigger.visible,
          setVisible = _useTrigger.setVisible,
          targetProps = _useTrigger.targetProps,
          targetRef = _useTrigger.targetRef,
          templateProps = _useTrigger.templateProps;

      var offset = convertToNumber(StyleSheet.value('tooltip-arrow-height'));
      return /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement(Target, _extends$1({}, elementProps, targetProps)), visible && /*#__PURE__*/React__default["default"].createElement(OverlayContainer, null, /*#__PURE__*/React__default["default"].createElement(Overlay, {
        placement: placement,
        targetRef: targetRef,
        arrowOffset: offset,
        visible: visible
      }, function (overlay, overlayRef) {
        return /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement(BackdropHandler, {
          toggleRef: targetRef,
          dialogRef: overlayRef,
          onClose: function onClose() {
            setVisible(false);
          },
          autoClose: autoClose
        }), /*#__PURE__*/React__default["default"].createElement(Tooltip, _extends$1({}, templateProps, {
          ref: overlayRef,
          placement: overlay.placement,
          popper: overlay.rendered,
          style: [overlay.overlayProps.style, {
            maxHeight: 'auto',
            opacity: overlay.rendered ? 1 : 0
          }],
          arrowStyle: overlay.arrowProps.style
        }), /*#__PURE__*/React__default["default"].createElement(Tooltip.Arrow, null), /*#__PURE__*/React__default["default"].createElement(Tooltip.Inner, null, title)));
      })));
    });
    OverlayTooltip.displayName = 'Overlay(Tooltip)';
    OverlayTooltip.propTypes = propTypes$H;
    return OverlayTooltip;
  }

  var _excluded$G = ["style", "styleName"];
  var propTypes$G = {
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    styleName: PropTypes.any
  };
  var Image = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var style = props.style,
        styleName = props.styleName,
        elementProps = _objectWithoutProperties(props, _excluded$G);

    var media = useMedia();
    var resolveStyle = useStyle(style, styleName);
    return /*#__PURE__*/React__default["default"].createElement(_reactNative.Image, _extends$1({}, elementProps, {
      ref: ref,
      style: resolveStyle({
        media: media
      })
    }));
  });
  Image.displayName = 'Image';
  Image.propTypes = propTypes$G;

  var _excluded$F = ["style", "styleName"];
  var propTypes$F = {
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    styleName: PropTypes.any
  };
  var ImageBackground = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var style = props.style,
        styleName = props.styleName,
        elementProps = _objectWithoutProperties(props, _excluded$F);

    var media = useMedia();
    var resolveStyle = useStyle(style, styleName);
    return /*#__PURE__*/React__default["default"].createElement(_reactNative.ImageBackground, _extends$1({}, elementProps, {
      ref: ref,
      style: resolveStyle({
        media: media
      })
    }));
  });
  ImageBackground.displayName = 'ImageBackground';
  ImageBackground.propTypes = propTypes$F;

  var _excluded$E = ["children", "style", "textStyle"];

  var _templateObject$z, _templateObject2$p;
  var propTypes$E = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$y = StyleSheet.create({
    '.form-label': css$1(_templateObject$z || (_templateObject$z = _taggedTemplateLiteral(["\n    margin-bottom: $form-label-margin-bottom;\n  "]))),
    '.form-label-text': css$1(_templateObject2$p || (_templateObject2$p = _taggedTemplateLiteral(["\n    font-size: $form-label-font-size;\n    font-style: $form-label-font-style;\n    font-weight: $form-label-font-weight;\n    color: $form-label-color;\n  "])))
  });
  var Label = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$E);

    var classes = getStyles(styles$y, ['.form-label']);
    var textClasses = getStyles(styles$y, ['.form-label-text']); // composite component

    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), /*#__PURE__*/React__default["default"].createElement(Text, {
      style: [textClasses, textStyle]
    }, children));
  });
  Label.displayName = 'Label';
  Label.propTypes = propTypes$E;

  var ListGroupContext = /*#__PURE__*/React__default["default"].createContext();
  ListGroupContext.displayName = 'ListGroupContext';

  var _excluded$D = ["children", "color", "active", "first", "last", "disabled", "style", "textStyle"];

  var _templateObject$y, _templateObject2$o, _templateObject3$c, _templateObject4$a, _templateObject5$8, _templateObject6$7, _templateObject7$5, _templateObject8$4, _templateObject9$3, _templateObject10$3, _templateObject11$3, _templateObject12$2, _templateObject13$2, _templateObject14$1;
  var propTypes$D = {
    children: PropTypes.node.isRequired,
    color: PropTypes.oneOf(Object.keys(THEME_COLORS)),
    active: PropTypes.bool,
    first: PropTypes.bool,
    last: PropTypes.bool,
    disabled: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$x = StyleSheet.create(_objectSpread2({
    '.list-group-item': css$1(_templateObject$y || (_templateObject$y = _taggedTemplateLiteral(["\n    position: relative;\n    // display: block;\n    padding: $list-group-item-padding-y $list-group-item-padding-x;\n    background-color: $list-group-bg;\n    border: $list-group-border-width solid $list-group-border-color;\n  "]))),
    '.list-group-item-text': css$1(_templateObject2$o || (_templateObject2$o = _taggedTemplateLiteral(["\n    color: $list-group-color;\n    text-decoration: none; // if($link-decoration == none, null, none);\n  "]))),
    '.list-group-item-first': css$1(_templateObject3$c || (_templateObject3$c = _taggedTemplateLiteral(["\n    border-top-left-radius: $list-group-border-radius;\n    border-top-right-radius: $list-group-border-radius;\n  "]))),
    '.list-group-item-last': css$1(_templateObject4$a || (_templateObject4$a = _taggedTemplateLiteral(["\n    border-bottom-left-radius: $list-group-border-radius;\n    border-bottom-right-radius: $list-group-border-radius;\n  "]))),
    '.list-group-item-disabled': css$1(_templateObject5$8 || (_templateObject5$8 = _taggedTemplateLiteral(["\n    // pointer-events: none;\n    background-color: $list-group-disabled-bg;\n  "]))),
    '.list-group-item-disabled-text': css$1(_templateObject6$7 || (_templateObject6$7 = _taggedTemplateLiteral(["\n    color: $list-group-disabled-color;\n  "]))),
    '.list-group-item-active': css$1(_templateObject7$5 || (_templateObject7$5 = _taggedTemplateLiteral(["\n    z-index: 2; // Place active items above their siblings for proper border styling\n    background-color: $list-group-active-bg;\n    border-color: $list-group-active-border-color;\n  "]))),
    '.list-group-item-active-text': css$1(_templateObject8$4 || (_templateObject8$4 = _taggedTemplateLiteral(["\n    color: $list-group-active-color;\n  "]))),
    '.list-group-item-not-first': css$1(_templateObject9$3 || (_templateObject9$3 = _taggedTemplateLiteral(["\n    border-top-width: 0;\n  "]))),
    '.list-group-item-not-first-active': css$1(_templateObject10$3 || (_templateObject10$3 = _taggedTemplateLiteral(["\n    margin-top: -$list-group-border-width;\n    border-top-width: $list-group-border-width;\n  "]))),
    '.list-group-item-flush': css$1(_templateObject11$3 || (_templateObject11$3 = _taggedTemplateLiteral(["\n    border-top-left-radius: 0; // added for bootstrap-rn\n    border-top-right-radius: 0; // added for bootstrap-rn\n    border-bottom-left-radius: 0; // added for bootstrap-rn\n    border-bottom-right-radius: 0; // added for bootstrap-rn\n    border-top-width: 0;\n    border-right-width: 0;\n    border-bottom-width: $list-group-border-width;\n    border-left-width: 0;\n  "]))),
    '.list-group-item-flush-last': css$1(_templateObject12$2 || (_templateObject12$2 = _taggedTemplateLiteral(["\n    border-bottom-width: 0;\n  "])))
  }, each(THEME_COLORS, function (state, value) {
    var _ref;

    return _ref = {}, _defineProperty(_ref, ".list-group-item-".concat(state), css$1(_templateObject13$2 || (_templateObject13$2 = _taggedTemplateLiteral(["\n      background-color: ", ";\n    "])), shiftColor(function (t) {
      return t['list-group-item-bg-scale'];
    }, value))), _defineProperty(_ref, ".list-group-item-".concat(state, "-text"), css$1(_templateObject14$1 || (_templateObject14$1 = _taggedTemplateLiteral(["\n      color: ", ";\n    "])), shiftColor(function (t) {
      return t['list-group-item-color-scale'];
    }, value))), _ref;
  })));
  var ListGroupItem = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        color = props.color,
        _props$active = props.active,
        active = _props$active === void 0 ? false : _props$active,
        _props$first = props.first,
        first = _props$first === void 0 ? false : _props$first,
        _props$last = props.last,
        last = _props$last === void 0 ? false : _props$last,
        _props$disabled = props.disabled,
        disabled = _props$disabled === void 0 ? false : _props$disabled,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$D);

    var _useForcedContext = useForcedContext(ListGroupContext),
        flush = _useForcedContext.flush;

    var classes = getStyles(styles$x, ['.list-group-item', first && '.list-group-item-first', last && '.list-group-item-last', active && '.list-group-item-active', disabled && '.list-group-item-disabled', !first && '.list-group-item-not-first', !first && active && '.list-group-item-not-first-active', flush && '.list-group-item-flush', flush && last && '.list-group-item-flush-last', color && ".list-group-item-".concat(color)]);
    var textClasses = getStyles(styles$x, ['.list-group-item-text', active && '.list-group-item-active-text', disabled && '.list-group-item-disabled-text', color && ".list-group-item-".concat(color, "-text")]);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children);
  });
  ListGroupItem.displayName = 'ListGroupItem';
  ListGroupItem.propTypes = propTypes$D;

  var _excluded$C = ["children", "color", "first", "last", "active", "disabled", "style", "activeStyle", "textStyle", "activeTextStyle"];

  var _templateObject$x, _templateObject2$n, _templateObject3$b, _templateObject4$9, _templateObject5$7, _templateObject6$6;
  var propTypes$C = {
    children: PropTypes.node.isRequired,
    color: PropTypes.oneOf(Object.keys(THEME_COLORS)),
    first: PropTypes.bool,
    last: PropTypes.bool,
    active: PropTypes.bool,
    disabled: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    activeStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    activeTextStyle: PropTypes.any
  };
  var actionStyles = StyleSheet.create(_objectSpread2({
    '.list-group-item-action': css$1(_templateObject$x || (_templateObject$x = _taggedTemplateLiteral(["\n    width: 100%; // For \"<button>\"s (anchors become 100% by default though)\n\n    // Hover state\n    &:hover {\n      z-index: 1; // Place hover/focus items above their siblings for proper border styling\n      background-color: $list-group-hover-bg;\n    }\n\n    &:focus {\n      z-index: 1; // Place hover/focus items above their siblings for proper border styling\n      background-color: $list-group-hover-bg;\n    }\n\n    &:active {\n      background-color: $list-group-action-active-bg;\n    }\n  "]))),
    '.list-group-item-action-text': css$1(_templateObject2$n || (_templateObject2$n = _taggedTemplateLiteral(["\n    color: $list-group-action-color;\n    // text-align: inherit; // For \"<button>\"s (anchors inherit)\n\n    // Hover state\n    &:hover {\n      color: $list-group-action-hover-color;\n      text-decoration: none;\n    }\n\n    &:focus {\n      color: $list-group-action-hover-color;\n      text-decoration: none;\n    }\n\n    &:active {\n      color: $list-group-action-active-color;\n    }\n  "])))
  }, each(THEME_COLORS, function (state, value) {
    var _ref;

    return _ref = {}, _defineProperty(_ref, ".list-group-item-".concat(state, "-action"), css$1(_templateObject3$b || (_templateObject3$b = _taggedTemplateLiteral(["\n      &:hover {\n        background-color: ", ";\n      }\n\n      &:focus {\n        background-color: ", ";\n      }\n    "])), shadeColor(0.1, shiftColor(function (t) {
      return t['list-group-item-bg-scale'];
    }, value)), shadeColor(0.1, shiftColor(function (t) {
      return t['list-group-item-bg-scale'];
    }, value)))), _defineProperty(_ref, ".list-group-item-".concat(state, "-action-text"), css$1(_templateObject4$9 || (_templateObject4$9 = _taggedTemplateLiteral(["\n      &:hover {\n        color: ", ";\n      }\n\n      &:focus {\n        color: ", ";\n      }\n    "])), shiftColor(function (t) {
      return t['list-group-item-color-scale'];
    }, value), shiftColor(function (t) {
      return t['list-group-item-color-scale'];
    }, value))), _defineProperty(_ref, ".list-group-item-".concat(state, "-action-active"), css$1(_templateObject5$7 || (_templateObject5$7 = _taggedTemplateLiteral(["\n      background-color: ", ";\n      border-color: ", ";\n    "])), shiftColor(function (t) {
      return t['list-group-item-color-scale'];
    }, value), shiftColor(function (t) {
      return t['list-group-item-color-scale'];
    }, value))), _defineProperty(_ref, ".list-group-item-".concat(state, "-action-active-text"), css$1(_templateObject6$6 || (_templateObject6$6 = _taggedTemplateLiteral(["\n      color: $white;\n    "])))), _ref;
  })));
  var ListGroupItemAction = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var _useModifier = useModifier('useTabbable', props, ref),
        _useModifier2 = _slicedToArray(_useModifier, 2),
        modifierProps = _useModifier2[0],
        modifierRef = _useModifier2[1];

    var children = modifierProps.children,
        color = modifierProps.color,
        _modifierProps$first = modifierProps.first,
        first = _modifierProps$first === void 0 ? false : _modifierProps$first,
        _modifierProps$last = modifierProps.last,
        last = _modifierProps$last === void 0 ? false : _modifierProps$last,
        _modifierProps$active = modifierProps.active,
        active = _modifierProps$active === void 0 ? false : _modifierProps$active,
        _modifierProps$disabl = modifierProps.disabled,
        disabled = _modifierProps$disabl === void 0 ? false : _modifierProps$disabl,
        style = modifierProps.style,
        activeStyle = modifierProps.activeStyle,
        textStyle = modifierProps.textStyle,
        activeTextStyle = modifierProps.activeTextStyle,
        elementProps = _objectWithoutProperties(modifierProps, _excluded$C);

    var _useForcedContext = useForcedContext(ListGroupContext),
        flush = _useForcedContext.flush;

    var styles = _objectSpread2(_objectSpread2({}, styles$x), actionStyles);

    var classes = getStyles(styles, ['.list-group-item', '.list-group-item-action', first && '.list-group-item-first', last && '.list-group-item-last', disabled && '.list-group-item-disabled', !first && '.list-group-item-not-first', !first && active && '.list-group-item-not-first-active', flush && '.list-group-item-flush', flush && last && '.list-group-item-flush-last', color && ".list-group-item-".concat(color), color && ".list-group-item-".concat(color, "-action")]);
    var activeClasses = getStyles(styles, ['.list-group-item-active', color && ".list-group-item-".concat(color, "-action-active")]);
    var textClasses = getStyles(styles, ['.list-group-item-text', '.list-group-item-action-text', disabled && '.list-group-item-disabled-text', color && ".list-group-item-".concat(color, "-text"), color && ".list-group-item-".concat(color, "-action-text")]);
    var activeTextClasses = getStyles(styles, ['.list-group-item-active-text', color && ".list-group-item-".concat(color, "-action-active-text")]);
    return /*#__PURE__*/React__default["default"].createElement(Pressable, _extends$1({}, elementProps, {
      ref: modifierRef,
      active: active,
      disabled: disabled,
      style: [].concat(_toConsumableArray(classes), [style]),
      activeStyle: [].concat(_toConsumableArray(activeClasses), [activeStyle]),
      textStyle: [].concat(_toConsumableArray(textClasses), [textStyle]),
      activeTextStyle: [].concat(_toConsumableArray(activeTextClasses), [activeTextStyle])
    }), children);
  });
  ListGroupItemAction.displayName = 'ListGroupItemAction';
  ListGroupItemAction.propTypes = propTypes$C;

  var _excluded$B = ["children", "flush", "style"];

  var _templateObject$w, _templateObject2$m;
  var propTypes$B = {
    children: PropTypes.node.isRequired,
    flush: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$w = StyleSheet.create({
    '.list-group': css$1(_templateObject$w || (_templateObject$w = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: column;\n\n    // No need to set list-style: none; since .list-group-item is block level\n    padding-left: 0; // reset padding because ul and ol\n    margin-bottom: 0;\n    border-radius: $list-group-border-radius;\n  "]))),
    '.list-group-flush': css$1(_templateObject2$m || (_templateObject2$m = _taggedTemplateLiteral(["\n    border-radius: 0;\n  "])))
  });
  var ListGroup = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        flush = props.flush,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$B);

    var classes = getStyles(styles$w, ['.list-group', flush && '.list-group-flush']); // TODO: Implement TabContext
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: null,
      style: [classes, style]
    }), /*#__PURE__*/React__default["default"].createElement(ListGroupContext.Provider, {
      value: {
        flush: flush
      }
    }, makeListChildren(children)));
  });
  ListGroup.displayName = 'ListGroup';
  ListGroup.propTypes = propTypes$B;
  ListGroup.Item = ListGroupItem;
  ListGroup.ItemAction = ListGroupItemAction;

  var _excluded$A = ["children", "onMouseEnter", "onMouseLeave", "onFocus", "onBlur", "onPressIn", "onPressOut", "style"];

  var _templateObject$v;
  var propTypes$A = {
    children: PropTypes.node.isRequired,
    onMouseEnter: PropTypes.func,
    onMouseLeave: PropTypes.func,
    onFocus: PropTypes.func,
    onBlur: PropTypes.func,
    onPressIn: PropTypes.func,
    onPressOut: PropTypes.func,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$v = StyleSheet.create({
    link: css$1(_templateObject$v || (_templateObject$v = _taggedTemplateLiteral(["\n    color: $link-color;\n    text-decoration-color: $link-color; // added for bootstrap-rn\n    text-decoration-line: $link-decoration;\n\n    &:hover {\n      color: $link-hover-color;\n      text-decoration-color: $link-hover-color; // added for bootstrap-rn\n      text-decoration-line: $link-hover-decoration;\n    }\n  "])))
  });
  var Link = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var _useModifier = useModifier('useActionable', props, ref),
        _useModifier2 = _slicedToArray(_useModifier, 2),
        modifierProps = _useModifier2[0],
        modifierRef = _useModifier2[1];

    var _useAction = useAction(modifierProps, modifierRef),
        _useAction2 = _slicedToArray(_useAction, 2),
        actionProps = _useAction2[0],
        actionRef = _useAction2[1];

    var children = actionProps.children,
        _actionProps$onMouseE = actionProps.onMouseEnter,
        _onMouseEnter = _actionProps$onMouseE === void 0 ? function () {} : _actionProps$onMouseE,
        _actionProps$onMouseL = actionProps.onMouseLeave,
        _onMouseLeave = _actionProps$onMouseL === void 0 ? function () {} : _actionProps$onMouseL,
        _actionProps$onFocus = actionProps.onFocus,
        _onFocus = _actionProps$onFocus === void 0 ? function () {} : _actionProps$onFocus,
        _actionProps$onBlur = actionProps.onBlur,
        _onBlur = _actionProps$onBlur === void 0 ? function () {} : _actionProps$onBlur,
        _actionProps$onPressI = actionProps.onPressIn,
        _onPressIn = _actionProps$onPressI === void 0 ? function () {} : _actionProps$onPressI,
        _actionProps$onPressO = actionProps.onPressOut,
        _onPressOut = _actionProps$onPressO === void 0 ? function () {} : _actionProps$onPressO,
        style = actionProps.style,
        elementProps = _objectWithoutProperties(actionProps, _excluded$A);

    var _useState = React.useState(false),
        _useState2 = _slicedToArray(_useState, 2),
        hovered = _useState2[0],
        setHovered = _useState2[1];

    var _useState3 = React.useState(false),
        _useState4 = _slicedToArray(_useState3, 2),
        focused = _useState4[0],
        setFocused = _useState4[1];

    var _useState5 = React.useState(false),
        _useState6 = _slicedToArray(_useState5, 2),
        pressed = _useState6[0],
        setPressed = _useState6[1];

    var media = useMedia();
    var classes = getStyles(styles$v, ['link', hovered]);
    var resolveStyle = useStyle([classes, style]);
    return /*#__PURE__*/React__default["default"].createElement(Text, _extends$1({}, elementProps, {
      ref: actionRef,
      accessibilityRole: getRole$1(actionProps),
      accessible: true,
      onMouseEnter: function onMouseEnter() {
        setHovered(true);

        _onMouseEnter();
      },
      onMouseLeave: function onMouseLeave() {
        setHovered(false);

        _onMouseLeave();
      },
      onFocus: function onFocus() {
        setFocused(true);

        _onFocus();
      },
      onBlur: function onBlur() {
        setFocused(false);

        _onBlur();
      },
      onPressIn: function onPressIn() {
        setPressed(true);

        _onPressIn();
      },
      onPressOut: function onPressOut() {
        setPressed(false);

        _onPressOut();
      },
      style: resolveStyle({
        media: media,
        interaction: {
          hovered: hovered,
          focused: focused,
          pressed: pressed
        }
      })
    }), children);
  });
  Link.displayName = 'Link';
  Link.propTypes = propTypes$A;

  var _excluded$z = ["children", "contentContainerStyle", "style", "textStyle", "styleName"];
  var propTypes$z = {
    children: PropTypes.node,
    // eslint-disable-next-line react/forbid-prop-types
    contentContainerStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    styleName: PropTypes.any
  };
  var ScrollView = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        contentContainerStyle = props.contentContainerStyle,
        style = props.style,
        textStyle = props.textStyle,
        styleName = props.styleName,
        elementProps = _objectWithoutProperties(props, _excluded$z);

    var media = useMedia();
    var context = React.useContext(TextStyleContext);
    var resolveContentContainerStyle = useStyle(contentContainerStyle);
    var resolveStyle = useStyle(style, styleName);
    var resolveTextStyle = useStyle([context && context.style, textStyle]);
    var hasTextStyle = context && context.style || textStyle;
    return /*#__PURE__*/React__default["default"].createElement(_reactNative.ScrollView, _extends$1({}, elementProps, {
      ref: ref,
      contentContainerStyle: resolveContentContainerStyle({
        media: media
      }),
      style: resolveStyle({
        media: media
      })
    }), hasTextStyle ? /*#__PURE__*/React__default["default"].createElement(TextStyleContext.Provider, {
      value: {
        style: resolveTextStyle({
          media: media
        }),
        hasAncestor: context && context.hasTextAncestor
      }
    }, children) : children);
  });
  ScrollView.displayName = 'ScrollView';
  ScrollView.propTypes = propTypes$z;

  var computeScrollbarWidth = function computeScrollbarWidth() {
    var documentWidth = document.documentElement.clientWidth;
    return Math.abs(window.innerWidth - documentWidth);
  };

  function useScrollbarEffects(_ref) {
    var keepBodyScroll = _ref.keepBodyScroll,
        visible = _ref.visible;

    if (_reactNative.Platform.OS !== 'web' || keepBodyScroll) {
      return;
    }

    var scrollbarWidth = React.useRef();
    React.useEffect(function () {
      if (!visible) {
        return undefined;
      }

      if (!scrollbarWidth.current) {
        scrollbarWidth.current = computeScrollbarWidth();
      } // const element = findNodeHandle(ref.current);


      var rect = document.body.getBoundingClientRect();
      var isBodyOverflowing = rect.left + rect.right < window.innerWidth; // Set body and fixed elements padding adjustments.

      var elements = [document.body].concat(_toConsumableArray(document.querySelectorAll('[data-fixed="true"]')));
      var originalWidths = elements.map(function (el) {
        return el.style.width || '';
      });
      var originalBodyOverflow = document.body.style.overflow || '';

      if (isBodyOverflowing) {
        elements.forEach(function (el) {
          // eslint-disable-next-line no-param-reassign
          el.style.width = "calc(100% - ".concat(scrollbarWidth.current, "px)");
        });
      } // Add "overflow: hidden" to body element.


      document.body.style.overflow = 'hidden';
      return function () {
        // Reset body padding adjustments.
        elements.forEach(function (el, key) {
          // eslint-disable-next-line no-param-reassign
          el.style.width = originalWidths[key] || '';
        }); // Remove "overflow: hidden" from body element.

        document.body.style.overflow = originalBodyOverflow;
      };
    }, [visible]);
  }

  function useModal(scrollable) {
    return React.useMemo(function () {
      return {
        scrollable: scrollable
      };
    }, [scrollable]);
  }

  var _excluded$y = ["children", "style"];

  var _templateObject$u;
  var propTypes$y = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$u = StyleSheet.create({
    '.modal-header': css$1(_templateObject$u || (_templateObject$u = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: row; // added for bootstrap-rn\n    flex-shrink: 0;\n    align-items: center;\n    justify-content: space-between; // Put modal header elements (title and dismiss) on opposite ends\n    padding: $modal-header-padding;\n    border-bottom-width: $modal-header-border-width;\n    border-style: solid;\n    border-color: $modal-header-border-color;\n    border-top-left-radius: $modal-content-inner-border-radius;\n    border-top-right-radius: $modal-content-inner-border-radius;\n  "])))
  });
  var ModalHeader = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$y);

    var classes = getStyles(styles$u, ['.modal-header']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), children);
  });
  ModalHeader.displayName = 'ModalHeader';
  ModalHeader.propTypes = propTypes$y;

  var _excluded$x = ["children", "style"];

  var _templateObject$t;
  var propTypes$x = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$t = StyleSheet.create({
    '.modal-title': css$1(_templateObject$t || (_templateObject$t = _taggedTemplateLiteral(["\n    margin-bottom: 0;\n    line-height: $font-size-base * $modal-title-line-height;\n  "])))
  });
  var ModalTitle = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$x);

    var classes = getStyles(styles$t, ['.modal-title']);
    return /*#__PURE__*/React__default["default"].createElement(Heading$1, _extends$1({
      size: 5
    }, elementProps, {
      ref: ref,
      style: [classes, style]
    }), children);
  });
  ModalTitle.displayName = 'ModalTitle';
  ModalTitle.propTypes = propTypes$x;

  var _excluded$w = ["children", "style", "contentContainerStyle"];

  var _templateObject$s;
  var propTypes$w = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    contentContainerStyle: PropTypes.any
  };
  var styles$s = StyleSheet.create({
    '.modal-body': css$1(_templateObject$s || (_templateObject$s = _taggedTemplateLiteral(["\n    position: relative;\n    // Enable \"flex-grow: 1\" so that the body take up as much space as possible\n    // when there should be a fixed height on \".modal-dialog\".\n    // Note from bootstrap-rn: Centered modals do not work with this style, but\n    // everything just works fine without this style.\n    // flex: 1 1 auto;\n    padding: $modal-inner-padding;\n  "])))
  });
  var ModalBody = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        contentContainerStyle = props.contentContainerStyle,
        elementProps = _objectWithoutProperties(props, _excluded$w);

    var _useForcedContext = useForcedContext(ModalContext),
        scrollable = _useForcedContext.scrollable;

    var classes = getStyles(styles$s, ['.modal-body']);
    var FlexView = scrollable ? ScrollView : View;
    return /*#__PURE__*/React__default["default"].createElement(FlexView, _extends$1({}, elementProps, {
      ref: ref,
      style: scrollable ? style : [classes, style],
      contentContainerStyle: scrollable ? [classes, contentContainerStyle] : undefined
    }), children);
  });
  ModalBody.displayName = 'ModalBody';
  ModalBody.propTypes = propTypes$w;

  var _excluded$v = ["children", "style"];

  var _templateObject$r;
  var propTypes$v = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$r = StyleSheet.create({
    '.modal-footer': css$1(_templateObject$r || (_templateObject$r = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: row; // added for bootstrap-rn\n    flex-shrink: 0;\n    flex-wrap: wrap;\n    align-items: center; // vertically center\n    justify-content: flex-end; // Right align buttons with flex property because text-align doesn't work on flex items\n    padding: $modal-inner-padding;\n    border-top-width: $modal-footer-border-width;\n    border-style: solid;\n    border-color: $modal-footer-border-color;\n    border-bottom-start-radius: $modal-content-inner-border-radius;\n    border-bottom-end-radius: $modal-content-inner-border-radius;\n  "])))
  });
  var ModalFooter = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$v);

    var classes = getStyles(styles$r, ['.modal-footer']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), children);
  });
  ModalFooter.displayName = 'ModalFooter';
  ModalFooter.propTypes = propTypes$v;

  var _excluded$u = ["children", "visible", "size", "backdrop", "scrollable", "centered", "onToggle", "style", "textStyle"];

  var _templateObject$q, _templateObject2$l, _templateObject3$a, _templateObject4$8, _templateObject5$6, _templateObject6$5, _templateObject7$4, _templateObject8$3, _templateObject9$2, _templateObject10$2, _templateObject11$2;
  var MODAL_SIZES = ['sm', 'lg', 'xl'];
  var propTypes$u = {
    children: PropTypes.node.isRequired,
    visible: PropTypes.bool.isRequired,
    size: PropTypes.oneOf(MODAL_SIZES),
    backdrop: PropTypes.oneOfType([PropTypes.bool, PropTypes.oneOf(['static'])]),
    scrollable: PropTypes.bool,
    centered: PropTypes.bool,
    onToggle: PropTypes.func.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$q = StyleSheet.create({
    '.modal': css$1(_templateObject$q || (_templateObject$q = _taggedTemplateLiteral(["\n    position: absolute; // fixed;\n    top: 0;\n    left: 0;\n    z-index: $zindex-modal;\n    // display: none;\n    width: 100%;\n    height: 100%;\n    // overflow-x: hidden;\n    // overflow-y: auto;\n    // Prevent Chrome on Windows from adding a focus outline. For details, see\n    // https://github.com/twbs/bootstrap/pull/10951.\n    @include platform(web) {\n      outline-width: 0; // outline: 0;\n    }\n    // We deliberately don't use \"-webkit-overflow-scrolling: touch;\" due to a\n    // gnarly iOS Safari bug: https://bugs.webkit.org/show_bug.cgi?id=158342\n    // See also https://github.com/twbs/bootstrap/issues/17695\n  "]))),
    '.modal-dialog': css$1(_templateObject2$l || (_templateObject2$l = _taggedTemplateLiteral(["\n    position: relative;\n    width: auto;\n    margin: $modal-dialog-margin;\n    // allow clicks to pass through for custom click handling to close modal\n    // pointer-events: none;\n\n    @include media-breakpoint-up(sm) {\n      width: 100%; // added for bootstrap-rn\n      max-width: $modal-md;\n      margin-right: auto;\n      margin-left: auto;\n    }\n  "]))),
    '.modal-dialog-scrollable': css$1(_templateObject3$a || (_templateObject3$a = _taggedTemplateLiteral(["\n    flex-shrink: 1; // added for bootstrap-rn\n    // height: calc(100% - var(--#{$prefix}modal-margin) * 2);\n  "]))),
    '.modal-dialog-scrollable .modal-content': css$1(_templateObject4$8 || (_templateObject4$8 = _taggedTemplateLiteral(["\n    max-height: 100%;\n    overflow: hidden;\n  "]))),
    '.modal-dialog-centered': css$1(_templateObject5$6 || (_templateObject5$6 = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: row; // added for bootstrap-rn\n    flex-grow: 1; // added for bootstrap-rn\n    align-items: center;\n    // min-height: calc(100% - var(--#{$prefix}modal-margin) * 2);\n  "]))),
    '.modal-content': css$1(_templateObject6$5 || (_templateObject6$5 = _taggedTemplateLiteral(["\n    position: relative;\n    display: flex;\n    flex-direction: column;\n    width: 100%; // Ensure \".modal-content\" extends the full width of the parent \".modal-dialog\"\n    // counteract the pointer-events: none; in the .modal-dialog\n    // pointer-events: auto;\n    background-color: $modal-content-bg;\n    // background-clip: padding-box;\n    border: $modal-content-border-width solid $modal-content-border-color;\n    border-radius: $modal-content-border-radius;\n    // @include box-shadow($modal-content-box-shadow-xs);\n    // Remove focus outline from opened modal\n    // outline: 0;\n\n    @include media-breakpoint-up(sm) {\n      // @include box-shadow($modal-content-box-shadow-sm-up);\n    }\n  "]))),
    '.modal-content-text': css$1(_templateObject7$4 || (_templateObject7$4 = _taggedTemplateLiteral(["\n    color: $modal-content-color;\n  "]))),
    '.modal-backdrop': css$1(_templateObject8$3 || (_templateObject8$3 = _taggedTemplateLiteral(["\n    position: absolute;\n    top: 0;\n    left: 0;\n    z-index: $zindex-modal-backdrop;\n    width: 100%;\n    height: 100%;\n    background-color: $modal-backdrop-bg;\n    opacity: $modal-backdrop-opacity;\n  "]))),
    '.modal-sm': css$1(_templateObject9$2 || (_templateObject9$2 = _taggedTemplateLiteral(["\n    @include media-breakpoint-up(sm) {\n      max-width: $modal-sm;\n    }\n  "]))),
    '.modal-lg': css$1(_templateObject10$2 || (_templateObject10$2 = _taggedTemplateLiteral(["\n    @include media-breakpoint-up(lg) {\n      max-width: $modal-lg;\n    }\n    @include media-breakpoint-up(xl) {\n      max-width: $modal-xl;\n    }\n  "]))),
    '.modal-xl': css$1(_templateObject11$2 || (_templateObject11$2 = _taggedTemplateLiteral(["\n    @include media-breakpoint-up(xl) {\n      max-width: $modal-xl;\n    }\n  "])))
  });
  var Modal = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        visible = props.visible,
        size = props.size,
        _props$backdrop = props.backdrop,
        backdrop = _props$backdrop === void 0 ? true : _props$backdrop,
        _props$scrollable = props.scrollable,
        scrollable = _props$scrollable === void 0 ? false : _props$scrollable,
        _props$centered = props.centered,
        centered = _props$centered === void 0 ? false : _props$centered,
        handleToggle = props.onToggle,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$u);

    var dialogRef = React.useRef();
    var modal = useModal(scrollable);
    useScrollbarEffects({
      keepBodyScroll: false,
      visible: visible
    });
    var backdropClasses = getStyles(styles$q, ['.modal-backdrop']);
    var classes = getStyles(styles$q, ['.modal']);
    var dialogClasses = getStyles(styles$q, ['.modal-dialog', size === 'sm' && '.modal-sm', size === 'lg' && '.modal-lg', size === 'xl' && '.modal-xl', scrollable && '.modal-dialog-scrollable', centered && '.modal-dialog-centered']);
    var contentClasses = getStyles(styles$q, ['.modal-content', scrollable && '.modal-dialog-scrollable .modal-content']);
    var contentTextClasses = getStyles(styles$q, ['.modal-content-text']); // If scrollable we use a ScrollView in ModalBody, so we can use a View here.

    var FlexView = scrollable ? View : ScrollView;
    return /*#__PURE__*/React__default["default"].createElement(_reactNative.Modal, {
      transparent: true,
      visible: visible,
      onRequestClose: handleToggle
    }, backdrop && /*#__PURE__*/React__default["default"].createElement(View, {
      style: backdropClasses
    }), /*#__PURE__*/React__default["default"].createElement(FlexView, {
      style: classes,
      contentContainerStyle: scrollable ? undefined : {
        flexGrow: 1
      }
    }, /*#__PURE__*/React__default["default"].createElement(BackdropHandler, {
      dialogRef: dialogRef,
      onClose: handleToggle,
      backdrop: backdrop
    }), /*#__PURE__*/React__default["default"].createElement(_reactNative.SafeAreaView, {
      style: {
        flexShrink: 1
      }
    }, /*#__PURE__*/React__default["default"].createElement(View, {
      ref: dialogRef,
      style: dialogClasses
    }, /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [contentClasses, style],
      textStyle: [contentTextClasses, textStyle]
    }), /*#__PURE__*/React__default["default"].createElement(ModalContext.Provider, {
      value: modal
    }, /*#__PURE__*/React__default["default"].createElement(OverlayProvider, null, children)))))));
  });
  Modal.displayName = 'Modal';
  Modal.propTypes = propTypes$u;
  Modal.Context = ModalContext;
  Modal.Header = ModalHeader;
  Modal.Title = ModalTitle;
  Modal.Body = ModalBody;
  Modal.Footer = ModalFooter;

  var NavContext = /*#__PURE__*/React__default["default"].createContext();
  NavContext.displayName = 'NavContext';

  var _excluded$t = ["children", "active", "disabled", "style", "activeStyle", "textStyle", "activeTextStyle"];

  var _templateObject$p, _templateObject2$k, _templateObject3$9, _templateObject4$7, _templateObject5$5, _templateObject6$4, _templateObject7$3, _templateObject8$2, _templateObject9$1, _templateObject10$1, _templateObject11$1, _templateObject12$1, _templateObject13$1, _templateObject14, _templateObject15, _templateObject16, _templateObject17, _templateObject18, _templateObject19, _templateObject20;
  var propTypes$t = {
    children: PropTypes.node.isRequired,
    active: PropTypes.bool,
    disabled: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    activeStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    activeTextStyle: PropTypes.any
  };
  var styles$p = StyleSheet.create(_objectSpread2(_objectSpread2({
    '.nav-link': css$1(_templateObject$p || (_templateObject$p = _taggedTemplateLiteral(["\n    // display: block;\n    flex-direction: row; // added for bootstrap-rn\n    align-items: center; // added for bootstrap-rn\n    padding: $nav-link-padding-y $nav-link-padding-x;\n    // @include transition($nav-link-transition);\n  "]))),
    '.nav-link-text': css$1(_templateObject2$k || (_templateObject2$k = _taggedTemplateLiteral(["\n    font-size: $nav-link-font-size;\n    font-weight: $nav-link-font-weight;\n    color: $nav-link-color;\n    text-decoration: none; // if($link-decoration == none, null, none);\n\n    &:hover {\n      color: $nav-link-hover-color;\n      text-decoration: none; // if($link-hover-decoration == underline, none, null);\n    }\n    &:focus {\n      color: $nav-link-hover-color;\n      text-decoration: none; // if($link-hover-decoration == underline, none, null);\n    }\n  "]))),
    '.nav-link-disabled': css$1(_templateObject3$9 || (_templateObject3$9 = _taggedTemplateLiteral(["\n    @include platform(web) {\n      pointer-events: none;\n      cursor: default;\n    }\n  "]))),
    '.nav-link-disabled-text': css$1(_templateObject4$7 || (_templateObject4$7 = _taggedTemplateLiteral(["\n    color: $nav-link-disabled-color;\n  "]))),
    '.nav-tabs .nav-link': css$1(_templateObject5$5 || (_templateObject5$5 = _taggedTemplateLiteral(["\n    margin-bottom: -$nav-tabs-border-width;\n    background: transparent; // none;\n    // Use longform for border, so that the border color is applied correctly on Android.\n    border-width: $nav-tabs-border-width;\n    border-style: solid;\n    border-color: transparent transparent;\n    border-top-left-radius: $nav-tabs-border-radius;\n    border-top-right-radius: $nav-tabs-border-radius;\n\n    &:hover {\n      // Prevents active .nav-link tab overlapping focus outline of previous/next .nav-link\n      // isolation: isolate;\n      border-color: $nav-tabs-link-hover-border-color;\n    }\n    &:focus {\n      // Prevents active .nav-link tab overlapping focus outline of previous/next .nav-link\n      // isolation: isolate;\n      border-color: $nav-tabs-link-hover-border-color;\n    }\n  "]))),
    '.nav-tabs .nav-link-disabled': css$1(_templateObject6$4 || (_templateObject6$4 = _taggedTemplateLiteral(["\n    background-color: transparent;\n    border-color: transparent;\n  "]))),
    '.nav-tabs .nav-link-disabled-text': css$1(_templateObject7$3 || (_templateObject7$3 = _taggedTemplateLiteral(["\n    color: $nav-link-disabled-color;\n  "]))),
    '.nav-tabs .nav-link-active': css$1(_templateObject8$2 || (_templateObject8$2 = _taggedTemplateLiteral(["\n    background-color: $nav-tabs-link-active-bg;\n    border-color: $nav-tabs-link-active-border-color;\n\n    &:hover {\n      background-color: $nav-tabs-link-active-bg; // added for bootstrap-rn\n      border-color: $nav-tabs-link-active-border-color; // added for bootstrap-rn\n    }\n    &:focus {\n      background-color: $nav-tabs-link-active-bg; // added for bootstrap-rn\n      border-color: $nav-tabs-link-active-border-color; // added for bootstrap-rn\n    }\n  "]))),
    '.nav-tabs .nav-link-active-text': css$1(_templateObject9$1 || (_templateObject9$1 = _taggedTemplateLiteral(["\n    color: $nav-tabs-link-active-color;\n\n    &:hover {\n      color: $nav-tabs-link-active-color; // added for bootstrap-rn\n    }\n    &:focus {\n      color: $nav-tabs-link-active-color; // added for bootstrap-rn\n    }\n  "]))),
    '.nav-pills .nav-link': css$1(_templateObject10$1 || (_templateObject10$1 = _taggedTemplateLiteral(["\n    background: transparent; // none;\n    border: 0;\n    border-radius: $nav-pills-border-radius;\n  "]))),
    '.nav-pills .nav-link-active': css$1(_templateObject11$1 || (_templateObject11$1 = _taggedTemplateLiteral(["\n    // @include gradient-bg($nav-pills-link-active-bg);\n    background-color: $nav-pills-link-active-bg; // added for bootstrap-rn\n\n    &:hover {\n      background-color: $nav-pills-link-active-bg; // added for bootstrap-rn\n    }\n    &:focus {\n      background-color: $nav-pills-link-active-bg; // added for bootstrap-rn\n    }\n  "]))),
    '.nav-pills .nav-link-active-text': css$1(_templateObject12$1 || (_templateObject12$1 = _taggedTemplateLiteral(["\n    color: $nav-pills-link-active-color;\n\n    &:hover {\n      color: $nav-pills-link-active-color; // added for bootstrap-rn\n    }\n    &:focus {\n      color: $nav-pills-link-active-color; // added for bootstyl\n    }\n  "]))),
    // Navbar styles
    '.navbar-nav .nav-link': css$1(_templateObject13$1 || (_templateObject13$1 = _taggedTemplateLiteral(["\n    padding-right: 0;\n    padding-left: 0;\n  "])))
  }, each(GRID_BREAKPOINTS, function (breakpoint) {
    return _defineProperty({}, ".navbar-expand".concat(infix(next(breakpoint)), " .navbar-nav .nav-link"), css$1(_templateObject14 || (_templateObject14 = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        padding-right: $navbar-nav-link-padding-x;\n        padding-left: $navbar-nav-link-padding-x;\n      }\n    "])), next(breakpoint)));
  })), {}, {
    '.navbar-light .navbar-nav .nav-link-text': css$1(_templateObject15 || (_templateObject15 = _taggedTemplateLiteral(["\n    color: $navbar-light-color;\n\n    &:hover {\n      color: $navbar-light-hover-color;\n    }\n    &:focus {\n      color: $navbar-light-hover-color;\n    }\n  "]))),
    '.navbar-light .navbar-nav .nav-link-disabled-text': css$1(_templateObject16 || (_templateObject16 = _taggedTemplateLiteral(["\n    color: $navbar-light-disabled-color;\n  "]))),
    '.navbar-light .navbar-nav .nav-link-active-text': css$1(_templateObject17 || (_templateObject17 = _taggedTemplateLiteral(["\n    color: $navbar-light-active-color;\n\n    &:hover {\n      color: $navbar-light-active-color; // added for bootstrap-rn\n    }\n    &:focus {\n      color: $navbar-light-active-color; // added for bootstrap-rn\n    }\n  "]))),
    '.navbar-dark .navbar-nav .nav-link-text': css$1(_templateObject18 || (_templateObject18 = _taggedTemplateLiteral(["\n    color: $navbar-dark-color;\n\n    &:hover {\n      color: $navbar-dark-hover-color;\n    }\n    &:focus {\n      color: $navbar-dark-hover-color;\n    }\n  "]))),
    '.navbar-dark .navbar-nav .nav-link-disabled-text': css$1(_templateObject19 || (_templateObject19 = _taggedTemplateLiteral(["\n    color: $navbar-dark-disabled-color;\n  "]))),
    '.navbar-dark .navbar-nav .nav-link-active-text': css$1(_templateObject20 || (_templateObject20 = _taggedTemplateLiteral(["\n    color: $navbar-dark-active-color;\n\n    &:hover {\n      color: $navbar-dark-active-color; // added for bootstrap-rn\n    }\n    &:focus {\n      color: $navbar-dark-active-color; // added for bootstrap-rn\n    }\n  "])))
  }));
  var NavLink = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var _useModifier = useModifier('useTabbable', props, ref),
        _useModifier2 = _slicedToArray(_useModifier, 2),
        modifierProps = _useModifier2[0],
        modifierRef = _useModifier2[1];

    var children = modifierProps.children,
        active = modifierProps.active,
        disabled = modifierProps.disabled,
        style = modifierProps.style,
        activeStyle = modifierProps.activeStyle,
        textStyle = modifierProps.textStyle,
        activeTextStyle = modifierProps.activeTextStyle,
        elementProps = _objectWithoutProperties(modifierProps, _excluded$t);

    var _useForcedContext = useForcedContext(NavContext),
        variant = _useForcedContext.variant;

    var navbar = React.useContext(NavbarContext);
    var classes = getStyles(styles$p, ['.nav-link', disabled && '.nav-link-disabled', variant && ".nav-".concat(variant, " .nav-link"), variant === 'tabs' && disabled && '.nav-tabs .nav-link-disabled', // Navbar styles
    navbar && '.navbar-nav .nav-link', navbar && navbar.expand && ".navbar-expand".concat(navbar.expand === true ? '' : "-".concat(navbar.expand), " .navbar-nav .nav-link"), navbar && ".navbar-".concat(navbar.variant, " .navbar-nav .nav-link"), navbar && disabled && ".navbar-".concat(navbar.variant, " .navbar-nav .nav-link-disabled")]);
    var activeClasses = getStyles(styles$p, [variant && ".nav-".concat(variant, " .nav-link-active"), // Navbar styles
    navbar && ".navbar-".concat(navbar.variant, " .navbar-nav .nav-link-active")]);
    var textClasses = getStyles(styles$p, ['.nav-link-text', disabled && '.nav-link-disabled-text', variant && ".nav-".concat(variant, " .nav-link-text"), variant === 'tabs' && disabled && '.nav-tabs .nav-link-disabled-text', // Navbar styles
    navbar && '.navbar-nav .nav-link-text', navbar && navbar.expand && ".navbar-expand".concat(infix(navbar.expand), " .navbar-nav .nav-link-text"), navbar && ".navbar-".concat(navbar.variant, " .navbar-nav .nav-link-text"), navbar && disabled && ".navbar-".concat(navbar.variant, " .navbar-nav .nav-link-disabled-text")]);
    var activeTextClasses = getStyles(styles$p, [variant && ".nav-".concat(variant, " .nav-link-active-text"), // Navbar styles
    navbar && ".navbar-".concat(navbar.variant, " .navbar-nav .nav-link-active-text")]);
    return /*#__PURE__*/React__default["default"].createElement(Pressable, _extends$1({}, elementProps, {
      ref: modifierRef,
      active: active,
      disabled: disabled,
      style: [].concat(_toConsumableArray(classes), [style]),
      activeStyle: [].concat(_toConsumableArray(activeClasses), [activeStyle]),
      textStyle: [].concat(_toConsumableArray(textClasses), [textStyle]),
      activeTextStyle: [].concat(_toConsumableArray(activeTextClasses), [activeTextStyle])
    }), children);
  });
  NavLink.displayName = 'NavLink';
  NavLink.propTypes = propTypes$t;

  var TabContext = /*#__PURE__*/React.createContext();
  TabContext.displayName = 'TabContext';

  var _excluded$s = ["children", "variant", "style"];

  var _templateObject$o, _templateObject2$j, _templateObject3$8, _templateObject4$6;
  var propTypes$s = {
    children: PropTypes.node.isRequired,
    variant: PropTypes.oneOf(['tabs', 'pills']),
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$o = StyleSheet.create(_objectSpread2({
    '.nav': css$1(_templateObject$o || (_templateObject$o = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: row; // added for bootstrap-rn\n    flex-wrap: wrap;\n    padding-left: 0;\n    margin-bottom: 0;\n    // list-style: none;\n  "]))),
    '.nav-tabs': css$1(_templateObject2$j || (_templateObject2$j = _taggedTemplateLiteral(["\n    border-bottom-width: $nav-tabs-border-width;\n    border-style: solid;\n    border-color: $nav-tabs-border-color;\n  "]))),
    // Navbar styles
    '.navbar-nav': css$1(_templateObject3$8 || (_templateObject3$8 = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: column; // cannot use \"inherit\" to get the \".navbar\"s value\n    padding-left: 0;\n    margin-bottom: 0;\n    // list-style: none;\n  "])))
  }, each(GRID_BREAKPOINTS, function (breakpoint) {
    return _defineProperty({}, ".navbar-expand".concat(infix(next(breakpoint)), " .navbar-nav"), css$1(_templateObject4$6 || (_templateObject4$6 = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        flex-direction: row;\n      }\n    "])), next(breakpoint)));
  })));

  var getRole = function getRole(tabbable, navbar) {
    if (tabbable) {
      return 'tablist';
    }

    if (_reactNative.Platform.OS === 'web' && !navbar) {
      return 'navigation';
    }

    return null;
  };

  var Nav = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        variant = props.variant,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$s);

    var navbar = React.useContext(NavbarContext);
    var tabbable = React.useContext(TabContext);
    var classes = getStyles(styles$o, [!navbar && '.nav', variant === 'tabs' && '.nav-tabs', // Navbar styles
    navbar && '.navbar-nav', navbar && navbar.expand && ".navbar-expand".concat(navbar.expand === true ? '' : "-".concat(navbar.expand), " .navbar-nav")]);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: getRole(tabbable, navbar),
      style: [classes, style]
    }), /*#__PURE__*/React__default["default"].createElement(NavContext.Provider, {
      value: {
        variant: variant
      }
    }, children));
  });
  Nav.displayName = 'Nav';
  Nav.propTypes = propTypes$s;
  Nav.Context = NavContext;
  Nav.Link = NavLink;

  var _excluded$r = ["children", "style", "textStyle"];

  var _templateObject$n, _templateObject2$i, _templateObject3$7;
  var propTypes$r = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$n = StyleSheet.create({
    '.navbar-text': css$1(_templateObject$n || (_templateObject$n = _taggedTemplateLiteral(["\n    padding-top: $nav-link-padding-y;\n    padding-bottom: $nav-link-padding-y;\n  "]))),
    '.navbar-light .navbar-text-text': css$1(_templateObject2$i || (_templateObject2$i = _taggedTemplateLiteral(["\n    color: $navbar-light-color;\n  "]))),
    '.navbar-dark .navbar-text-text': css$1(_templateObject3$7 || (_templateObject3$7 = _taggedTemplateLiteral(["\n    color: $navbar-dark-color;\n  "])))
  });
  var NavbarText = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$r);

    var _useForcedContext = useForcedContext(NavbarContext),
        variant = _useForcedContext.variant;

    var classes = getStyles(styles$n, ['.navbar-text']);
    var textClasses = getStyles(styles$n, [".navbar-".concat(variant, " .navbar-text-text")]); // composite component

    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), /*#__PURE__*/React__default["default"].createElement(Text, {
      style: [textClasses, textStyle]
    }, children));
  });
  NavbarText.displayName = 'NavbarText';
  NavbarText.propTypes = propTypes$r;

  var _excluded$q = ["children", "style", "textStyle"];

  var _templateObject$m, _templateObject2$h, _templateObject3$6, _templateObject4$5;
  var propTypes$q = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$m = StyleSheet.create({
    '.navbar-brand': css$1(_templateObject$m || (_templateObject$m = _taggedTemplateLiteral(["\n    padding-top: $navbar-brand-padding-y;\n    padding-bottom: $navbar-brand-padding-y;\n    margin-right: $navbar-brand-margin-end;\n  "]))),
    '.navbar-brand-text': css$1(_templateObject2$h || (_templateObject2$h = _taggedTemplateLiteral(["\n    font-size: $navbar-brand-font-size;\n    line-height: $navbar-brand-font-size * $line-height-base; // added for bootstrap-rn\n    text-decoration: none; // if($link-decoration == none, null, none);\n    // white-space: nowrap;\n\n    &:hover {\n      text-decoration: none; // if($link-hover-decoration == underline, none, null);\n    }\n    &:focus {\n      text-decoration: none; // if($link-hover-decoration == underline, none, null);\n    }\n  "]))),
    '.navbar-light .navbar-brand-text': css$1(_templateObject3$6 || (_templateObject3$6 = _taggedTemplateLiteral(["\n    color: $navbar-light-brand-color;\n\n    &:hover {\n      color: $navbar-light-brand-hover-color;\n    }\n    &:focus {\n      color: $navbar-light-brand-hover-color;\n    }\n  "]))),
    '.navbar-dark .navbar-brand-text': css$1(_templateObject4$5 || (_templateObject4$5 = _taggedTemplateLiteral(["\n    color: $navbar-dark-brand-color;\n\n    &:hover {\n      color: $navbar-dark-brand-hover-color;\n    }\n    &:focus {\n      color: $navbar-dark-brand-hover-color;\n    }\n  "])))
  });
  var NavbarBrand = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$q);

    var _useForcedContext = useForcedContext(NavbarContext),
        variant = _useForcedContext.variant;

    var classes = getStyles(styles$m, ['.navbar-brand']);
    var textClasses = getStyles(styles$m, ['.navbar-brand-text', ".navbar-".concat(variant, " .navbar-brand-text")]);
    return /*#__PURE__*/React__default["default"].createElement(Pressable, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children);
  });
  NavbarBrand.displayName = 'NavbarBrand';
  NavbarBrand.propTypes = propTypes$q;

  var _excluded$p = ["children", "style"];

  var _templateObject$l, _templateObject2$g;
  var propTypes$p = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$l = StyleSheet.create(_objectSpread2({
    '.navbar-collapse': css$1(_templateObject$l || (_templateObject$l = _taggedTemplateLiteral(["\n    flex-basis: 100%;\n    flex-grow: 1;\n    // For always expanded or extra full navbars, ensure content aligns itself\n    // properly vertically. Can be easily overridden with flex utilities.\n    // align-items: center;\n  "])))
  }, each(GRID_BREAKPOINTS, function (breakpoint) {
    return _defineProperty({}, ".navbar-expand".concat(infix(next(breakpoint)), " .navbar-collapse"), css$1(_templateObject2$g || (_templateObject2$g = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        flex-direction: row; // added for bootstrap-rn\n        display: flex;\n        flex-basis: auto;\n      }\n    "])), next(breakpoint)));
  })));
  var NavbarCollapse = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$p);

    var _useForcedContext = useForcedContext(NavbarContext),
        expand = _useForcedContext.expand,
        expanded = _useForcedContext.expanded;

    var media = useMedia();
    var classes = getStyles(styles$l, ['.navbar-collapse', expand && ".navbar-expand".concat(expand === true ? '' : "-".concat(expand), " .navbar-collapse")]);
    var show = expanded || expand && (expand === true || media.up(expand));

    if (!show) {
      return null;
    }

    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), children);
  });
  NavbarCollapse.displayName = 'NavbarCollapse';
  NavbarCollapse.propTypes = propTypes$p;

  var _excluded$o = ["onPress"];
  function useToggleNavbar(props) {
    var context = useForcedContext(NavbarContext);

    var handlePress = props.onPress,
        restProps = _objectWithoutProperties(props, _excluded$o);

    return _objectSpread2(_objectSpread2({}, restProps), {}, {
      nativeID: context.identifier,
      onPress: function onPress(event) {
        if (handlePress) handlePress(event);
        context.setExpanded(function (value) {
          return !value;
        });
      },
      accessibilitControls: context.identifier,
      accessibilityExpanded: context.expanded,
      accessibilityLabel: 'Toggle navigation'
    });
  }

  var _excluded$n = ["style", "textStyle", "iconStyle"];

  var _templateObject$k, _templateObject2$f, _templateObject3$5, _templateObject4$4, _templateObject5$4, _templateObject6$3, _templateObject7$2, _templateObject8$1;
  var propTypes$o = {
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    iconStyle: PropTypes.any
  };
  var styles$k = StyleSheet.create(_objectSpread2(_objectSpread2({
    '.navbar-toggler': css$1(_templateObject$k || (_templateObject$k = _taggedTemplateLiteral(["\n    padding: $navbar-toggler-padding-y $navbar-toggler-padding-x;\n    background-color: transparent; // remove default button style\n    border: $border-width solid transparent; // remove default button style\n    border-radius: $navbar-toggler-border-radius;\n    // @include transition($navbar-toggler-transition);\n\n    &:focus {\n      @include platform(web) {\n        outline-width: 0; // outline: 0;\n      }\n      // box-shadow: 0 0 0 $navbar-toggler-focus-width;\n    }\n  "]))),
    '.navbar-toggler-text': css$1(_templateObject2$f || (_templateObject2$f = _taggedTemplateLiteral(["\n    font-size: $navbar-toggler-font-size;\n    line-height: $navbar-toggler-font-size * $line-height-base;\n\n    &:hover {\n      text-decoration: none;\n    }\n\n    &:focus {\n      text-decoration: none;\n    }\n  "]))),
    '.navbar-toggler-icon': css$1(_templateObject3$5 || (_templateObject3$5 = _taggedTemplateLiteral(["\n    // display: inline-block;\n    width: $navbar-toggler-font-size * 1.5; // 1.5em;\n    height: $navbar-toggler-font-size * 1.5; // 1.5em;\n    // vertical-align: middle;\n    // background-repeat: no-repeat;\n    // background-position: center;\n    // background-size: 100%;\n  "])))
  }, each(GRID_BREAKPOINTS, function (breakpoint) {
    return _defineProperty({}, ".navbar-expand".concat(infix(next(breakpoint)), " .navbar-toggler"), css$1(_templateObject4$4 || (_templateObject4$4 = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        display: none;\n      }\n    "])), next(breakpoint)));
  })), {}, {
    '.navbar-light .navbar-toggler': css$1(_templateObject5$4 || (_templateObject5$4 = _taggedTemplateLiteral(["\n    border-color: $navbar-light-toggler-border-color;\n  "]))),
    '.navbar-light .navbar-toggler-text': css$1(_templateObject6$3 || (_templateObject6$3 = _taggedTemplateLiteral(["\n    color: $navbar-light-color;\n  "]))),
    '.navbar-dark .navbar-toggler': css$1(_templateObject7$2 || (_templateObject7$2 = _taggedTemplateLiteral(["\n    border-color: $navbar-dark-toggler-border-color;\n  "]))),
    '.navbar-dark .navbar-toggler-text': css$1(_templateObject8$1 || (_templateObject8$1 = _taggedTemplateLiteral(["\n    color: $navbar-dark-color;\n  "])))
  }));
  var NavbarToggler = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var style = props.style,
        textStyle = props.textStyle,
        iconStyle = props.iconStyle,
        elementProps = _objectWithoutProperties(props, _excluded$n);

    var _useForcedContext = useForcedContext(NavbarContext),
        variant = _useForcedContext.variant,
        expand = _useForcedContext.expand;

    var classes = getStyles(styles$k, ['.navbar-toggler', ".navbar-".concat(variant, " .navbar-toggler"), expand && ".navbar-expand".concat(expand === true ? '' : "-".concat(expand), " .navbar-toggler")]);
    var textClasses = getStyles(styles$k, ['.navbar-toggler-text', ".navbar-".concat(variant, " .navbar-toggler-text")]);
    var iconClasses = getStyles(styles$k, ['.navbar-toggler-icon']);
    return /*#__PURE__*/React__default["default"].createElement(Pressable, _extends$1({}, elementProps, {
      ref: ref,
      toggle: useToggleNavbar,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), /*#__PURE__*/React__default["default"].createElement(View, {
      style: [iconClasses, iconStyle]
    }, StyleSheet.value("navbar-".concat(variant, "-toggler-icon-bg"))));
  });
  NavbarToggler.displayName = 'NavbarToggler';
  NavbarToggler.propTypes = propTypes$o;

  function useNavbar(variant, defaultExpanded, controlledExpanded, onToggle, expand) {
    var identifier = useIdentifier('navbar');

    var _useControlledState = useControlledState(defaultExpanded, controlledExpanded, onToggle),
        _useControlledState2 = _slicedToArray(_useControlledState, 2),
        expanded = _useControlledState2[0],
        setExpanded = _useControlledState2[1];

    return React.useMemo(function () {
      return {
        identifier: identifier,
        variant: variant,
        expanded: expanded,
        setExpanded: setExpanded,
        expand: expand
      };
    }, [variant, expanded, expand]);
  }

  var _excluded$m = ["onPress"];
  function useDismissNavbar(props) {
    var context = useForcedContext(NavbarContext);

    var handlePress = props.onPress,
        restProps = _objectWithoutProperties(props, _excluded$m);

    return _objectSpread2(_objectSpread2({}, restProps), {}, {
      onPress: function onPress(event) {
        if (handlePress) handlePress(event);
        context.setExpanded(false);
      },
      accessibilityLabel: 'Close'
    });
  }

  var _excluded$l = ["children", "variant", "defaultExpanded", "expanded", "onToggle", "expand", "style"];

  var _templateObject$j, _templateObject2$e;
  var propTypes$n = {
    children: PropTypes.node.isRequired,
    variant: PropTypes.oneOf(['light', 'dark']),
    defaultExpanded: PropTypes.bool,
    expanded: PropTypes.bool,
    onToggle: PropTypes.func,
    expand: PropTypes.oneOf([true, 'sm', 'md', 'lg', 'xl', 'xxl']),
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$j = StyleSheet.create(_objectSpread2({
    '.navbar': css$1(_templateObject$j || (_templateObject$j = _taggedTemplateLiteral(["\n    position: relative;\n    display: flex;\n    flex-wrap: wrap; // allow us to do the line break for collapsing content\n    align-items: center;\n    justify-content: space-between; // space out brand from logo\n    padding-top: $navbar-padding-y;\n    padding-right: $navbar-padding-x; // default: null\n    padding-bottom: $navbar-padding-y;\n    padding-left: $navbar-padding-x; // default: null\n    // @include gradient-bg();\n  "])))
  }, each(GRID_BREAKPOINTS, function (breakpoint) {
    return _defineProperty({}, ".navbar-expand".concat(infix(next(breakpoint))), css$1(_templateObject2$e || (_templateObject2$e = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        flex-wrap: nowrap;\n        justify-content: flex-start;\n      }\n    "])), next(breakpoint)));
  })));
  var Navbar = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        _props$variant = props.variant,
        variant = _props$variant === void 0 ? 'light' : _props$variant,
        _props$defaultExpande = props.defaultExpanded,
        defaultExpanded = _props$defaultExpande === void 0 ? false : _props$defaultExpande,
        expanded = props.expanded,
        onToggle = props.onToggle,
        expand = props.expand,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$l);

    var navbar = useNavbar(variant, defaultExpanded, expanded, onToggle, expand);
    var classes = getStyles(styles$j, ['.navbar', expand && ".navbar-expand".concat(expand === true ? '' : "-".concat(expand))]);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), /*#__PURE__*/React__default["default"].createElement(NavbarContext.Provider, {
      value: navbar
    }, children));
  });
  Navbar.displayName = 'Navbar';
  Navbar.propTypes = propTypes$n;
  Navbar.Brand = NavbarBrand;
  Navbar.Text = NavbarText;
  Navbar.Collapse = NavbarCollapse;
  Navbar.Toggler = NavbarToggler;
  Navbar.useDismiss = useDismissNavbar;
  Navbar.useToggle = useToggleNavbar;

  function useOffcanvas() {
    return React.useMemo(function () {
      return {};
    }, []);
  }

  var _excluded$k = ["children", "style"];

  var _templateObject$i, _templateObject2$d;
  var propTypes$m = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$i = StyleSheet.create(_objectSpread2({
    '.offcanvas-header': css$1(_templateObject$i || (_templateObject$i = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: row; // added for bootstrap-rn\n    align-items: center;\n    justify-content: space-between;\n    padding: $offcanvas-padding-y $offcanvas-padding-x;\n  "])))
  }, each(GRID_BREAKPOINTS, function (breakpoint) {
    return _defineProperty({}, ".navbar-expand".concat(infix(next(breakpoint)), " .offcanvas-header"), css$1(_templateObject2$d || (_templateObject2$d = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        display: none;\n      }\n    "])), next(breakpoint)));
  })));
  var OffcanvasHeader = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$k);

    var navbar = React.useContext(NavbarContext);
    var classes = getStyles(styles$i, ['.offcanvas-header', navbar && navbar.expand && ".navbar-expand".concat(navbar.expand === true ? '' : "-".concat(navbar.expand), " .offcanvas-header")]);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), children);
  });
  OffcanvasHeader.displayName = 'OffcanvasHeader';
  OffcanvasHeader.propTypes = propTypes$m;

  var _excluded$j = ["children", "style"];

  var _templateObject$h;
  var propTypes$l = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$h = StyleSheet.create({
    '.offcanvas-title': css$1(_templateObject$h || (_templateObject$h = _taggedTemplateLiteral(["\n    margin-bottom: 0;\n    line-height: $font-size-base * $offcanvas-title-line-height;\n  "])))
  });
  var OffcanvasTitle = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$j);

    var classes = getStyles(styles$h, ['.offcanvas-title']);
    return /*#__PURE__*/React__default["default"].createElement(Heading$1, _extends$1({
      size: 5
    }, elementProps, {
      ref: ref,
      style: [classes, style]
    }), children);
  });
  OffcanvasTitle.displayName = 'OffcanvasTitle';
  OffcanvasTitle.propTypes = propTypes$l;

  var _excluded$i = ["children", "style", "contentContainerStyle"];

  var _templateObject$g, _templateObject2$c;
  var propTypes$k = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    contentContainerStyle: PropTypes.any
  };
  var styles$g = StyleSheet.create(_objectSpread2({
    '.offcanvas-body': css$1(_templateObject$g || (_templateObject$g = _taggedTemplateLiteral(["\n    // flex-grow: 1;\n    padding: $offcanvas-padding-y $offcanvas-padding-x;\n    // overflow-y: auto;\n  "])))
  }, each(GRID_BREAKPOINTS, function (breakpoint) {
    return _defineProperty({}, ".navbar-expand".concat(infix(next(breakpoint)), " .offcanvas-body"), css$1(_templateObject2$c || (_templateObject2$c = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        display: flex;\n        flex-grow: 0;\n        padding: 0;\n        // overflow-y: visible;\n      }\n    "])), next(breakpoint)));
  })));
  var OffcanvasBody = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        contentContainerStyle = props.contentContainerStyle,
        elementProps = _objectWithoutProperties(props, _excluded$i);

    var navbar = React.useContext(NavbarContext);
    var contentContainerClasses = getStyles(styles$g, ['.offcanvas-body', navbar && navbar.expand && ".navbar-expand".concat(navbar.expand === true ? '' : "-".concat(navbar.expand), " .offcanvas-body")]);
    return /*#__PURE__*/React__default["default"].createElement(ScrollView, _extends$1({}, elementProps, {
      ref: ref,
      style: style,
      contentContainerStyle: [contentContainerClasses, contentContainerStyle]
    }), children);
  });
  OffcanvasBody.displayName = 'OffcanvasBody';
  OffcanvasBody.propTypes = propTypes$k;

  var _excluded$h = ["children", "visible", "placement", "backdrop", "scroll", "onToggle", "style", "textStyle"];

  var _templateObject$f, _templateObject2$b, _templateObject3$4, _templateObject4$3, _templateObject5$3, _templateObject6$2, _templateObject7$1, _templateObject8, _templateObject9, _templateObject10, _templateObject11, _templateObject12, _templateObject13;
  var PLACEMENTS = ['top', 'bottom', 'start', 'end']; // , 'auto'

  var propTypes$j = {
    children: PropTypes.node.isRequired,
    visible: PropTypes.bool,
    placement: PropTypes.oneOf(PLACEMENTS),
    backdrop: PropTypes.oneOfType([PropTypes.bool, PropTypes.oneOf(['static'])]),
    // Currently only supported on web.
    scroll: PropTypes.bool,
    onToggle: PropTypes.func,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$f = StyleSheet.create(_objectSpread2({
    '.offcanvas': css$1(_templateObject$f || (_templateObject$f = _taggedTemplateLiteral(["\n    position: absolute; // fixed;\n    // bottom: 0;\n    z-index: $zindex-offcanvas;\n    display: flex;\n    flex-direction: column;\n    max-width: 100%;\n    // visibility: hidden;\n    background-color: $offcanvas-bg-color;\n    // background-clip: padding-box;\n    @include platform(web) {\n      outline-width: 0; // outline: 0;\n    }\n    // @include box-shadow($offcanvas-box-shadow);\n    // @include transition(transform $offcanvas-transition-duration ease-in-out);\n  "]))),
    '.offcanvas-text': css$1(_templateObject2$b || (_templateObject2$b = _taggedTemplateLiteral(["\n    color: $offcanvas-color;\n  "]))),
    '.offcanvas-backdrop': css$1(_templateObject3$4 || (_templateObject3$4 = _taggedTemplateLiteral(["\n    position: absolute;\n    top: 0;\n    left: 0;\n    z-index: $zindex-offcanvas-backdrop;\n    width: 100%;\n    height: 100%;\n    background-color: $offcanvas-backdrop-bg;\n    opacity: $offcanvas-backdrop-opacity;\n  "]))),
    '.offcanvas-start': css$1(_templateObject4$3 || (_templateObject4$3 = _taggedTemplateLiteral(["\n    top: 0;\n    bottom: 0; // added for bootstrap-rn\n    left: 0;\n    // width: $offcanvas-horizontal-width;\n    border-right-width: $offcanvas-border-width;\n    border-style: solid;\n    border-color: $offcanvas-border-color;\n    // transform: translateX(-100%);\n  "]))),
    '.offcanvas-end': css$1(_templateObject5$3 || (_templateObject5$3 = _taggedTemplateLiteral(["\n    top: 0;\n    bottom: 0; // added for bootstrap-rn\n    right: 0;\n    // width: $offcanvas-horizontal-width;\n    border-left-width: $offcanvas-border-width;\n    border-style: solid;\n    border-color: $offcanvas-border-color;\n    // transform: translateX(100%);\n  "]))),
    '.offcanvas-top': css$1(_templateObject6$2 || (_templateObject6$2 = _taggedTemplateLiteral(["\n    top: 0;\n    right: 0;\n    left: 0;\n    // height: $offcanvas-vertical-height;\n    max-height: 100%;\n    border-bottom-width: $offcanvas-border-width;\n    border-style: solid;\n    border-color: $offcanvas-border-color;\n    // transform: translateY(-100%);\n  "]))),
    '.offcanvas-bottom': css$1(_templateObject7$1 || (_templateObject7$1 = _taggedTemplateLiteral(["\n    bottom: 0; // added for bootstrap-rn\n    right: 0;\n    left: 0;\n    // height: $offcanvas-vertical-height;\n    max-height: 100%;\n    width: 100%;\n    border-top-width: $offcanvas-border-width;\n    border-style: solid;\n    border-color: $offcanvas-border-color;\n    // transform: translateY(100%);\n  "]))),
    // The following .offcanvas-dialog classes are added for bootstrap-rn,
    // because otherwise the text would exceed a width of 100% on native
    // and also additional width by SafeAreaView would not be applied.
    '.offcanvas-dialog': css$1(_templateObject8 || (_templateObject8 = _taggedTemplateLiteral(["\n    max-width: 100%;\n    max-height: 100%;\n  "]))),
    '.offcanvas-dialog-start': css$1(_templateObject9 || (_templateObject9 = _taggedTemplateLiteral(["\n    width: $offcanvas-horizontal-width;\n  "]))),
    '.offcanvas-dialog-end': css$1(_templateObject10 || (_templateObject10 = _taggedTemplateLiteral(["\n    width: $offcanvas-horizontal-width;\n  "]))),
    '.offcanvas-dialog-top': css$1(_templateObject11 || (_templateObject11 = _taggedTemplateLiteral(["\n    height: $offcanvas-vertical-height;\n  "]))),
    '.offcanvas-dialog-bottom': css$1(_templateObject12 || (_templateObject12 = _taggedTemplateLiteral(["\n    height: $offcanvas-vertical-height;\n  "])))
  }, each(GRID_BREAKPOINTS, function (breakpoint) {
    return _defineProperty({}, ".navbar-expand".concat(infix(next(breakpoint)), " .offcanvas"), css$1(_templateObject13 || (_templateObject13 = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        position: relative; // inherit;\n        bottom: 0;\n        // z-index: auto;\n        flex-grow: 1;\n        // visibility: visible !important; // stylelint-disable-line declaration-no-important\n        background-color: transparent;\n        border-right-width: 0;\n        border-left-width: 0;\n        // @include box-shadow(none);\n        // @include transition(none);\n        // transform: none;\n      }\n    "])), next(breakpoint)));
  })));
  var Offcanvas = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        visible = props.visible,
        _props$placement = props.placement,
        placement = _props$placement === void 0 ? 'top' : _props$placement,
        _props$backdrop = props.backdrop,
        backdrop = _props$backdrop === void 0 ? true : _props$backdrop,
        _props$scroll = props.scroll,
        scroll = _props$scroll === void 0 ? false : _props$scroll,
        handleToggle = props.onToggle,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$h);

    var media = useMedia();
    var navbar = React.useContext(NavbarContext);
    var offcanvasRef = React.useRef();
    var offcanvas = useOffcanvas();
    useScrollbarEffects({
      keepBodyScroll: scroll,
      visible: visible
    });
    var backdropClasses = getStyles(styles$f, ['.offcanvas-backdrop']);
    var classes = getStyles(styles$f, ['.offcanvas', ".offcanvas-".concat(placement), navbar && navbar.expand && ".navbar-expand".concat(navbar.expand === true ? '' : "-".concat(navbar.expand), " .offcanvas")]);
    var dialogClasses = getStyles(styles$f, ['.offcanvas-dialog', ".offcanvas-dialog-".concat(placement)]);
    var textClasses = getStyles(styles$f, ['.offcanvas-content-text']); // Render children without modal for navbar.

    if (navbar && navbar.expand && (navbar.expand === true || media.up(navbar.expand))) {
      return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
        ref: ref,
        style: [classes, style],
        textStyle: [textClasses, textStyle]
      }), children);
    }

    return /*#__PURE__*/React__default["default"].createElement(_reactNative.Modal, {
      transparent: true,
      visible: navbar ? navbar.expanded : visible,
      onRequestClose: handleToggle
    }, backdrop && /*#__PURE__*/React__default["default"].createElement(View, {
      style: backdropClasses
    }, /*#__PURE__*/React__default["default"].createElement(BackdropHandler, {
      dialogRef: offcanvasRef,
      onClose: handleToggle,
      backdrop: backdrop
    })), /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: concatRefs(offcanvasRef, ref),
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), /*#__PURE__*/React__default["default"].createElement(_reactNative.SafeAreaView, {
      style: {
        flexShrink: 1
      }
    }, /*#__PURE__*/React__default["default"].createElement(View, {
      style: dialogClasses
    }, /*#__PURE__*/React__default["default"].createElement(OffcanvasContext.Provider, {
      value: offcanvas
    }, /*#__PURE__*/React__default["default"].createElement(OverlayProvider, null, children))))));
  });
  Offcanvas.displayName = 'Offcanvas';
  Offcanvas.propTypes = propTypes$j;
  Offcanvas.Context = OffcanvasContext;
  Offcanvas.Header = OffcanvasHeader;
  Offcanvas.Title = OffcanvasTitle;
  Offcanvas.Body = OffcanvasBody;

  var PickerContext = /*#__PURE__*/React__default["default"].createContext();
  PickerContext.displayName = 'PickerContext';

  var _templateObject$e, _templateObject2$a;
  var propTypes$i = {
    label: PropTypes.string.isRequired,
    value: PropTypes.oneOfType([PropTypes.bool, PropTypes.number, PropTypes.string]),
    disabled: PropTypes.bool
  };
  var styles$e = StyleSheet.create({
    '.form-select-item': css$1(_templateObject$e || (_templateObject$e = _taggedTemplateLiteral(["\n    margin: 0.25rem 1rem;\n    padding: 0.25rem;\n  "]))),
    '.form-select-item-disabled': css$1(_templateObject2$a || (_templateObject2$a = _taggedTemplateLiteral([""])))
  });
  var PickerItem = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var label = props.label,
        value = props.value,
        _props$disabled = props.disabled,
        disabled = _props$disabled === void 0 ? false : _props$disabled;
    var context = React.useContext(PickerContext);
    var media = useMedia();
    var provideWebComponent = _reactNative.Platform.OS === 'web' && (!context || !context.useNativeComponent);
    var commonProps = {
      disabled: disabled
    };

    if (provideWebComponent) {
      return /*#__PURE__*/React__default["default"].createElement(_reactNative.Picker.Item, _extends$1({}, commonProps, {
        ref: ref,
        label: label,
        value: value
      }));
    }

    var classes = getStyles(styles$e, ['.form-select-item', disabled && '.form-select-item-disabled']);
    var resolveStyle = useStyle(classes);
    var selected = value === context.value;
    return /*#__PURE__*/React__default["default"].createElement(Pressable, _extends$1({}, commonProps, {
      ref: ref,
      onPress: function onPress() {
        context.onChange(value);
      },
      accessibilitySelected: selected,
      style: resolveStyle({
        media: media
      })
    }), /*#__PURE__*/React__default["default"].createElement(Text, {
      styleName: selected && 'text-primary'
    }, label));
  });
  PickerItem.displayName = 'PickerItem';
  PickerItem.propTypes = propTypes$i;

  var _excluded$g = ["children", "value", "onChange", "onFocus", "onBlur", "placeholder", "size", "disabled", "valid", "invalid", "useNativeComponent", "style", "styleName"];

  var _templateObject$d, _templateObject2$9, _templateObject3$3, _templateObject4$2, _templateObject5$2, _templateObject6$1, _templateObject7;
  var propTypes$h = {
    children: PropTypes.node.isRequired,
    value: PropTypes.oneOfType([PropTypes.bool, PropTypes.number, PropTypes.string]),
    onChange: PropTypes.func,
    onFocus: PropTypes.func,
    onBlur: PropTypes.func,
    placeholder: PropTypes.string,
    size: PropTypes.oneOf(['sm', 'lg']),
    disabled: PropTypes.bool,
    valid: PropTypes.bool,
    invalid: PropTypes.bool,
    useNativeComponent: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    styleName: PropTypes.any
  };
  var styles$d = StyleSheet.create(_objectSpread2(_objectSpread2({
    '.form-select': css$1(_templateObject$d || (_templateObject$d = _taggedTemplateLiteral(["\n    // display: block;\n    width: 100%;\n    padding: $form-select-padding-y $form-select-indicator-padding\n      $form-select-padding-y $form-select-padding-x;\n    // See https://github.com/twbs/bootstrap/issues/32636\n    // -moz-padding-start: subtract($form-select-padding-x, 3px);\n    font-family: $form-select-font-family;\n    font-size: $form-select-font-size;\n    font-weight: $form-select-font-weight;\n    line-height: $form-select-font-size * $form-select-line-height;\n    color: $form-select-color;\n    background-color: $form-select-bg;\n    // background-image: escape-svg($form-select-indicator);\n    // background-repeat: no-repeat;\n    // background-position: $form-select-bg-position;\n    // background-size: $form-select-bg-size;\n    border: $form-select-border-width solid $form-select-border-color;\n    border-radius: $form-select-border-radius;\n    // @include box-shadow($form-select-box-shadow);\n    // @include transition($form-select-transition);\n    @include platform(web) {\n      appearance: none;\n    }\n\n    &:focus {\n      border-color: $form-select-focus-border-color;\n      @include platform(web) {\n        outline-width: 0; // outline: 0;\n      }\n      /* @if $enable-shadows {\n        @include box-shadow(\n          $form-select-box-shadow,\n          $form-select-focus-box-shadow\n        );\n      } @else {\n        // Avoid using mixin so we can pass custom focus shadow properly\n        box-shadow: $form-select-focus-box-shadow;\n      } */\n    }\n  "]))),
    '.form-select-disabled': css$1(_templateObject2$9 || (_templateObject2$9 = _taggedTemplateLiteral(["\n    color: $form-select-disabled-color;\n    background-color: $form-select-disabled-bg;\n    border-color: $form-select-disabled-border-color;\n  "]))),
    '.form-select-sm': css$1(_templateObject3$3 || (_templateObject3$3 = _taggedTemplateLiteral(["\n    padding-top: $form-select-padding-y-sm;\n    padding-bottom: $form-select-padding-y-sm;\n    padding-left: $form-select-padding-x-sm;\n    font-size: $form-select-font-size-sm;\n    border-radius: $form-select-border-radius-sm;\n  "]))),
    '.form-select-lg': css$1(_templateObject4$2 || (_templateObject4$2 = _taggedTemplateLiteral(["\n    padding-top: $form-select-padding-y-lg;\n    padding-bottom: $form-select-padding-y-lg;\n    padding-left: $form-select-padding-x-lg;\n    font-size: $form-select-font-size-lg;\n    border-radius: $form-select-border-radius-lg;\n  "])))
  }, each(FORM_VALIDATION_STATES, function (state, data) {
    return _defineProperty({}, ".form-select.is-".concat(state), css$1(_templateObject5$2 || (_templateObject5$2 = _taggedTemplateLiteral(["\n      border-color: ", ";\n\n      &:focus {\n        border-color: ", ";\n        // box-shadow: $focus-box-shadow;\n      }\n    "])), function (t) {
      return data(t).color;
    }, function (t) {
      return data(t).color;
    }));
  })), {}, {
    '.form-select-offcanvas': css$1(_templateObject6$1 || (_templateObject6$1 = _taggedTemplateLiteral([""]))),
    '.form-select-offcanvas-body': css$1(_templateObject7 || (_templateObject7 = _taggedTemplateLiteral(["\n    align-items: center;\n  "])))
  }));
  var Picker = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var _useModifier = useModifier('useFormField', props, ref),
        _useModifier2 = _slicedToArray(_useModifier, 2),
        modifierProps = _useModifier2[0],
        modifierRef = _useModifier2[1];

    var children = modifierProps.children,
        value = modifierProps.value,
        _modifierProps$onChan = modifierProps.onChange,
        _onChange = _modifierProps$onChan === void 0 ? function () {} : _modifierProps$onChan,
        _modifierProps$onFocu = modifierProps.onFocus,
        _onFocus = _modifierProps$onFocu === void 0 ? function () {} : _modifierProps$onFocu,
        _modifierProps$onBlur = modifierProps.onBlur,
        _onBlur = _modifierProps$onBlur === void 0 ? function () {} : _modifierProps$onBlur,
        placeholder = modifierProps.placeholder,
        size = modifierProps.size,
        _modifierProps$disabl = modifierProps.disabled,
        disabled = _modifierProps$disabl === void 0 ? false : _modifierProps$disabl,
        _modifierProps$valid = modifierProps.valid,
        valid = _modifierProps$valid === void 0 ? false : _modifierProps$valid,
        _modifierProps$invali = modifierProps.invalid,
        invalid = _modifierProps$invali === void 0 ? false : _modifierProps$invali,
        _modifierProps$useNat = modifierProps.useNativeComponent,
        useNativeComponent = _modifierProps$useNat === void 0 ? false : _modifierProps$useNat,
        style = modifierProps.style,
        styleName = modifierProps.styleName,
        elementProps = _objectWithoutProperties(modifierProps, _excluded$g);

    var _useState = React.useState(false),
        _useState2 = _slicedToArray(_useState, 2),
        focused = _useState2[0],
        setFocused = _useState2[1];

    var _useState3 = React.useState(false),
        _useState4 = _slicedToArray(_useState3, 2),
        open = _useState4[0],
        setOpen = _useState4[1];

    var media = useMedia();
    var classes = getStyles(styles$d, ['.form-select', disabled && '.form-select-disabled', size === 'sm' && '.form-select-sm', size === 'lg' && '.form-select-lg', valid && '.form-select.is-valid', invalid && '.form-select.is-invalid']);
    var resolveStyle = useStyle([classes, style], styleName);
    var provideWebComponent = _reactNative.Platform.OS === 'web' && !useNativeComponent;
    var commonProps = {
      onFocus: function onFocus() {
        if (disabled) return;
        setFocused(true);

        _onFocus();
      },
      onBlur: function onBlur() {
        if (disabled) return;
        setFocused(false);

        _onBlur();
      },
      disabled: disabled,
      style: resolveStyle({
        media: media,
        interaction: {
          focused: focused
        }
      })
    };

    if (provideWebComponent) {
      return /*#__PURE__*/React__default["default"].createElement(_reactNative.Picker, _extends$1({}, elementProps, commonProps, {
        ref: modifierRef,
        selectedValue: value,
        onValueChange: _onChange
      }), /*#__PURE__*/React__default["default"].createElement("option", {
        value: "",
        disabled: true,
        hidden: true
      }, placeholder), children);
    }

    var offcanvasClasses = getStyles(styles$d, ['.form-select-offcanvas']);
    var offcanvasBodyClasses = getStyles(styles$d, ['.form-select-offcanvas-body']);
    var items = React__default["default"].Children.map(children, function (child) {
      return {
        label: child.props.label,
        value: child.props.value
      };
    });
    var selectedItem = items.find(function (item) {
      return item.value === value;
    });
    return /*#__PURE__*/React__default["default"].createElement(PickerContext.Provider, {
      value: {
        value: value,
        onChange: function onChange(nextValue) {
          _onChange(nextValue);

          setOpen(false);
        },
        useNativeComponent: true
      }
    }, /*#__PURE__*/React__default["default"].createElement(Text, _extends$1({}, elementProps, commonProps, {
      ref: modifierRef // role "listbox" is not supported in react-native :(
      ,
      accessibilityRole: "button",
      accessibilityDisabled: disabled,
      accessible: true,
      focusable: !disabled,
      selectable: false,
      onPress: function onPress() {
        if (disabled) return;
        setOpen(true);
      }
    }), selectedItem ? selectedItem.label : placeholder), /*#__PURE__*/React__default["default"].createElement(Offcanvas, {
      placement: "bottom",
      visible: open,
      onToggle: function onToggle() {
        setOpen(false);
      },
      style: offcanvasClasses
    }, /*#__PURE__*/React__default["default"].createElement(Offcanvas.Body, {
      style: offcanvasBodyClasses
    }, children)));
  });
  Picker.displayName = 'Picker';
  Picker.propTypes = propTypes$h;
  Picker.Item = PickerItem;

  var _excluded$f = ["children", "style"];

  var _templateObject$c;
  var propTypes$g = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$c = StyleSheet.create({
    '.placeholders': css$1(_templateObject$c || (_templateObject$c = _taggedTemplateLiteral([""])))
  });
  var Placeholders = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$f);

    var classes = getStyles(styles$c, ['.placeholders']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), children);
  });
  Placeholders.displayName = 'Placeholders';
  Placeholders.propTypes = propTypes$g;
  /*
  $placeholder-opacity-max:           .5;
  $placeholder-opacity-min:           .2;
  */

  var ProgressContext = /*#__PURE__*/React__default["default"].createContext();
  ProgressContext.displayName = 'ProgressContext';

  var _excluded$e = ["children", "value", "style", "textStyle"];

  var _templateObject$b, _templateObject2$8;
  var propTypes$f = {
    children: PropTypes.node,
    value: PropTypes.number.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$b = StyleSheet.create({
    '.progress-bar': css$1(_templateObject$b || (_templateObject$b = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: column;\n    justify-content: center;\n    overflow: hidden;\n    background-color: $progress-bar-bg;\n    // @include transition($progress-bar-transition);\n  "]))),
    '.progress-bar-text': css$1(_templateObject2$8 || (_templateObject2$8 = _taggedTemplateLiteral(["\n    color: $progress-bar-color;\n    text-align: center;\n    // white-space: nowrap;\n  "])))
  });
  var ROUND_PRECISION = 1000;

  var getPercentage = function getPercentage(value, min, max) {
    var percentage = (value - min) / (max - min) * 100;
    return Math.round(percentage * ROUND_PRECISION) / ROUND_PRECISION;
  };

  var ProgressBar = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        value = props.value,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$e);

    var _useForcedContext = useForcedContext(ProgressContext),
        min = _useForcedContext.min,
        max = _useForcedContext.max;

    var classes = getStyles(styles$b, ['.progress-bar']);
    var textClasses = getStyles(styles$b, ['.progress-bar-text']); // composite component

    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: "progressbar",
      accessibilityValueNow: value,
      accessibilityValueMin: min,
      accessibilityValueMax: max,
      style: [classes, style, {
        width: "".concat(getPercentage(value, min, max), "%")
      }]
    }), children && /*#__PURE__*/React__default["default"].createElement(Text, {
      style: [textClasses, textStyle]
    }, children));
  });
  ProgressBar.displayName = 'ProgressBar';
  ProgressBar.propTypes = propTypes$f;

  function useProgress(min, max) {
    return React.useMemo(function () {
      return {
        min: min,
        max: max
      };
    }, [min, max]);
  }

  var _excluded$d = ["children", "min", "max", "style", "textStyle"];

  var _templateObject$a, _templateObject2$7;
  var propTypes$e = {
    children: PropTypes.node.isRequired,
    min: PropTypes.number,
    max: PropTypes.number,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$a = StyleSheet.create({
    '.progress': css$1(_templateObject$a || (_templateObject$a = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: row; // added for bootstrap-rn\n    height: $progress-height;\n    overflow: hidden; // force rounded corners by cropping it\n    background-color: $progress-bg;\n    border-radius: $progress-border-radius;\n    // @include box-shadow($progress-box-shadow);\n  "]))),
    '.progress-text': css$1(_templateObject2$7 || (_templateObject2$7 = _taggedTemplateLiteral(["\n    font-size: $progress-font-size;\n    line-height: $progress-font-size * $line-height-base; // added for bootstrap-rn\n  "])))
  });
  var Progress = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        _props$min = props.min,
        min = _props$min === void 0 ? 0 : _props$min,
        _props$max = props.max,
        max = _props$max === void 0 ? 100 : _props$max,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$d);

    var progress = useProgress(min, max);
    var classes = getStyles(styles$a, ['.progress']);
    var textClasses = getStyles(styles$a, ['.progress-text']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), /*#__PURE__*/React__default["default"].createElement(ProgressContext.Provider, {
      value: progress
    }, children));
  });
  Progress.displayName = 'Progress';
  Progress.propTypes = propTypes$e;
  Progress.Bar = ProgressBar;

  var _excluded$c = ["children", "lead", "style"];

  var _templateObject$9, _templateObject2$6;
  var propTypes$d = {
    children: PropTypes.node.isRequired,
    lead: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$9 = StyleSheet.create({
    paragraph: css$1(_templateObject$9 || (_templateObject$9 = _taggedTemplateLiteral(["\n    margin-top: 0;\n    margin-bottom: $paragraph-margin-bottom;\n  "]))),
    '.lead': css$1(_templateObject2$6 || (_templateObject2$6 = _taggedTemplateLiteral(["\n    font-size: $lead-font-size;\n    line-height: $lead-font-size * $line-height-base; // added for bootstrap-rn\n    font-weight: $lead-font-weight;\n  "])))
  });
  var Heading = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        lead = props.lead,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$c);

    var classes = getStyles(styles$9, ['paragraph', lead && '.lead']); // Accessiblity role paragraph is only supported on web.

    var role = _reactNative.Platform.OS === 'web' ? 'paragraph' : null;
    return /*#__PURE__*/React__default["default"].createElement(Text, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: role,
      style: [classes, style]
    }), children);
  });
  Heading.displayName = 'Heading';
  Heading.propTypes = propTypes$d;

  var _excluded$b = ["children", "first", "last", "active", "disabled", "style", "textStyle"];

  var _templateObject$8, _templateObject2$5, _templateObject3$2, _templateObject4$1, _templateObject5$1;
  var propTypes$c = {
    children: PropTypes.node.isRequired,
    active: PropTypes.bool,
    first: PropTypes.bool,
    last: PropTypes.bool,
    disabled: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$8 = StyleSheet.create({
    '.pagination-item': css$1(_templateObject$8 || (_templateObject$8 = _taggedTemplateLiteral(["\n    padding-bottom: $pagination-padding-y;\n    padding-top: $pagination-padding-y;\n    padding-left: $pagination-padding-x;\n    padding-right: $pagination-padding-x;\n    border: $list-group-border-width solid $list-group-border-color;\n\n    &:hover {\n      color: $pagination-hover-color;\n      background-color: $pagination-hover-bg;\n      border-color: $pagination-hover-border-color;\n    }\n\n    &:focus {\n      color: $pagination-focus-color;\n      background-color: $pagination-focus-bg;\n      //$pagination-focus-box-shadow:\n      //$pagination-focus-outline:\n    }\n  "]))),
    '.pagination-item-first': css$1(_templateObject2$5 || (_templateObject2$5 = _taggedTemplateLiteral(["\n    border-top-left-radius: $list-group-border-radius;\n    border-bottom-left-radius: $list-group-border-radius;\n  "]))),
    '.pagination-item-last': css$1(_templateObject3$2 || (_templateObject3$2 = _taggedTemplateLiteral(["\n    border-top-right-radius: $list-group-border-radius;\n    border-bottom-right-radius: $list-group-border-radius;\n  "]))),
    '.pagination-item-active': css$1(_templateObject4$1 || (_templateObject4$1 = _taggedTemplateLiteral(["\n    color: $pagination-active-color;\n    background-color: $pagination-active-bg;\n    border-color: $pagination-active-border-color;\n  "]))),
    '.pagination-item-disabled': css$1(_templateObject5$1 || (_templateObject5$1 = _taggedTemplateLiteral(["\n    color: $pagination-disabled-color;\n    background-color: $pagination-disabled-bg;\n    border-color: $pagination-disabled-border-color;\n  "])))
  });
  var PaginationItem = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        _props$first = props.first,
        first = _props$first === void 0 ? false : _props$first,
        _props$last = props.last,
        last = _props$last === void 0 ? false : _props$last,
        _props$active = props.active,
        active = _props$active === void 0 ? false : _props$active,
        _props$disabled = props.disabled,
        disabled = _props$disabled === void 0 ? false : _props$disabled,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$b);

    var classes = getStyles(styles$8, ['.pagination-item', first && '.pagination-item-first', last && '.pagination-item-last', active && '.pagination-item-active', disabled && '.pagination-item-disabled']);
    var textClasses = getStyles(styles$8, [active && '.pagination-item-active', disabled && '.pagination-item-disabled']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children);
  });
  PaginationItem.displayName = 'PaginationItem';
  PaginationItem.propTypes = propTypes$c;
  /*
  $pagination-padding-y:              .375rem;
  $pagination-padding-x:              .75rem;
  $pagination-padding-y-sm:           .25rem;
  $pagination-padding-x-sm:           .5rem;
  $pagination-padding-y-lg:           .75rem;
  $pagination-padding-x-lg:           1.5rem;

  $pagination-color:                  $link-color;
  $pagination-bg:                     $white;
  $pagination-border-width:           $border-width;
  $pagination-border-radius:          $border-radius;
  $pagination-margin-start:           -$pagination-border-width;
  $pagination-border-color:           $gray-300;

  $pagination-focus-color:            $link-hover-color;
  $pagination-focus-bg:               $gray-200;
  $pagination-focus-box-shadow:       $input-btn-focus-box-shadow;
  $pagination-focus-outline:          0;

  $pagination-hover-color:            $link-hover-color;
  $pagination-hover-bg:               $gray-200;
  $pagination-hover-border-color:     $gray-300;

  $pagination-active-color:           $component-active-color;
  $pagination-active-bg:              $component-active-bg;
  $pagination-active-border-color:    $pagination-active-bg;

  $pagination-disabled-color:         $gray-600;
  $pagination-disabled-bg:            $white;
  $pagination-disabled-border-color:  $gray-300;

  $pagination-transition:              color .15s ease-in-out, background-color .15s ease-in-out, border-color .15s ease-in-out, box-shadow .15s ease-in-out;

  $pagination-border-radius-sm:       $border-radius-sm;
  $pagination-border-radius-lg:       $border-radius-lg;

  */

  var _excluded$a = ["children", "style"];

  var _templateObject$7;
  var propTypes$b = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$7 = StyleSheet.create({
    '.pagination': css$1(_templateObject$7 || (_templateObject$7 = _taggedTemplateLiteral(["\n    background-color: $white;\n    flex-direction: row;\n  "])))
  });
  var Pagination = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$a);

    var classes = getStyles(styles$7, ['.pagination']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), makeListChildren(children));
  });
  Pagination.displayName = 'Pagination';
  Pagination.propTypes = propTypes$b;
  Pagination.Item = PaginationItem;

  var RadioContext = /*#__PURE__*/React__default["default"].createContext();
  RadioContext.displayName = 'RadioContext';

  var _excluded$9 = ["children", "value", "onChange", "disabled"];
  var propTypes$a = {
    children: PropTypes.node.isRequired,
    value: PropTypes.oneOfType([PropTypes.bool, PropTypes.number, PropTypes.string]),
    onChange: PropTypes.func,
    disabled: PropTypes.bool
  };
  var RadioGroup = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        value = props.value,
        _props$onChange = props.onChange,
        onChange = _props$onChange === void 0 ? function () {} : _props$onChange,
        _props$disabled = props.disabled,
        disabled = _props$disabled === void 0 ? false : _props$disabled,
        elementProps = _objectWithoutProperties(props, _excluded$9);

    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: "radiogroup"
    }), /*#__PURE__*/React__default["default"].createElement(RadioContext.Provider, {
      value: {
        value: value,
        onChange: onChange,
        disabled: disabled
      }
    }, children));
  });
  RadioGroup.displayName = 'RadioGroup';
  RadioGroup.propTypes = propTypes$a;

  var _excluded$8 = ["value"];
  var propTypes$9 = {
    value: PropTypes.oneOfType([PropTypes.bool, PropTypes.number, PropTypes.string])
  };
  var Radio = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var value = props.value,
        elementProps = _objectWithoutProperties(props, _excluded$8);

    var context = useForcedContext(RadioContext);
    return /*#__PURE__*/React__default["default"].createElement(CheckInput, _extends$1({}, elementProps, {
      ref: ref,
      type: "radio",
      value: value === context.value,
      onChange: function onChange() {
        context.onChange(value);
      },
      disabled: context.disabled
    }));
  });
  Radio.displayName = 'Radio';
  Radio.propTypes = propTypes$9;
  Radio.Group = RadioGroup;

  var _excluded$7 = ["children", "style"];

  var _templateObject$6;
  var propTypes$8 = {
    children: PropTypes.node.isRequired,
    rows: PropTypes.number,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$6 = StyleSheet.create({
    '.row': css$1(_templateObject$6 || (_templateObject$6 = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: row; // added for bootstrap-rn\n    flex-wrap: wrap;\n    margin-top: 0;\n    margin-right: -0.5 * $grid-gutter-width;\n    margin-left: -0.5 * $grid-gutter-width;\n  "])))
  });
  var Row = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$7);

    var classes = getStyles(styles$6, ['.row']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), children);
  });
  Row.displayName = 'Row';
  Row.propTypes = propTypes$8;

  var Switch = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var elementProps = _extends$1({}, props);

    return /*#__PURE__*/React__default["default"].createElement(CheckInput, _extends$1({}, elementProps, {
      ref: ref,
      type: "switch"
    }));
  });
  Switch.displayName = 'Switch';

  var _excluded$6 = ["variant", "color", "size", "style"];

  var _templateObject$5, _templateObject2$4, _templateObject3$1, _templateObject4, _templateObject5, _templateObject6;
  var propTypes$7 = {
    variant: PropTypes.oneOf(['border', 'grow']),
    color: PropTypes.oneOf(Object.keys(THEME_COLORS)),
    size: PropTypes.oneOf(['sm']),
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$5 = StyleSheet.create(_objectSpread2(_objectSpread2(_objectSpread2({
    '.spinner-border': css$1(_templateObject$5 || (_templateObject$5 = _taggedTemplateLiteral(["\n    // display: inline-block;\n    width: $spinner-width;\n    height: $spinner-height;\n    // vertical-align: $spinner-vertical-align;\n    border-width: $spinner-border-width;\n    border-style: solid;\n    border-top-color: $body-color;\n    border-bottom-color: $body-color;\n    border-left-color: $body-color;\n    border-right-color: transparent;\n    border-radius: $spinner-width * 0.5; // 50%;\n    // animation: $spinner-animation-speed linear infinite spinner-border;\n  "])))
  }, each(THEME_COLORS, function (color, value) {
    return _defineProperty({}, ".spinner-border-".concat(color), css$1(_templateObject2$4 || (_templateObject2$4 = _taggedTemplateLiteral(["\n      border-top-color: ", ";\n      border-bottom-color: ", ";\n      border-left-color: ", ";\n    "])), value, value, value));
  })), {}, {
    '.spinner-border-sm': css$1(_templateObject3$1 || (_templateObject3$1 = _taggedTemplateLiteral(["\n    width: $spinner-width-sm;\n    height: $spinner-height-sm;\n    border-width: $spinner-border-width-sm;\n  "]))),
    '.spinner-grow': css$1(_templateObject4 || (_templateObject4 = _taggedTemplateLiteral(["\n    // display: inline-block;\n    width: $spinner-width;\n    height: $spinner-height;\n    // vertical-align: $spinner-vertical-align;\n    background-color: $body-color;\n    border-radius: $spinner-width * 0.5; // 50%;\n    opacity: 0;\n    // animation: $spinner-animation-speed linear infinite spinner-grow;\n  "])))
  }, each(THEME_COLORS, function (color, value) {
    return _defineProperty({}, ".spinner-grow-".concat(color), css$1(_templateObject5 || (_templateObject5 = _taggedTemplateLiteral(["\n      background-color: ", ";\n    "])), value));
  })), {}, {
    '.spinner-grow-sm': css$1(_templateObject6 || (_templateObject6 = _taggedTemplateLiteral(["\n    width: $spinner-width-sm;\n    height: $spinner-height-sm;\n  "])))
  }));
  var AnimatedView = _reactNative.Animated.createAnimatedComponent(View);

  var getAnimationStyle = function getAnimationStyle(variant, animation) {
    switch (variant) {
      case 'border':
        return {
          transform: [{
            rotate: animation.interpolate({
              inputRange: [0, 1],
              outputRange: ['0deg', '360deg']
            })
          }]
        };

      case 'grow':
        return {
          transform: [{
            scale: animation.interpolate({
              inputRange: [0, 0.5, 1],
              outputRange: [0, 1, 1]
            })
          }],
          opacity: animation.interpolate({
            inputRange: [0, 0.5, 1],
            outputRange: [0, 1, 0]
          })
        };

      default:
        throw new Error('Unknown spinner variant.');
    }
  };

  var Spinner = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var _props$variant = props.variant,
        variant = _props$variant === void 0 ? 'border' : _props$variant,
        color = props.color,
        size = props.size,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$6);

    var classes = getStyles(styles$5, [".spinner-".concat(variant), color && ".spinner-".concat(variant, "-").concat(color), size === 'sm' && ".spinner-".concat(variant, "-sm")]);
    var role = _reactNative.Platform.OS === 'web' ? 'status' : null;
    var animation = React.useMemo(function () {
      return new _reactNative.Animated.Value(0);
    }, []);
    React.useEffect(function () {
      var duration = parseFloat(StyleSheet.value('spinner-animation-speed')) * 1000;
      _reactNative.Animated.loop(_reactNative.Animated.timing(animation, {
        toValue: 1,
        duration: duration,
        easing: _reactNative.Easing.linear,
        useNativeDriver: _reactNative.Platform.OS !== 'web'
      })).start();
    }, []);
    return /*#__PURE__*/React__default["default"].createElement(AnimatedView, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: role,
      accessibilityHidden: true,
      style: [classes, getAnimationStyle(variant, animation), style]
    }));
  });
  Spinner.displayName = 'Spinner';
  Spinner.propTypes = propTypes$7;

  function useTabbable(defaultActiveTarget, controlledActiveTarget, onChange) {
    var identifier = useIdentifier('tabbable');

    var _useControlledState = useControlledState(defaultActiveTarget, controlledActiveTarget, onChange),
        _useControlledState2 = _slicedToArray(_useControlledState, 2),
        activeTarget = _useControlledState2[0],
        setActiveTarget = _useControlledState2[1];

    return React.useMemo(function () {
      return {
        identifier: identifier,
        activeTarget: activeTarget,
        setActiveTarget: setActiveTarget
      };
    }, [activeTarget]);
  }

  var propTypes$6 = {
    children: PropTypes.node.isRequired,
    defaultActiveTarget: PropTypes.string.isRequired,
    activeTarget: PropTypes.string,
    onChange: PropTypes.func
  };

  var TabProvider = function TabProvider(props) {
    var children = props.children,
        defaultActiveTarget = props.defaultActiveTarget,
        activeTarget = props.activeTarget,
        onChange = props.onChange;
    var tabbable = useTabbable(defaultActiveTarget, activeTarget, onChange);
    return /*#__PURE__*/React__default["default"].createElement(TabContext.Provider, {
      value: tabbable
    }, children);
  };

  TabProvider.displayName = 'TabProvider';
  TabProvider.propTypes = propTypes$6;

  var propTypes$5 = {
    children: PropTypes.node.isRequired
  };
  var TabContent = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var elementProps = _extends$1({}, props);

    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref
    }));
  });
  TabContent.displayName = 'TabContent';
  TabContent.propTypes = propTypes$5;

  var _excluded$5 = ["id", "style"];

  var _templateObject$4, _templateObject2$3;
  var propTypes$4 = {
    children: PropTypes.node.isRequired,
    id: PropTypes.string.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$4 = StyleSheet.create({
    '.tab-pane': css$1(_templateObject$4 || (_templateObject$4 = _taggedTemplateLiteral(["\n    display: none;\n  "]))),
    '.active': css$1(_templateObject2$3 || (_templateObject2$3 = _taggedTemplateLiteral(["\n    display: flex;\n  "])))
  });
  var TabPane = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var target = props.id,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$5);

    var tabbable = useForcedContext(TabContext);
    var classes = getStyles(styles$4, ['.tab-pane', tabbable.activeTarget === target && '.active']);
    var id = getElementId(tabbable.identifier, target); // Accessiblity role tabpanel is only supported on web.

    var role = _reactNative.Platform.OS === 'web' ? 'tabpanel' : null;
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      nativeID: id,
      accessibilityRole: role,
      accessibilityLabelledBy: "".concat(id, "-tab"),
      style: [classes, style]
    }));
  });
  TabPane.displayName = 'TabPane';
  TabPane.propTypes = propTypes$4;

  var _excluded$4 = ["target", "onPress"];
  function useToggleTab(props) {
    var context = useForcedContext(TabContext);

    var target = props.target,
        handlePress = props.onPress,
        restProps = _objectWithoutProperties(props, _excluded$4);

    invariant(target, 'Prop "target" is required.');
    var id = getElementId(context.identifier, target);
    var active = context.activeTarget === target;
    return _objectSpread2(_objectSpread2({}, restProps), {}, {
      nativeID: "".concat(id, "-tab"),
      onPress: function onPress(event) {
        if (handlePress) handlePress(event);
        event.preventDefault();
        context.setActiveTarget(target);
      },
      active: active,
      accessibilityRole: 'tab',
      accessibilityControls: id,
      accessibilitySelected: active
    });
  }

  var Tab = {};
  Tab.Context = TabContext;
  Tab.Provider = TabProvider;
  Tab.Content = TabContent;
  Tab.Pane = TabPane;
  Tab.useToggle = useToggleTab;

  var _excluded$3 = ["children", "style", "textStyle"];

  var _templateObject$3, _templateObject2$2;
  var propTypes$3 = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$3 = StyleSheet.create({
    '.toast-header': css$1(_templateObject$3 || (_templateObject$3 = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: row; // added for bootstrap-rn\n    align-items: center;\n    padding: $toast-padding-y $toast-padding-x;\n    background-color: $toast-header-background-color;\n    // background-clip: padding-box;\n    border-bottom-width: $toast-border-width;\n    border-style: solid;\n    border-color: $toast-header-border-color;\n    border-top-left-radius: ", ";\n    border-top-right-radius: ", ";\n  "])), subtract(function (t) {
      return t['toast-border-radius'];
    }, function (t) {
      return t['toast-border-width'];
    }), subtract(function (t) {
      return t['toast-border-radius'];
    }, function (t) {
      return t['toast-border-width'];
    })),
    '.toast-header-text': css$1(_templateObject2$2 || (_templateObject2$2 = _taggedTemplateLiteral(["\n    color: $toast-header-color;\n  "])))
  });
  var ToastHeader = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$3);

    var classes = getStyles(styles$3, ['.toast-header']);
    var textClasses = getStyles(styles$3, ['.toast-header-text']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children);
  });
  ToastHeader.displayName = 'ToastHeader';
  ToastHeader.propTypes = propTypes$3;

  var _excluded$2 = ["children", "style", "textStyle"];

  var _templateObject$2, _templateObject2$1;
  var propTypes$2 = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$2 = StyleSheet.create({
    '.toast-body': css$1(_templateObject$2 || (_templateObject$2 = _taggedTemplateLiteral(["\n    padding: $toast-padding-x; // apply to both vertical and horizontal\n  "]))),
    '.toast-body-text': css$1(_templateObject2$1 || (_templateObject2$1 = _taggedTemplateLiteral(["\n    @include platform(web) {\n      word-wrap: break-word;\n    }\n  "])))
  });
  var ToastBody = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$2);

    var classes = getStyles(styles$2, ['.toast-body']);
    var textClasses = getStyles(styles$2, [".toast-body-text"]);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children);
  });
  ToastBody.displayName = 'ToastBody';
  ToastBody.propTypes = propTypes$2;

  var ToastContainerContext = /*#__PURE__*/React__default["default"].createContext();
  ToastContainerContext.displayName = 'ToastContainerContext';

  var _excluded$1 = ["children", "last", "style", "textStyle"];

  var _templateObject$1, _templateObject2, _templateObject3;
  var propTypes$1 = {
    children: PropTypes.node.isRequired,
    last: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$1 = StyleSheet.create({
    '.toast': css$1(_templateObject$1 || (_templateObject$1 = _taggedTemplateLiteral(["\n    width: $toast-max-width;\n    max-width: 100%;\n    // pointer-events: auto;\n    background-color: $toast-background-color;\n    // background-clip: padding-box;\n    border: $toast-border-width solid $toast-border-color;\n    // box-shadow: $toast-box-shadow;\n    border-radius: $toast-border-radius;\n  "]))),
    '.toast-text': css$1(_templateObject2 || (_templateObject2 = _taggedTemplateLiteral(["\n    font-size: $toast-font-size;\n    line-height: $toast-font-size * $line-height-base; // added for bootstrap-rn\n    color: $toast-color;\n  "]))),
    '.toast-container .toast': css$1(_templateObject3 || (_templateObject3 = _taggedTemplateLiteral(["\n    margin-bottom: $toast-spacing;\n  "])))
  });
  var Toast = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        _props$last = props.last,
        last = _props$last === void 0 ? false : _props$last,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$1);

    var container = React.useContext(ToastContainerContext);
    var classes = getStyles(styles$1, ['.toast', container && !last && '.toast-container .toast']);
    var textClasses = getStyles(styles$1, [".toast-text"]);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: "alert",
      accessibilityLive: "assertive",
      accessibilityAtomic: true,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children);
  });
  Toast.displayName = 'Toast';
  Toast.propTypes = propTypes$1;
  Toast.Header = ToastHeader;
  Toast.Body = ToastBody;

  var _excluded = ["children", "style"];

  var _templateObject;
  var propTypes = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles = StyleSheet.create({
    '.toast-container': css$1(_templateObject || (_templateObject = _taggedTemplateLiteral(["\n    width: 100%; // max-content;\n    max-width: 100%;\n    // pointer-events: none;\n  "])))
  });
  var ToastContainer = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded);

    var classes = getStyles(styles, ['.toast-container']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), /*#__PURE__*/React__default["default"].createElement(ToastContainerContext.Provider, {
      value: true
    }, makeListChildren(children)));
  });
  ToastContainer.displayName = 'ToastContainer';
  ToastContainer.propTypes = propTypes;

  exports.Alert = Alert;
  exports.Badge = Badge;
  exports.Blockquote = Blockquote;
  exports.Body = Body;
  exports.Breadcrumb = Breadcrumb;
  exports.Button = Button;
  exports.ButtonGroup = ButtonGroup;
  exports.ButtonToolbar = ButtonToolbar;
  exports.Card = Card;
  exports.Checkbox = Checkbox;
  exports.CloseButton = CloseButton;
  exports.Code = Code;
  exports.Col = Col;
  exports.Collapse = Collapse;
  exports.Container = Container;
  exports.Context = Context;
  exports.DisplayHeading = DisplayHeading;
  exports.Dropdown = Dropdown;
  exports.Feedback = Feedback;
  exports.FormText = FormText;
  exports.Heading = Heading$1;
  exports.Image = Image;
  exports.ImageBackground = ImageBackground;
  exports.Input = Input;
  exports.Label = Label;
  exports.Link = Link;
  exports.ListGroup = ListGroup;
  exports.Modal = Modal;
  exports.Nav = Nav;
  exports.Navbar = Navbar;
  exports.Offcanvas = Offcanvas;
  exports.Pagination = Pagination;
  exports.Paragraph = Heading;
  exports.Picker = Picker;
  exports.Placeholders = Placeholders;
  exports.Popover = Popover;
  exports.PortalProvider = PortalProvider;
  exports.Pressable = Pressable;
  exports.Progress = Progress;
  exports.Provider = Provider;
  exports.Radio = Radio;
  exports.Row = Row;
  exports.ScrollView = ScrollView;
  exports.Spinner = Spinner;
  exports.StyleSheet = StyleSheet;
  exports.Switch = Switch;
  exports.Tab = Tab;
  exports.Text = Text;
  exports.TextInput = TextInput;
  exports.Toast = Toast;
  exports.ToastContainer = ToastContainer;
  exports.Tooltip = Tooltip;
  exports.View = View;
  exports.add = add;
  exports.colorContrast = colorContrast;
  exports.css = css$1;
  exports.divide = divide;
  exports.fn = fn;
  exports.injectPopover = injectPopover;
  exports.injectTooltip = injectTooltip;
  exports.makeTheme = makeTheme;
  exports.makeUtilities = makeUtilities;
  exports.shadeColor = shadeColor;
  exports.shiftColor = shiftColor;
  exports.subtract = subtract;
  exports.tintColor = tintColor;
  exports.useMedia = useMedia;
  exports.useStyle = useStyle;

  Object.defineProperty(exports, '__esModule', { value: true });

}));
